(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2786158,      54720]*)
(*NotebookOutlinePosition[   2788153,      54779]*)
(*  CellTagsIndexPosition[   2787914,      54770]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Cumulative Selection", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] August 1997 (copyright)"], 
  "Subsubtitle"],

Cell[CellGroupData[{

Cell["\<\
On the evolution of strings: Evolving Shakespeare\.b4s \
\[RightGuillemet]Hamlet\[LeftGuillemet]?\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
In this chapter we will show how the accumulation of small, even \
random changes in combination with a selection scheme unveil the fundamental \
principles of evolutionary search and adaptation.\
\>", "Text"],

Cell[TextData[
"Let us suppose, we got some predefined sentence, a sequence of characters \
over the alphabet {A, B, \[Ellipsis], Z} together with a blank space symbol \
and the punctuation marks of comma and full stop. So we might, for instance, \
take the sentence"], "Text"],

Cell["METHINKS IT IS LIKE A WEASEL.", "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Courier"],

Cell["\<\
How could an evolutionary search algorithm look like which should \
be able to \[RightGuillemet]evolve\[LeftGuillemet] this sentence whenever we \
start from a randomly generated sequence of characters like, e.g.,\
\>", 
  "Text"],

Cell["SOM.RXMNOL,MFQHVJNBTH YBQIMI,", "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Courier"],

Cell["which has the same length as the objective sentence?", "Text"],

Cell[TextData[{
  "In order to explain the fundamental difference of a creationist approach \
versus an evolutionary, step-by-step adaptive approach Richard Dawkins refers \
to a scene from Shakespeare\.b4s \[RightGuillemet]Hamlet\[LeftGuillemet] ( ",
  ButtonBox["Dawkins 1986",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "References.nb"}], "Dawkins 1986"},
    ButtonStyle->"Hyperlink"],
  ", chapter 3; ",
  ButtonBox["Dawkins 1996",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "References.nb"}], "Dawkins 1996"},
    ButtonStyle->"Hyperlink"],
  "). While looking at the passing clouds in the sky Hamlet and Polonius \
reflect upon the shapes of the clouds and what creatures those might \
resemble."
}], "Text"],

Cell["\<\
HAMLET:      Do you see yonder cloud that\.b4s almost in shape of a \
camel?\
\>", "Text",
  CellMargins->{{90, 3}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["POLONIUS:   By the mass, and \.b4tis like a camel, indeed.", "Text",
  CellMargins->{{90, 53}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "HAMLET:      ",
  StyleBox["Methinks it is like a weasel.",
    FontWeight->"Bold"]
}], "Text",
  CellMargins->{{90, 53}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["POLONIUS:   It is backed like a weasel.", "Text",
  CellMargins->{{90, 53}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["HAMLET:      Or like a whale?", "Text",
  CellMargins->{{90, 53}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["POLONIUS:   Very like a whale.", "Text",
  CellMargins->{{90, 53}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The shapes of the clouds are, of course, only by chance looking like \
\[RightGuillemet]a weasel\[LeftGuillemet] or \[RightGuillemet]a whale\
\[LeftGuillemet], the interpretation of those emerging forms depend very much \
on the observer\.b4s imagination. However, this scene serves well as an \
example of ",
  StyleBox["single-step",
    FontSlant->"Italic"],
  " selection: Whenever you recognize a special cloud shape like a, let\.b4s \
name it XYZ, you might say: \[RightGuillemet]Oh, have a look at this XYZ in \
the sky\[LeftGuillemet]. "
}], "Text"],

Cell["\<\
The situation becomes more difficult and much more lengthy if you \
intend to wait for a special shape XYZ to emerge. One must be very, very \
lucky to have just this shape discovered in the sky unless you are willing to \
stare at the sky for a long, long time.\
\>", "Text"],

Cell[TextData[{
  "Returning to our sentences we would like to \[RightGuillemet]discover\
\[LeftGuillemet] by evolutionary methods, the following sections will, first \
of all, give an approximation of the search space we have to deal with. It \
will be shown that ",
  ButtonBox["single-step selection",
    ButtonData:>"single step selection",
    ButtonStyle->"Hyperlink"],
  ", i.e., random search, will practically not be feasible even for this \
simple task. Finally, the two sections about \[RightGuillemet]",
  ButtonBox["cumulative selection",
    ButtonData:>"cumulative selection: introducation",
    ButtonStyle->"Hyperlink"],
  "\[LeftGuillemet] will explain the evolutionary principle of iterated \
mutations and selections by a few ",
  ButtonBox["examples",
    ButtonData:>"cumulative selection: experiments",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Single Step Selection", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Let us first stick with the random search style of single-step \
selection and get a feeling about the size of search spaces we will have to \
deal with.\
\>", "Text",
  CellTags->"single step selection"],

Cell[TextData[{
  "Can we \[RightGuillemet]discover\[LeftGuillemet] the sentence\n\n   ",
  StyleBox["ME THINKS IT IS LIKE A WEASEL.",
    FontWeight->"Bold"],
  "\n\nby random search? Sure we can. But how long would it take?\nLet\.b4s \
examine the size of the encountered search space:\n\n\[Bullet] 26 letters + 1 \
space + 2 punctuation marks (comma, full stop): 29 characters.\n\[Bullet] \
Length of the sentence: 30 characters (punctuation mark included)\n\nSo we \
can compute the size ",
  StyleBox["s",
    FontSlant->"Italic"],
  "  of our search space as follows:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = 29\^30\)], "Input"],

Cell[BoxData[
    \(74462898441675122902293018227199467668020601\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[s]\)], "Input"],

Cell[BoxData[
    \(7.44628984416751229027`*^43\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This means we are looking for one in about ",
  Cell[BoxData[
      \(TraditionalForm\`\(10\^43\ \(sentences.\)\ \)\)]],
  "This would take a 100 MHz processor approximately ",
  Cell[BoxData[
      \(TraditionalForm\`10\^28\)]],
  " years, if it generated and checked for identity with the objective \
sentence at every tick:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[s\/\(10\^8\ 3600\ 24\ 365\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(2.36120302009370633248`*^28\)], "Output"]
}, Open  ]],

Cell["\<\
However, this is the most \[RightGuillemet]unintelligent\
\[LeftGuillemet] way of doing this search job.
Cumulative selection should perform much better here, as we will see in the \
next section.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cumulative Selection: Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
This chapter, first of all, demonstrates how to encode strings as \
vectors of numbers, which in the sequel will serve as our genotypic \
representations of the sentences. Using numbers to represent characters makes \
it especially easy to define mutation operators on those integers. In the \
second part you will find a few examples of mutations on these vectors and \
character sequences. \
\>", "Text",
  CellTags->"cumulative selection: introducation"],

Cell[CellGroupData[{

Cell["The encoding scheme:", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Each of the letters A, B, \[Ellipsis], Z as well as the blank symbol and the \
punctuation marks comma and fullstop will be encoded as integer numbers as \
follows:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(encodeSentence["\<ABCDEFGHIJKLMNOPQRSTUVWXYZ ,.\>"]\)], "Input"],

Cell[BoxData[
    \({65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 
      82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93}\)], "Output"]
}, Open  ]],

Cell["\<\
The numbers range between 65 and 93. For the letters these \
encodings correspond to the standard ASCII encoding scheme. The codes for the \
blank symbol and punctuation marks simply continue the number sequence such \
that all character codes lie within a compact interval.\
\>", "Text"],

Cell["\<\
With this scheme we can encode any sequence of words over the \
defined alphabet, as for instance:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(objSentence = encodeSentence["\<ME THINKS IT IS LIKE A WEASEL.\>"]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 91, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 
      73, 75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell["\<\
The output shows the encoding of this sentence as a vector of \
integer numbers. The length of this string is 30 (including the punctuation \
mark):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[objSentence]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(30\)], "Output"]
}, Open  ]],

Cell["\<\
We may decode the number vector into its string representation as \
follows:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(interpretSentence[objSentence]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("ME THINKS IT IS LIKE A WEASEL."\)], "Output"]
}, Open  ]],

Cell["\<\
Thus we have got an encoding-decoding scheme for sentences, so let\
\.b4s now move on to mutations.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A few mutation examples", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Vectors of integer numbers serve as our \[RightGuillemet]genotypic\
\[LeftGuillemet] representations of sentences or strings. How can we define a \
mutation operator on these vectors? As mutations perform on genotypes, the \
mutation operator has to alter the vector elements in some way. We might \
define a (point-) mutation just by substituting any of the encoding numbers \
by some integer randomly selected from the encoding set {65, \[Ellipsis], \
93}."], "Text",
  CellTags->"mutation"],

Cell["\<\
Instead, we will use a more constrained mutation operator \
parametrized by two values:\
\>", "Text"],

Cell[TextData[
"  \[Bullet] mutation probability \[Mu] and\n  \[Bullet] mutation radius \
\[Rho]."], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[
"The first parameter \[Mu] gives the per-character probability for a \
mutation, while the mutation radius \[Rho] defines the size of the character \
interval from which the mutated characters can be selected. Thus with \
\[Rho]=1 a \[RightGuillemet]D\[LeftGuillemet] might mutate to one of the \
elements from the set {C, D, E}; for \[Rho]=2 the mutation set is {B, C, D, \
E, F}, etc. Please note that we do not exclude the case, that a character (or \
rather: a number code) is replaced by the same character (number) again."], 
  "Text"],

Cell["We still keep with our introductory objective sentence:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(objSentence = encodeSentence["\<ME THINKS IT IS LIKE A WEASEL.\>"]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 91, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 
      73, 75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(interpretSentence[objSentence]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("ME THINKS IT IS LIKE A WEASEL."\)], "Output"]
}, Open  ]],

Cell["\<\
The following examples show the mutation effects for different \
mutation probabilities as well as radii:\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 1, \[Mu] = 0.1"], "Subsubsection"],

Cell[TextData[{
  "Here on average each one in ten characters undergoes a mutation. Due to \
the mutation radius of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 1\)]],
  " the new characters are only the next neighbors within the alphabet \
encoding. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 1; \[Mu] = 0.1; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("ME THINKS,IT IS LIKE B WEASEL."\)},
          {\("ME THINKS IT IS LIJE A WEASEL."\)},
          {\("ME THINKS IT IS,LIKE A XEASFL."\)},
          {\("ME THINKS IT IS LIKE,A,WEASDL."\)},
          {\("ME THIMKS IT IS LIKE A,WEASEL."\)},
          {\("LE UHINKS IT IS LIKE A WEATEL."\)},
          {\("ME THINKSZIT IS LIKF A WEASEL."\)},
          {\("ME THINKS IT IR LIKE A WEASEL."\)},
          {\("ME SHINKS HT JS LIKE A WEASEL."\)},
          {\("ME THINKS ITZJS LIKE A WEASEM."\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"ME THINKS,IT IS LIKE B WEASEL.", "ME THINKS IT IS LIJE A WEASEL.", 
        "ME THINKS IT IS,LIKE A XEASFL.", "ME THINKS IT IS LIKE,A,WEASDL.", 
        "ME THIMKS IT IS LIKE A,WEASEL.", "LE UHINKS IT IS LIKE A WEATEL.", 
        "ME THINKSZIT IS LIKF A WEASEL.", "ME THINKS IT IR LIKE A WEASEL.", 
        "ME SHINKS HT JS LIKE A WEASEL.", 
        "ME THINKS ITZJS LIKE A WEASEM."}]]], "Output"]
}, Open  ]],

Cell["\<\
It is still easy to guess the original sentence from these mutants.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 1, \[Mu] = 0.2"], "Subsubsection"],

Cell["\<\
Here we have doubled the probability for point-mutations (compared \
to the previous section).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 1; \[Mu] = 0.2; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("ME THINKS IT IS,LIKE A WEASEK."\)},
          {\("MF THJNKS IT IS LHKE A WEASEL."\)},
          {\("NE THINKS IT IS LIKE A WEASEL."\)},
          {\("MEZTHINKS IT IS LIKE AZWEASEL."\)},
          {\("ME THHNJS IT HS LJKD A WFASEL."\)},
          {\("MEZSHINKS IT IS LJKD,A WEASEL."\)},
          {\("LE THINKS,IT ISZMIKE A WEAREL."\)},
          {\("LE THINKS IT HS LIJE A XDAREK,"\)},
          {\("ME,THINKS IT IT LIKE,A WFASEL."\)},
          {\("ME THINKS IT IS,LIKE A WEASEL."\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"ME THINKS IT IS,LIKE A WEASEK.", "MF THJNKS IT IS LHKE A WEASEL.", 
        "NE THINKS IT IS LIKE A WEASEL.", "MEZTHINKS IT IS LIKE AZWEASEL.", 
        "ME THHNJS IT HS LJKD A WFASEL.", "MEZSHINKS IT IS LJKD,A WEASEL.", 
        "LE THINKS,IT ISZMIKE A WEAREL.", "LE THINKS IT HS LIJE A XDAREK,", 
        "ME,THINKS IT IT LIKE,A WFASEL.", 
        "ME THINKS IT IS,LIKE A WEASEL."}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 1, \[Mu] = 0.5"], "Subsubsection"],

Cell["\<\
Here on average every second character is substituted by one of its \
neighboring characters (or by itself, a mutation which is not visible).\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 1; \[Mu] = 0.5; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("NE,SIIMKT,IT IS,LHLD A XEASEL."\)},
          {\("NE UHINKT ITZIR MIJF A WEBSDL,"\)},
          {\("MDZUHINKRZIT IT LHLF B VEBTDK."\)},
          {\("LD,UHHMKR IU IS,LIKE,B VFASEK."\)},
          {\("LD THINKS HTZIS LIKE,A WFASEL."\)},
          {\("LF SHIOKS HSZIS,LIJE,A WEBSEL."\)},
          {\("ME THINJT ITZIS LIKE,AZXDASDL."\)},
          {\("MF,TIIOLS IT,IT,LIJF A WDASEL."\)},
          {\("NE SHHNKS HT,IT LJKE A XEASEL."\)},
          {\("ME THINKSZIU HS LIJE BZWDASDL,"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"NE,SIIMKT,IT IS,LHLD A XEASEL.", "NE UHINKT ITZIR MIJF A WEBSDL,", 
        "MDZUHINKRZIT IT LHLF B VEBTDK.", "LD,UHHMKR IU IS,LIKE,B VFASEK.", 
        "LD THINKS HTZIS LIKE,A WFASEL.", "LF SHIOKS HSZIS,LIJE,A WEBSEL.", 
        "ME THINJT ITZIS LIKE,AZXDASDL.", "MF,TIIOLS IT,IT,LIJF A WDASEL.", 
        "NE SHHNKS HT,IT LJKE A XEASEL.", 
        "ME THINKSZIU HS LIJE BZWDASDL,"}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 1, \[Mu] = 1.0"], "Subsubsection"],

Cell[TextData[
"Setting the mutation rate to \[Mu]=1 results in totally unreadable \
sentences. However, note that the basic word structure is preserved as the \
mutants are not generated totally at random but taken from restricted \
intervalls of radius \[Rho]=1."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 1; \[Mu] = 1; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("MEZSIIOLT,JS,JS,KILE,AZWDASEL."\)},
          {\("ND,UHJOKS,HS JT,LIKDZBZVDBTDM."\)},
          {\("MFZTIJNLS HT IS MIJD BZVFBTDK,"\)},
          {\("NFZUHHMJS,HU HR,KILDZAZWFASEL,"\)},
          {\("MF,UGIMKT,IT JRZLHLD A XFASFM,"\)},
          {\("LF TGIOKR HS HR,KILF AZXDARFL."\)},
          {\("NE UHJNKR,IU,HTZMJKF B,VEASFL."\)},
          {\("ND,SIINJT,JSZHSZKHJF,AZWDATDL."\)},
          {\("NE,TIINLTZJSZJT,KJJD,B XDAREK."\)},
          {\("LD SIJMKS,JS,IR,KHLD,A WFATFL."\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"MEZSIIOLT,JS,JS,KILE,AZWDASEL.", "ND,UHJOKS,HS JT,LIKDZBZVDBTDM.", 
        "MFZTIJNLS HT IS MIJD BZVFBTDK,", "NFZUHHMJS,HU HR,KILDZAZWFASEL,", 
        "MF,UGIMKT,IT JRZLHLD A XFASFM,", "LF TGIOKR HS HR,KILF AZXDARFL.", 
        "NE UHJNKR,IU,HTZMJKF B,VEASFL.", "ND,SIINJT,JSZHSZKHJF,AZWDATDL.", 
        "NE,TIINLTZJSZJT,KJJD,B XDAREK.", 
        "LD SIJMKS,JS,IR,KHLD,A WFATFL."}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 2, \[Mu] = 0.2"], "Subsubsection"],

Cell[TextData[
"With a mutation probability of 20 percent and a mutation radius \[Rho]=2 it \
becomes more difficult to tell the original sentence from the mutated \
character sequences."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 2; \[Mu] = 0.2; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("OE THINKT IV IS LIKF A WEASEL."\)},
          {\("ME THINKS IT IQ LIKE,AYWEASEL."\)},
          {\("ME THIMKS IT ITYKIJE A WFASEL."\)},
          {\("NE TJINKS JT IS LKKE A WEASEL,"\)},
          {\("MEYRHINKS IT IS LIKE A WEASEL."\)},
          {\("ME,THHNMS IT GS LIKDZB WEBSEN."\)},
          {\("ME TFINKS KT IS LIKE A WEASEL."\)},
          {\("ME TJINKS IR ISZLIKE A VEASGL."\)},
          {\("LC THJNJS ITYIT LIKG A WEASGL."\)},
          {\("ME THINKS JT IQ LIKE C WEASEL "\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"OE THINKT IV IS LIKF A WEASEL.", "ME THINKS IT IQ LIKE,AYWEASEL.", 
        "ME THIMKS IT ITYKIJE A WFASEL.", "NE TJINKS JT IS LKKE A WEASEL,", 
        "MEYRHINKS IT IS LIKE A WEASEL.", "ME,THHNMS IT GS LIKDZB WEBSEN.", 
        "ME TFINKS KT IS LIKE A WEASEL.", "ME TJINKS IR ISZLIKE A VEASGL.", 
        "LC THJNJS ITYIT LIKG A WEASGL.", 
        "ME THINKS JT IQ LIKE C WEASEL "}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 5, \[Mu] = 0.5"], "Subsubsection"],

Cell["\<\
A good guess for the original sentence now becomes even more \
difficult.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 5; \[Mu] = 0.5; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("HD THENGSZDS IS KFGC.D.WEBSHP."\)},
          {\("QE.QHINMT.IO.ISXJIKBWA,WDASEL."\)},
          {\("ME OHIKKR.ITYIS LIKEYA.WFBSEL."\)},
          {\("ME RHINKSXJS DW GIKE.A.WHATCL."\)},
          {\("ME OHIOKS.IX MS IDGA D WEDSEOZ"\)},
          {\("HEZWHIOKS.EUYLS LIOE FXREBTDL."\)},
          {\("MI XDIKFX,IS.MQ LIKEYA SCATEL."\)},
          {\("MF THIKMR.LTZISZLGFAZA WIASBM."\)},
          {\("ME.XHIRKS NT IS LKHJ A REASEL."\)},
          {\("LE.TJEKKSYLY IS QIGGVA TADVEL."\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"HD THENGSZDS IS KFGC.D.WEBSHP.", "QE.QHINMT.IO.ISXJIKBWA,WDASEL.", 
        "ME OHIKKR.ITYIS LIKEYA.WFBSEL.", "ME RHINKSXJS DW GIKE.A.WHATCL.", 
        "ME OHIOKS.IX MS IDGA D WEDSEOZ", "HEZWHIOKS.EUYLS LIOE FXREBTDL.", 
        "MI XDIKFX,IS.MQ LIKEYA SCATEL.", "MF THIKMR.LTZISZLGFAZA WIASBM.", 
        "ME.XHIRKS NT IS LKHJ A REASEL.", 
        "LE.TJEKKSYLY IS QIGGVA TADVEL."}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Rho] = 15, \[Mu] = 1.0"], "Subsubsection"],

Cell[TextData[{
  "Of course, for a mutation radius of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 15\)]],
  ", which allows to select from the whole range of characters, and a \
mutation probability of \[Mu]=1 we get totally random mutations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho] = 15; \[Mu] = 1.0; \n\n
    Table[\n\tinterpretSentence[mutateSentence[objSentence, \[Rho], \[Mu]]], {
          10}] // TableForm\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("QAR.RQSW .WO.IM. OJAPA..NFQHAV"\)},
          {\("QAZFGL Y..LRZXEXTDLARKVUANDAQY"\)},
          {\("RL.QDECAKPSMSAHUSAAN.LOJBAHAN."\)},
          {\("PC.PKKNAX.M,.PFTEAXDOA.KAAXTR."\)},
          {\(" J..ACYQX.H..OU. AVQ.A.VOAYAAZ"\)},
          {\("AA..GLKAPWA .B.VLTYI.A.HAAHAV."\)},
          {\("YGO.EATZ.VAS.VQPAAGAZCT.OAOAOR"\)},
          {\("JKY.AKUB..A..A,ZNAPAPDRUNBQLLV"\)},
          {\("ZDM.AAVAPPOT.WD.KSHGPMONJA EA."\)},
          {\("IAP,RSUYVRASVAZ.SAEMRFXNAJ AAS"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"QAR.RQSW .WO.IM. OJAPA..NFQHAV", "QAZFGL Y..LRZXEXTDLARKVUANDAQY", 
        "RL.QDECAKPSMSAHUSAAN.LOJBAHAN.", "PC.PKKNAX.M,.PFTEAXDOA.KAAXTR.", 
        " J..ACYQX.H..OU. AVQ.A.VOAYAAZ", "AA..GLKAPWA .B.VLTYI.A.HAAHAV.", 
        "YGO.EATZ.VAS.VQPAAGAZCT.OAOAOR", "JKY.AKUB..A..A,ZNAPAPDRUNBQLLV", 
        "ZDM.AAVAPPOT.WD.KSHGPMONJA EA.", 
        "IAP,RSUYVRASVAZ.SAEMRFXNAJ AAS"}]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cumulative Selection: Evolution Experiments", "Section"],

Cell["\<\
Finally, several evolution experiments will demonstrate how \
cumulative selection in conjunction with mutations eventually discovers an \
objective sentence.\
\>", "Text",
  CellTags->"cumulative selection: experiments"],

Cell[CellGroupData[{

Cell["The Basic Evolution and Evaluation Scheme", "Subsection"],

Cell["\<\
The iterated selection and mutation scheme we will use in our \
experiments can be characterized as follows:\
\>", "Text"],

Cell["1. Initialization: ", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "Generate an initial set ",
  Cell[BoxData[
      \(TraditionalForm\`\(S = {s\_1, \[Ellipsis], s\_m}\ \)\)]],
  "of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " random character sequences, each of length ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". Each ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i = \(s\_i1\) \[Ellipsis]\ s\_iN\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i \[Element] {1, \[Ellipsis], m}\)]],
  ", takes its elements from the alphabet \[Alpha] = {A, B, \[Ellipsis], Z, \
\[RightGuillemet] \[LeftGuillemet], \[RightGuillemet],\[LeftGuillemet], \
\[RightGuillemet].\[LeftGuillemet]}."
}], "Text",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["2. Evaluation:", "Text",
  PageBreakAbove->True,
  FontWeight->"Bold"],

Cell[TextData[{
  "For each individual s",
  Cell[BoxData[
      \(TraditionalForm\`\_i\)]],
  " compute its fitness value ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau](s\_i\)\)]],
  "), which is its ",
  StyleBox["Hamming",
    FontSlant->"Italic"],
  " ",
  StyleBox["distance",
    FontSlant->"Italic"],
  " to the objective sentence ",
  Cell[BoxData[
      \(TraditionalForm\`s\^obj\)]],
  ":"
}], "Text",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Tau](s\_i) := 
      \[Sum]\+\(k = 1\)\%N\((\[Epsilon](s\_ik) - \[Epsilon](s\_k\^obj))\)\^2
          \)]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Here \[Epsilon] refers to the encoding function which returns an integer \
from the set ",
  Cell[BoxData[
      \(TraditionalForm\`{65, \[Ellipsis], 93}\)]],
  " for each element of alphabet \[Alpha]. "
}], "Text",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["3. Selection and mutation:", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "Select the best evaluated sentence ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\^*\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Tau](\(s\^*\)) = min {\[Tau](s) | \ s \[Element] S}\)]],
  ", i.e., the one closest to the objective sentence, and generate ",
  StyleBox["m-1",
    FontSlant->"Italic"],
  " mutated offspring from ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\^*\)\)]],
  ". "
}], "Text",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["4. Termination check:", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "If the objective sentence has not yet emerged, that is, as long as ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\^*\) \[NotEqual] s\^obj\)]],
  ", continue with step 2."
}], "Text",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The following sections will show how to perform these described \
selection-mutation scheme in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Several evolution experiments will be shown by example which unveil the \
influence of parameters like mutation rate and mutation distance on the speed \
and dynamics of the evolution processes."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introductory Evolution Example", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
This section might just serve as an introductory example of how to \
evolve character sequences. We will show how to set up and perform an \
evolution experiment and, finally, how to visualize fitness values and \
generate animations of the evolved sentences.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Iterated selection and mutation", "Subsubsection"],

Cell["We define an objective sentence.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(objSentence = encodeSentence["\<WEASEL.\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We start an evolution experiment with a population size of ",
  StyleBox["m=30",
    FontSlant->"Italic"],
  ", that is, we will have 30 individual sentences per generation. Mutations \
are applied with a probability of ",
  StyleBox["\[Mu]=0.1",
    FontSlant->"Italic"],
  ", the mutation radius is set to ",
  StyleBox["\[Rho]=2",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveSentences[objSentence, m = 30, \[Rho] = 2, \[Mu] = .1]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\(0\[InvisibleSpace]": Min.: "\[InvisibleSpace]314\),
      SequenceForm[ 0, ": Min.: ", 314],
      Editable->False]], "Print"],

Cell[BoxData[
    \("OGCUNAW"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]": Min.: "\[InvisibleSpace]274\),
      SequenceForm[ 1, ": Min.: ", 274],
      Editable->False]], "Print"],

Cell[BoxData[
    \("OGCUNCW"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]": Min.: "\[InvisibleSpace]239\),
      SequenceForm[ 2, ": Min.: ", 239],
      Editable->False]], "Print"],

Cell[BoxData[
    \("OGBULCW"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]": Min.: "\[InvisibleSpace]192\),
      SequenceForm[ 3, ": Min.: ", 192],
      Editable->False]], "Print"],

Cell[BoxData[
    \("OEBULEX"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]": Min.: "\[InvisibleSpace]168\),
      SequenceForm[ 4, ": Min.: ", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    \("OEBULGX"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]": Min.: "\[InvisibleSpace]140\),
      SequenceForm[ 5, ": Min.: ", 140],
      Editable->False]], "Print"],

Cell[BoxData[
    \("QEBULGX"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]": Min.: "\[InvisibleSpace]121\),
      SequenceForm[ 6, ": Min.: ", 121],
      Editable->False]], "Print"],

Cell[BoxData[
    \("SDBULGX"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]": Min.: "\[InvisibleSpace]102\),
      SequenceForm[ 7, ": Min.: ", 102],
      Editable->False]], "Print"],

Cell[BoxData[
    \("SDBTLIX"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]": Min.: "\[InvisibleSpace]86\),
      SequenceForm[ 8, ": Min.: ", 86],
      Editable->False]], "Print"],

Cell[BoxData[
    \("SDBTLIZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(9\[InvisibleSpace]": Min.: "\[InvisibleSpace]74\),
      SequenceForm[ 9, ": Min.: ", 74],
      Editable->False]], "Print"],

Cell[BoxData[
    \("UDBTLIZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(10\[InvisibleSpace]": Min.: "\[InvisibleSpace]66\),
      SequenceForm[ 10, ": Min.: ", 66],
      Editable->False]], "Print"],

Cell[BoxData[
    \("UDBTLKZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(11\[InvisibleSpace]": Min.: "\[InvisibleSpace]42\),
      SequenceForm[ 11, ": Min.: ", 42],
      Editable->False]], "Print"],

Cell[BoxData[
    \("UDBTJKZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(12\[InvisibleSpace]": Min.: "\[InvisibleSpace]41\),
      SequenceForm[ 12, ": Min.: ", 41],
      Editable->False]], "Print"],

Cell[BoxData[
    \("UDBSJKZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(13\[InvisibleSpace]": Min.: "\[InvisibleSpace]25\),
      SequenceForm[ 13, ": Min.: ", 25],
      Editable->False]], "Print"],

Cell[BoxData[
    \("UDBSHKZ"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(14\[InvisibleSpace]": Min.: "\[InvisibleSpace]19\),
      SequenceForm[ 14, ": Min.: ", 19],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WDBSHJ "\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(15\[InvisibleSpace]": Min.: "\[InvisibleSpace]14\),
      SequenceForm[ 15, ": Min.: ", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WDBSGJ "\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]": Min.: "\[InvisibleSpace]14\),
      SequenceForm[ 16, ": Min.: ", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WDBSGJ "\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(17\[InvisibleSpace]": Min.: "\[InvisibleSpace]10\),
      SequenceForm[ 17, ": Min.: ", 10],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WDBSGJ."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(18\[InvisibleSpace]": Min.: "\[InvisibleSpace]6\),
      SequenceForm[ 18, ": Min.: ", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WDBSGL."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(19\[InvisibleSpace]": Min.: "\[InvisibleSpace]1\),
      SequenceForm[ 19, ": Min.: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WEBSEL."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(20\[InvisibleSpace]": Min.: "\[InvisibleSpace]0\),
      SequenceForm[ 20, ": Min.: ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("WEASEL."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fitness plot", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
We may have a look at the evolution of the fitness values for the \
best sentence per generation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, AxesLabel \[Rule] {"\<Gen.\>", "\<Fit\>"}, 
      PlotJoined \[Rule] True, PlotRange \[Rule] All]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0238095 0.047619 0.0147151 0.00187453 [
[.45238 .00222 -6 -9 ]
[.45238 .00222 6 0 ]
[.69048 .00222 -6 -9 ]
[.69048 .00222 6 0 ]
[.92857 .00222 -6 -9 ]
[.92857 .00222 6 0 ]
[1.025 .01472 0 -7 ]
[1.025 .01472 28 7 ]
[.20179 .10844 -12 -4.5 ]
[.20179 .10844 0 4.5 ]
[.20179 .20217 -18 -4.5 ]
[.20179 .20217 0 4.5 ]
[.20179 .2959 -18 -4.5 ]
[.20179 .2959 0 4.5 ]
[.20179 .38962 -18 -4.5 ]
[.20179 .38962 0 4.5 ]
[.20179 .48335 -18 -4.5 ]
[.20179 .48335 0 4.5 ]
[.20179 .57708 -18 -4.5 ]
[.20179 .57708 0 4.5 ]
[.21429 .64303 -11 0 ]
[.21429 .64303 11 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.45238 .01472 m
.45238 .02097 L
s
[(10)] .45238 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(15)] .69048 .00222 0 1 Mshowa
.92857 .01472 m
.92857 .02097 L
s
[(20)] .92857 .00222 0 1 Mshowa
.125 Mabswid
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gen) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 15.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.21429 .10844 m
.22054 .10844 L
s
[(50)] .20179 .10844 1 0 Mshowa
.21429 .20217 m
.22054 .20217 L
s
[(100)] .20179 .20217 1 0 Mshowa
.21429 .2959 m
.22054 .2959 L
s
[(150)] .20179 .2959 1 0 Mshowa
.21429 .38962 m
.22054 .38962 L
s
[(200)] .20179 .38962 1 0 Mshowa
.21429 .48335 m
.22054 .48335 L
s
[(250)] .20179 .48335 1 0 Mshowa
.21429 .57708 m
.22054 .57708 L
s
[(300)] .20179 .57708 1 0 Mshowa
.125 Mabswid
.21429 .03346 m
.21804 .03346 L
s
.21429 .05221 m
.21804 .05221 L
s
.21429 .07095 m
.21804 .07095 L
s
.21429 .0897 m
.21804 .0897 L
s
.21429 .12719 m
.21804 .12719 L
s
.21429 .14593 m
.21804 .14593 L
s
.21429 .16468 m
.21804 .16468 L
s
.21429 .18342 m
.21804 .18342 L
s
.21429 .22091 m
.21804 .22091 L
s
.21429 .23966 m
.21804 .23966 L
s
.21429 .2584 m
.21804 .2584 L
s
.21429 .27715 m
.21804 .27715 L
s
.21429 .31464 m
.21804 .31464 L
s
.21429 .33339 m
.21804 .33339 L
s
.21429 .35213 m
.21804 .35213 L
s
.21429 .37088 m
.21804 .37088 L
s
.21429 .40837 m
.21804 .40837 L
s
.21429 .42711 m
.21804 .42711 L
s
.21429 .44586 m
.21804 .44586 L
s
.21429 .4646 m
.21804 .4646 L
s
.21429 .50209 m
.21804 .50209 L
s
.21429 .52084 m
.21804 .52084 L
s
.21429 .53958 m
.21804 .53958 L
s
.21429 .55833 m
.21804 .55833 L
s
.21429 .59582 m
.21804 .59582 L
s
.21429 .61457 m
.21804 .61457 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
gsave
.21429 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fit) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .60332 m
.07143 .52834 L
.11905 .46273 L
.16667 .37463 L
.21429 .32964 L
.2619 .27715 L
.30952 .24153 L
.35714 .20592 L
.40476 .17593 L
.45238 .15343 L
.5 .13843 L
.54762 .09345 L
.59524 .09157 L
.64286 .06158 L
.69048 .05033 L
.7381 .04096 L
.78571 .04096 L
.83333 .03346 L
.88095 .02596 L
.92857 .01659 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l06P000?l06P0006X00ol400;o;`03o`<0
0ol_00Co0`02ocH0001[0003o`00008000Co003o;`000ol000050003o`0002d000?o00000P001?l0
0?le0000J`000ol000020004o`00obl000?o00001@000ol0000^0005o`000?l00P000ol0000c0000
J`000ol000020004o`00obl000?o00000P03oc8000Co003o0P000ol0000c0000J`000ol000020004
o`00obl000?o00000P000ol0000_0004o`00o`8000Co003o=@0006X00_l500;o;`02o`@01?l_00;o
1002ocH0003o01X0000h0003o`000;d01?l300Co00@0ool00_l200;o300003P000?o0000_0001Ol0
003o008000?o00000`001?l00?l300;o300003P000?o0000_0000ol0o`02o`801Ol01@3o003o0140
00060>_o1P000ol000040007o`000?l0o`020003o`0000l0000;0003o`0000P000?o000020000ol0
00090003o`0000P000?o000020000ol000080003o`0000P000?o000020000ol000080003o`0000T0
00?o000020000ol000080003o`0000P000?o000020000ol000080003o`0000P000?o00002@000ol0
00080003o`0000D02Ol50003o`0000X000Go0000o`0300?o00<0ool00olA0000>0000ol0000d0003
o`0003D000?o0000;@05o`<000?o00005P04oad0000h0003o`0009H01_m20000>0000ol0002A00Go
B00003P00_n<00KoC@0003P000?o0000Q@06oe<0000h0003o`0007@04OmI0000>0000ol0001_00Go
JP0003P00_mZ00KoK`0003P000?o0000I005ogD0000h0003o`0006001?mj0000>0000ol0001O0003
o`0007`0000h0003o`0005d00_mo0000>002oe`00_n10000>0000ol0001J0003o`000840000h0003
o`0005P00_n40000>0000ol0001G0003o`0008@0000h00;oDP06ohL0000h0003o`0004X01on=0000
:P03o`@00_l50003o`0004T000?o0000TP0002d000Co003o0P000ol000020003o`0004P000?o0000
T`0002d000Co003o0P000ol0000200;oB0000ol0002D0000:P03o`<000Co003o10000ol000160003
o`0009D0000Z0003o`0000<000Co003o10000ol000150003o`0009H0000Z00Co0`02o`D000?o0000
A0000ol0002G0000>0000ol000130003o`0009P0000h00;o@`000ol0002I0000>0000ol000110003
o`0009X0000h0003o`0003l00_nM0000>0000ol0000l00?oW`0003P00_lj00?oXP0003P000?o0000
=P03ojD0000h0003o`0003<00onX0000>0000ol0000a00;oZ`0003P000?o0000;P03ojd0000h00;o
;@02ok00000h0003o`0002X00_nb0000>0000ol0000X00;o]00003P000?o00009`000ol0002d0000
>002obH00_ng0000>0000ol0000S00;o^@0002@00ol400;o1002o`D000?o00008P000ol0002i0000
9@000ol000020004o`00o`8000Co003o10000ol0000P00;o_00002D000?o00000P001?l00?l20004
o`00o`@00_lP0003o`000;`0000U0003o`00008000Co003o0P001?l00?l40003o`0001d00_no0000
9@000ol000020004o`00o`8000Co003o10000ol0000L0003o`000;l0000T00;o1@02o`@00_l50003
o`0001/000?o0000`00003P000?o00006P000ol000310000>002oaT00_o40000>0000ol0000G0003
o`000<@0000h0003o`0001H000?o0000a@0003P000?o00005@000ol000360000>002oaD000?o0000
a`0003P000?o00004P02olX0000h0003o`00014000?o0000bP0003P000?o000040000ol0003;0000
>002o`l00_o>0000>0000ol0000=0003o`000<h0000h0003o`0000/00_oA0000>0000ol0000:0003
o`000=40000h0003o`0000T000?o0000dP0003P00_l90003o`000=<0000h0003o`0000P000?o0000
d`0002@00ol300?o1002o`D000?o00001`000ol0003D00009@000ol000050004o`00o`8000?o0000
0P000ol000060003o`000=D0000U0003o`0000D000Co003o0P000ol0000200;o1P000ol0003F0000
9@000ol0000200?o0`001?l00?l40003o`0000@000?o0000e`0002D000?o00000P000ol000030004
o`00o`@000?o00000`000ol0003H00009002o`@01?l300;o1@000ol000020003o`000=T0000h0005
o`000?l0g00003P00_l00`3o003L0000>0000ol0o`3N0000>002oml0000h0003o`000=h0000g00?o
g`0003H000?o0?l0h00003D000Co003oh00003@000Go0000o`3P0000<`000ol0000200;og`000380
00?o00000`000ol0003N0000<@000ol000040003o`000=h0000`0003o`0000D000?o0000gP0002l0
00?o00001P000ol0003N0000;P000ol0000700;og`0002d000?o000020000ol0003N00009004o`<0
0ol300;o1@000ol0003N00009@000ol000020004o`3oo`8000Co003o10000ol0003N00009P001?l0
0002o`050?l00?l00P000ol0000200;og`0002L000?o00000_l01@3o003o008000?o00000P000ol0
003N000090001?l00?l20004o`00o`8000Co003o10000ol0003N00009@02o`<00ol400;o1@000ol0
003N0000:@000ol0000<0003o`000=h0000X0003o`0000d00_oO0000:0000ol0000=0003o`000=h0
000W0003o`0000h000?o0000gP0002L000?o00003P000ol0003N00009P000ol0000?00;og`0002D0
00?o000040000ol0003N00009@000ol0000@0003o`000=h0000T0003o`00014000?o0000gP0002@0
00?o00004@02oml0000S0003o`00018000?o0000gP00028000?o00004`000ol0003N00008P000ol0
000C0003o`000=h0000Q0003o`0001@000?o0000gP00024000?o00005002oml0000P0003o`0001D0
00?o0000gP0001l000?o00000P04o`800ol400;o1@000ol0003N00007`000ol000030003o`0000D0
00Co003o0P000ol000020003o`000=h0000N0003o`0000D000?o000010001?l00?l20003o`000080
0_oO00007@000ol000070003o`0000?o0`001?l00?l40003o`000=h0000M0003o`0000@000Co003o
0P000ol000030004o`00o`@000?o0000gP0001`000?o00001P02o`<01?l300;o1@000ol0003N0000
6`000ol0000J0003o`000=h0000J0003o`0001/00_oO00006P000ol0000K0003o`000=h0000I0003
o`0001`000?o0000gP0001P000?o00007@000ol0003N000060000ol0000M00;og`0001L000?o0000
7P000ol0003N00005P000ol0000O0003o`000=h0000F0003o`0001l000?o0000gP0001D000?o0000
8002oml0000D0003o`00024000?o0000gP0001@000?o00008@000ol0003N00004`000ol0000R0003
o`000=h0000B0003o`0002<000?o0000gP00018000?o00008`02oml0000A0003o`0002@000?o0000
gP00010000?o00004@03o`@00_l400;o1@000ol0003N000040000ol0000D0004o`00o`8000Co003o
0P000ol000020003o`000=h0000?0003o`0001D000Co003o0P001?l00?l20003o`0000800_oO0000
3`000ol0000C00;o0`001?l00?l20004o`00o`@000?o0000gP0000h000?o00005P001?l00?l20004
o`00o`8000?o00000P000ol0003N00003@000ol0000D00?o1002o`@00_l50003o`000=h0000=0003
o`0002P00_oO000030000ol0000Y0003o`000=h0000;0003o`0002X000?o0000gP0003P000?o0000
gP0003P000?o0000gP0003P00_oO0000>0000ol0003N0000o`0J0000o`0J0000o`0J0000o`0J0000
o`0J0000o`0J0000o`0J0000o`0J0000;`03o`@01Ol200?of@00030000?o00001@000ol000020004
o`00omP0000`0003o`0000D000?o00000P000ol0003I0000<003o`D000?o00000P000ol0003I0000
<0000ol0000400;o0`04omT0000_00Go2@000ol0003I0000>0000ol000020003o`000=T0003o01X0
003o01X0003o01X0003o01X00000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-0.041502, -27.1787, 0.0897144, 
  2.27903}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sentences overview", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["This lists all the best \[RightGuillemet]sentences\[LeftGuillemet] per \
generation.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[interpretSentence/@bestSentences]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("OGCUNAW"\)},
          {\("OGCUNCW"\)},
          {\("OGBULCW"\)},
          {\("OEBULEX"\)},
          {\("OEBULGX"\)},
          {\("QEBULGX"\)},
          {\("SDBULGX"\)},
          {\("SDBTLIX"\)},
          {\("SDBTLIZ"\)},
          {\("UDBTLIZ"\)},
          {\("UDBTLKZ"\)},
          {\("UDBTJKZ"\)},
          {\("UDBSJKZ"\)},
          {\("UDBSHKZ"\)},
          {\("WDBSHJ "\)},
          {\("WDBSGJ "\)},
          {\("WDBSGJ "\)},
          {\("WDBSGJ."\)},
          {\("WDBSGL."\)},
          {\("WEBSEL."\)},
          {\("WEASEL."\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"OGCUNAW", "OGCUNCW", "OGBULCW", "OEBULEX", "OEBULGX", "QEBULGX", 
        "SDBULGX", "SDBTLIX", "SDBTLIZ", "UDBTLIZ", "UDBTLKZ", "UDBTJKZ", 
        "UDBSJKZ", "UDBSHKZ", "WDBSHJ ", "WDBSGJ ", "WDBSGJ ", "WDBSGJ.", 
        "WDBSGL.", "WEBSEL.", "WEASEL."}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation ...", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
An animation of the evolution process can be achieved as follows.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MapIndexed[
      Show[Graphics[
            Text["\<(\>"<>ToString[First[#2]]<>"\<) \>"<>
                interpretSentence[#1], {0, 0}], 
            DefaultFont \[Rule] {"\<Courier\>", 24}], 
          AspectRatio \[Rule] .1]&, bestSentences]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OGCUNAW) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o1`09o`H00_lK00Go2@06o`T01Ol:00Co1`06o`<0
0_l00`3oo`04o`<01_l200;o1002omL0003M0003o`0000H02Ol70003o`0001L02Ol500[o1@09o`H0
2?l500Ko0P03o`030?oo00Co0`06o`800_l400;oe`000=`00_l<00;o2P02oaL00ol500?o0`04o`D0
0_l400?o1@03o`D00_l400;o1P02o`@01?l300;o1`02o`<00ol400?oeP000=`00_l<00;o2P02oaL0
0_l700;o0`02o`L00_l400;o1`02o`@00_l600;o1@02o`@01?l300;o1`02o`<01?l300?oeP000=`0
0_l<00;o2P02oaH00_l900;o00@0oooo1`02o`<00ol=00;o1P02o`D00_l300Go0`0;o`<01?l200Co
eP000=`00_l<00;o2P02oaH00_l900;o00<0ool01007o`800_l>00;o1P02o`D00_l300;o00<0ool0
1009o`@00_l0103o0004omH0003L00;o3002o`X00_lF00;o2@02o`030?oo00@01ol200;o3P02o`H0
0_l500;o0P03o`030?oo00@00_l500;o1002o`060?l00?l00_oF0000g002o``00_l:00;o5P02o`T0
0_l00`3oo`0=00;o3P02o`H00_l500;o0P02o`800_l500;o0`02o`D00_l00`3oo`02o`030?oo0=H0
003L00;o3002o`X00_lF00;o2@02o`030?oo00d00_l>00;o1P02o`D00_l00`3oo`0300;o1@02o`<0
0_l500;o00<0ool00_l00`3oo`3F0000g@02o`/00_l:0003o`0001D00_l900;o00<0ool02002o`<0
0ol700;o1002o`H00_l500Go0`02o`H00_l0103oool400;o0`02o`<00_oE0000g@02o`/00_l900;o
6002o`L00_l300;o1P03o`@00_l700;o1002o`H00_l500Co1002o`H00_l00`3oo`0500;o0`02o`<0
0_oE0000g@02o`/00_l900;o6003o`D00ol300?o1004o`@00ol500?o1002o`H00_l500Co1002o`H0
1Ol500;o2002omD0003N0003o`0000D00ol00`3oo`090003o`0001P02Ol500[o1@0:o`<01?l400Co
0`04o`801_l200Oo1@06o`801_oD0000gP02o`H01_l800;o7005o`T01Ol00`3oo`0700Go00<0ool0
0`04o`@01?l300?o0`06o`801ol500Ko0P06om@0003O0003o`0000L00ol80003o`000?l0C`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OGCUNCW) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o1P0:o`H00_lK00Go2@06o`T01Ol:00Co1`06o`<0
0_l600Go1`02o`@00_oG0000g@000ol0000500[o1`000ol0000G00Wo1@0:o`D02Ol600So1@06o`80
0ol400Wo1@02o`@00_oG0000g002o`P00_l500;o1`02oaL00ol500?o0`04o`D00_l400?o1@03o`D0
0_l400;o1P02o`@01?l300?o1@03o`<00ol400?oeP000=`00_l900?o3002oaL00_l700;o0`02o`L0
0_l400;o1`02o`@00_l600;o1@02o`@01?l300;o1`02o`<01?l300?oeP000=`00_l:00?o2`02oaH0
0_l900;o00@0oooo1`02o`<00ol=00;o1P02o`D00_l300Go0P03o``01?l200CoeP000=`00_l;00?o
2P02oaH00_l900;o00<0ool01007o`800_l>00;o1P02o`D00_l300;o00<0ool00P02o`d00_l0103o
0004omH0003L00;o3003o`T00_lF00;o2@02o`030?oo00@01ol200;o3P02o`H00_l500;o0P03o`03
0?oo00800_l=00;o00H0o`00o`02omH0003L00;o3@03o`P00_lF00;o2@02o`030?oo00d00_l>00;o
1P02o`D00_l200;o0P02o`800_l=00;o00<0ool00_l00`3oo`3F0000g002o`h00_l800;o5P02o`T0
0_l00`3oo`0=00;o3P02o`H00_l500;o00<0ool00`02o`800_l=00;o00<0ool00_l00`3oo`3F0000
g@02o`h00_l70003o`0001D00_l900;o00<0ool02002o`<00ol700;o1002o`H00_l500Go0`02o`80
0ol700;o0P02o`<00_l300;oe@000=d00_l>00;o1P02oaP00_l700;o0`02o`H00ol400;o1`02o`@0
0_l600;o1@04o`@00_l300;o1`02o`800_l300;o0`02omD0003M00;o1`02o`D00_l600;o6003o`D0
0ol300?o1004o`@00ol500?o1002o`H00_l500Co1002o`<00ol500?o0P02o`P00_oE0000gP000ol0
000500?o0`03o`H000?o00006009o`D02_l500[o0`04o`@01?l300Co0P06o`<02_l00`3oo`04o`80
1_oD0000gP02o`L01ol600;o7005o`T01Ol00`3oo`0700Go00<0ool00`04o`@01?l300?o0`06o`D0
1Ol0103oo`06o`801_oD0000g`000ol0000600Go1`000ol0003o04l0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000001\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OGBULCW) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o2005o`T00_lK00Go2@06o`D02_l900Co1P0=o`D0
1Ol700;o1002omL0003M0003o`0000D02Ol80003o`0001L02Ol500[o0`0;o`H02?l400go0`09o`D0
0_l400;oe`000=`00_l700;o1@02o`P00_lG00?o1@03o`<01?l500;o1@02o`D00ol500;o1002o`L0
0_l600;o0P03o`D00ol300?o1003omH0003L00;o3`02o`L00_lG00;o1`02o`<00_l700;o1@02o`H0
0_l400;o1P02o`H00_l600;o0P02o`L00_l300Co0`03omH0003L00;o3`02o`L00_lF00;o2@02o`04
0?ooo`L00_l500;o1P02o`@00_l600;o1P02o`H00_l0103oool<00Co0P04omH0003L00;o3`02o`L0
0_lF00;o2@02o`030?oo00@01ol400;o1P02o`@00_l600;o1P02o`H00_l00`3oo`0=00;o00@0o`00
1?oF0000g002o`h00_l800;o5P02o`T00_l00`3oo`0400Oo1002o`D00ol400;o1P02o`H00_l900;o
3@02o`060?l00?l00_oF0000g002o`/01?l900;o5P02o`T00_l00`3oo`0?00Wo1@02o`H00_l600;o
2@02o`d00_l00`3oo`02o`030?oo0=H0003L00;o2`03o`X00_lF00;o2@02o`030?oo00l02?l600;o
1P02o`H00_l900;o3@02o`030?oo00;o00<0ool0eP000=d00_l<00;o2@000ol0000E00;o2@02o`03
0?oo00P00_l500;o1003o`D00_l600;o1P02o`T00ol700;o0P02o`<00_l300;oe@000=d00_l=00;o
1`02oaP00_l700;o0`02o`H00ol500;o1@02o`D00_l600;o1P02o`X00_l700;o0P02o`<00_l300;o
e@000=d00_l=00;o1`02oaP00ol500?o0`03o`@01?l500;o1003o`D00_l600;o1P02o`X00ol500?o
0P02o`P00_oE0000gP000ol0000500;o0`03o`L000?o00006009o`D02_l300[o1@04o`@01?l200So
200:o`030?oo00Co0P06om@0003N00;o1P07o`L00_lL00Go2@05o`030?oo00<02Ol600Co1004o`80
2?l:00Go00@0ool01_l200Koe0000=l000?o00001P04o`P000?o0000o`1?0000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OEBULEX) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o2P06o`H00_lK00Go1@0<o`<02_l900Co1P0=o`03
0?oo00[o0P05o`801OoE0000g@000ol0000900Ko1`000ol0000G00Wo0`0<o`<02ol600So100=o`03
0?oo00[o0P05o`801OoE0000g002o`d00_l900;o5`03o`D00ol400;o1P02o`D00_l500?o1@02o`@0
0_l700;o1P02o`<00_l600;o0`03o`@00ooF0000g002o`d00_l900;o5`02o`L00_l400;o1P02o`D0
0_l600;o1002o`H00_l600;o1P02o`<00_l600;o1003o`800ooG0000g002o`L02_l700;o5P02o`T0
0_l300;o0P02o`800_l500;o1P02o`@00_l600;o1P02o`H00_l300;o0P02o`800_l500;o0P02omP0
003L00;o1`0:o`L00_lF00;o2@02o`<00_l200;o2@02o`H00_l400;o1P02o`H00_l600;o0`02o`80
0_l:00Cof@000=`00_l700;o1002o`T00_lF00;o2@02o`<01_l900;o1@03o`@00_l600;o1P02o`/0
1_l:00Cof@000=`00_l800;o0`02o`T00_lF00;o2@02o`<01_l900Wo1@02o`H00_l600;o2`06o`X0
0ooJ0000g002o`T000Co00000_l900;o5P02o`T00_l300;o0P02o`T02?l600;o1P02o`H00_l;00;o
0P02o`X01?oI0000g@02o`P00_l200;o2@000ol0000E00;o2@02o`<00_l200;o0P02o`D00_l400?o
1@02o`H00_l600;o2`02o`800_l200;o1@06omP0003M00;o2@000ol00002o`P00_lH00;o1`02o`@0
0_l600;o1@02o`D00_l500;o1P02o`H00_l;00;o1P02o`@00ol200?oe`000=d00_l:0004o`3oo`P0
0_lH00?o1@03o`@00_l600;o1@02o`@00ol500;o1P02o`H00_l;00;o1P02o`@00_l400;oe`000=h0
00?o00002004o`P000?o00006009o`<03?l300[o1@04o`@01?l200So1P0<o`801Ol200Goe@000=h0
0_l:00?o1`02oa`01Ol500co0`09o`H01?l400Co0P08o`H03?l200Go0P05omD0003O0003o`0000P0
0ol70003o`000?l0C`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OEBULGX) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o2005o`T00_lK00Go1@0<o`<02_l900Co1P0=o`D0
1_l400Go0P05omD0003M0003o`0000D02Ol80003o`0001L02Ol300co0`0;o`H02?l400go0`0:o`80
1Ol200Goe@000=`00_l700;o1@02o`P00_lG00?o1@03o`@00_l600;o1@02o`D00ol500;o1002o`L0
0_l600;o0P04o`D00_l300?o1003omH0003L00;o3`02o`L00_lG00;o1`02o`@00_l600;o1@02o`H0
0_l400;o1P02o`H00_l600;o0P02o`L00_l400?o0P03omL0003L00;o3`02o`L00_lF00;o2@02o`<0
0_l200;o0P02o`D00_l600;o1002o`H00_l600;o1P02o`040?ooo`L00_l500;o0P02omP0003L00;o
3`02o`L00_lF00;o2@02o`<00_l200;o2@02o`H00_l400;o1P02o`H00_l600;o00<0ool01007o`D0
1?oI0000g002o`l00_l700;o5P02o`T00_l300Ko2@02o`D00ol400;o1P02o`H00_l900;o1007o`D0
1?oI0000g002o`P00_l400;o2002oaH00_l900;o0`06o`T02Ol500;o1P02o`H00_l900;o4003omX0
003L00;o2008o`P00_lF00;o2@02o`<00_l200;o2@08o`H00_l600;o1P02o`T00_l@00Cof@000=d0
0_l700Oo2@000ol0000E00;o2@02o`<00_l200;o0P02o`D00_l400?o1@02o`H00_l600;o2@02o`P0
0_l500Kof0000=d00_l700;o3@02oaP00_l700;o1002o`H00_l500;o1@02o`D00_l600;o1P02o`X0
0_l600?o1003o`800ooG0000g@02o`L00_l=00;o6003o`D00ol400;o1P02o`D00_l400?o1@02o`H0
0_l600;o2P03o`@01?l400;o1002omL0003N0003o`0000D00_l=0003o`0001P02Ol300co0`0:o`D0
1?l400Co0P08o`P02_l200Go0P05omD0003N00;o1P08o`H00_lL00Go1@0<o`<02Ol600Co1004o`80
2?l:00Go00<0ool00P05o`801OoE0000g`000ol0000400So1P000ol0003o04l0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000001\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(QEBULGX) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o00006P02o`@00ooo02`0003N00;o5002oa/02_oo02/0
003N0003o`0001@000?o00006P05o`800_oo02/0003M00;o5P02oa/000?o0000o`0a0000g@02o`T0
1?l900;o6`05o`D03?l300[o2@04o`H03Ol500Ko1005o`801OoE0000g@000ol0000700Oo20000ol0
000G00Wo0`0<o`<02ol600So100=o`<02_l200Go0P05omD0003L00;o2002o`@00_l800;o5`03o`D0
0ol400;o1P02o`D00_l500?o1@02o`@00_l700;o1P02o`801?l500;o0`03o`@00ooF0000g002o`L0
0_l600;o1`02oaL00_l700;o1002o`H00_l500;o1P02o`@00_l600;o1P02o`H00_l200;o1`02o`@0
0ol200?oe`000=`00_l700;o1P02o`L00_lF00;o2@02o`<00_l200;o0P02o`D00_l600;o1002o`H0
0_l600;o1P02o`040?ooo`L00_l500;o0P02omP0003L00;o1`02o`H00_l700;o5P02o`T00_l300;o
0P02o`T00_l600;o1002o`H00_l600;o1P02o`030?oo00@01ol500Cof@000=`00_l700;o1P02o`L0
0_lF00;o2@02o`<01_l900;o1@03o`@00_l600;o1P02o`T00_l400Oo1@04omT0003L00;o1`03o`@0
0_l800;o5P02o`T00_l300Ko2@09o`D00_l600;o1P02o`T00_l@00?ofP000=`00_l700Wo2002oaH0
0_l900;o0`02o`800_l900So1P02o`H00_l600;o2@02oa001?oI0000g@02o`H00_l00`3oo`02o`X0
00?o00005@03o`P00_l300;o0P02o`800_l500;o1003o`D00_l600;o1P02o`T00_l800;o1@06omP0
003M00;o1`02o`d00_lH00;o1`02o`@00_l600;o1@02o`D00_l500;o1P02o`H00_l:00;o1P03o`@0
0ol200?oe`000=d00_l700?o3002oaT00_l500;o1@02o`H00_l500;o1003o`D00_l600;o1P02o`X0
0ol400Co1002o`@00_oG0000gP000ol0000600?o2`000ol0000H00Wo0`0<o`<02_l500Co1004o`80
2?l800[o0P05o`801OoE0000gP02o`P01ol500;o7005o`D03?l300Wo1P04o`@01?l200So2P05o`03
0?oo00801Ol200Goe@000=l000?o00002005o`D000?o0000o`1?0000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(SDBULGX) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o2@02o`/00_lH00;o00<0ool00ol600So1P0:o`T0
1?l600go1@06o`@01Ol200Goe@000=d000?o00002002o``000?o00005P0:o`@02_l400_o1P08o`@0
3Ol300[o0P05o`801OoE0000g002o`/00_l;00;o5`03o`D00ol400;o1004o`D00_l500?o1@02o`@0
0_l700;o1P02o`801?l500;o0`03o`@00ooF0000g002o`/00_l;00;o5`02o`L00_l400;o1P02o`D0
0_l600;o1002o`H00_l600;o1P02o`800_l700;o1003o`800ooG0000g002o`/00_l;00;o5`02o`L0
0_l400;o1`02o`@00_l600;o1002o`H00_l600;o1P02o`040?ooo`L00_l500;o0P02omP0003L00;o
30000ol0000900;o7`03o`@00_l700;o1002o`H00_l400;o1P02o`H00_l600;o00<0ool01007o`D0
1?oI0000g002o``00_l:00;o6P07o`D00_l700;o1002o`D00ol400;o1P02o`H00_l900;o1007o`D0
1?oI0000g002o``00_l:00;o6007o`L00_l700;o1009o`D00_l600;o1P02o`T00_l@00?ofP000=`0
0_l=0003o`0000P00_lG00?o3002o`L00_l400So1P02o`H00_l600;o2@02oa001?oI0000g@02o``0
0_l90003o`0001H00_l70003o`0000<00_l700;o1002o`@00ol500;o1P02o`H00_l900;o2002o`D0
1_oH0000g@02o``00_l800;o6002o`H00_l500;o1P02o`D00_l500;o1@02o`H00_l600;o2P02o`H0
0ol400?o0P03omL0003M00;o3@000ol0000600;o6003o`@00ol500;o1004o`D00_l400?o1@02o`H0
0_l600;o2P03o`@01?l400;o1002omL0003N0003o`0000@00_l500;o1`000ol0000H00Wo100:o`@0
2_l500Co1004o`802?l800[o0P05o`801OoE0000gP02o`D02Ol600;o7005o`030?l000<02?l600Wo
1P04o`@01?l200So2P05o`030?oo00801Ol200Goe@000=l000?o00000`09o`H000?o0000o`1?0000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(SDBTLIX) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o2@04o`T00_lH00;o00<0ool00ol600So1P0:o`H0
2?l500go0P0:o`<01Ol200Goe@000=d000?o00001P08o`P000?o00005P0:o`@02_l400_o1@08o`D0
3Ol200[o0`05o`801OoE0000g002o`L00ol400?o1`02oaL00ol500?o1002o`@01?l500;o1@03o`L0
0_l;00;o1P02o`H00_l800?o1003omH0003L00;o1`02o`H00_l700;o5`02o`L00_l400;o1P02o`D0
0_l600;o1`02o`/00_l600;o1P02o`T00ol200?oe`000=`00_l700;o1P02o`L00_lG00;o1`02o`@0
0_l700;o1002o`H00_l700;o2`02o`H00_l600;o2P02o`800_oH0000g002o`L00_l600;o1`02oal0
0ol400;o1`02o`@00_l600;o1`02o`/00_l600;o1P02o`/01?oI0000g002o`P00_l400;o2002oaX0
1ol500;o1`02o`@00_l500?o1`02o`/00_l>00;o2`04omT0003L00;o2@07o`P00_lH00Oo1`02o`L0
0_l400Wo2002o`/00_l>00;o2`03omX0003L00;o2@06o`T00_lG00?o3002o`L00_l400So1002o`<0
0_l300;o1P02o`h00_l;00Cof@000=d00_l700;o1002o`P000?o00005P02o`L000?o00000`02o`L0
0_l400;o1003o`<00_l300;o0`02o`H00_l>00;o2P06omP0003M00;o1P02o`H00_l600;o6002o`H0
0_l500;o1P02o`D00_l500;o0`02o`<00_l300;o1P02o`h00_l900?o0P03omL0003M00;o1P02o`H0
0_l600;o6003o`@00ol500;o1004o`D00_l400?o0`02o`<00_l300;o1P02o`h00_l900;o1002omL0
003N0003o`0000@00ol400?o1P000ol0000H00Wo100:o`@02_l400co0`08o`L02_l300Go0P05omD0
003N00;o1P08o`H00_lL00Go00<0o`000`08o`H02Ol500co0`08o`L02_l300Go0P05omD0003O0003
o`0000D01_l70003o`000?l0C`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -140 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.000000 20.000000 moveto
(L) show
119.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(SDBTLIZ) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003O0003o`00018000?o0000o`1?0000gP02oa@00_oo0500003N0003o`0001@0
00?o0000o`1>0000g@02oaH00_oo04l0003M00;o1P05o`/00_lH00;o00<0ool00ol600So1P0:o`H0
2?l500go0P0:o`@02_oF0000g@000ol0000500Oo2P000ol0000F00[o100:o`@02ol500So1@0=o`80
2_l400[oeP000=`00_l<00?o2@02oaL00ol500?o1002o`@01?l500;o1@03o`L00_l;00;o1P02o`H0
0_l900;o1@02omH0003L00;o3@03o`P00_lG00;o1`02o`@00_l600;o1@02o`H00_l700;o2`02o`H0
0_l600;o2@03o`@00_oF0000g002o`h00_l800;o5`02o`L00_l400;o1`02o`@00_l600;o1`02o`/0
0_l600;o1P02o`X00ol300;oeP000=`00_l:00Co00<0ool01`02oal00ol400;o1`02o`@00_l600;o
1`02o`/00_l600;o1P02o`/00_l300;oeP000=`00_l800Wo1`02oaX01ol500;o1`02o`@00_l500?o
1`02o`/00_l>00;o2`03omX0003L00;o2002o`@00ol700;o6007o`L00_l700;o1009o`P00_l;00;o
3P02o``00ooI0000g002o`L00_l600;o1`02oaL00ol<00;o1`02o`@02?l400;o0`02o`<00_l600;o
3P02o`P00_l300;of@000=d00_l600;o1P02o`L000?o00005P02o`L000?o00000`02o`L00_l400;o
1003o`<00_l300;o0`02o`H00_l>00;o2002o`<00ooH0000g@02o`H00_l600;o1P02oaP00_l600;o
1@02o`H00_l500;o1@02o`<00_l300;o0`02o`H00_l>00;o2002o`@00ooG0000g@02o`H00_l60003
o`0000D00_lH00?o1003o`D00_l400Co1@02o`@00ol300;o0`02o`<00_l600;o3P02o`P00_l500;o
e`000=h000?o00001@02o`@00_l70003o`0001P02Ol400[o100:o`@03?l300So1`0:o`@02_oF0000
gP02o`H01ol700;o7005o`030?l000<02?l600Wo1@0<o`<02?l700[o100:omH0003O0003o`0000H0
1?l80003o`000?l0C`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(UDBTLIZ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`L01?l900;o7004o`H02?l600[o1P08o`D0
3Ol200[o100:oll0003F0003o`0000H02Ol600Ko2@000ol0000H00So100:o`@02ol500So1@0=o`80
2_l400[oc`000=D00_l<00;o2003o`800ol800;o6@02o`@00_l500;o1004o`D00_l500?o1`02o`/0
0_l600;o1P02o`T00_l500;oc`000=D00_l<00;o2002o`@00_l800;o6002o`H00_l400;o1P02o`D0
0_l600;o1`02o`/00_l600;o1P02o`T00ol400;oc`000=D00_l<00;o1`02o`H00_l700;o6002o`H0
0_l400;o1`02o`@00_l600;o1`02o`/00_l600;o1P02o`X00ol300;oc`000=D00_l<00;o1`02o`H0
0_l700;o6002o`H00_l400;o1`02o`@00_l600;o1`02o`/00_l600;o1P02o`/00_l300;oc`000=D0
0_l<00;o1`02o`H00_l700;o6002o`H00_l400;o1`02o`@00_l500?o1`02o`/00_l>00;o2`03om<0
003E00;o3002o`L00_l600;o1`02oaP00_l600;o1002o`L00_l400Wo2002o`/00_l>00;o3003om80
003E00;o3002o`L00_l600;o1`02oaP00_l600;o1002o`L00_l400So1002o`<00_l300;o1P02o`h0
0_l800;o0`02om80003F00;o2`02o`L00_l600;o1`000ol0000G00;o1P02o`@00_l700;o1002o`@0
0ol300;o0`02o`<00_l600;o3P02o`P00_l300?od@000=H00_l;00;o1`02o`H00_l600;o6@02o`H0
0_l400;o1P02o`D00_l500;o0`02o`<00_l300;o1P02o`h00_l800;o1003om00003F00;o2`02o`P0
0_l400;o1`02oaT00_l600;o1002o`@01?l500;o1003o`<00_l300;o0`02o`H00_l>00;o2002o`D0
0_o@0000e`000ol0000500?o00<0ool02003o`800ol70003o`0001L01?l400Co0P0:o`@02_l400co
0`08o`L02_l400[oc`000=L00_l600Ko2@06o`L00_lI00Co1004o`802?l600Wo1@0<o`<02?l700[o
100:oll0003H0003o`0000L00ol:00Co20000ol0003o04P0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000001\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(UDBTLKZ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`D02Ol600;o7004o`H02?l600[o1P08o`D0
3Ol00`3oo`03o`H00_l200[oc`000=H000?o00001P09o`D02Ol70003o`0001P02?l400[o100;o`D0
2?l500go00<0ool00ol500?o0P0:oll0003E00;o3002o``00_l:00;o6@02o`@00_l500;o1004o`D0
0_l500?o1`02o`/00_l600;o0`02o`D00ol400;o1@02oll0003E00;o3002o``00_l:00;o6002o`H0
0_l400;o1P02o`D00_l600;o1`02o`/00_l600;o0`02o`D00_l500?o1002oll0003E00;o3002o``0
0_l:00;o6002o`H00_l400;o1`02o`@00_l600;o1`02o`/00_l600;o0`02o`@00_l700?o0`02oll0
003E00;o3002o``00_l:00;o6002o`H00_l400;o1`02o`@00_l600;o1`02o`/00_l600;o0`03o`80
0ol800;o0`02oll0003E00;o3002o``00_l:00;o6002o`H00_l400;o1`02o`@00_l500?o1`02o`/0
0_l;00Oo2@03om<0003E00;o3002o``00_l:00;o6002o`H00_l400;o1`02o`@02Ol800;o2`02o`/0
1Ol<00?odP000=D00_l<00;o3002o`X00_lH00;o1P02o`@00_l700;o1008o`@00_l300;o0`02o`H0
0_l;00;o00@0oooo1`02o`<00_oB0000eP02o`/00_l<00;o2P000ol0000G00;o1P02o`@00_l700;o
1002o`@00ol300;o0`02o`<00_l600;o2`02o`800ol600;o0`03om40003F00;o2`02o``00_l900;o
6@02o`H00_l400;o1P02o`D00_l500;o0`02o`<00_l300;o1P02o`/00_l300?o1@02o`@00oo@0000
eP02o`/00_l<00;o2@02oaT00_l600;o1002o`@01?l500;o1003o`<00_l300;o0`02o`H00_l;00;o
1003o`@00_l500;od0000=L000?o00001@03o`030?oo00P00ol00`3oo`090003o`0001L01?l400Co
0P0:o`@02_l400co0`08o`H01Ol300Go0P0:oll0003G00;o1P06o`P01_l800;o6@04o`@01?l200So
1P09o`D03?l300So1P05o`<01Ol200[oc`000=P000?o00001`03o`/00ol80003o`000?l0B0000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(UDBTJKZ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`@02_l600;o7004o`H02?l600[o1P08o`L0
1_l600Go1P02o`802_o?0000eP000ol0000600Wo100:o`L000?o00006008o`@02_l400_o1@08o`D0
2Ol500Go1@03o`802_o?0000e@02o``00_l800;o1@02o`L00_lI00;o1002o`D00_l400Co1@02o`D0
0ol700;o2003o`@00ol600;o1@03o`@00_l500;oc`000=D00_l<00;o2@03o``00_lH00;o1P02o`@0
0_l600;o1@02o`H00_l700;o2002o`H00_l600;o1@02o`D00ol400;oc`000=D00_l<00;o2P03o`/0
0_lH00;o1P02o`@00_l700;o1002o`H00_l700;o2002o`H00_l600;o1002o`L00ol300;oc`000=D0
0_l<00;o2`03o`X00_lH00;o1P02o`@00_l700;o1002o`H00_l700;o2002o`H00_l600?o0P03o`P0
0_l300;oc`000=D00_l<00;o3003o`T00_lH00;o1P02o`@00_l700;o1002o`D00ol700;o4002o`H0
1ol900?od`000=D00_l<00;o3@03o`P00_lH00;o1P02o`@00_l700;o1009o`P00_l@00;o1P05o``0
0ooB0000e@02o``00_l>00;o2002oaP00_l600;o1002o`L00_l400So1002o`<00_l300;o2`02o`H0
0_l0103oool700;o0`02om80003F00;o2`02o`l00_l70003o`0001L00_l600;o1002o`L00_l400;o
1003o`<00_l300;o0`02o`/00_l600;o0P03o`H00_l300?od@000=H00_l;00;o3`02o`H00_lI00;o
1P02o`@00_l600;o1@02o`D00_l300;o0`02o`<00_l;00;o1P02o`<00ol500;o1003om00003F00;o
2`02o`P00_l500;o1P02oaT00_l600;o1002o`@01?l500;o1003o`<00_l300;o0`02o`/00_l600;o
1003o`@00_l500;od0000=L000?o00001@03o`030?oo00P00ol300?o1P000ol0000G00Co1004o`80
2_l400[o100<o`H02_l00`3oo`03o`<01Ol200[oc`000=L00_l600Ko2@07o`H00_lI00Co1004o`80
2?l600Wo1@0<o`H02_l00`3oo`03o`<01Ol200[oc`000=P000?o00001`03o`X01Ol70003o`000?l0
B0000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(UDBSJKZ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`H01Ol900;o7004o`H02?l600[o1@02o`03
0?oo00?o2006o`H01Ol600;o0P0:oll0003F0003o`0000H02Ol400Wo20000ol0000H00So100:o`@0
2ol400[o1009o`D01Ol500?o0P0:oll0003E00;o3002o`L00_l500;o2002oaT00_l400;o1@02o`@0
1?l500;o1@03o`<00ol500?o0`03o`@00ol600;o1@03o`@00_l500;oc`000=D00_l<00;o3`02o`L0
0_lH00;o1P02o`@00_l600;o1@02o`H00_l300;o1`02o`<00_l600;o1P02o`D00_l500?o1002oll0
003E00;o3002o`l00_l700;o6002o`H00_l400;o1`02o`@00_l600;o0`02o`L00_l300;o1P02o`H0
0_l400;o1`03o`<00_o?0000e@02o``00_l?00;o1`02oaP00_l600;o1002o`L00_l400;o1P02o`/0
0ol300;o1P02o`H00ol200?o2002o`<00_o?0000e@02o``00_l>00;o2002oaP00_l600;o1002o`L0
0_l400;o1@03o`H01ol<00;o1P07o`T00ooC0000e@02o``00_l;00Co2@02oaP00_l600;o1002o`L0
0_l400Wo1@07o`h00_l600Go3003om80003E00;o3002o`/00ol:00;o6002o`H00_l400;o1`02o`@0
2?l500?o4`02o`H00_l0103oool700;o0`02om80003F00;o2`02o`d00_l90003o`0001L00_l600;o
1002o`L00_l400;o1003o`@00_l70003o`0000X00_l600;o0P03o`H00_l300?od@000=H00_l;00;o
3P02o`L00_lI00;o1P02o`@00_l600;o1@02o`D00_l400;o1P02o``00_l600;o0`03o`D00_l400?o
d0000=H00_l;00;o3P02o`L00_lI00;o1P02o`@00_l400Co1@02o`@00ol400?o1003o``00_l600;o
1003o`@00_l500;od0000=L000?o00001@03o`030?oo00P00_l300?o1`000ol0000G00Co1004o`80
2_l400[o1P09o`L02_l00`3oo`03o`<01Ol200[oc`000=L00_l600Ko2007o`L00_lI00Co1004o`80
2?l600Wo2@05o`030?l000H02_l00`3oo`03o`<01Ol200[oc`000=P000?o00001`03o`X01?l80003
o`000?l0B0000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(UDBSHKZ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`P01_l600;o7004o`H02?l600[o1@02o`03
0?oo00?o1`04o`<01?l200Go1P02o`802_o?0000eP000ol0000600Wo2006o`L000?o00006008o`@0
2_l400_o100:o`D01?l300Co0P05o`D00ol200[oc`000=D00_l<00;o3@02o`T00_lI00;o1002o`D0
0_l400Co1@02o`D00ol300?o1@03o`D00_l500;o1@02o`D00ol400;o1@02oll0003E00;o3002o`d0
0_l900;o6002o`H00_l400;o1P02o`D00_l600;o0`02o`L00_l500;o1@02o`D00_l500;o1@03o`@0
0_o?0000e@02o``00_l700[o1`02oaP00_l600;o1002o`L00_l400;o1P02o`<00_l700;o1@02o`D0
0_l500;o1002o`L00ol300;oc`000=D00_l<00;o1`0:o`L00_lH00;o1P02o`@00_l700;o1002o`H0
0_l;00?o1@02o`D00_l500?o0P03o`P00_l300;oc`000=D00_l<00;o1`02o`@00_l900;o6002o`H0
0_l400;o1`02o`@00_l500?o1P07o`H00_l500;o1@07o`T00ooC0000e@02o``00_l800;o0`02o`T0
0_lH00;o1P02o`@00_l700;o1009o`D01ol800Wo1@05o``00ooB0000e@02o``00_l90004o`0000;o
2@02oaP00_l600;o1002o`L00_l400So1@03o`d02Ol500;o00@0oooo1`02o`<00_oB0000eP02o`/0
0_l900;o0P02o`T000?o00005`02o`H00_l400;o1`02o`@00_l400?o1002o`L000?o00001002o`D0
0_l500;o0P03o`H00_l300?od@000=H00_l;00;o2P000ol00002o`P00_lI00;o1P02o`@00_l600;o
1@02o`D00_l400;o1P02o`H00_l500;o1@02o`<00ol500;o1003om00003F00;o2`02o`/000Co0?oo
2002oaT00_l600;o1002o`@01?l500;o1003o`@00ol400?o1P02o`D00_l500;o1003o`@00_l500;o
d0000=L000?o00001@03o`030?oo00/01?l80003o`0001L01?l400Co0P0:o`@02_l600Wo1@04o`<0
1?l200Go0`05o`802_o?0000e`02o`H01_l<00?o1`02oaT01?l400Co0P08o`H02Ol900Go00<0o`00
1004o`<01?l200Go0`05o`802_o?0000f0000ol0000700?o3003o`L000?o0000o`180000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WDBSHJ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`H01Ol900;o6@02o`@00_l500So1P0:o`D0
0_l00`3oo`03o`L01?l300Co1006on00003F0003o`0000H02Ol400Wo20000ol0000G00;o1002o`D0
2_l400_o100:o`D01?l300Co0P09oml0003E00;o3002o`L00_l500;o2002oaL00ol400?o1@02o`@0
1?l500;o1@03o`<00ol500?o1@02o`D00_l300?o1003omh0003E00;o3002o`l00_l700;o5`04o`<0
0ol500;o1P02o`D00_l600;o0`02o`L00_l500;o1@02o`<00_l600;ogP000=D00_l<00;o3`02o`L0
0_lG00Co0P04o`D00_l700;o1002o`H00_l300;o1`02o`D00_l500;o0`02o`H00_oN0000e@02o``0
0_l?00;o1`02oaL00_l0103o0004o`D00_l700;o1002o`H00_l;00?o1@02o`D00_l300;o1P02omh0
003E00;o3002o`l00_l700;o5`02o`060?l00?l00_l500;o1`02o`@00_l500?o1P07o`H00_l500;o
2`02omh0003E00;o3002o`P00_l400;o2002oaL00_l00`3oo`02o`030?oo00D00_l700;o1009o`D0
1ol800Wo2`02omh0003E00;o3002o`P02?l800;o5`02o`030?oo00;o00<0ool01@02o`L00_l400So
1@03o`d02Ol;00;ogP000=H00_l;00;o2007o`T000?o00005@02o`<00_l300;o1002o`L00_l400;o
1003o`@00_l70003o`0000@00_l500;o2`02omh0003F00;o2`02o`P00_l=00;o5`02o`<00_l300;o
1002o`H00_l500;o1@02o`@00_l600;o1P02o`D00_l;00;ogP000=H00_l;00;o2002o`d00_lG00;o
2002o`@00_l400Co1@02o`@00ol400?o1003o`H00_l500;o2`02omh0003G0003o`0000D00ol00`3o
o`0800;o3@000ol0000E00Ko0P06o`802_l400[o1P09o`D01?l300Co1@0:om/0003G00;o1P06o`P0
2?l600;o5`06o`801_l200So1P09o`T01Ol00`3o000400Co0`04o`D02_oK0000f0000ol0000700?o
2008o`H000?o0000o`180000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WDBSGJ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`L01?l900;o6@02o`@00_l500So1P0:o`D0
0_l00`3oo`03o`X01_l600Koh0000=H000?o00001P09o`H01ol80003o`0001L00_l400;o1@0:o`@0
2ol400[o1P0:o`802OoO0000e@02o``00_l800;o1002o`P00_lG00?o1003o`D00_l400Co1@02o`D0
0ol300?o1@03o`@01?l500;o0P03o`@00ooN0000e@02o``00_l700;o1P02o`L00_lG00Co0`03o`D0
0_l600;o1@02o`H00_l300;o1`02o`@00_l700;o0P02o`H00_oN0000e@02o``00_l700;o1P02o`L0
0_lG00Co0P04o`D00_l700;o1002o`H00_l300;o1`02o`<00ol700;o0P02o`H00_oN0000e@02o``0
0_l700;o1P02o`L00_lG00;o00@0o`001?l500;o1`02o`@00_l600;o2`03o`<00_l400Oo00<0ool0
1P02omh0003E00;o3002o`L00_l600;o1`02oaL00_l01P3o003o00;o1@02o`L00_l400;o1@03o`H0
1ol400;o1007o`T00_oN0000e@02o``00_l700?o1002o`P00_lG00;o00<0ool00_l00`3oo`0500;o
1`02o`@02Ol500Oo1P02oa@00_oN0000e@02o``00_l700Wo2002oaL00_l00`3oo`02o`030?oo00D0
0_l700;o1008o`D00ol;00;o5002omh0003F00;o2`02o`L00_l00`3oo`02o`X000?o00005@02o`<0
0_l300;o1002o`L00_l400;o1003o`@00_l70003o`0000800_l800;o2P02omh0003F00;o2`02o`P0
0_l=00;o5`02o`<00_l300;o1002o`H00_l500;o1@02o`@00_l600;o1@02o`H00ol:00;ogP000=H0
0_l;00;o2003o``00_lG00;o2002o`@00_l400Co1@02o`@00ol400?o1003o`D00ol400Co2P02omh0
003G0003o`0000D00ol00`3oo`0900?o2`000ol0000E00Ko0P06o`802_l400[o1P09o`H02_l500[o
f`000=L00_l600Ko2P07o`D00_lG00Ko0P06o`802?l600Wo2@05o`030?l000L01Ol00`3oo`0500[o
f`000=P000?o00001`03o``01Ol50003o`000?l0B0000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WDBSGJ) show
231.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`L00_l;00;o6@02o`@00_l500So1P0:o`D0
0_l00`3oo`03o`X01_l600Koh0000=H000?o00001P09o`L00_l<0003o`0001L00_l400;o1@0:o`@0
2ol400[o1P0:o`802OoO0000e@02o``00_l;00;o2`02oaL00ol400?o1@02o`@01?l500;o1@03o`<0
0ol500?o1004o`D00_l200?o1003omh0003E00;o3002o`/00_l;00;o5`04o`<00ol500;o1P02o`D0
0_l600;o0`02o`L00_l400;o1`02o`800_l600;ogP000=D00_l<00;o2`02o`/00_lG00Co0P04o`D0
0_l700;o1002o`H00_l300;o1`02o`<00ol700;o0P02o`H00_oN0000e@02o``00_l<0003o`0000T0
0_lG00;o00@0o`001?l500;o1`02o`@00_l600;o2`03o`<00_l400Oo00<0ool01P02omh0003E00;o
3002o``00_l:00;o5`02o`060?l00?l00_l500;o1`02o`@00_l500?o1P07o`@00_l400Oo2@02omh0
003E00;o3002o``00_l:00;o5`02o`030?oo00;o00<0ool01@02o`L00_l400Wo1@07o`H00_lD00;o
gP000=D00_l<00;o3@000ol0000800;o5`02o`030?oo00;o00<0ool01@02o`L00_l400So1@03o`/0
0_lD00;ogP000=H00_l;00;o3@02o`T000?o00005@02o`<00_l300;o1002o`L00_l400;o1003o`@0
0_l70003o`0000800_l800;o2P02omh0003F00;o2`02o`d00_l800;o5`02o`<00_l300;o1002o`H0
0_l500;o1@02o`@00_l600;o1@02o`H00ol:00;ogP000=H00_l;00;o3P000ol0000600;o5`02o`P0
0_l400;o1004o`D00_l400?o1003o`@00ol500?o1004o`X00_oN0000e`000ol0000500?o00<0ool0
1`02o`D00_l70003o`0001D01_l200Ko0P0:o`@02_l600Wo1P0:o`D02_oK0000e`02o`H01_l700Wo
1P02oaL01_l200Ko0P08o`H02Ol900Go00<0o`001`05o`030?oo00D02_oK0000f0000ol0000700?o
1`09o`H000?o0000o`180000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WDBSGJ) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
231.000000 20.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`L01?l900;o6@02o`@00_l500So1P0:o`D0
0_l00`3oo`03o`X01_l600Ko2@02omD0003F0003o`0000H02Ol500So20000ol0000G00;o1002o`D0
2_l400_o100:o`H02_l200Wo1`04om@0003E00;o3002o`L00ol400?o1`02oaL00ol400?o1@02o`@0
1?l500;o1@03o`<00ol500?o1004o`D00_l200?o1003o`H01?oD0000e@02o``00_l700;o1P02o`L0
0_lG00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`@00_l700;o0P02o`H00_l700;oe@000=D0
0_l<00;o1`02o`H00_l700;o5`04o`801?l500;o1`02o`@00_l600;o0`02o`L00_l300?o1`02o`80
0_l600;ogP000=D00_l<00;o1`02o`H00_l700;o5`02o`040?l000Co1@02o`L00_l400;o1P02o`/0
0ol300;o1007o`030?oo00H00_oN0000e@02o``00_l800;o1002o`P00_lG00;o00H0o`00o`02o`D0
0_l700;o1002o`D00ol600Oo1002o`@01ol900;ogP000=D00_l<00;o2@07o`P00_lG00;o00<0ool0
0_l00`3oo`0500;o1`02o`@02Ol500Oo1P02oa@00_oN0000e@02o``00_l900Ko2@02oaL00_l00`3o
o`02o`030?oo00D00_l700;o1008o`D00ol;00;o5002omh0003F00;o2`02o`P00_l400;o20000ol0
000E00;o0`02o`<00_l400;o1`02o`@00_l400?o1002o`L000?o00000P02o`P00_l:00;ogP000=H0
0_l;00;o1`02o`H00_l600;o5`02o`<00_l300;o1002o`H00_l500;o1@02o`@00_l600;o1@02o`H0
0ol:00;ogP000=H00_l;00;o1`02o`H00_l600;o5`02o`P00_l400;o1004o`D00_l400?o1003o`@0
0ol500?o1004o`X00_oN0000e`000ol0000500?o00<0ool01`03o`@00ol60003o`0001D01_l200Ko
0P0:o`@02_l600Wo1P0:o`D02_oK0000e`02o`H01_l800So1P02oaL01_l200Ko0P08o`H02Ol900Go
00<0o`001`05o`030?oo00D02_oK0000f0000ol0000700?o2@06o`L000?o0000o`180000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L00000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WDBSGL) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
231.000000 20.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1`09o`@01Ol;00;o6@02o`@00_l500So1P0:o`D0
0_l00`3oo`03o`X01_l400go1002omD0003F0003o`0000H02Ol400Oo2P000ol0000G00;o1002o`D0
2_l400_o100:o`H02_l200go0`04om@0003E00;o3002o``00ol900;o5`03o`@00ol500;o1004o`D0
0_l500?o0`03o`D00ol400Co1@02o`D00_l600;o0`04om@0003E00;o3002o`d00ol800;o5`04o`<0
0ol500;o1P02o`D00_l600;o0`02o`L00_l400;o1`02o`D00_l600;o1002omD0003E00;o3002o`h0
0_l800;o5`04o`801?l500;o1`02o`@00_l600;o0`02o`L00_l300?o1`02o`D00_l600;of`000=D0
0_l<00;o2P04o`030?oo00L00_lG00;o00@0o`001?l500;o1`02o`@00_l600;o2`03o`<00_l400Oo
1002o`H00_oK0000e@02o``00_l800Wo1`02oaL00_l01P3o003o00;o1@02o`L00_l400;o1@03o`H0
1ol400;o1007o`@00_oS0000e@02o``00_l800;o1003o`L00_lG00;o00<0ool00_l00`3oo`0500;o
1`02o`@02Ol500Oo1P02o`l00_oS0000e@02o``00_l700;o1P02o`L00_lG00;o00<0ool00_l00`3o
o`0500;o1`02o`@02?l500?o2`02o`l00_oS0000eP02o`/00_l700;o1P02o`L000?o00005@02o`<0
0_l300;o1002o`L00_l400;o1003o`@00_l70003o`0000800_l800;o1@02on<0003F00;o2`02o`L0
0_l600;o1P02oaL00_l300;o0`02o`@00_l600;o1@02o`D00_l400;o1P02o`D00_l600?o1@02on<0
003F00;o2`02o`L00_l60003o`0000D00_lG00;o2002o`@00_l400Co1@02o`@00ol400?o1003o`D0
0ol400Co1@02on<0003G0003o`0000D00ol00`3oo`0800;o1002o`L000?o00005@06o`801_l200[o
100:o`H02Ol600[o0P08on00003G00;o1P06o`P01ol700;o5`06o`801_l200So1P09o`T01Ol00`3o
000700Go00<0ool00P08on00003H0003o`0000L00ol:00Co20000ol0003o04P0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000001\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WEBSEL) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
231.000000 20.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1P0:o`L01?l900;o6@02o`@00_l400co0`0:o`D0
0_l00`3oo`03o`H03?l200go1002omD0003F0003o`0000D02_l600Ko2@000ol0000G00;o1002o`@0
3?l300_o100:o`@03?l200go0`04om@0003E00;o2002o`D00_l500?o0P03o`P00_lG00?o1003o`D0
0_l600;o1@02o`D00ol300?o1@03o`D00_l600;o1@02o`H00_l300Coe0000=D00_l900?o2P02o`@0
0_l800;o5`04o`<00ol500;o1P02o`D00_l600;o0`02o`L00_l500;o1P02o`D00_l600;o1002omD0
003E00;o2P03o`P00_l600;o1`02oaL01?l200Co1@02o`800_l200;o1@02o`H00_l300;o1`02o`D0
0_l200;o0P02o`D00_l600;of`000=D00_l;00?o1`02o`H00_l700;o5`02o`040?l000Co1@02o`80
0_l900;o1P02o`/00ol500;o0P02o`T00_l600;of`000=D00_l<00?o1P02o`H00_l700;o5`02o`06
0?l00?l00_l500Ko2@02o`D00ol600Oo1P06o`T00_oS0000e@02o`d00ol500;o1P02o`L00_lG00;o
00<0ool00_l00`3oo`0500Ko2@09o`D01ol800Ko2@02on<0003E00;o3P02o`D00_l600;o1`02oaL0
0_l00`3oo`02o`030?oo00D00_l200;o2@08o`D00ol=00;o0P02o`T00_oS0000eP02o`h00_l400;o
1P02o`L000?o00005@02o`<00_l300;o1002o`800_l200;o1@02o`@00ol400;o1`000ol0000400;o
0P02o`800_l500;oh`000=H00_l>00;o1002o`H00_l600;o5`02o`<00_l300;o1002o`H00_l500;o
1@02o`@00_l600;o1P02o`H00_l500;oh`000=H00_l700;o1@02o`D00_l400;o1`02oaL00_l800;o
1002o`H00_l500;o1003o`@00ol400?o1P02o`H00_l500;oh`000=L000?o00001@03o`<00ol500?o
0P03o`L000?o00005@06o`801_l00`3oo`0:o`<02_l600Wo100<o`802?oP0000e`02o`L01ol700Ko
1`02oaL01_l200Ko00<0ool02_l300Wo2@05o`030?l000<03?l200Soh0000=P000?o00001P05o`T0
1?l80003o`000?l0B0000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0
A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000
o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.05 0.047619 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
0 g
gsave
.5 .05 -147 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
63.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 20.000000 moveto
(H) show
77.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 20.000000 moveto
(L) show
133.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(WEASEL) show
217.000000 20.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 24.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
231.000000 20.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{581.188, 58},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.271883,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000950000>PP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003H0003o`00020000?o0000o`180000e`02ob800_oo04T0003G0003o`000280
00?o0000o`170000eP02ob@00_oo04P0003F00;o1P0:o`D02Ol600;o6@02o`@00_l400co0P06o`<0
1_l0103oo`05o`H03?l200go1002omD0003F0003o`0000D02_l500Wo1`000ol0000G00;o1002o`@0
3?l200Ko0`06o`030?oo00So100<o`803Ol300Coe0000=D00_l800;o1@02o`T00_l:00;o5`03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol500;o1P02o`D00_l600;o0`04om@0003E00;o2@03o`h0
0_l:00;o5`04o`<00ol500;o1P02o`@00_l700;o0`02o`L00_l500;o1P02o`D00_l600;o1002omD0
003E00;o2P03o`d00_l:00;o5`04o`801?l500;o0P02o`800_l400_o0`02o`L00_l500;o0P02o`80
0_l500;o1P02om/0003E00;o2`03o``00_l:00;o5`02o`040?l000Co1@02o`800_l900Wo3003o`D0
0_l200;o2@02o`H00_oK0000e@02o``00ol;00;o2P02oaL00_l01P3o003o00;o1@06o`T00_l500;o
1`07o`H01_l900;oh`000=D00_l=00?o2P02o`X00_lG00;o00<0ool00_l00`3oo`0500Ko2P02o`<0
0_l600Oo2006o`T00_oS0000e@02o`h00_l:00;o2P02oaL00_l00`3oo`02o`030?oo00D00_l200;o
2P02o`<00_l500?o3@02o`800_l900;oh`000=H00_l>00;o2@02o`X000?o00005@02o`<00_l300;o
1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000@00_l200;o0P02o`D00_oS0000eP02o`h0
0_l900;o2@02oaL00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1P02o`H00_l500;o
h`000=H00_l700;o1@02o`T00_l900;o5`02o`P00_l400;o1P02o`L01Ol600?o1003o`H00_l600;o
1@02on<0003G0003o`0000D00ol300?o1@03o`030?oo00T000?o00005@06o`801_l00`3oo`0:o`@0
1ol800Wo100<o`802?oP0000e`02o`L01ol600Ko2002oaL01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000<03?l200Soh0000=P000?o00001P05o`X00ol80003o`000?l0B0000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0
o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0003o0?l0A`000?l0o`170000o`3o04L0
003o0?l0A`000?l0o`170000\
\>"],
  ImageRangeCache->{{{0, 580.188}, {57, 0}} -> {-1.06878, -1.05001, 
  0.00368425, 0.0368425}}]
}, Closed]]
}, Open  ]],

Cell["\<\
Each image shows the generation number together with the best \
sentence of the respective generation.
Double-clicking on the graphic will start the animation sequence.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Experiment 1:\n\[Dash] 50 individuals, mutation radius: 1, mutation rate: \
0.1"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Iterated selection and mutation", "Subsubsection"],

Cell["We define an objective sentence.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(weaselSentence = encodeSentence["\<METHINKS IT IS LIKE A WEASEL.\>"]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 73, 
      75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We start an evolution experiment with a population size of ",
  StyleBox["m=50",
    FontSlant->"Italic"],
  ", that is, we will have 50 individual sentences per generation. Mutations \
are applied with a probability of ",
  StyleBox["\[Mu]=0.1",
    FontSlant->"Italic"],
  ", the mutation radius is set to ",
  StyleBox["\[Rho]=1",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveSentences[weaselSentence, m = 50, \[Rho] = 1, \[Mu] = .1]\)], 
  "Input"],

Cell["\<\
0: Min.: 2119
SOMVRXMNOLOMFQHVJNBTHPYBQIMI
1: Min.: 2065
SOMVQXMNOLOMFQIVJNBTHPYBQIMI
2: Min.: 1992
SOMVQXMNPLOMFQIUJNBTHPYBPIMI
3: Min.: 1952
SOMVQXMNPLPMFPJUINBTHPYBPIMI
4: Min.: 1901
SOMUQXMNQLPMFPJUINBTHPXBPIMI
5: Min.: 1836
SOMUQXMNQLPNGPJUIMBTGPXBPILI
6: Min.: 1775
SOMUQWMNQLPNGPJUIMBUGPXBOILI
7: Min.: 1738
SOMUPVMNQLPNGPJUIMCUGPXBOILI
8: Min.: 1670
SOMUPUMNQLPNGPJUIMCUGQXBOJKI
9: Min.: 1617
SOMUPUMNRLQNGPJUILCUGQYBNJKI
10: Min.: 1567
SOMUPUMNRLQNGPKTILCUGQYBNJKI
11: Min.: 1514
SOMTOUMNRLQNGPKSILCUGQYBNJKI
12: Min.: 1470
SOMTOULNRLQNGQLSILCUGQYBNJKJ
13: Min.: 1435
SOMTNULNRLQNGQLRILCVGQYBNJKJ
14: Min.: 1375
SOMSNULNRLQOGQLRILCVGQZBNKKJ
15: Min.: 1347
SOMSNULNRLQOGRLRILCVGQZBMKKJ
16: Min.: 1291
SOMRNULORLQOFRLRILCVGQZCLKKK
17: Min.: 1262
SOMRNULORLQOFRMRILCVGQZCLKKK
18: Min.: 1228
SONRNULPRLQOFRMRILCWFQ CLKKL
19: Min.: 1201
SONRNULPRLQOFRNRILCWFQ CLKKL
20: Min.: 1153
RONRNULPRMQOFRORILCWFR CLKKL
21: Min.: 1111
RNNRNULPRMQPFRORILCWFR CLKKL
22: Min.: 1079
RMNRNULPRMQPFRORILCWFR CLLKL
23: Min.: 1040
RNNQNULPRMQPFRORILCXER CKLKL
24: Min.: 1007
RMNQNULPRMQPFRORJLCXES CKLKL
25: Min.: 962
RMOQNULPRMQPFRPQJLCXES CKLKL
26: Min.: 924
RMOPNTLPRMQPFRPQJKCXDS CKLKL
27: Min.: 884
RMOPNTLPRMQQFRPQJKCXDS CJLKL
28: Min.: 851
RMOPNTLPSMQQFSPQJKCXDT CJLKL
29: Min.: 817
RMOPNSLQSMQRFSPQJKCXDT CJLKK
30: Min.: 788
QMOPNSLQSMQRFSQQJLCXDT CJLKK
31: Min.: 756
QMOPNSLQSMQRFSRQJLCXDU CJLKK
32: Min.: 715
QMOONSMQTMQRFSSPJLCXDUZCKLKK
33: Min.: 696
QMOONSMQTMQRFSSPJLCXDUZCJLKK
34: Min.: 674
QMONNSMQTMQSFSSPJLBXDUZCJLKJ
35: Min.: 635
PMONNSMQTMQSFSTPJLBXDUZCILKJ
36: Min.: 601
PMONNSMQUMQTESUPJLBXDUZCILKJ
37: Min.: 562
PLONNSMQULQTESUPKLBXDUYCHLKJ
38: Min.: 535
OLONMSMQULQTESUPKLBXDUYCHMKJ
39: Min.: 500
OLONMSMQULQTESVPKLBXDUYCGNKJ
40: Min.: 464
OLOMMSMQVLQTESVPJLBXDUYCFNKJ
41: Min.: 439
OLOMMSMQVKQUESVOJLBXDUYCFNKJ
42: Min.: 421
OLOMMSMQWKQUESVOJLBXDUYCFOKJ
43: Min.: 399
OKPMMSMQWKQUESVOJLBXDUYCFOKJ
44: Min.: 381
OKPMMSMQXKQUESVOJLBXDVYCFOKJ
45: Min.: 363
OKPMMSMQXKQUFSVOJLBXDVYCFOJJ
46: Min.: 347
OKPMMSMQXKQUFSVOJLBXDVYCFPIJ
47: Min.: 324
OKPMMRMQXKQVFSVOJLBXDVXCFPIJ
48: Min.: 304
OJPMMRMQXKQVFSVOJLBXDVXCEPIJ
49: Min.: 291
OJPMMRMQXKQVFSVOJLBYDVWCEPHJ
50: Min.: 279
OJPMMRMRXKQVFSWOJLBYDVWCEPHJ
51: Min.: 261
NJPMMRMSXKQWFSWOJLCYDVWCEPHJ
52: Min.: 245
NIPMMRMSXKQXFSWOJLCYDVWCEPHJ
53: Min.: 228
NIPMMQMSXJQXFSXOJLCYDVWCEPHJ
54: Min.: 212
NIPLMQMSXJQXFSXOJLCYDVWCDPHJ
55: Min.: 191
NIPKMQMSXJQXFSXOJLCYCWWCDPHJ
56: Min.: 176
NIPKMQLSYJQXFSXOJLCYCXWCDPHJ
57: Min.: 160
NIPKLQLSYJRXFRXOJLCYCXWCDQHJ
58: Min.: 149
NIPJLQLSZJRXFRXOJLCYCXWCDRHJ
59: Min.: 140
NIPJLQKSZJRXFRYOJLCZCXWCDRHJ
60: Min.: 127
NHPILQKSZJRXFRYOJLDZCXWCDRHJ
61: Min.: 118
NHQILQJRZJRXFSYOJLDZCXWCDRHK
62: Min.: 103
NHRILQJRZKSYFSYOJLDZCXWCCRHK
63: Min.: 94
NHRHKQJRZKSZFSYOJLDZCXWCCRHK
64: Min.: 87
NGRHKQJR KSZFSYOJLDZCXWCCRHL
65: Min.: 81
NGSHJQJR KSZFSYOJLDZCXWCCRHL
66: Min.: 70
NGSHJQKR JTZFSYOJLDZCYWCCSHL
67: Min.: 64
NGSHJPKR JTZFSYOJLDZCYWDCTHM
68: Min.: 56
NGSHJPKR JTZGSYOJLDZBYWDCTHM
69: Min.: 50
NGSIJOKR JTZGSYOJLD BYWDBTHM
70: Min.: 47
NFSIJOKR JTZGSYOJLD BYWDBTHM
71: Min.: 41
NFSIJOKR JTZHSZOJLD BYWDBTHM
72: Min.: 36
NFSIJOKR JTZHSZNJLD BYWDBTHM
73: Min.: 30
OFTIIOLR JTZHSZMJLD BYWDBTGM
74: Min.: 28
OFTIINLR JTZHSZMJLD BYWDBTGL
75: Min.: 24
OFTIINLR JTZHSZMJLD BZWEBTGL
76: Min.: 21
NFTIINLR JTZHSZMJLD BZWEBTGL
77: Min.: 18
NFSIINLR JT ISZMJLD B WEBSGL
78: Min.: 16
NFTIINLR JT ISZMJLD A WEBSGL
79: Min.: 14
MFTIJNLR IT ISZMJKD A WEBSGL
80: Min.: 12
MFTIJNLR IT ISZLJKE A WEBSGL
81: Min.: 11
MFTIJNLR IT ISZLIKE A WEBSGL
82: Min.: 9
MFTIJNLR IT ISZLIJE A WEBSFL
83: Min.: 8
MFTIJNLR IT IS LIJE A WEBSFL
84: Min.: 7
MFTIJNLR IT IS LIJE A WEASFL
85: Min.: 5
MFTIJNKR IT IS LIJE A WEASEL
86: Min.: 4
MFTIJNKR IT IS LIKE A WEASEL
87: Min.: 3
MFTIINKR IT IS LIKE A WEASEL
88: Min.: 3
MFTIINKR IT IS LIKE A WEASEL
89: Min.: 2
METIINKR IT IS LIKE A WEASEL
90: Min.: 2
METIINKR IT IS LIKE A WEASEL
91: Min.: 2
METIINKR IT IS LIKE A WEASEL
92: Min.: 1
METIINKS IT IS LIKE A WEASEL
93: Min.: 0
METHINKS IT IS LIKE A WEASEL\
\>", "Print"]
}, Closed]],

Cell["\<\
The result of this command is a list of evolved character \
sequences. The evolution cycle only stops when the objective sentence has \
been found.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitness plot", "Subsubsection"],

Cell["\<\
The following graph depicts the development of the Hamming distance \
of the best sentence within each generation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] All, PlotLabel \[Rule] "\<Hamming distance\>", 
      AxesLabel \[Rule] {"\<Gen.\>", "\<Fit.\>"}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0101317 0.0147151 0.000277774 [
[.22644 .00222 -6 -9 ]
[.22644 .00222 6 0 ]
[.42908 .00222 -6 -9 ]
[.42908 .00222 6 0 ]
[.63171 .00222 -6 -9 ]
[.63171 .00222 6 0 ]
[.83435 .00222 -6 -9 ]
[.83435 .00222 6 0 ]
[1.025 .01472 0 -7 ]
[1.025 .01472 28 7 ]
[.01131 .1536 -18 -4.5 ]
[.01131 .1536 0 4.5 ]
[.01131 .29249 -24 -4.5 ]
[.01131 .29249 0 4.5 ]
[.01131 .43138 -24 -4.5 ]
[.01131 .43138 0 4.5 ]
[.01131 .57026 -24 -4.5 ]
[.01131 .57026 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 14 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22644 .01472 m
.22644 .02097 L
s
[(20)] .22644 .00222 0 1 Mshowa
.42908 .01472 m
.42908 .02097 L
s
[(40)] .42908 .00222 0 1 Mshowa
.63171 .01472 m
.63171 .02097 L
s
[(60)] .63171 .00222 0 1 Mshowa
.83435 .01472 m
.83435 .02097 L
s
[(80)] .83435 .00222 0 1 Mshowa
.125 Mabswid
.07447 .01472 m
.07447 .01847 L
s
.12513 .01472 m
.12513 .01847 L
s
.17579 .01472 m
.17579 .01847 L
s
.2771 .01472 m
.2771 .01847 L
s
.32776 .01472 m
.32776 .01847 L
s
.37842 .01472 m
.37842 .01847 L
s
.47974 .01472 m
.47974 .01847 L
s
.5304 .01472 m
.5304 .01847 L
s
.58105 .01472 m
.58105 .01847 L
s
.68237 .01472 m
.68237 .01847 L
s
.73303 .01472 m
.73303 .01847 L
s
.78369 .01472 m
.78369 .01847 L
s
.88501 .01472 m
.88501 .01847 L
s
.93566 .01472 m
.93566 .01847 L
s
.98632 .01472 m
.98632 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gen) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 15.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .1536 m
.03006 .1536 L
s
[(500)] .01131 .1536 1 0 Mshowa
.02381 .29249 m
.03006 .29249 L
s
[(1000)] .01131 .29249 1 0 Mshowa
.02381 .43138 m
.03006 .43138 L
s
[(1500)] .01131 .43138 1 0 Mshowa
.02381 .57026 m
.03006 .57026 L
s
[(2000)] .01131 .57026 1 0 Mshowa
.125 Mabswid
.02381 .04249 m
.02756 .04249 L
s
.02381 .07027 m
.02756 .07027 L
s
.02381 .09805 m
.02756 .09805 L
s
.02381 .12582 m
.02756 .12582 L
s
.02381 .18138 m
.02756 .18138 L
s
.02381 .20916 m
.02756 .20916 L
s
.02381 .23693 m
.02756 .23693 L
s
.02381 .26471 m
.02756 .26471 L
s
.02381 .32027 m
.02756 .32027 L
s
.02381 .34804 m
.02756 .34804 L
s
.02381 .37582 m
.02756 .37582 L
s
.02381 .4036 m
.02756 .4036 L
s
.02381 .45915 m
.02756 .45915 L
s
.02381 .48693 m
.02756 .48693 L
s
.02381 .51471 m
.02756 .51471 L
s
.02381 .54249 m
.02756 .54249 L
s
.02381 .59804 m
.02756 .59804 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fit) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 15.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hamming) show
111.000000 15.000000 moveto
(distance) show
159.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03394 .60332 m
.04407 .58832 L
.0542 .56804 L
.06434 .55693 L
.07447 .54276 L
.0846 .52471 L
.09473 .50776 L
.10486 .49749 L
.11499 .4786 L
.12513 .46388 L
.13526 .44999 L
.14539 .43527 L
.15552 .42304 L
.16565 .41332 L
.17579 .39665 L
.18592 .38888 L
.19605 .37332 L
.20618 .36527 L
.21631 .35582 L
.22644 .34832 L
.23658 .33499 L
.24671 .32332 L
.25684 .31443 L
.26697 .3036 L
.2771 .29443 L
.28723 .28193 L
.29737 .27138 L
.3075 .26027 L
.31763 .2511 L
.32776 .24166 L
.33789 .2336 L
.34802 .22471 L
.35816 .21332 L
.36829 .20805 L
.37842 .20193 L
.38855 .1911 L
.39868 .18166 L
.40881 .17082 L
.41895 .16332 L
.42908 .1536 L
.43921 .1436 L
.44934 .13666 L
.45947 .13166 L
.4696 .12555 L
.47974 .12055 L
.48987 .11555 L
.5 .1111 L
.51013 .10471 L
.52026 .09916 L
.5304 .09555 L
Mistroke
.54053 .09221 L
.55066 .08721 L
.56079 .08277 L
.57092 .07805 L
.58105 .0736 L
.59119 .06777 L
.60132 .0636 L
.61145 .05916 L
.62158 .0561 L
.63171 .0536 L
.64184 .04999 L
.65198 .04749 L
.66211 .04333 L
.67224 .04083 L
.68237 .03888 L
.6925 .03721 L
.70263 .03416 L
.71277 .03249 L
.7229 .03027 L
.73303 .0286 L
.74316 .02777 L
.75329 .0261 L
.76342 .02471 L
.77356 .02305 L
.78369 .02249 L
.79382 .02138 L
.80395 .02055 L
.81408 .01972 L
.82421 .01916 L
.83435 .0186 L
.84448 .01805 L
.85461 .01777 L
.86474 .01722 L
.87487 .01694 L
.88501 .01666 L
.89514 .0161 L
.90527 .01583 L
.9154 .01555 L
.92553 .01555 L
.93566 .01527 L
.9458 .01527 L
.95593 .01527 L
.96606 .01499 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l08@000?l08@000?l08@000?l08@0004@0
1?l300;o9`03o`<00_lW00;o1002obL00_l400;oAP0004D000?o00000P001?l00?lW0005o`000?l0
0P000ol0000S0004o`00o`8000Co003o9@001?l00?l20004o`00odD000160005o`000?l00P000ol0
000S00Co0P001?l00?lU0004o`00o`8000Co003o9@001?l00?l20004o`00odD000170004o`00o`80
00?o00008`000ol0o`030004o`00obD00ol30004o`00obH00_l30004o`00odD000140004o`00o`80
00Co003o9@000ol0o`030004o`00obD000?o00000`001?l00?lU0004o`00o`8000Co003oA@0004D0
0_l400;o9`02o`@00_lW00?o0`02obL00_l400;oAP000?l08@0001X000?o0000j@04o`<01?l0103o
o`02o`800_l500006P000ol0003X0005o`000?l00P000ol000030004o`00o`<00_l500006P000ol0
003X0003o`3o00;o0P05o`050?l00?l02P0001D0jOl70003o`0000@000Oo0000o`3o008000?o0000
200001X000?o00002@000ol000090003o`0000T000?o000020000ol000090003o`0000T000?o0000
2@000ol000080003o`0000T000?o00002@000ol000090003o`0000P000?o00002@000ol000090003
o`0000T000?o00000`0Bo`/000?o00002@000ol000080005o`000?l00`03o`030?oo00?o2P0001X0
00?o0000;0000ol0000/0003o`0002`000?o00006`0<o`D000?o0000;@04oaH0000J0003o`000:40
1omK00006P000ol0002L00GoHP0001X000?o0000U`05ofL0000J0003o`0009<01?m/00006P02oi40
0om`00006P000ol0002<00CoL`0001X000?o0000R@03ogL0000J0003o`0008D01?mj00006P000ol0
002200?oOP0001X000?o0000P@000ol0001o00006P02oh4000?o0000P00001X000?o0000OP02oh<0
000J0003o`0007/00on500006P000ol0001i00;oR00001X000?o0000M`02ohX0000J0003o`0007@0
0on<00006P02og<00_n?00006P000ol0001_00?oT@0001X000?o0000K@02oi@0000J0003o`0006/0
0_nF00006P000ol0001Z0003o`0009H0000J0003o`0006P00_nI00006P000ol0001V00;oV`0001X0
0_mU00;oW@0001X000?o0000H@03oil0000J0003o`00060000?o0000X00001X000?o0000G`000ol0
002Q00001`03o`@00_l400;o10000ol0001M00;oY00000X000Co003o0P001?l00?l20005o`000?l0
GP000ol0002T00002P001?l00?l20004o`00o`8000Co00000omK0003o`000:D0000700?o0`001?l0
0?l20004o`00o`<000?o0000F`000ol0002U00001`000ol000030004o`00o`8000Co003o0`000ol0
001J0003o`000:H0000700Co0`02o`@00_l40003o`0005P00_nY00006P000ol0001G0003o`000:T0
000J0003o`0005H000?o0000ZP0001X000?o0000E@000ol0002[00006P02oeD000?o0000[00001X0
00?o0000D`000ol0002]00006P000ol0001B0003o`000:h0000J0003o`00058000?o0000[P0001X0
00?o0000D@000ol0002_00006P000ol0001?00;o/P0001X00_m=00?o]00001X000?o0000B`000ol0
002e00006P000ol0001;0003o`000;D0000J0003o`0004X000?o0000]P0001X000?o0000B002okT0
000J0003o`0004L000?o0000^@0001X000?o0000AP000ol0002j00006P02odH000?o0000^`0001X0
00?o0000A0000ol0002l00006P000ol000130003o`000;d0000J0003o`0004400_o000006P000ol0
00100003o`000<00000J0003o`0003l000?o0000`@0001X00_m00003o`000<40000J0003o`0003h0
00?o0000`P0001X000?o0000?002olD0000J0003o`0003/000?o0000a@0001X000?o0000>P000ol0
0036000000@0oooo1002o`@00_l400;o10000ol0000j0003o`000<H000020003o`00008000Co003o
0P001?l00?l20004o`00o`<000?o0000>@000ol0003700000P000ol000020004o`00o`8000Co003o
0P001?l00?l300?o>0000ol0003800000P000ol000020004o`00o`8000Co003o0P001?l00?l30003
o`0003L000?o0000b@00008000?o00000P001?l00?l20004o`00o`8000Co003o0`000ol0000f0003
o`000<X000000`3oo`0500;o1002o`@00_l40003o`0003D000?o0000b`0001X000?o0000=0000ol0
003<00006P000ol0000c0003o`000<d0000J00;o<`000ol0003>00006P000ol0000a0003o`000<l0
000J0003o`00030000?o0000d00001X000?o0000;`000ol0003A00006P000ol0000^0003o`000=80
000J0003o`0002d000?o0000d`0001X00_l]0003o`000=@0000J0003o`0002/000?o0000e@0001X0
00?o0000:P000ol0003F00006P000ol0000Y0003o`000=L0000J0003o`0002L00_oJ00006P000ol0
000V0003o`000=X0000J0003o`0002D000?o0000f`0001X00_lV0003o`000=/0000J0003o`0002@0
00?o0000g00001X000?o000090000ol0003L00006P000ol0000S0003o`000=d0000J0003o`000280
00?o0000gP0001X000?o00008@000ol0003O00006P02ob8000?o0000g`0001X000?o000080000ol0
003P00006P000ol0000O0003o`000>40000J0003o`0001h000?o0000hP0001X000?o00007@000ol0
003S000000@0oooo0`03o`@00_l400;o10000ol0000L0003o`000>@000020003o`0000D000Co003o
0P001?l00?l20005o`000?l07P000ol0003T00000P000ol000050004o`00o`8000Co003o0P001?l0
0003oa/000?o0000i@00008000?o00000P03o`<000Co003o0P001?l00?l30003o`0001X000?o0000
iP00008000?o00000P000ol000030004o`00o`8000Co003o0`000ol0000I0003o`000>L000000`3o
o`0400Co0`02o`@00_l40003o`0001P000?o0000j00001X000?o00005`000ol0003Y00006P000ol0
000G0003o`000>T0000J00;o5`000ol0003Z00006P000ol0000E0003o`000>/0000J0003o`0001D0
00?o0000j`0001X000?o000050000ol0003/00006P000ol0000D0003o`000>`0000J0003o`0001<0
00?o0000k@0001X000?o00004`000ol0003]00006P02oa<000?o0000kP0001X000?o00004@000ol0
003_00006P000ol0000@0003o`000?00000J0003o`0000l000?o0000l@0001X000?o00003P000ol0
003b00006P000ol0000>0003o`000?80000J00;o3P000ol0003c00006P000ol0000<0003o`000?@0
000J0003o`0000/000?o0000m@0001X000?o00002`000ol0003e00006P000ol0000:0003o`000?H0
000J0003o`0000X000?o0000mP0001X00_l;0003o`000?H0000J0003o`0000T000?o0000m`0001X0
00?o00002@000ol0003g00006P000ol000080003o`000?P0000J0003o`0000H00_ok000000<0ool0
0_l300;o1002o`@00_l40003o`0000D000?o0000n`00008000?o00000P001?l00?l20004o`00o`80
00Co003o0`000ol000040003o`000?`000030005o`000?l00P001?l00?l20004o`00o`8000Co0000
0ol40003o`000?`000040004o`00o`8000Co003o0P001?l00?l20005o`000?l01@000ol0003m0000
00D0o`00o`020004o`00o`8000Co003o0P001?l00?l30003o`0000<000?o0000o@0000800_l400;o
1002o`@00_l40003o`0000<000?o0000o@0001X000?o00000P000ol0003n00006P000ol000020003
o`000?h0000J00;o0P000ol0003o00006P001Ol0003o0?l00P0001X000Co003oo`0300006P000ol0
003o00@0000J0003o`000?l0100001X000?o0000o`040000o`0Q0000o`0Q0000o`0Q0000o`0Q0000
O`03oih000220003o`0009/0001I00;o0P02o`030?oo00?o00d0o`3o0?l0o`3o0?l000Go00@0ool0
0_l200Co200:o`030?oo00;o0`03o`801Ol0103oo`02o`800ol300CoI`0005X000Co003o0P001?l0
0?l2000;o`3o0?l0o`3o0?l00`001Ol0003o008000Co003o0`000ol000050005o`000?l00`000ol0
00040005o`000?l00P000ol0o`020004o`00o`8000Co003o0`000ol0o`1[0000FP001?l00?l200Co
0P002ol0o`3o0?l0o`3o00<000Go0000o`020004o`00o`<000?o00001@001Ol0003o00<000Co0000
1?l30003o`0000801?l20004o`00o`8000?o00000`05ofL0000>00?o1005o`800ol300;o=P04o`D0
00ko003o0?l0o`3o0?l0o`<000Go0000o`020004o`00o`<000?o00001@001Ol0003o00<000Go0000
o`060003o`0000D000Co003o0P001?l00?l30003o`3o00<000?o0000I@0000l000?o00001@000ol0
00020004o`00o`800_lf0004o`00o`<00ol00`3oo`0:o`800_l200Go0`05o`L01?l200;o0`04o`80
1?l300?o00<0ool00ol300Co0P03ofP0000?0003o`0000D000?o00000P000ol0000j00;o0P02obl0
00?o000030000ol0002000003`03o`D000?o00000P000ol0001E0003o`0001H00_l30003o`0000P0
00?o0000P00000l000?o00001002o`<01?oo0080000>00Go2@000ol0003o0080000G0003o`000080
00?o0000o`020000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{155.25, 442.25}, {401.938, 225}} -> {-77.5507, 3267.54, 
  0.425755, 15.5292}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sentences overview", "Subsubsection"],

Cell["\<\
The following table shows the step-by-step evolution from a random \
initial sequence of characters up to the final objective sentence. Each \
\[RightGuillemet]sentence\[LeftGuillemet] is tje best evaluated of its \
population.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[interpretSentence/@bestSentences]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("SOMVRXMNOLOMFQHVJNBTHPYBQIMI"\)},
          {\("SOMVQXMNOLOMFQIVJNBTHPYBQIMI"\)},
          {\("SOMVQXMNPLOMFQIUJNBTHPYBPIMI"\)},
          {\("SOMVQXMNPLPMFPJUINBTHPYBPIMI"\)},
          {\("SOMUQXMNQLPMFPJUINBTHPXBPIMI"\)},
          {\("SOMUQXMNQLPNGPJUIMBTGPXBPILI"\)},
          {\("SOMUQWMNQLPNGPJUIMBUGPXBOILI"\)},
          {\("SOMUPVMNQLPNGPJUIMCUGPXBOILI"\)},
          {\("SOMUPUMNQLPNGPJUIMCUGQXBOJKI"\)},
          {\("SOMUPUMNRLQNGPJUILCUGQYBNJKI"\)},
          {\("SOMUPUMNRLQNGPKTILCUGQYBNJKI"\)},
          {\("SOMTOUMNRLQNGPKSILCUGQYBNJKI"\)},
          {\("SOMTOULNRLQNGQLSILCUGQYBNJKJ"\)},
          {\("SOMTNULNRLQNGQLRILCVGQYBNJKJ"\)},
          {\("SOMSNULNRLQOGQLRILCVGQZBNKKJ"\)},
          {\("SOMSNULNRLQOGRLRILCVGQZBMKKJ"\)},
          {\("SOMRNULORLQOFRLRILCVGQZCLKKK"\)},
          {\("SOMRNULORLQOFRMRILCVGQZCLKKK"\)},
          {\("SONRNULPRLQOFRMRILCWFQ CLKKL"\)},
          {\("SONRNULPRLQOFRNRILCWFQ CLKKL"\)},
          {\("RONRNULPRMQOFRORILCWFR CLKKL"\)},
          {\("RNNRNULPRMQPFRORILCWFR CLKKL"\)},
          {\("RMNRNULPRMQPFRORILCWFR CLLKL"\)},
          {\("RNNQNULPRMQPFRORILCXER CKLKL"\)},
          {\("RMNQNULPRMQPFRORJLCXES CKLKL"\)},
          {\("RMOQNULPRMQPFRPQJLCXES CKLKL"\)},
          {\("RMOPNTLPRMQPFRPQJKCXDS CKLKL"\)},
          {\("RMOPNTLPRMQQFRPQJKCXDS CJLKL"\)},
          {\("RMOPNTLPSMQQFSPQJKCXDT CJLKL"\)},
          {\("RMOPNSLQSMQRFSPQJKCXDT CJLKK"\)},
          {\("QMOPNSLQSMQRFSQQJLCXDT CJLKK"\)},
          {\("QMOPNSLQSMQRFSRQJLCXDU CJLKK"\)},
          {\("QMOONSMQTMQRFSSPJLCXDUZCKLKK"\)},
          {\("QMOONSMQTMQRFSSPJLCXDUZCJLKK"\)},
          {\("QMONNSMQTMQSFSSPJLBXDUZCJLKJ"\)},
          {\("PMONNSMQTMQSFSTPJLBXDUZCILKJ"\)},
          {\("PMONNSMQUMQTESUPJLBXDUZCILKJ"\)},
          {\("PLONNSMQULQTESUPKLBXDUYCHLKJ"\)},
          {\("OLONMSMQULQTESUPKLBXDUYCHMKJ"\)},
          {\("OLONMSMQULQTESVPKLBXDUYCGNKJ"\)},
          {\("OLOMMSMQVLQTESVPJLBXDUYCFNKJ"\)},
          {\("OLOMMSMQVKQUESVOJLBXDUYCFNKJ"\)},
          {\("OLOMMSMQWKQUESVOJLBXDUYCFOKJ"\)},
          {\("OKPMMSMQWKQUESVOJLBXDUYCFOKJ"\)},
          {\("OKPMMSMQXKQUESVOJLBXDVYCFOKJ"\)},
          {\("OKPMMSMQXKQUFSVOJLBXDVYCFOJJ"\)},
          {\("OKPMMSMQXKQUFSVOJLBXDVYCFPIJ"\)},
          {\("OKPMMRMQXKQVFSVOJLBXDVXCFPIJ"\)},
          {\("OJPMMRMQXKQVFSVOJLBXDVXCEPIJ"\)},
          {\("OJPMMRMQXKQVFSVOJLBYDVWCEPHJ"\)},
          {\("OJPMMRMRXKQVFSWOJLBYDVWCEPHJ"\)},
          {\("NJPMMRMSXKQWFSWOJLCYDVWCEPHJ"\)},
          {\("NIPMMRMSXKQXFSWOJLCYDVWCEPHJ"\)},
          {\("NIPMMQMSXJQXFSXOJLCYDVWCEPHJ"\)},
          {\("NIPLMQMSXJQXFSXOJLCYDVWCDPHJ"\)},
          {\("NIPKMQMSXJQXFSXOJLCYCWWCDPHJ"\)},
          {\("NIPKMQLSYJQXFSXOJLCYCXWCDPHJ"\)},
          {\("NIPKLQLSYJRXFRXOJLCYCXWCDQHJ"\)},
          {\("NIPJLQLSZJRXFRXOJLCYCXWCDRHJ"\)},
          {\("NIPJLQKSZJRXFRYOJLCZCXWCDRHJ"\)},
          {\("NHPILQKSZJRXFRYOJLDZCXWCDRHJ"\)},
          {\("NHQILQJRZJRXFSYOJLDZCXWCDRHK"\)},
          {\("NHRILQJRZKSYFSYOJLDZCXWCCRHK"\)},
          {\("NHRHKQJRZKSZFSYOJLDZCXWCCRHK"\)},
          {\("NGRHKQJR KSZFSYOJLDZCXWCCRHL"\)},
          {\("NGSHJQJR KSZFSYOJLDZCXWCCRHL"\)},
          {\("NGSHJQKR JTZFSYOJLDZCYWCCSHL"\)},
          {\("NGSHJPKR JTZFSYOJLDZCYWDCTHM"\)},
          {\("NGSHJPKR JTZGSYOJLDZBYWDCTHM"\)},
          {\("NGSIJOKR JTZGSYOJLD BYWDBTHM"\)},
          {\("NFSIJOKR JTZGSYOJLD BYWDBTHM"\)},
          {\("NFSIJOKR JTZHSZOJLD BYWDBTHM"\)},
          {\("NFSIJOKR JTZHSZNJLD BYWDBTHM"\)},
          {\("OFTIIOLR JTZHSZMJLD BYWDBTGM"\)},
          {\("OFTIINLR JTZHSZMJLD BYWDBTGL"\)},
          {\("OFTIINLR JTZHSZMJLD BZWEBTGL"\)},
          {\("NFTIINLR JTZHSZMJLD BZWEBTGL"\)},
          {\("NFSIINLR JT ISZMJLD B WEBSGL"\)},
          {\("NFTIINLR JT ISZMJLD A WEBSGL"\)},
          {\("MFTIJNLR IT ISZMJKD A WEBSGL"\)},
          {\("MFTIJNLR IT ISZLJKE A WEBSGL"\)},
          {\("MFTIJNLR IT ISZLIKE A WEBSGL"\)},
          {\("MFTIJNLR IT ISZLIJE A WEBSFL"\)},
          {\("MFTIJNLR IT IS LIJE A WEBSFL"\)},
          {\("MFTIJNLR IT IS LIJE A WEASFL"\)},
          {\("MFTIJNKR IT IS LIJE A WEASEL"\)},
          {\("MFTIJNKR IT IS LIKE A WEASEL"\)},
          {\("MFTIINKR IT IS LIKE A WEASEL"\)},
          {\("MFTIINKR IT IS LIKE A WEASEL"\)},
          {\("METIINKR IT IS LIKE A WEASEL"\)},
          {\("METIINKR IT IS LIKE A WEASEL"\)},
          {\("METIINKR IT IS LIKE A WEASEL"\)},
          {\("METIINKS IT IS LIKE A WEASEL"\)},
          {\("METHINKS IT IS LIKE A WEASEL"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"SOMVRXMNOLOMFQHVJNBTHPYBQIMI", "SOMVQXMNOLOMFQIVJNBTHPYBQIM      I", 
        "SOMVQXMNPLOMFQIUJNBTHPYBPIMI", "SOMVQXMNPLPMFPJUINBTHPYBPIMI", 
        "SOMUQXMNQLPMFPJUINBTHPXBPIMI", "SOMUQXMNQLPNGPJUIMBTGPXBPILI", 
        "SOMUQWMNQLPNGPJUIMBUGPXBOILI", "SOMUPVMNQLPNGPJUIMCUGPXBOILI", 
        "SOMUPUMNQLPNGPJUIMCUGQXBOJKI", "SOMUPUMNRLQNGPJUILCUGQYBNJKI", 
        "SOMUPUMNRLQNGPKTILCUGQYBNJKI", "SOMTOUMNRLQNGPKSILCUGQYBNJKI", 
        "SOMTOULNRLQNGQLSILCUGQYBNJKJ", "SOMTNULNRLQNGQLRILCVGQYBNJKJ", 
        "SOMSNULNRLQOGQLRILCVGQZBNKKJ", "SOMSNULNRLQOGRLRILCVGQZBMKKJ", 
        "SOMRNULORLQOFRLRILCVGQZCLKKK", "SOMRNULORLQOFRMRILCVGQZCLKKK", 
        "SONRNULPRLQOFRMRILCWFQ CLKKL", "SONRNULPRLQOFRNRILCWFQ CLKKL", 
        "RONRNULPRMQOFRORILCWFR CLKKL", "RNNRNULPRMQPFRORILCWFR CLKKL", 
        "RMNRNULPRMQPFRORILCWFR CLLKL", "RNNQNULPRMQPFRORILCXER CKLKL", 
        "RMNQNULPRMQPFRORJLCXES CKLKL", "RMOQNULPRMQPFRPQJLCXES CKLKL", 
        "RMOPNTLPRMQPFRPQJKCXDS CKLKL", "RMOPNTLPRMQQFRPQJKCXDS CJLKL", 
        "RMOPNTLPSMQQFSPQJKCXDT CJLKL", "RMOPNSLQSMQRFSPQJKCXDT CJLKK", 
        "QMOPNSLQSMQRFSQQJLCXDT CJLKK", "QMOPNSLQSMQRFSRQJLCXDU CJLKK", 
        "QMOONSMQTMQRFSSPJLCXDUZCKLKK", "QMOONSMQTMQRFSSPJLCXDUZCJLKK", 
        "QMONNSMQTMQSFSSPJLBXDUZCJLKJ", "PMONNSMQTMQSFSTPJLBXDUZCILKJ", 
        "PMONNSMQUMQTESUPJLBXDUZCILKJ", "PLONNSMQULQTESUPKLBXDUYCHLKJ", 
        "OLONMSMQULQTESUPKLBXDUYCHMKJ", "OLONMSMQULQTESVPKLBXDUYCGNKJ", 
        "OLOMMSMQVLQTESVPJLBXDUYCFNKJ", "OLOMMSMQVKQUESVOJLBXDUYCFNKJ", 
        "OLOMMSMQWKQUESVOJLBXDUYCFOKJ", "OKPMMSMQWKQUESVOJLBXDUYCFOKJ", 
        "OKPMMSMQXKQUESVOJLBXDVYCFOKJ", "OKPMMSMQXKQUFSVOJLBXDVYCFOJJ", 
        "OKPMMSMQXKQUFSVOJLBXDVYCFPIJ", "OKPMMRMQXKQVFSVOJLBXDVXCFPIJ", 
        "OJPMMRMQXKQVFSVOJLBXDVXCEPIJ", "OJPMMRMQXKQVFSVOJLBYDVWCEPHJ", 
        "OJPMMRMRXKQVFSWOJLBYDVWCEPHJ", "NJPMMRMSXKQWFSWOJLCYDVWCEPHJ", 
        "NIPMMRMSXKQXFSWOJLCYDVWCEPHJ", "NIPMMQMSXJQXFSXOJLCYDVWCEPHJ", 
        "NIPLMQMSXJQXFSXOJLCYDVWCDPHJ", "NIPKMQMSXJQXFSXOJLCYCWWCDPHJ", 
        "NIPKMQLSYJQXFSXOJLCYCXWCDPHJ", "NIPKLQLSYJRXFRXOJLCYCXWCDQHJ", 
        "NIPJLQLSZJRXFRXOJLCYCXWCDRHJ", "NIPJLQKSZJRXFRYOJLCZCXWCDRHJ", 
        "NHPILQKSZJRXFRYOJLDZCXWCDRHJ", "NHQILQJRZJRXFSYOJLDZCXWCDRHK", 
        "NHRILQJRZKSYFSYOJLDZCXWCCRHK", "NHRHKQJRZKSZFSYOJLDZCXWCCRHK", 
        "NGRHKQJR KSZFSYOJLDZCXWCCRHL", "NGSHJQJR KSZFSYOJLDZCXWCCRHL", 
        "NGSHJQKR JTZFSYOJLDZCYWCCSHL", "NGSHJPKR JTZFSYOJLDZCYWDCTHM", 
        "NGSHJPKR JTZGSYOJLDZBYWDCTHM", "NGSIJOKR JTZGSYOJLD BYWDBTHM", 
        "NFSIJOKR JTZGSYOJLD BYWDBTHM", "NFSIJOKR JTZHSZOJLD BYWDBTHM", 
        "NFSIJOKR JTZHSZNJLD BYWDBTHM", "OFTIIOLR JTZHSZMJLD BYWDBTGM", 
        "OFTIINLR JTZHSZMJLD BYWDBTGL", "OFTIINLR JTZHSZMJLD BZWEBTGL", 
        "NFTIINLR JTZHSZMJLD BZWEBTGL", "NFSIINLR JT ISZMJLD B WEBSGL", 
        "NFTIINLR JT ISZMJLD A WEBSGL", "MFTIJNLR IT ISZMJKD A WEBSGL", 
        "MFTIJNLR IT ISZLJKE A WEBSGL", "MFTIJNLR IT ISZLIKE A WEBSGL", 
        "MFTIJNLR IT ISZLIJE A WEBSFL", "MFTIJNLR IT IS LIJE A WEBSFL", 
        "MFTIJNLR IT IS LIJE A WEASFL", "MFTIJNKR IT IS LIJE A WEASEL", 
        "MFTIJNKR IT IS LIKE A WEASEL", "MFTIINKR IT IS LIKE A WEASEL", 
        "MFTIINKR IT IS LIKE A WEASEL", "METIINKR IT IS LIKE A WEASEL", 
        "METIINKR IT IS LIKE A WEASEL", "METIINKR IT IS LIKE A WEASEL", 
        "METIINKS IT IS LIKE A WEASEL", "METHINKS IT IS LIKE A WEASEL"}]]], 
  "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation ...", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MapIndexed[
      Show[Graphics[
            Text["\<(\>"<>ToString[First[#2]]<>"\<) \>"<>
                interpretSentence[#1], {0, 0}], 
            DefaultFont \[Rule] {"\<Courier\>", 24}], 
          AspectRatio \[Rule] .1]&, bestSentences]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(1\\) SOMVRXMNOLOMFQHVJNBTHPYBQIMI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  AnimationCycleOffset->0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002omD00_l400?oU@02o`@00om400007002oaX0
0_oD00[oU00:od<0000K00;o7002om@01Ol200;oU@05o`800_m300006`02oa`00_oD0003o`0009/0
00?o0000B@0001/00_l900Wo2P02oaH00_l00`3oo`03o`T01Ol500Go0`05o`L00_l700Go1P03o`03
0?oo00?o0P05o`801Ol300Go0P06o`<00_l700Go1@0=o`H01Ol500Go0`05o`030?oo00Go3005o`H0
1?l300Co2002o`T01_l700Ko0`02o`<02_l600So1P04o`<01?l200So2008o`D02_l800Go1`0:o`<0
1Ol300Go0P0:oaX0000J00;o2P09o`/00_lE00[o1@09o`<01Ol300Go1P04o`H01Ol500Co00<0ool0
0ol200Go0P05o`<01Ol200Ko0P03o`D02Ol300go1009o`<01Ol300Go00<0ool01Ol:00Wo1004o`<0
1?l700Co1P09o`H01_l200?o0`0;o`D02?l600Co0`04o`802?l800So1@0;o`D02Ol500[o0`05o`<0
1Ol200[o6P0001X00_l>00;o3P02oaD00ol500?o0`03o`D00ol300;o1`02o`L01?l800;o1@03o`@0
0ol400?o1002o`L00_l400;o1004o`@00ol500?o1@02o`H00_l300?o1@03o`<00_l700;o1002o``0
0ol500?o1002o`D00_l800Co1P03o`@00ol600;o1004o`D00_l500?o1`02o`X00_l500;o1@02o`l0
0_l:00;o1@03o`<00ol500?o2002o`P00_l700;o1`02oah0000J00;o3P02o`h00_lE00;o1`02o`<0
0_l700;o0`02o`L00_l700Co2002o`D00_l600?o0P03o`D00_l700;o1002o`@01?l400;o1`02o`D0
0_l600;o0`02o`L00_l300;o1`02o`@00_l<00;o1`02o`@00_l500;o2004o`H00_l600;o1P02o`@0
1?l500;o1P02o`L00_l:00;o1@02o`D00_l?00;o2P02o`H00_l300;o1`02o`P00_l800;o1`02o`L0
0_lN00006P02o`h00_l>00;o5@02o`L00_l200;o2@02o`800_l300;o0P02o`H00_l200;o1`02o`@0
0_l800;o0P02o`H00_l300;o0P02o`@00_l300Go0`02o`T00_l400;o1P02o`800_l900;o0P02o`<0
0_l200;o1002o`800_l700;o2@02o`<00_l500;o1`02o`800_l500;o1P02o`H00_l300Go1@02o`H0
0_l700;o2P02o`D00_l500;o3`02o`X00_l600;o0P02o`T00_l700;o2002o`<00_l200;o1`02oah0
000J00;o3P02o`h00_lM00?o0P02o`T00_l200;o0P03o`800_l600;o0P02o`L00_l300?o2@04o`L0
0_l200?o0P02o`@00_l300;o00<0ool00`02o`T00_l400;o1P02o`800_l900;o0P02o`800ol200;o
1002o`800_l700;o2@02o`<00_l500;o1`02o`800_l500;o1P02o`H00_l300;o00<0ool01@02o`H0
0_l700;o2P02o`D00_l500Oo2P02o`X00_l600;o0P02o`T00_l700;o2002o`800ol200;o1`02oah0
000J00;o3P02o`h00_lH00Oo0`02o`T00_l200;o0P000ol0o`0200;o1@03o`800ol600Oo2P04o`L0
0_l20003o`3o00800_l400;o0P03o`030?oo00<00_l900;o1002o`X00_l900;o0P02o`8000?o0?l0
0P02o`@01_l700;o2@02o`<00_l500;o1P03o`800ol<00;o1P02o`800ol00`3oo`0500;o1@03o`L0
0_l:00;o1@02o`D02Ol800?o2@02o`D00ol200;o2@02o`L00_l800;o0P000ol0o`0200;o1`02oah0
000J00;o3P02o`h00_lF00Oo1@02o`T00_l200;o00@0ool00_l00`3oo`0500;o1002o`H02Ol800?o
2002o`040?oo00;o00<0ool01002o`800_l200;o0`02o`T00_l400;o2P02o`T00_l200;o00@0ool0
0_l00`3oo`0400Ko1`02o`T00_l300Wo1P02o`@00_l<00;o1P02o`800_l200;o1@09o`P00_l:00Wo
1@02o`D00ol600Co2@09o`<00_l900;o1`02o`P00_l0103oo`02o`030?oo00L00_lN00006`02o`d0
0_l=00;o5P03o`X00_l900;o0P02o`030?oo008000Co0?oo1@02o`@00_l600;o1@03o`L01?l700;o
00<0ool00P001?l0ool400;o00<0ool00`02o`<00_l900;o1002o`X00_l900;o0P02o`030?oo0080
00Co0?oo1002o`800_l700;o2@02o`<02Ol600;o1002o``00_l600;o00<0ool00`02o`D02?l400;o
0`02o`<00_l500Wo1@02o`H00_l500Ko2008o`@00_l900;o1`02o`P00_l00`3oo`020004o`3oo`L0
0_lN00006`02o`d00_l=00;o5P02o`L000Co00000_l900;o0P02o`030?l0008000Co0?oo1002o`H0
0_l500;o1P02o`H01_l600;o00<0o`000P001?l0ool400Go0`02o`<00_l900;o1002o`X00_l900;o
0P02o`030?l0008000Co0?oo1002o`800_l200;o0`03o`P00_l300;o1@02o`D00_l600;o2`02o`H0
1Ol300;o1@02o`@00ol300;o0`02o`<00_l500;o1@02o`D00_l600;o1@02o`800_l800;o1003o`<0
0ol800;o1`02o`P00_l00`3o00020004o`3oo`L00_lN00006`03o``00_l=00;o5P02o`H00_l400;o
1`02o`<01?l300Co1002o`H00_l500;o1P02o`D00ol200?o1@04o`<01?l400Co1002o`@00_l700;o
1@02o`/00_l700;o0`04o`<01?l400;o1P02o`@00_l700;o1002o`D00_l500;o1P02o`/00_l600Co
1002o`D00_l500;o0`02o`<00_l300;o1@02o`D00_l500;o1P02o`@00ol300;o1`02o`D00_l400;o
1`02o`P00_l800Co0`04o`L00_lN00007002o``00_l<00;o5`03o`@00ol400?o1@03o`<01?l400?o
0`03o`H00ol400;o1@03o`D00_l400;o1@04o`@00ol400Co1002o`@00ol500?o1@02o`/00ol500?o
0`04o`@00ol400;o1P02o`D00_l500;o1@02o`D00_l400?o1P03o`X00_l600Co1002o`D00_l400?o
0`02o`<00_l300;o1@02o`D00_l500;o1@03o`@00_l400;o1`02o`@00ol500;o1@02o`T00_l800Co
1003o`L00_lN00007@02o`L00ol00`3oo`0;00;o6@09o`D02Ol300Co1@04o`030?oo00Co0P06o`03
0?oo00Wo1005o`801Ol200Co1@04o`801?l200Ko1009o`<02?l900Wo0`04o`D01?l00`3oo`0:o`D0
2Ol400Co0`04o`801_l200Ko100:o`801?l200Ko0P0:o`@03?l400Co0`04o`802ol300Go0P05o`<0
2_l600Wo1@0:o`<01?l500Co0P0:oaX0000N0003o`0000D01_l;0003o`0001X01Ol00`3o000600Go
1@04o`D01?l00`3oo`04o`801_l00`3oo`07o`H01Ol200Go0P04o`D01?l200?o0`06o`H01Ol500So
2`05o`D01?l500Co00<0ool02_l700Go1P04o`<01?l200Ko0P06o`@02_l200?o0`06o`802Ol500co
1004o`<01?l200Wo1@05o`801Ol300Wo2@05o`L02_l300Co1@04o`802_lJ0000:@03ool0cP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(2\\) SOMVQXMNOLOMFQIVJNBTHPYBQIMI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?oN@02o`@00onE00;o1003od@0
000L00;o6P02oe802_mh00[oU00:od<0000K00;o7002oe801Ol200;oN@05o`800_nE00Go0P02od<0
000K00;o7002oe8000?o0000O`000ol0002K0003o`0004T0000K00;o200:o`X00_lF00;o00<0ool0
0ol900Go1@05o`<01Ol700;o2`05o`H01Ol200Go0P05o`<01Ol200Ko0`02o`L01Ol500go1P05o`D0
1Ol300Go00<0ool01Ol<00Go1P0:o`T00_l900Ko1`06o`<00_l300[o1P08o`H01?l300Co0P08o`P0
2?l500[o2005o`L02_l300Go0`05o`802_lJ00006P02o`T02_l;00;o5@0:o`D02Ol300Go0`05o`H0
1?l800Wo1005o`801Ol200Go0`05o`801_l200?o1@09o`<03Ol400Wo0`05o`<01Ol00`3oo`05o`X0
2Ol400[o2004o`H02Ol600Ko0P03o`<02ol500So1P04o`<01?l200So2008o`D02ol500Wo1@0:o`<0
1Ol300Go0P0:oaX0000J00;o2P02o`D00_l;00;o5@03o`D00ol300?o1@03o`<00_l700;o1`04o`L0
0ol500?o1003o`@00ol400;o1`02o`@00_l400Co1003o`D00ol500;o1P02o`<00ol500?o0`02o`L0
0_l400;o3003o`D00ol700;o3004o`H00ol400?o1P02o`@01?l500;o1@03o`L00_l:00;o1@02o`D0
0_l?00;o2P02o`D00ol300?o1@03o`P00_l800;o1`02o`L00_lN00006P02o`/00ol@00;o5@02o`L0
0_l300;o1`02o`<00_l700;o1`04o`L00_l700;o1@03o`800ol500;o1`02o`@00_l400Co1002o`L0
0_l500;o1P02o`<00_l700;o0`02o`L00_l400;o3002o`L00_l700;o3004o`H00_l600;o1P02o`@0
1?l500;o1P02o`L00_l:00;o1@02o`D00_l?00;o2P02o`H00_l300;o1`02o`P00_l800;o1`02o`L0
0_lN00006P02o``00ol?00;o5@02o`L00_l200;o2@02o`800_l300;o0P02o`H00_l200;o1@02o`T0
0_l500;o0P02o`H00_l300;o0P02o`@00_l300Go0`02o`T00_l400;o1P02o`800_l900;o0P02o`<0
0_l200;o1002o`800_l700;o2@02o`H00_l;00;o0P02o`D00_l600;o1P02o`<01Ol500;o1P02o`L0
0_l:00;o1@02o`D00_l?00;o2P02o`H00_l200;o2@02o`L00_l800;o0`02o`800_l700;o7P0001X0
0_l=00?o3P02oad00ol200;o2@02o`800_l200?o0P02o`H00_l200;o1@02o`T00_l600Co1`02o`80
0ol200;o1002o`<00_l00`3oo`0300;o2@02o`@00_l600;o0P02o`T00_l200;o0P03o`800_l400;o
0P02o`L00_l900;o1P02o`/00_l200;o1@02o`H00_l600;o0`02o`030?oo00D00_l600;o1`02o`X0
0_l500;o1@07o`X00_l:00;o1P02o`800_l900;o1`02o`P00_l200?o0P02o`L00_lN00006P02o`h0
0ol=00;o6007o`<00_l900;o0P02o`8000?o0?l00P02o`D00ol200?o1002o`T00_l600Co1`02o`80
00?o0?l00P02o`@00_l200?o00<0ool00`02o`T00_l400;o2P02o`T00_l200;o0P000ol0o`0200;o
1006o`L00_l900;o1P02o`X00ol200?o3002o`H00_l200?o00<0ool01@02o`D00ol700;o2P02o`D0
0_l500Wo2003o`T00_l500?o0P02o`T00_l700;o2002o`8000?o0?l00P02o`L00_lN00006P02o`l0
0ol<00;o5P07o`D00_l900;o0P02o`040?oo00;o00<0ool01@02o`@00_l400;o2@02o`H00ol800;o
00@0ool00_l00`3oo`0400;o0P02o`800_l300;o2@02o`@00_l:00;o2@02o`800_l0103oo`02o`03
0?oo00@01_l700;o2@02o`H00_l:00;o1002o``00_l600;o0P02o`800_l500Wo2002o`X02Ol500;o
1@03o`H01?l900Wo0`02o`T00_l700;o2002o`040?oo00;o00<0ool01`02oah0000K00;o3`02o`/0
0_lF00?o2P02o`T00_l200;o00<0ool00P001?l0ool500;o1002o`@00_l900;o1P04o`L00_l00`3o
o`020004o`3oo`@00_l00`3oo`0300;o0`02o`T00_l400;o2P02o`T00_l200;o00<0ool00P001?l0
ool400;o0P02o`L00_l900;o1P02o`X00_l400;o3002o`H00_l00`3oo`0300;o1@08o`@00_l300;o
0`02o`D02Ol500;o1P02o`D01_l800So1002o`T00_l700;o2002o`030?oo008000Co0?oo1`02oah0
000K00;o4002o`X00_lF00;o1`001?l00002o`T00_l200;o00<0o`000P001?l0ool400;o1P02o`<0
0ol800;o1@06o`H00_l00`3o00020004o`3oo`@01Ol300;o0`02o`T00_l400;o2P02o`T00_l200;o
00<0o`000P001?l0ool400;o0P02o`800_l300?o2002o`H00_l900;o1P02o`/00_l600Go0`02o`D0
0_l400?o0`02o`<00_l300;o1@02o`D00_l500;o1P02o`D00_l200;o2002o`@00ol300?o2002o`L0
0_l800;o00<0o`000P001?l0ool700;o7P0001/00ol?00;o2P02oaH00_l600;o1002o`L00_l300Co
0`04o`@00_l600;o1002o`L00_l500?o0P03o`D01?l300Co1004o`@00_l400;o1`02o`D00_l;00;o
1`02o`<01?l300Co1002o`H00_l400;o1`02o`L00_l900;o1P02o`/00_l600Co1002o`D00_l500;o
0`02o`<00_l300;o1@02o`D00_l500;o1P02o`@00ol300;o1`02o`D00_l400;o1`02o`P00_l800Co
0`04o`L00_lN00007002o`P00_l500;o2@02oaL00ol400?o1003o`D00ol300Co1003o`<00ol600?o
1002o`D00_l600;o1002o`D01?l400?o1004o`@00_l400?o1@03o`D00_l;00?o1@03o`<01?l400?o
1002o`H00_l500;o1@02o`P00_l800?o1P03o`X00_l600Co1002o`D00_l400?o0`02o`<00_l300;o
1@02o`D00_l500;o1@03o`@00_l400;o1`02o`@00ol500;o1@02o`T00_l800Co1003o`L00_lN0000
7@02o`L00ol300?o2002oaT02Ol500Wo0`04o`D01?l00`3oo`04o`801_l300Wo1005o`801Ol200Co
1@04o`801?l200Ko1009o`<02?l900Wo0`04o`D01?l00`3oo`0:o`D02Ol400[o0`06o`801_l400[o
0P04o`801_l200[o100<o`@01?l300Co0P0;o`<01Ol200Go0`0:o`H02Ol500[o0`04o`D01?l200[o
6P0001h000?o00001P07o`T000?o00006P05o`030?l000H01Ol500Co1@04o`030?oo00Co0P06o`D0
1Ol600Go0P05o`801?l500Co0P03o`<01_l600Go1@08o`/01Ol500Co1@04o`030?oo00[o1`05o`H0
2_l300Ko0P06o`@02_l200?o0`06o`802Ol500co1004o`<01?l200Wo1@05o`801Ol300Wo2@05o`L0
2_l300Co1@04o`802_lJ0000:005ool0c@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(3\\) SOMVQXMNPLOMFQIUJNBTHPYBPIMI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?oN@02o`@00ooR00007002oaX0
0_mB00[oN00:on40000K00;o7002oe801Ol200;oN@05o`800_oQ00006`02oa`00_mB0003o`0007l0
00?o0000i`0001/00_l:00Go3@02oaH00_l00`3oo`03o`T01Ol500Go0`05o`L00_l;00Go1P05o`80
1Ol200Go0`05o`801_l300;o0`08o`H03Ol600Go1@05o`<01Ol00`3oo`05o``01Ol600[o2@04o`L0
1_l700Ko0`02o`<02_l600So1P04o`<01?l200So2008o`D02_l400So200:o`<01Ol300Go0P0:oaX0
000J00;o2@09o``00_lE00[o1@09o`<01Ol300Go1P04o`P02Ol400Go0P05o`801Ol300Go0P06o`80
0ol300So1P0=o`@02Ol300Go0`05o`030?oo00Go2P09o`@02_l700So0`09o`H01_l200?o0`0;o`D0
2?l600Co0`04o`802?l800So1@0;o`<02?l800[o0`05o`<01Ol200[o6P0001X00_l900;o1@02o``0
0_lE00?o1@03o`<00ol500?o0`02o`L00_l700Co1`03o`D00ol400?o1003o`@00_l700;o1002o`@0
1?l500;o3@02o`H00_l300?o1@03o`<00_l700;o1002o``00ol500?o1`02o`/00_l400;o0`03o`@0
0ol600;o1004o`D00_l500?o1`02o`X00_l500;o1@02o`l00_l:00;o1@03o`@00_l@00;o2002o`L0
0_l700;o7P0001X00_lA00;o2`02oaD00_l700;o0`02o`L00_l300;o1`02o`L01?l700;o1`02o`D0
0ol200?o1@02o`L00_l400;o1004o`D00_l=00;o1P02o`<00_l700;o0`02o`L00_l400;o3002o`L0
0_l700;o2P02o`H00_l200;o1P02o`H00_l400Co1@02o`H00_l700;o2P02o`D00_l500;o3`02o`X0
0_l600;o1002oa000_l800;o1`02o`L00_lN00006P02oa400_l;00;o5@02o`L00_l200;o2@02o`80
0_l300;o0P02o`H00_l200;o1@02o`T00_l500;o0P02o`H00_l300;o0P02o`@00_l300Go1@02o`d0
0_l600;o0P02o`T00_l200;o0`02o`800_l400;o0P02o`L00_l900;o1P02o`X00_l600;o0P02o`H0
0_l600;o0`05o`D00_l600;o1`02o`X00_l500;o1@02o`l00_l:00;o1P02o`@00_l@00;o2002o`<0
0_l200;o1`02oah0000J00;o4@02o`/00_lM00?o0P02o`T00_l200;o0P03o`800_l600;o0P02o`D0
0_l900;o1P04o`L00_l200?o0P02o`@00_l300;o00<0ool01@07o`P00_l600;o0P02o`T00_l200;o
0P03o`800_l400;o0P02o`L00_l900;o1P02o`X00_l600;o0P02o`H00_l600;o0`02o`030?oo00D0
0_l600;o1`02o`X00_l500;o1@07o`X00_l:00;o1P02o`@01ol;00;o2002o`800ol200;o1`02oah0
000J00;o4002o``00_lH00Oo0`02o`T00_l200;o0P000ol0o`0200;o1@03o`800ol400;o2@02o`H0
1?l700;o0P000ol0o`0200;o1002o`800ol00`3oo`0500Wo1P02o`X00_l900;o0P02o`8000?o0?l0
0P02o`@01_l700;o2@02o`H00_l:00;o1P02o`X00_l600;o0P03o`030?oo00D00_l500?o1`02o`X0
0_l500;o1@09o`P00ol900;o1@03o`@02Ol900;o2002o`8000?o0?l00P02o`L00_lN00006P02o`d0
1?l=00;o5P07o`D00_l900;o0P02o`040?oo00;o00<0ool01@02o`@00_l400;o2@02o`H00ol800;o
00@0ool00_l00`3oo`0400;o0P02o`800_l500;o1@03o`D00_l:00;o2@02o`800_l0103oo`02o`03
0?oo00@01_l700;o2@02o`H00_l:00;o1P02o`X00_l600;o0P02o`800_l500Wo2002o`X02Ol500;o
1@03o`H01?l900Wo1@02o`D00ol800;o2002o`040?oo00;o00<0ool01`02oah0000K00;o3003o`d0
0_lF00?o2P02o`T00_l200;o00<0ool00P001?l0ool500;o1002o`@00_l900;o1P04o`L00_l00`3o
o`020004o`3oo`@00_l00`3oo`0300;o1@02o`H00_l500;o2P02o`T00_l200;o00<0ool00P001?l0
ool400;o0P02o`L00_l900;o1P02o`X00_l600;o2P02o`H00_l00`3oo`0300;o1@08o`@00_l300;o
0`02o`D02Ol500;o1P02o`D01_l800So1P02o`H00_l800;o2002o`030?oo008000Co0?oo1`02oah0
000K00;o3P02o``00_lF00;o1`001?l00002o`T00_l200;o00<0o`000P001?l0ool400;o1P02o`<0
0ol800;o1@06o`H00_l00`3o00020004o`3oo`@01Ol300;o1@02o`H00_l500;o2P02o`T00_l200;o
00<0o`000P001?l0ool400;o0P02o`800_l300?o2002o`H00_l:00;o1P02o`X00_l600Go0`02o`D0
0_l400?o0`02o`<00_l300;o1@02o`D00_l500;o1P02o`D00_l200;o2002o`@00ol500;o1P02o`P0
0_l800;o00<0o`000P001?l0ool700;o7P0001/00ol>00;o2`02oaH00_l600;o1002o`L00_l300Co
0`04o`@00_l600;o1002o`L00_l500?o0P03o`D01?l300Co1004o`@00_l500;o1P02o`D00_l;00;o
1`02o`<01?l300Co1002o`H00_l400;o1`02o`L00_l:00;o1P02o`X00_l600Co1002o`D00_l500;o
0`02o`<00_l300;o1@02o`D00_l500;o1P02o`@00ol300;o1`02o`D00_l500;o1P02o`P00_l800Co
0`04o`L00_lN00007002o`h00_l:00;o5`03o`@00ol400?o1@03o`<01?l400?o0`03o`H00ol400;o
1@02o`H00_l400;o1@04o`@00ol400Co1002o`D00_l500?o1@02o`/00ol500?o0`04o`@00ol400;o
1P02o`D00_l500;o2002o`X00_l600;o2P02o`H01?l400;o1@02o`@00ol300;o0`02o`<00_l500;o
1@02o`D00_l500?o1002o`@00_l700;o1003o`D00_l500?o2002o`P01?l400?o1`02oah0000M00;o
1`02o`<00ol900;o6@09o`D02Ol300Co1@04o`030?oo00Co0P06o`<02Ol400Go0P05o`801?l500Co
0P04o`801_l200_o0`08o`T02Ol300Co1@04o`030?oo00[o1@09o`@02_l500Co1004o`@02_l200Co
0P06o`802_l400co1004o`<01?l200_o0`05o`801Ol300[o100;o`D02_l300Co1@04o`802_lJ0000
7P000ol0000500Oo2P000ol0000J00Go00<0o`001P05o`D01?l500Co00<0ool01?l200Ko1@05o`H0
1Ol200Go0P04o`D01?l200?o0`06o`802Ol500So2`05o`D01?l500Co00<0ool02_l700Go1P0:o`D0
1?l400Co100:o`800ol300Ko0P09o`D03?l400Co0`04o`802Ol500Go0P05o`<02Ol500Wo1`0:o`<0
1?l500Co0P0:oaX0000X00Coo`3>0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(4\\) SOMVQXMNPLPMFPJUINBTHPYBPIMI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?oo`1U00007002oaX00_mB00[o
o`1T00006`02oa`00_mB00Go0P02ool0I00001/00_lL00;oDP000ol0003o06X0000K00;o3006o`X0
0_lF00;o00<0ool00ol900Go1@05o`<01Ol700;o2`05o`H01Ol200Go0P05o`<01Ol200Ko0`02o`<0
2?l600go0P08o`H01Ol300Go00<0ool01Ol800So2006o``01?l600[o1006o`<00_l300[o1P08o`H0
1?l300Co0P08o`P02?l500[o1008o`P02_l300Go0`05o`802_lJ00006P02o`d01_l;00;o5@0:o`D0
2Ol300Go0`05o`H01?l800Wo1005o`801Ol200Go0`05o`801_l200?o0`08o`H03Ol200So1P05o`<0
1Ol00`3oo`05o`P02?l600Wo2@08o`@02_l400Ko0P03o`<02ol500So1P04o`<01?l200So2008o`D0
2ol300So200:o`<01Ol300Go0P0:oaX0000J00;o3`02o`d00_lE00?o1@03o`<00ol500?o0`02o`L0
0_l700Co1`03o`D00ol400?o1003o`@00_l700;o1002o`@01?l500;o3@02o`H00_l400;o2`02o`L0
0_l400;o3@02o`X00ol400?o2002o`@00_l800;o2@02o`@01?l500;o1@03o`L00_l:00;o1@02o`D0
0_l?00;o2P02o`D00ol400;o4002o`P00_l700;o1`02oah0000J00;o3`02o`d00_lE00;o1`02o`<0
0_l700;o0`02o`L00_l700Co1`02o`L00_l500?o0P03o`D00_l700;o1002o`@01?l500;o3@02o`H0
0_l400;o2`02o`L00_l400;o3@02o`X00_l600;o1`02o`H00_l700;o2@02o`@01?l500;o1P02o`L0
0_l:00;o1@02o`D00_l?00;o2P02o`H00_l400;o4002o`P00_l700;o1`02oah0000J00;o2@0:o`/0
0_lE00;o1`02o`800_l900;o0P02o`<00_l200;o1P02o`800_l500;o2@02o`D00_l200;o1P02o`<0
0_l200;o1002o`<01Ol500;o3@02o`H00_l400;o2`02o`<00_l200;o1002o`800_l900;o2P02o`H0
0_l700;o1P02o`L00_l900;o0`05o`D00_l600;o1`02o`X00_l500;o1@02o`l00_l:00;o1P02o`@0
0_l@00;o2002o`<00_l200;o1`02oah0000J00;o2@0:o`/00_lM00?o0P02o`T00_l200;o0P03o`80
0_l600;o0P02o`D00_l900;o1P04o`L00_l200?o0P02o`@00_l300;o00<0ool01@07o`P00_l600;o
1007o`H00_l200?o0P02o`@00_l200;o2@07o`D00_l600;o1`02o`H00_l700;o2@02o`<00_l00`3o
o`0500;o1P02o`L00_l:00;o1@02o`D01ol:00;o2P02o`H00_l400Oo2`02o`P00_l200?o0P02o`L0
0_lN00006P02o`T00_l400;o3@02oaP01ol300;o2@02o`800_l20003o`3o00800_l500?o0P03o`@0
0_l900;o1P04o`L00_l20003o`3o00800_l400;o0P03o`030?oo00D02Ol600;o3009o`@00_l20003
o`3o00800_l400Ko2@09o`/00_l700;o1P02o`L00_l900;o0P03o`030?oo00D00_l500?o1`02o`X0
0_l500;o1@09o`P00ol900;o1@03o`@02Ol900;o2002o`8000?o0?l00P02o`L00_lN00006P02o`X0
0_l300;o3@02oaH01ol500;o2@02o`800_l0103oo`02o`030?oo00D00_l400;o1002o`T00_l600?o
2002o`040?oo00;o00<0ool01002o`800_l200;o1@02o`D00ol500;o3002o`D00ol300;o00@0ool0
0_l00`3oo`0400Ko2@02o`D00ol:00;o1`02o`H00_l700;o2@02o`800_l200;o1@09o`P00_l:00Wo
1@02o`D00ol600Co2@09o`D00_l500?o2002o`P00_l0103oo`02o`030?oo00L00_lN00006`02o`X0
00Co00000_l<00;o5P03o`X00_l900;o0P02o`030?oo008000Co0?oo1@02o`@00_l400;o2@02o`H0
1?l700;o00<0ool00P001?l0ool400;o00<0ool00`02o`D00_l600;o1@02o``00_l600;o0`02o`03
0?oo008000Co0?oo1002o`800_l900;o1P02o`X00_l700;o1P02o`L00_l900;o00<0ool00`02o`D0
2?l400;o0`02o`<00_l500Wo1@02o`H00_l500Ko2008o`H00_l600;o2002o`P00_l00`3oo`020004
o`3oo`L00_lN00006`02o`X00_l200;o3002oaH00_l70004o`0000;o2@02o`800_l00`3o00020004
o`3oo`@00_l600;o0`03o`P00_l500Ko1P02o`030?l0008000Co0?oo1005o`<00_l500;o1P02o`D0
0_l<00;o1P02o`<00_l00`3o00020004o`3oo`@00_l200;o0P02o`D00_l600;o2P02o`L00_l600;o
1`02o`T01Ol300;o1@02o`@00ol300;o0`02o`<00_l500;o1@02o`D00_l600;o1@02o`800_l800;o
1003o`D00_l600;o2002o`P00_l00`3o00020004o`3oo`L00_lN00006`03o`X000?o00000_l<00;o
5P02o`H00_l400;o1`02o`<01?l300Co1002o`H00_l400;o1`02o`D00ol200?o1@04o`<01?l400Co
1002o`D00_l600;o1@02o``00_l600;o0`04o`<01?l400;o1P02o`D00_l600;o2P02o`L00_l600;o
1`02o`T01?l400;o1@02o`D00_l300;o0`02o`<00_l500;o1@02o`D00_l600;o1003o`<00_l700;o
1@02o`D00_l600;o2002o`P01?l300Co1`02oah0000L00;o2`001?l0ool;00;o5`03o`@00ol400?o
1@03o`<01?l400?o0`03o`H00ol400;o1@02o`H00_l400;o1@04o`@00ol400Co1002o`D00_l500?o
1@02o``00_l500?o0`04o`@00ol400;o1P02o`D00_l500?o2P02o`L00_l600;o1`02o`T01?l400;o
1@02o`@00ol300;o0`02o`<00_l500;o1@02o`D00_l500?o1002o`@00_l700;o1003o`D00_l500?o
2002o`P01?l400?o1`02oah0000M00;o2P04o`X00_lI00Wo1@09o`<01?l500Co00<0ool01?l200Ko
0`09o`@01Ol200Go0P04o`D01?l200Co0P06o`802ol300So1`0;o`<01?l500Co00<0ool02_l300_o
1P0:o`<01?l400Co0P0:o`@01?l200Ko0P0:o`@03?l400Co0`04o`802ol300Go0P05o`<02_l400_o
1@0:o`<01?l500Co0P0:oaX0000N0003o`0000T00ol:0003o`0001X01Ol00`3o000600Go1@04o`D0
1?l00`3oo`04o`801_l500Go1P05o`801Ol200Co1@04o`800ol300Ko0P09o`D02?l700Wo1@04o`D0
1?l00`3oo`0:o`<02Ol800[o0`04o`@01?l200[o1003o`<01_l200Wo1@0<o`@01?l300Co0P09o`D0
1Ol200Go0`09o`D02Ol700[o0`04o`D01?l200[o6P0002X00ooo0<d0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(5\\) SOMUQXMNQLPMFPJUINBTHPXBPIMI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?o<@02o`@00ooo02/0000L00;o
6P02oe802_l`00[oo`0Z00006`02oa`00_mB00Go0P02oc401Ol200;oo`0Z00006`02oa`00_mB0003
o`0003L000?o0000o`0`00006`02o`X01Ol=00;o5P02o`030?oo00?o2@05o`D01Ol300Go1`04o`T0
1Ol600Go0P05o`801Ol300Go0P06o`<00_l700Go1@0=o`802?l600Go0`05o`030?oo00Go2008o`P0
1_l<00Co1P0:o`@01_l300;o0`0:o`H02?l600Co0`04o`802?l600Go0P05o`<02_l400So200:o`<0
1Ol300Go0P0:oaX0000J00;o2@09o``00_lE00[o1@09o`<01Ol300Go1@08o`D02Ol400Go0P05o`80
1Ol300Go0P06o`800ol500Wo0`0=o`802?l600Go0`05o`030?oo00Go2008o`H02Ol900So100:o`@0
1_l200?o0`0;o`D02?l600Co0`04o`802?l600Go0P05o`<02ol300So200:o`<01Ol300Go0P0:oaX0
000J00;o2@02o`D00_l<00;o5@03o`D00ol300?o1@03o`<00_l700;o1P02o`@00_l400?o1@03o`@0
0ol400?o1002o`L00_l400;o1004o`@00ol500?o1@02o`H00_l400;o2`02o`L00_l400;o3@02o`X0
0ol400?o2002o`@00_l800;o2@02o`@01?l500;o1@03o`L00_l:00;o1@02o`D00_l;00?o1003o`H0
0_l500?o1002oa000_l800;o1`02o`L00_lN00006P02oa400_l;00;o5@02o`L00_l300;o1`02o`<0
0_l700;o1@02o`H00_l300;o1`02o`D00ol200?o1@02o`L00_l400;o1004o`@00_l700;o1@02o`H0
0_l400;o2`02o`L00_l400;o3@02o`X00_l600;o1`02o`H00_l700;o2@02o`@01?l500;o1P02o`L0
0_l:00;o1@02o`D00_l<00?o0P03o`L00_l600;o1002oa000_l800;o1`02o`L00_lN00006P02oa40
0_l;00;o5@02o`L00_l200;o2@02o`800_l300;o0P02o`D00_l600;o0P02o`T00_l500;o0P02o`H0
0_l300;o0P02o`@00_l300Go0`02o`T00_l400;o1P02o`@00_l;00;o0`02o`800_l400;o0P02o`T0
0_l:00;o1P02o`L00_l600;o1`02o`T00_l300Go1@02o`H00_l700;o2P02o`D00_l500;o3@02o`80
0_l800;o1P02o`@00_l@00;o2002o`<00_l200;o1`02oah0000J00;o4@02o`/00_lM00?o0P02o`T0
0_l200;o0P03o`800_l500;o1P02o`800_l900;o1P04o`L00_l200?o0P02o`@00_l300;o00<0ool0
0`02o`T00_l400;o1P02o`@01ol600;o0P03o`800_l400;o0P02o`T01ol500;o1P02o`L00_l600;o
1`02o`T00_l300;o00<0ool01@02o`H00_l700;o2P02o`D00_l500Oo2@04o`T00_l600;o1007o`/0
0_l800;o0P03o`800_l700;o7P0001X00_lA00;o2`02oaP01ol300;o2@02o`800_l20003o`3o0080
0_l500;o1P02o`800_l900;o1P04o`L00_l20003o`3o00800_l400;o0P03o`030?oo00<00_l900;o
1002o``02Ol400;o0P000ol0o`0200;o1006o`T02Ol;00;o1`02o`H00_l700;o2@02o`800ol00`3o
o`0500;o1@03o`L00_l:00;o1@02o`D02Ol700Co2@02o`D00ol400Wo2@02o`P00_l20003o`3o0080
0_l700;o7P0001X00_l:00;o1002o``00_lF00Oo1@02o`T00_l200;o00@0ool00_l00`3oo`0500;o
1P02o`800_l900;o1P03o`P00_l0103oo`02o`030?oo00@00_l200;o0P02o`<00_l900;o1002o``0
0_l500?o0`02o`040?oo00;o00<0ool01006o`T00_l500?o2P02o`L00_l600;o1`02o`T00_l200;o
0P02o`D02Ol800;o2P09o`D00_l500?o1P03o`X02Ol500;o1@03o`P00_l800;o00@0ool00_l00`3o
o`0700;o7P0001/00_l900So2`02oaH00ol:00;o2@02o`800_l00`3oo`020004o`3oo`D00_l600;o
0P02o`T00_l600Co1`02o`030?oo008000Co0?oo1002o`030?oo00<00_l300;o2@02o`@00_l<00;o
1P02o`<00_l00`3oo`020004o`3oo`@00_l200;o2@02o`H00_l:00;o1`02o`H00_l700;o2@02o`03
0?oo00<00_l500So1002o`<00_l300;o1@09o`D00_l600;o1P04o`T02?l600;o1P02o`P00_l800;o
00<0ool00P001?l0ool700;o7P0001/00_l900Oo3002oaH00_l70004o`0000;o2@02o`800_l00`3o
00020004o`3oo`D00_l600;o0P03o`P00_l500Ko1P02o`030?l0008000Co0?oo1005o`<00_l300?o
2002o`@00_l<00;o1P02o`<00_l00`3o00020004o`3oo`@00_l200;o0P02o`D00_l600;o2P02o`L0
0_l600;o1`02o`T01Ol300;o1@02o`@00ol300;o0`02o`<00_l500;o1@02o`D00_l600;o1@06o`P0
0_l400?o1@02o`H00_l800;o2002o`030?l0008000Co0?oo1`02oah0000K00?o2002oa400_lF00;o
1P02o`@00_l700;o0`04o`<01?l500;o1P02o`<00_l700;o1@03o`800ol500Co0`04o`@01?l400;o
1002o`L00_l500;o3002o`H00_l300Co0`04o`@00_l600;o1@02o`H00_l:00;o1`02o`H00_l700;o
2@04o`@00_l500;o1@02o`<00_l300;o0`02o`D00_l500;o1@02o`H00_l400?o0P03o`L00_l500;o
1@02o`H00_l800;o2004o`<01?l700;o7P0001`00_l800;o4002oaL00ol400?o1003o`D00ol300Co
1003o`D00_l600;o1002o`D00_l600;o1002o`D01?l400?o1004o`@00_l500;o1@02o`H00_l<00;o
1@03o`<01?l400?o1002o`H00_l500;o1@03o`X00_l700;o1P02o`L00_l900Co1002o`D00_l400?o
0`02o`<00_l300;o1@02o`D00_l500;o1@03o`@00_l400;o1`02o`@00ol500;o1@03o`P00_l800Co
1003o`L00_lN00007@02o`L00_l?00;o6@09o`D02Ol300Co1@04o`<01?l400Co0`09o`@01Ol200Go
0P04o`D01?l200Co0P06o`@02Ol300So1`0;o`<01?l500Co00<0ool02_l300_o1P0:o`<01?l400Co
0P0:o`@01?l200Ko0P0:o`@03?l400Co0`04o`802ol300Go0P05o`<02_l400_o1@0:o`<01?l500Co
0P0:oaX0000N0003o`0000D02?l90003o`0001X01Ol00`3o000600Go1@04o`D01?l300Co1004o`D0
1Ol600Go0P05o`801?l500Co0P03o`<01_l600Go1@08o`L02Ol500Co1@04o`030?oo00[o0`09o`P0
2_l300Co1004o`802_l400?o0`06o`802Ol500co1004o`<01?l200Wo1@05o`801Ol300Wo1@09o`L0
2_l300Co1@04o`802_lJ00009P08ool0c0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(6\\) SOMUQXMNQLPNGPJUIMBTGPXBPILI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?o<@02o`@00ooo02/0000L00;o
6P02oe802_l`00[oo`0Z00006`02oa`00_mB00Go0P02oc401Ol200;oo`0Z00006`02oa`00_mB0003
o`0003L000?o0000o`0`00006`02o`/01?l=00;o5P02o`030?oo00?o2@05o`D01Ol300Go1`04o`T0
1Ol600Go0P05o`801Ol300Go0P06o`<00_l700Go1@0=o`802?l700Ko0`02o`H01_l500So2006o``0
1?l600[o0`05o`<01Ol200[o1P08o`T01_l400So1P05o`801Ol300[o1008o`P02_l300go0P0:oaX0
000J00;o2`07o``00_lE00[o1@09o`<01Ol300Go1@08o`D02Ol400Go0P05o`801Ol300Go0P06o`80
0ol500Wo0`0=o`802?l700Ko0P03o`@02_l300So1P09o`T02?l400[o0`05o`<01Ol200_o1@08o`L0
2_l200So1P05o`801Ol300_o0`08o`P02_l300go0P0:oaX0000J00;o2P02o`@00_l<00;o5@03o`D0
0ol300?o1@03o`<00_l700;o1P02o`@00_l400?o1@03o`@00ol400?o1002o`L00_l400;o1004o`@0
0ol500?o1@02o`H00_l400;o3002o`@01?l300Co1@02o`D00_l:00?o1003o`P00_l400;o2002o`P0
0_l700;o1@02o`D00ol700;o2@04o`D00_l400;o2`03o`@00ol600;o1@03o`@00_l@00;o2P02o`H0
0_l600;o7P0001X00_l900;o1P02o`/00_lE00;o1`02o`<00_l700;o0`02o`L00_l500;o1P02o`<0
0_l700;o1@03o`800ol500;o1`02o`@00_l400Co1002o`L00_l500;o1P02o`@00_l<00;o1004o`<0
0_l700;o1@02o`X00_l600;o1`02o`H00_l700;o2002o`L00_l500;o1P02o`L00_l900;o1`02o`@0
0_l<00?o0P03o`L00_l600;o1002oa000_l:00;o1P02o`H00_lN00006P02o`T00_l600;o2`02oaD0
0_l700;o0P02o`T00_l200;o0`02o`800_l500;o1P02o`800_l900;o1@02o`800_l600;o0`02o`80
0_l400;o0`05o`<00_l900;o1002o`H00_l400;o3002o`<01Ol200?o1`02o`D00_l:00;o1P02o`L0
0_l600;o1`02o`P00_l300;o0P02o`D00_l600;o1`02o`P00ol700;o1002o`d00_l200;o2002o`H0
0_l400;o4002o`X00_l600;o1P02oah0000J00;o2@02o`H00_l;00;o7@03o`800_l900;o0P02o`80
0ol200;o1@02o`H00_l200;o2@02o`H01?l700;o0P03o`800_l400;o0`02o`030?oo00<00_l900;o
1002o`H00_l400Oo1`02o`<00_l00`3oo`0200;o1007o`@01ol500;o1P02o`L00_l600;o1`02o`P0
0_l200?o0P02o`D00_l600;o1`02o`P00_l400Oo0`07o`T01?l900;o1P02o`@01ol;00;o2P02o`H0
0_l600;o7P0001X00_l900;o1P02o`/00_lH00Oo0`02o`T00_l200;o0P000ol0o`0200;o1@02o`H0
0_l200;o2@02o`H01?l700;o0P000ol0o`0200;o1002o`800ol00`3oo`0300;o2@02o`@00_l<00Wo
1@02o`800ol00`3oo`0200;o1007o`@02Ol;00;o1`02o`H00_l700;o2002o`8000?o0?l00P02o`D0
0_l500?o1`02o`P00_l400Oo0`09o`L01?l900;o1@03o`@02Ol900;o2P02o`h00_lN00006P02o`T0
0ol400;o3002oaH01ol500;o2@02o`800_l0103oo`02o`030?oo00D00_l600;o0P02o`T00_l600?o
2002o`040?oo00;o00<0ool01002o`800_l200;o0`02o`T00_l400;o3002o`D00ol400;o0P02o`80
0_l200;o3`02o`D00ol:00;o1`02o`H00_l700;o2002o`040?oo00;o00<0ool01@09o`P00_l800;o
3P02o`D00ol600?o2P09o`D00_l500?o2002o`X00_l>00;o7P0001/00_l800Wo2`02oaH00ol:00;o
2@02o`800_l00`3oo`020004o`3oo`D00_l600;o0P02o`T00_l600Co1`02o`030?oo008000Co0?oo
1002o`030?oo00<00_l300;o2@02o`@00_l<00;o1P02o`@00_l00`3oo`0300;o0P02o`l00_l600;o
2P02o`L00_l600;o1`02o`P00_l00`3oo`020004o`3oo`D02?l400;o0`02o`<00_l300;o3P02o`H0
0_l600Co2@08o`H00_l600;o2002o`X00_l>00;o7P0001/00_l800;o00<0ool00_l=00;o5P02o`L0
00Co00000_l900;o0P02o`030?l0008000Co0?oo1@02o`H00_l200?o2002o`D01_l600;o00<0o`00
0P001?l0ool400Go0`02o`<00ol800;o1002o``00_l600;o1005o`<00_l200;o2002o`D00_l600;o
2P02o`L00_l600;o1`02o`P00_l00`3o00020004o`3oo`D00_l400?o0`02o`<00_l300;o0`02o`P0
0_l400;o1P02o`D01_l800;o1003o`D00_l600;o2002o`X00_l>00;o7P0001/00ol800;o4@02oaH0
0_l600;o1002o`L00_l300Co0`04o`D00_l600;o0`02o`L00_l500?o0P03o`D01?l300Co1004o`@0
0_l400;o1`02o`D00_l<00;o1P02o`@01?l400;o0`02o`H00ol500;o1P02o`X00_l700;o1P02o`L0
0_l800Co0`04o`D00_l500;o0`02o`<00_l300;o1002o`H00ol400;o1P02o`@00ol200?o1`02o`D0
0_l500;o1P02o`P00_l:00;o3P02oah0000L00;o2003o`l00_lG00?o1003o`@00ol500?o0`04o`@0
0ol500;o1P02o`@00_l500;o1P02o`@00_l500Co1003o`@01?l400;o1@02o`D00_l600;o3002o`D0
0ol400Co1002o`<00ol400Co1@02o`D00ol:00;o1`02o`H00_l700;o2004o`@00ol500;o1003o`<0
0_l300;o0`02o`@00ol400Co1002o`D00ol400;o1002o`L00_l400?o1@02o`D00ol800;o2P02o`h0
0_lN00007@02o`P00ol=00;o6@09o`D02Ol300Co1@04o`<01?l400Co0`09o`@01Ol200Go0P04o`D0
1?l200Co0P06o`@02Ol300So1`0;o`@01?l200Ko0`0:o`<02ol600[o0`04o`@01?l200[o0`04o`D0
1?l200[o100<o`D02_l200_o0`05o`801Ol300[o100;o`D02_l300So1`0:oaX0000N0003o`0000L0
1ol80003o`0001X01Ol00`3o000600Go1@04o`D01?l300Co1004o`D01Ol600Go0P05o`801?l500Co
0P03o`<01_l600Go1@08o`L02Ol600?o0`06o`D01Ol00`3oo`0300Wo200:o`<01?l400Co0P0:o`<0
1?l500Co0P09o`D03?l700Go00<0ool00P09o`D01Ol200Go0`09o`D02Ol700[o0`08o`L02_lJ0000
:P05ool0b`000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(7\\) SOMUQWMNQLPNGPJUIMBUGPXBOILI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oe<00_l400?o<@02o`@00ooo02/0000L00;o
6P02oe802_l`00[oo`0Z00006`02oa`00_mB00Go0P02oc401Ol200;oo`0Z00006`02oa`00_mB0003
o`0003L000?o0000o`0`00006`02o`/00_l?00;o5P02o`030?oo00?o2@05o`D01Ol300Go1`04o`T0
1Ol800;o1002o`@01Ol300Go0P06o`<00_l700Go1@0=o`802?l700Ko0`02o`H01_l500So2006o``0
1?l600[o0`05o`<01Ol200[o2@04o`X01_l400So1P05o`801Ol300[o2005o`L02_l300go0P0:oaX0
000J00;o3002oa000_lE00[o1@09o`<01Ol300Go1@08o`D02Ol600;o1002o`@01Ol300Go0P06o`80
0ol500Wo0`0=o`802?l700Ko0P03o`@02_l300So1P09o`T02?l400[o0`05o`<01Ol200_o1P08o`H0
2_l200So1P05o`801Ol300_o1@09o`D02_l300go0P0:oaX0000J00;o3@02o`l00_lE00?o1@03o`<0
0ol500?o0`02o`L00_l600;o1002o`@00ol500?o1003o`@00ol400;o1`02o`@00_l400Co1003o`D0
0ol500;o1P02o`@00_l<00;o1004o`<01?l500;o1@02o`X00ol400?o2002o`@00_l800;o2002o`L0
0_l500;o1@03o`D00_l400;o1@04o`D00_l400;o2`03o`@00ol600;o1@03o`<00ol500?o2002o`X0
0_l600;o1P02oah0000J00;o3@02o`l00_lE00;o1`02o`<00_l700;o0`02o`L00_l500;o1P02o`<0
0_l700;o1004o`<00ol400;o1`02o`@00_l400Co1002o`L00_l500;o1P02o`@00_l<00;o1004o`<0
0_l700;o1@02o`X00_l600;o1`02o`H00_l700;o2002o`L00_l500;o1P02o`@00_l600;o1002o`L0
0_l400;o3003o`800ol700;o1P02o`<00_l700;o2002o`X00_l600;o1P02oah0000J00;o3@02o`l0
0_lE00;o1`02o`800_l900;o0P02o`<00_l200;o1@02o`H00_l200;o2@02o`<01?l200Co1002o`<0
0_l200;o1002o`<01Ol300;o2@02o`@00_l600;o1002o``00_l300Go0P03o`L00_l500;o2P02o`H0
0_l700;o1P02o`L00_l800;o0`02o`800_l500;o1P02o`@00_l600;o0`03o`L00_l400;o3@02o`80
0_l800;o1P02o`800_l900;o1`02o`X00_l600;o1P02oah0000J00;o3P000ol0000=00;o7@03o`80
0_l900;o0P02o`800ol200;o1@02o`H00_l200;o2@02o`<00_l0103o0004o`@00_l200?o0P02o`@0
0_l300;o00<0ool00`02o`T00_l400;o1P02o`@01ol700;o0`02o`030?oo00800_l400Oo1007o`D0
0_l600;o1`02o`H00_l700;o2002o`800ol200;o1@02o`H00_l400;o1P02o`<00_l400Oo0`07o`T0
1?l900;o1P02o`800_l900;o1`02o`X00_l600;o1P02oah0000J00;o3P02o`h00_lH00Oo0`02o`T0
0_l200;o0P000ol0o`0200;o1@02o`H00_l200;o2@02o`<00_l01P3o003o00;o1002o`8000?o0?l0
0P02o`@00_l200?o00<0ool00`02o`T00_l400;o3009o`D00_l200?o00<0ool00P02o`@01ol400Wo
2`02o`L00_l600;o1`02o`P00_l20003o`3o00800_l500;o1@03o`@00_l600;o0`02o`@01ol300Wo
1`04o`T00_l500?o0P02o`T00_l700;o2P02o`h00_lN00006P02o`h00_l>00;o5P07o`D00_l900;o
0P02o`040?oo00;o00<0ool01@02o`H00_l200;o2@02o`<00_l00`3oo`02o`030?oo00@00_l0103o
o`02o`030?oo00@00_l200;o0P02o`<00_l900;o1002o``00_l500?o1002o`800_l200;o0P02o`l0
0_l500?o2P02o`L00_l600;o1`02o`P00_l0103oo`02o`030?oo00D02Ol500;o1P02o`<00_l>00;o
1@03o`H00ol:00Wo0`02o`T00_l700;o2P02o`h00_lN00006`02o`h000?o00002`02oaH00ol:00;o
2@02o`800_l00`3oo`020004o`3oo`D00_l600;o0P02o`T00_l300;o00<0ool00_l00`3oo`0400;o
00<0ool00P001?l0ool400;o00<0ool00`02o`<00_l900;o1002o``00_l600;o1002o`030?oo00<0
0_l200;o3`02o`H00_l:00;o1`02o`H00_l700;o2002o`030?oo008000Co0?oo1@08o`H00_l600;o
0`02o`h00_l600;o1P04o`T02?l400;o2@02o`L00_l:00;o3P02oah0000K00;o3P02o``00_lF00;o
1`001?l00002o`T00_l200;o00<0o`000P001?l0ool500;o1P02o`800ol800;o0P02o`<00_l300;o
0`02o`030?l0008000Co0?oo1005o`<00_l300?o2002o`@00_l<00;o1P02o`@01Ol300;o0P02o`P0
0_l500;o1P02o`X00_l700;o1P02o`L00_l800;o00<0o`000P001?l0ool500;o1003o`D00_l600;o
0`02o`P00_l400;o1P02o`D01_l800;o1003o`<00_l900;o1`02o`X00_l>00;o7P0001/00ol=00;o
3002oaH00_l600;o1002o`L00_l300Co0`04o`D00_l600;o0`02o`L00_l300;o0`02o`<00_l300Co
0`04o`@01?l400;o1002o`L00_l500;o3002o`H00_l400Co1002o`<00_l600?o1@02o`H00_l:00;o
1`02o`H00_l700;o2004o`<01?l500;o1@02o`D00_l600;o1002o`H00ol400;o1P02o`@00ol200?o
1`02o`D00_l400;o1`02o`P00_l:00;o3P02oah0000L00;o3P000ol0000900;o5`03o`@00ol400?o
1@03o`<01?l400?o1@02o`H00_l400;o1@02o`@00_l800;o0`04o`@00ol400Co1002o`D00_l500;o
1P02o``00_l500?o1004o`@00_l300?o1004o`D00_l500?o2P02o`L00_l600;o1`02o`P01?l400?o
1@02o`@00ol500;o1P02o`@00ol400Co1002o`D00ol400;o1002o`L00_l400?o1003o`D00ol800;o
2P02o`h00_lN00007@02o`H00_l500;o2@02oaT02Ol500Wo0`04o`D01?l300Co1004o`<02Ol300Ko
0P06o`030?oo00;o1@04o`801?l200Ko1009o`<02?l700_o1004o`801_l300[o0`0;o`H02_l300Co
1004o`802_l300Co1@04o`802_l500Co1004o`@02_l200_o0`05o`801Ol300[o1P09o`D02_l300So
1`0:oaX0000N0003o`0000@02Ol90003o`0001X01Ol00`3o000600Go1@04o`D01?l300Co1004o`D0
1Ol500Ko0P06o`030?oo00;o1@04o`800ol300Ko1P05o`D02?l700Wo1P03o`<01_l500Go00<0ool0
0`09o`P02_l300Co1004o`802_l300Co1@04o`802Ol600Co1004o`H01Ol00`3oo`0200Wo1@05o`80
1Ol300Wo2@05o`L02_l300So1`0:oaX0000U00Woo`3<0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(8\\) SOMUPVMNQLPNGPJUIMCUGPXBOILI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ohd00_l400?oo`0[00007002oaX00_n<00[o
o`0Z00006`02oa`00_n<00Go0P02ool0:P0001/00_lL00;oS0000ol0003o0300000K00;o2`04o`d0
0_lF00;o00<0ool00ol900Go1@05o`<01Ol700Co1@08o``00_l700Go0`05o`801_l300;o1`05o`D0
3Ol200So1`06o`<00_l600Ko1@08o`P01_l<00Co1P0:o`<01Ol300Go1P05o`X01?l:00Ko1008o`H0
1Ol200Go0`0:o`P01Ol700[o0`0=o`802_lJ00006P02o`X02?l<00;o5@0:o`D02Ol300Go0`05o`D0
2?l300So2`04o`H01Ol300Go0P06o`800ol500Wo0`0=o`802?l700Ko0P03o`@02_l300So1P09o`T0
2?l400[o0`05o`<01Ol400Wo1P08o`H02_l200So1P05o`801Ol300_o1@09o`D02_l300go0P0:oaX0
000J00;o2@03o`@00ol;00;o5@03o`D00ol300?o1@03o`<00_l700;o1P02o`@00_l500;o3`04o`L0
0_l700;o1002o`@01?l400?o1@03o`D00_l600;o1002o``00_l400Co0`04o`D00_l500;o2P03o`@0
0ol800;o1002o`P00_l800;o1`02o`@00ol500?o1@02o`@00_l500Co1@02o`@00_l;00?o1003o`H0
0_l500?o0`03o`D00ol800;o2P02o`H00_l600;o7P0001X00_l900;o1P02o`/00_lE00;o1`02o`<0
0_l700;o0`02o`L00_l500;o1P02o`@00_l?00Co1`02o`L00_l400;o1004o`@00_l700;o1@02o`H0
0_l400;o3002o`@01?l300;o1`02o`D00_l:00;o1P02o`L00_l600;o1`02o`P00_l700;o1002o`L0
0_l400;o1P02o`@00_l700;o1002o``00ol200?o1`02o`H00_l300;o1`02o`P00_l:00;o1P02o`H0
0_lN00006P02o`T00_l600;o2`02oaD00_l700;o0P02o`T00_l200;o0`02o`800_l500;o1P02o`@0
0_l>00;o0P02o`H00_l300;o0P02o`@00_l300Go0`02o`T00_l400;o1P02o`@00_l<00;o0`05o`80
0ol700;o1@02o`X00_l600;o1`02o`H00_l700;o2002o`<00_l200;o0`03o`d00_l600;o0`03o`L0
0_l400;o3@02o`800_l800;o1P02o`800_l900;o1`02o`X00_l600;o1P02oah0000J00;o2@02o`H0
0_l;00;o7@03o`800_l900;o0P02o`800ol200;o1@02o`H00_l400Oo2@02o`800_l600;o0P03o`80
0_l400;o0`02o`030?oo00<00_l900;o1002o`H00_l400Oo1`02o`<00_l00`3oo`0200;o1007o`@0
1ol500;o1P02o`L00_l600;o1`02o`P00_l200?o0P02o`<00_l>00;o1P02o`<00_l400Oo0`07o`T0
1?l900;o1P02o`800_l900;o1`02o`X00_l600;o1P02oah0000J00;o2P02o`@00_l<00;o6007o`<0
0_l900;o0P02o`8000?o0?l00P02o`D00_l600;o1009o`H00ol200?o1@02o`8000?o0?l00P02o`@0
0_l200?o00<0ool00`02o`T00_l400;o3009o`D00_l200?o00<0ool00P02o`@01ol400Wo2`02o`L0
0_l600;o1`02o`P00_l20003o`3o00800_l300;o3P02o`H00_l300;o1007o`<02Ol700Co2@02o`D0
0ol200;o2@02o`L00_l:00;o3P02oah0000J00;o2`07o``00_lF00Oo1@02o`T00_l200;o00@0ool0
0_l00`3oo`0500;o1P02o`@00_l500?o1@02o`@00_l500;o00@0ool00_l00`3oo`0400;o0P02o`80
0_l300;o2@02o`@00_l<00;o1@03o`@00_l200;o0P02o`800_l?00;o1@03o`X00_l700;o1P02o`L0
0_l800;o00@0ool00_l00`3oo`0300;o3P02o`H00_l300;o3P02o`D00ol600?o2P09o`<00_l900;o
1`02o`X00_l>00;o7P0001/00_l:00Ko3002oaH00ol:00;o2@02o`800_l00`3oo`020004o`3oo`D0
0_l600;o1002o`H00_l500;o1002o`D00_l00`3oo`020004o`3oo`@00_l00`3oo`0300;o0`02o`T0
0_l400;o3002o`H00_l400;o00<0ool00`02o`800_l?00;o1P02o`X00_l700;o1P02o`L00_l800;o
00<0ool00P001?l0ool300;o3P02o`H00_l300;o3P02o`H00_l600Co2@08o`@00_l900;o1`02o`X0
0_l>00;o7P0001/00_l900;o1002o`/00_lF00;o1`001?l00002o`T00_l200;o00<0o`000P001?l0
ool500;o1P02o`@00_l600;o1002o`H00_l400;o00<0o`000P001?l0ool400Go0`02o`<00ol800;o
1002o``00_l600;o1005o`<00_l200;o2002o`D00_l600;o2P02o`L00_l600;o1`02o`P00_l00`3o
00020004o`3oo`<00ol700;o1002o`H00_l300;o2002o`@00_l600;o1@06o`P00_l400?o0`02o`T0
0_l700;o2P02o`h00_lN00006`03o`L00_l600;o2P02oaH00_l600;o1002o`L00_l300Co0`04o`D0
0_l600;o1002o`H00_l400;o1P02o`@01?l300Co1004o`@00_l400;o1`02o`D00_l<00;o1P02o`@0
1?l400;o0`02o`H00ol500;o1P02o`X00_l700;o1P02o`L00_l800Co0`04o`@00_l700;o1002o`H0
0_l400;o1P03o`@00_l600;o1003o`800ol700;o1@02o`@00_l700;o2002o`X00_l>00;o7P0001`0
0_l700;o1P02o`T00_lG00?o1003o`@00ol500?o0`04o`@00ol500;o1P02o`@00_l500?o0`03o`H0
0ol300Co1003o`@01?l400;o1@02o`D00_l600;o3002o`D00ol400Co1002o`<00ol400Co1@02o`D0
0ol:00;o1`02o`H00_l700;o2004o`@00ol400?o1@03o`@00_l600;o1003o`@01?l400;o1@03o`@0
0_l400;o1`02o`@00ol400?o1@03o`P00_l:00;o3P02oah0000M00;o1P03o`@00ol800;o6@09o`D0
2Ol300Co1@04o`<01?l400Co00<0ool02Ol300Ko0P06o`030?oo00;o1@04o`801?l200Ko1009o`<0
2?l700_o1004o`801_l300[o0`0;o`H02_l300Co1004o`802_l300Co1@04o`@02_l300Co1004o`@0
2_l200_o0`05o`801Ol300[o1P09o`D02_l300So1`0:oaX0000N0003o`0000D02?l90003o`0001X0
1Ol00`3o000600Go1@04o`D01?l300Co1004o`030?oo00Oo1@06o`801_l00`3oo`02o`D01?l200?o
0`06o`H01Ol500So1`09o`H00ol300Ko1@05o`030?oo00<02Ol800[o0`04o`@01?l200[o0`04o`D0
1?l600Go00<0ool00`04o`@01?l600Go00<0ool00P09o`D01Ol200Go0`09o`T01Ol700[o0`08o`L0
2_lJ00009`06ool0c@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(9\\) SOMUPUMNQLPNGPJUIMCUGQXBOJKI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ohd00_l400?o/P02o`@00om_00007002oaX0
0_n<00[o/@0:ofh0000K00;o7002oh`01Ol200;o/P05o`800_m^00006`02oa`00_n<0003o`000;P0
00?o0000M00001/00_l800Go3`02oaH00_l00`3oo`03o`T01Ol500Go0`05o`L01?l500So3004o`D0
1Ol300Go0P06o`<00_l700Go1@0=o`802?l700Ko0`02o`H01_l500So2006o``01?l600[o0`05o`<0
1Ol600Go2P04o`X01_l800Go1@05o`801Ol300[o2005o`P01_l600Go1P02o`802_lJ00006P02o`T0
1ol>00;o5@0:o`D02Ol300Go0`05o`D02?l300So2P08o`<01Ol300Go0P06o`800ol500Wo0`0=o`80
2?l700Ko0P03o`@02_l300So1P09o`T02?l400[o0`05o`<01Ol400Wo1P08o`H02_l400Wo0`05o`80
1Ol300_o1@09o`@02Ol500Go1@03o`802_lJ00006P02o`h00ol=00;o5@03o`D00ol300?o1@03o`<0
0_l700;o1P02o`@00_l500;o3P02o`@00_l400;o1`02o`@00_l400Co1003o`D00ol500;o1P02o`@0
0_l<00;o1004o`<01?l500;o1@02o`X00ol400?o2002o`@00_l800;o2002o`L00_l400?o1@03o`D0
0_l400;o1@04o`D00_l300?o1@03o`<00ol400?o1P02o`D00ol300?o1@03o`<00ol400?o1P02o`D0
0ol700;o7P0001X00_l?00?o3002oaD00_l700;o0`02o`L00_l300;o1`02o`D00_l600;o1002o`d0
0_l600;o0`02o`L00_l400;o1004o`@00_l700;o1@02o`H00_l400;o3002o`@01?l300;o1`02o`D0
0_l:00;o1P02o`L00_l600;o1`02o`P00_l700;o1002o`L00_l400;o1P02o`@00_l700;o0`02o`L0
0_l400?o0P03o`L00_l600;o0`02o`L00_l300;o1P02o`H00_l500;o2002oah0000J00;o4002o``0
0_lE00;o1`02o`800_l900;o0P02o`<00_l200;o1@02o`H00_l400;o3@02o`H00_l300;o0`02o`80
0_l400;o0`05o`<00_l900;o1002o`H00_l400;o3002o`<01Ol200?o1`02o`D00_l:00;o1P02o`L0
0_l600;o1`02o`P00_l300;o0P02o`<00ol=00;o1P02o`<00ol700;o0P02o`T00_l400;o0P02o`P0
0_l600;o0P02o`T00_l200;o1P02o`H00_l400;o2@02oah0000J00;o3004o`030?oo00/00_lM00?o
0P02o`T00_l200;o0P03o`800_l500;o1P02o`@01ol800;o1P02o`<00_l200?o0P02o`@00_l300;o
00<0ool00`02o`T00_l400;o1P02o`@01ol700;o0`02o`030?oo00800_l400Oo1007o`D00_l600;o
1`02o`H00_l700;o2002o`800ol200;o0`02o`h00_l600;o0`02o`@01ol00`3oo`0900;o1@04o`T0
0_l600;o0P02o`T00_l200;o1P02o`H00ol200?o2@02oah0000J00;o2P09o`/00_lH00Oo0`02o`T0
0_l200;o0P000ol0o`0200;o1@02o`H00_l400Wo1P02o`H00_l300;o0P000ol0o`0200;o1002o`80
0ol00`3oo`0300;o2@02o`@00_l<00Wo1@02o`800ol00`3oo`0200;o1007o`@02Ol;00;o1`02o`H0
0_l700;o2002o`8000?o0?l00P02o`<00_l>00;o1P02o`<00_l400Oo00<0ool02@02o`D01?l900;o
1@03o`800_l900;o2P02o`H01ol:00;o7P0001X00_l:00;o1003o`/00_lF00Oo1@02o`T00_l200;o
00@0ool00_l00`3oo`0500;o1P02o`@00_l500?o1@02o`H00_l300;o00@0ool00_l00`3oo`0400;o
0P02o`800_l300;o2@02o`@00_l<00;o1@03o`@00_l200;o0P02o`800_l?00;o1@03o`X00_l700;o
1P02o`L00_l800;o00@0ool00_l00`3oo`0300;o3P02o`H00_l300;o3002o`T00_l500?o2P09o`<0
0_l900;o2P02o`H01Ol<00;o7P0001/00_l800;o1P02o`X00_lF00?o2P02o`T00_l200;o00<0ool0
0P001?l0ool500;o1P02o`@00_l600;o1@02o`H00_l300;o00<0ool00P001?l0ool400;o00<0ool0
0`02o`<00_l900;o1002o``00_l600;o1002o`030?oo00<00_l200;o3`02o`H00_l:00;o1`02o`H0
0_l700;o2002o`030?oo008000Co0?oo0`02o`h00_l600;o0`02o``00_l900;o1@04o`T02?l400;o
2@02o`X00_l600;o00@0oooo2`02oah0000K00;o2002o`H00_l:00;o5P02o`L000Co00000_l900;o
0P02o`030?l0008000Co0?oo1@02o`H00_l400;o1P02o`D00_l600;o0`02o`030?l0008000Co0?oo
1005o`<00_l300?o2002o`@00_l<00;o1P02o`@01Ol300;o0P02o`P00_l500;o1P02o`X00_l700;o
1P02o`L00_l800;o00<0o`000P001?l0ool300?o1`02o`@00_l600;o0`02o`P00_l200?o2002o`@0
1_l800;o1003o`<00_l900;o2P02o`H00_l200?o2P02oah0000K00?o1`02o`H00_l:00;o5P02o`H0
0_l400;o1`02o`<01?l300Co1@02o`H00_l400;o1P02o`D00_l600;o0`04o`<01?l400Co1002o`@0
0_l700;o1@02o``00_l600;o1004o`@00_l300;o1P03o`D00_l600;o2P02o`L00_l600;o1`02o`P0
1?l300Co1002o`L00_l400;o1P02o`@00_l600?o0`02o`L00_l400?o0P03o`L00_l500;o1002o`L0
0_l;00;o1P02o`<00ol900;o7P0001`00_l700;o1P000ol0000800;o5`03o`@00ol400?o1@03o`<0
1?l400?o1@02o`H00_l400;o1@03o`D00_l600;o0`04o`@00ol400Co1002o`D00_l500;o1P02o``0
0_l500?o1004o`@00_l300?o1004o`D00_l500?o2P02o`L00_l600;o1`02o`P01?l400?o1003o`D0
0ol400;o1P02o`@00ol400Co1002o`D00_l500;o1002o`L00_l400?o1003o`D00ol;00;o1P02o`@0
0ol800;o7P0001d00_l700;o1002o`T00_lI00Wo1@09o`<01?l500Co0`04o`@01?l00`3oo`09o`D0
1?l400Co00<0ool00_l500Co0P04o`801_l400Wo0`08o`L02ol400Co0P06o`<02_l300_o1P0:o`<0
1?l400Co0P0:o`<01?l500Co100:o`<01?l400Co100:o`@02Ol300Go0P05o`<02_l600Wo1`0:o`03
0?oo00?o0`05o`802_lJ00007P000ol0000500Oo2P000ol0000J00Go00<0o`001P05o`D01?l500Co
0`04o`@01?l00`3oo`07o`L01?l400Co00<0ool00_l500Co0P03o`<01_l600Go1@08o`L02Ol600?o
0`06o`D01Ol00`3oo`0300Wo200:o`<01?l400Co0P0:o`<01?l500Co1P05o`030?oo00<01?l400Co
1P05o`030?oo00H01Ol500Go0P05o`<02Ol900Go2@0:o`030?oo00?o0`05o`802_lJ0000:004ool0
cP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(10\\) SOMUPUMNRLQNGPJUILCUGQYBNJKI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo2004o``00_lF00;o00<0ool00ol900Go1P05o`<01Ol600Co1P08o`/0
1?l500Go0`05o`<01_l300;o0P05o`H00ol00`3oo`0;o`D01Ol600Ko0`02o`L01_l400So2@06o`/0
1?l600[o100=o`D01Ol;00Co2@06o`P01Ol800So100:o`H01_l300;o1006o`H01Ol600;o0`0:oa80
000C00;o2P09o`L01_l<00;o5@0:o`D02Ol400Go0`05o`@02?l400So2@08o`<01Ol300Go0`06o`80
0ol200Go1@04o`030?oo00_o0`09o`@01_l200?o1@0:o`802?l700Wo2008o`@02_l400go0`09o`L0
2?l500[o1009o`H02?l400_o1@06o`800ol200Wo1@05o`D00ol300[o4P0001<00_l>00;o2@03o`80
0ol;00;o5@03o`D00ol300?o1@03o`@00_l700;o1@02o`@00_l600;o3@02o`@00_l400;o1`02o`D0
0_l400Co1002o`D00ol600;o1P02o`800ol500?o1002o`@01?l400Co1@02o`@00_l;00?o1003o`L0
0_l400;o2002o`/00_l600;o0P03o`D00ol600;o1002o`@01?l500;o0`03o`D00ol800;o2@02o`D0
0ol500;o1004o`800ol400?o1P02o`D00ol800;o5P0001<00_l>00;o2@02o`@00_l;00;o5@02o`L0
0_l300;o1`02o`@00_l700;o1002o`H00_l500;o3002o`H00_l300;o1`02o`D00_l400Co1002o`D0
0_l700;o1P02o`800_l700;o1002o`@01?l400;o1`02o`@00_l;00;o1P02o`H00_l600;o1`02o`/0
0_l600;o0P02o`L00_l500;o1P02o`<00_l700;o0`02o`L00_l800;o2@02o`H00_l500;o1004o`80
0_l600;o1P02o`D00_l900;o5P0001<00_l>00;o2002o`H00_l:00;o5@02o`L00_l200;o2@02o`<0
0_l300;o0P02o`@00_l600;o1@02o``00_l600;o0`02o`<00_l200;o1@02o`<01Ol400;o1002o`P0
0_l600;o00<0ool02@02o`<00_l300Go0`03o`L00_l400;o2`02o`H00_l600;o1P02o`L00_l;00;o
1P02o`040?ooo`h00_l600;o0P03o`L00_l200;o2@02o`L00_l900;o1P02o`D00_l300Go0P02o`H0
0_l600;o1002o`X00_lF00004`02o`h00_l800;o1P02o`X00_lM00?o0P02o`T00_l300;o0P03o`80
0_l400;o1P02o`D01ol700;o1P02o`<00_l200?o0P02o`D00_l300;o00<0ool01002o`<00ol800;o
1P02o`030?oo00T00_l300;o0`02o`030?oo00<00_l400Oo0`07o`H00_l600;o1P02o`H00_l700;o
2`02o`H00_l00`3oo`0?00;o1P02o`800_l400Oo00<0ool02@02o`L00_l900;o1P02o`D00_l300;o
00<0ool00P02o`H00_l600?o0P03o`X00_lF00004`02o`h00_l800;o1P02o`X00_lH00Oo0`02o`T0
0_l300;o0P000ol0o`0200;o1002o`H00_l500Wo1@02o`H00_l300;o0P000ol0o`0200;o1@02o`80
0ol00`3oo`0400Oo2@02o`T00_l900;o0`02o`800ol00`3oo`0300;o1007o`<02Ol<00;o1P02o`H0
0_l700;o2`02o`T00_l?00;o1P02o`800_l400Oo00<0ool02@02o`L00ol800;o1@03o`D00_l200?o
00<0ool02P02o`H01ol;00;o5P0001<00_l>00;o2002o`H00_l:00;o5P07o`D00_l900;o0`02o`04
0?oo00;o00<0ool01002o`H00_l500;o1@03o`@00_l600;o0`02o`040?oo00;o00<0ool01@02o`80
0_l200;o1009o`L00_l900;o2@02o`<00_l200;o0P02o`<00_l>00;o1@03o`/00_l600;o1P02o`L0
0_l;00;o2@02o`l00_l600;o0P02o``00_l900;o1P04o`P02Ol600;o0P02o`800_l:00;o1P05o`d0
0_lF00005002o`d00_l800;o1P02o`T00_lF00?o2P02o`T00_l300;o00<0ool00P001?l0ool400;o
1P02o`D00_l600;o1002o`H00_l300;o00<0ool00P001?l0ool500;o00<0ool00`02o`@00_l500?o
1P02o`T00_l900;o0`02o`030?oo00<00_l300;o3P02o`H00_l;00;o1P02o`H00_l700;o2`02o`T0
0_l?00;o1P02o`800_l<00;o2@02o`D01_l700So1`02o`030?oo00<00_l:00;o1P02o`040?ooo``0
0_lF00005002o`d00_l800;o1P02o`T00_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0
ool400;o1P02o`D00_l600;o1002o`H00_l300;o00<0o`000P001?l0ool500Go0`02o`@00_l600;o
1P02o`T00ol800;o0`05o`<00_l300;o2002o`@00_l600;o2`02o`H00_l600;o1`02o`/00_l900?o
1`02o`D00_l600;o0P02o`P00_l200?o2002o`D00_l200;o1`02o`@00ol600Go0`02o`X00_l600;o
0P03o`/00_lF00005003o``00_l800;o1P02o`T00_lF00;o1P02o`@00_l700;o1004o`<01?l400;o
1P02o`D00_l600;o1002o`H00_l300Co0`04o`D01?l400;o1002o`H00_l600;o2P02o`L00_l400Co
1002o`@00_l600?o1002o`H00_l;00;o1P02o`H00_l700;o2`02o`X00_l700;o1@02o`H00_l300;o
1P03o`<00_l700;o1@03o`<00_l600;o1@02o`H01?l400;o2P02o`H00_l300?o2P02oaH0000E00;o
3002o`T00_l400;o2@02oaL00ol400?o1003o`D00ol400Co1003o`@00_l600;o1@02o`D00ol400;o
1P02o`<01?l400?o1@04o`@00_l400;o1@03o`H00_l;00;o1@02o`D01?l400;o1003o`@01?l400;o
1@03o`/00_l600;o1P02o`L00_l;00;o2P03o`D00ol500;o1P02o`<00ol400Co1002o`D00_l600;o
1002o`H00_l400?o1P04o`@00_l:00;o1P02o`@00ol900;o5P0001H00_l700?o00<0ool02@03o`80
0ol800;o6@09o`D02Ol400Co1@04o`801?l400Co0P0;o`@01?l400Co00<0ool00_l500Co0`04o`80
1_l00`3oo`09o`@02?l800Wo1004o`801_l400[o0P0;o`L02_l200Co1004o`802_l400So200:o`@0
1?l400Co0`0:o`@02Ol400Go0P05o`802_l600Co0P06o`@02_l00`3oo`03o`<01Ol300[o4P0001L0
00?o00001@06o`X01_l90003o`0001X01Ol00`3o000600Go1P04o`D01?l200Co1004o`802Ol600Co
1004o`030?oo00;o1@04o`<00ol300Ko00<0ool01ol600So2P05o`H00ol300Ko1P05o`030?oo0080
2Ol900[o0P04o`@01?l200[o1008o`X01Ol00`3oo`0400Co1004o`D01Ol00`3oo`0600Go1P05o`80
1Ol200Wo1`03o`<01_l400[o00<0ool00ol300Go0`0:oa80000R00?o2`04ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(11\\) SOMUPUMNRLQNGPKTILCUGQYBNJKI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo1P09o`T00_lF00;o00<0ool00ol900Go1P05o`<01Ol600Co1P08o`/0
1?l500Go0`05o`<01_l300;o0P05o`H00ol00`3oo`0;o`D01Ol600Ko0`02o`L01_l400So1`05o`H0
0_l300So1@0:o`@03Ol500Go2`04o`T01_l800Go2008o`@02_l600Ko0`02o`@01_l600Go1P02o`<0
2_lB00004`02o`X02Ol600Wo2P02oaD02_l500Wo1005o`<01Ol400So1008o`T02?l300Go0`05o`<0
1_l200?o0P05o`D01?l00`3oo`0;o`<02Ol400Ko0P03o`D02_l200So1`05o`D00ol300So1@0:o`@0
3Ol300Wo1`08o`D02_l400Wo1P08o`@02ol500Ko0P03o`802Ol500Go1@03o`<02_lB00004`02o`h0
0_l=00;o3@02oaD00ol500?o0`03o`D00ol400;o1`02o`D00_l400;o1P02o`d00_l400;o1002o`L0
0_l500;o1004o`@00_l500?o1P02o`H00_l200?o1@03o`@00_l400Co1004o`D00_l400;o3@02o`D0
0ol700;o3002o`/00_l600;o0P03o`D00ol600;o1002o`@01?l500;o0`03o`D00ol800;o2@02o`D0
0ol500;o1004o`800ol400?o1P02o`D00ol800;o5P0001<00_l>00;o3@02o`d00_lE00;o1`02o`<0
0_l700;o1002o`L00_l400;o1P02o`D00_l<00;o1P02o`<00_l700;o1@02o`@01?l400;o1@02o`L0
0_l600;o0P02o`L00_l400;o1004o`@00_l700;o1002o`d00_l500;o2002o``00_l;00;o1P02o`80
0_l700;o1@02o`H00_l300;o1`02o`<00_l700;o2002o`T00_l600;o1@02o`@01?l200;o1P02o`H0
0_l500;o2@02oaH0000C00;o3P02o`d00_l=00;o5@02o`L00_l200;o2@02o`<00_l300;o0P02o`@0
0_l600;o1@02o``00_l600;o0`02o`<00_l200;o1@02o`<01Ol400;o1002o`P00_l600;o00<0ool0
2@02o`<00_l300Go0`03o`L00_l400;o3@02o`@00_l900;o3002o`/00_l600;o00@0oooo3P02o`H0
0_l200?o1`02o`800_l900;o1`02o`T00_l600;o1@02o`<01Ol200;o1P02o`H00_l400;o2P02oaH0
000C00;o3P02o`d00_l=00;o7@03o`800_l900;o0`02o`800ol200;o1002o`H00_l500Oo1`02o`H0
0_l300;o0P03o`800_l500;o0`02o`030?oo00@00_l300?o2002o`H00_l00`3oo`0900;o0`02o`<0
0_l00`3oo`0300;o1007o`<01ol800?o0P03o`T00_l<00;o2`02o`H00_l00`3oo`0?00;o1P02o`80
0_l400Oo00<0ool02@02o`L00_l900;o1P02o`D00_l300;o00<0ool00P02o`H00_l600?o0P03o`X0
0_lF00004`02o`h00_l=00;o3@02oaP01ol300;o2@02o`<00_l20003o`3o00800_l400;o1P02o`D0
2Ol500;o1P02o`<00_l20003o`3o00800_l500;o0P03o`030?oo00@01ol900;o2@02o`T00_l300;o
0P03o`030?oo00<00_l400Oo0`09o`H01ol:00;o3002o`/00_l900;o3`02o`H00_l200;o1007o`03
0?oo00T00_l700?o2002o`D00ol500;o0P03o`030?oo00X00_l600Oo2`02oaH0000C00;o3P02o`d0
0_l=00;o5P07o`D00_l900;o0`02o`040?oo00;o00<0ool01002o`H00_l500;o1@03o`@00_l600;o
0`02o`040?oo00;o00<0ool01@02o`800_l200;o1009o`L00_l900;o2@02o`<00_l200;o0P02o`<0
0_l>00;o1@03o`D01Ol<00;o3002o`/00_l900;o3`02o`H00_l200;o3002o`T00_l600Co2009o`H0
0_l200;o0P02o`X00_l600Go3@02oaH0000D00;o3@02o`d00_l<00;o5P03o`X00_l900;o0`02o`03
0?oo008000Co0?oo1002o`H00_l500;o1P02o`@00_l600;o0`02o`030?oo008000Co0?oo1@02o`03
0?oo00<00_l400;o1@03o`H00_l900;o2@02o`<00_l00`3oo`0300;o0`02o`h00_l600;o1@02o`04
0?ooo`H00_l300;o0`02o`L00_l;00;o2@02o`l00_l600;o0P02o``00_l900;o1@06o`L02?l700;o
00<0ool00`02o`X00_l600;o00@0oooo3002oaH0000D00;o3@02o`d00_l<00;o5P02o`L000Co0000
0_l900;o0`02o`030?l0008000Co0?oo1002o`H00_l500;o1P02o`@00_l600;o0`02o`030?l00080
00Co0?oo1@05o`<00_l400;o1P02o`H00_l900?o2002o`<01Ol300;o0`02o`P00_l400;o1P02o`D0
0_l200?o1@02o`<00_l300;o1`02o`/00_l900?o1`02o`D00_l600;o0P02o`P00_l200?o2002o`D0
0_l200;o1`02o`@00ol600Go0`02o`X00_l600;o0P03o`/00_lF00005003o``00_l=00;o3002oaH0
0_l600;o1002o`L00_l400Co0`04o`@00_l600;o1@02o`H00_l400;o1P02o`<01?l300Co1@04o`@0
0_l400;o1P02o`H00_l:00;o1`02o`@01?l400;o1002o`H00ol400;o1P02o`D00_l300?o1002o`<0
0_l300;o1`02o`/00_l:00;o1`02o`D00_l600;o0`02o`H00ol300;o1`02o`D00ol300;o1P02o`D0
0_l600Co1002o`X00_l600;o0`03o`X00_lF00005@02o``00_l=00;o2`02oaL00ol400?o1003o`D0
0ol400Co1003o`@00_l600;o1@02o`D00ol400;o1P02o`<01?l400?o1@04o`@00_l400;o1@03o`H0
0_l;00;o1@02o`D01?l400;o1003o`@01?l400;o1@03o`D00_l400?o0`02o`<00_l300;o1`02o`/0
0_l:00?o1@03o`D00_l600;o0`03o`@01?l400;o1@02o`H00_l400;o1P02o`@00ol600Co1002o`X0
0_l600;o1003o`T00_lF00005P02o`L00ol00`3oo`0900?o00<0ool02P02oaT02Ol500Wo1004o`D0
1?l200Co1004o`802ol400Co1004o`030?oo00;o1@04o`<01?l200Ko00<0ool02Ol400So2009o`@0
1?l200Ko100:o`802ol400Go0`05o`030?oo00[o0`0:o`@02?l800[o1004o`@01?l300[o1009o`@0
1Ol200Go0P0:o`H01?l200Ko100:o`030?oo00?o0`05o`<02_lB00005`000ol0000500Ko2@06o`X0
00?o00006P05o`030?l000H01Ol600Co1@04o`801?l400Co0P09o`H01?l400Co00<0ool00_l500Co
0`03o`<01_l00`3oo`07o`H02?l:00Go1P03o`<01_l600Go00<0ool00P09o`H01Ol300Go00<0ool0
2_l300[o1008o`X01Ol00`3oo`0400Co1004o`D01Ol00`3oo`0600Go1P05o`801Ol200Wo1`03o`<0
1_l400[o00<0ool00ol300Go0`0:oa80000R00?o3003ool0aP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(12\\) SOMTOUMNRLQNGPKSILCUGQYBNJKI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo1@0:o`T00_lF00;o00<0ool00ol900Go1P05o`<01Ol300So2@05o`X0
1?l500Go0`05o`<01_l300;o0P05o`H00ol00`3oo`0;o`D01Ol600Ko0`02o`L01_l400So1`05o`H0
0_l200;o00<0ool00ol600[o100=o`D01Ol;00Co2@06o`P01Ol800So100:o`H01_l300;o1006o`H0
1Ol600;o0`0:oa80000C00;o2P09o`D02_l:00;o5@0:o`D02Ol400Go0`05o`<02?l700Wo1P08o`<0
1Ol300Go0`06o`800ol200Go1@04o`030?oo00_o0`09o`@01_l200?o1@0:o`802?l700Go1@03o`80
2_l400[o100=o`<02Ol700So1@0:o`@02Ol600So100;o`D01_l200?o0P09o`D01Ol500?o0`0:oa80
000C00;o3P02o`T00_l500;o2P02oaD00ol500?o0`03o`D00ol400;o1`02o`L00_l900?o1@03o`D0
0_l400;o1002o`L00_l500;o1004o`@00_l500?o1P02o`H00_l200?o1@03o`@00_l400Co1004o`D0
0_l400;o3@02o`D00ol300?o1@03o`L00_l;00;o1P02o`800ol500?o1P02o`@00_l400Co1@02o`<0
0ol500?o2002o`T00_l500?o1@02o`@01?l200?o1003o`H00_l500?o2002oaH0000C00;o3P02o`X0
0ol?00;o5@02o`L00_l300;o1`02o`@00_l700;o1`02o`T00_l700;o1002o`H00_l300;o1`02o`D0
0_l400Co1002o`D00_l700;o1P02o`800_l700;o1002o`@01?l400;o1`02o`@00_l=00;o1@02o`@0
0_l700;o1`02o`/00_l600;o0P02o`L00_l500;o1P02o`<00_l700;o0`02o`L00_l800;o2@02o`H0
0_l500;o1004o`800_l600;o1P02o`D00_l900;o5P0001<00_l>00;o2`03o`h00_lE00;o1`02o`80
0_l900;o0`02o`<00_l200;o1`02o`P00_l900;o0`02o`H00_l300;o0`02o`800_l500;o0`05o`@0
0_l400;o2002o`H00_l00`3oo`0900;o0`02o`<01Ol300?o1`02o`@00_l=00;o1002o`D00_l700;o
1`02o`/00_l600;o00@0oooo3P02o`H00_l200?o1`02o`800_l900;o1`02o`T00_l600;o1@02o`<0
1Ol200;o1P02o`H00_l400;o2P02oaH0000C00;o3P02o``00ol=00;o7@03o`800_l900;o0`02o`80
0ol200;o1`02o`P00_l900;o0`02o`H00_l300;o0P03o`800_l500;o0`02o`030?oo00@00_l300?o
2002o`H00_l00`3oo`0900;o0`02o`<00_l00`3oo`0300;o1007o`<01ol800?o0P03o`d00ol700;o
2`02o`H00_l00`3oo`0?00;o1P02o`800_l400Oo00<0ool02@02o`L00_l900;o1P02o`D00_l300;o
00<0ool00P02o`H00_l600?o0P03o`X00_lF00004`02o`h00_l=00?o3002oaP01ol300;o2@02o`<0
0_l20003o`3o00800_l700;o2002o`T00_l300;o1P02o`<00_l20003o`3o00800_l500;o0P03o`03
0?oo00@01ol900;o2@02o`T00_l300;o0P03o`030?oo00<00_l400Oo0`09o`H01ol900Oo2002o`/0
0_l900;o3`02o`H00_l200;o1007o`030?oo00T00_l700?o2002o`D00ol500;o0P03o`030?oo00X0
0_l600Oo2`02oaH0000C00;o3P02o`h00ol;00;o5P07o`D00_l900;o0`02o`040?oo00;o00<0ool0
1`02o`P00_l900;o0`02o`H00_l300;o00@0ool00_l00`3oo`0500;o0P02o`800_l400Wo1`02o`T0
0_l900;o0`02o`800_l200;o0`02o`h00_l500?o1@05o`T01ol:00;o2`02o`T00_l?00;o1P02o`80
0_l<00;o2@02o`H01?l800Wo1P02o`800_l200;o2P02o`H01Ol=00;o5P0001@00_l=00;o3`02o`X0
0_lF00?o2P02o`T00_l300;o00<0ool00P001?l0ool200;o0`02o`<00_l300;o2@02o`<00_l600;o
0`02o`030?oo008000Co0?oo1@02o`030?oo00<00_l400;o1@03o`H00_l900;o2@02o`<00_l00`3o
o`0300;o0`02o`h00_l600;o1@02o`040?ooo`L00ol?00;o2`02o`T00_l?00;o1P02o`800_l<00;o
2@02o`D01_l700So1`02o`030?oo00<00_l:00;o1P02o`040?ooo``00_lF00005002o`d00_l@00;o
2@02oaH00_l70004o`0000;o2@02o`<00_l00`3o00020004o`3oo`800_l300;o0`02o`<00_l900;o
0`02o`H00_l300;o00<0o`000P001?l0ool500Go0`02o`@00_l600;o1P02o`T00ol800;o0`05o`<0
0_l300;o2002o`@00_l600;o1@02o`800ol600;o1`000ol0000600;o2`02o`T00ol700;o1@02o`H0
0_l200;o2002o`800ol800;o1@02o`800_l700;o1003o`H01Ol300;o2P02o`H00_l200?o2`02oaH0
000D00?o3002oa000_l900;o5P02o`H00_l400;o1`02o`@01?l300Co0P02o`<00_l300;o1002o`L0
0_l400;o1P02o`<01?l300Co1@04o`@00_l400;o1P02o`H00_l:00;o1`02o`@01?l400;o1002o`H0
0ol400;o1P02o`D00_l300?o1@02o`H00_l800;o2`02o`X00_l700;o1@02o`H00_l300;o1P03o`<0
0_l700;o1@03o`<00_l600;o1@02o`H01?l400;o2P02o`H00_l300?o2P02oaH0000E00;o3002o`T0
0_l500;o2002oaL00ol400?o1003o`D00ol400Co1003o`800_l300;o0`02o`@00ol500?o1002o`H0
0_l300Co1003o`D01?l400;o1002o`D00ol600;o2`02o`D00_l500Co1002o`@00ol400Co1002o`D0
0ol500;o1003o`@00ol400?o2002o`/00_l:00?o1@03o`D00_l600;o0`03o`@01?l400;o1@02o`H0
0_l400;o1P02o`@00ol600Co1002o`X00_l600;o1003o`T00_lF00005P02o`L00ol00`3oo`0900?o
0`03o`L00_lI00Wo1@09o`@01?l500Co00<0ool02_l500Wo1004o`@01?l00`3oo`02o`D01?l300Co
0P06o`030?oo00Wo1008o`P02Ol400Co0P06o`@02_l200_o1005o`<01Ol300Wo100:o`@02?l800[o
1004o`@01?l300[o1009o`@01Ol200Go0P0:o`H01?l200Ko100:o`030?oo00?o0`05o`<02_lB0000
5`000ol0000500Ko2P07o`P000?o00006P05o`030?l000H01Ol600Co1@04o`030?oo00[o1`05o`H0
1?l400Co00<0ool00_l500Co0`03o`<01_l00`3oo`07o`H02?l:00Go1P03o`<01_l600Go00<0ool0
0P09o`H01Ol300Go1@05o`030?l000<02_l400So2P05o`030?oo00@01?l400Co1@05o`030?oo00H0
1Ol600Go0P05o`802Ol700?o0`06o`@02_l00`3oo`03o`<01Ol300[o4P0002800ol;00Goo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(13\\) SOMTOULNRLQNGQLSILCUGQYBNJKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00omZ00;o1003ofP0
000E00;o:002ojT02_lQ00[oJ@0:ofL0000D00;o:P02ojT01Ol200;o8P05o`800_mZ00Go0P02ofL0
000D00;o:P02ojT000?o0000:0000ol0001`0003o`0006d0000D00;o2@09o`L01Ol<00;o5P02o`03
0?oo00?o2@05o`H01Ol300Go0`08o`T01Ol:00Co1@0=o`<01_l300;o0P05o`H00ol00`3oo`0;o`D0
1Ol600Ko0`02o`L01_l800Go1P0=o`800_l00`3oo`03o`H02_l400go1@05o`/01?l900Ko2005o`P0
2?l400[o1P06o`<00_l400Ko1P05o`H00_l400Ko5@0001<00_l:00Wo1@09o`/00_lE00[o1@09o`@0
1Ol300Go0`08o`L02Ol600So0`0=o`<01_l200?o0P05o`D01?l00`3oo`0;o`<02Ol400Ko0P03o`D0
2_l400Wo100=o`802_l400[o100=o`<02Ol700So1@0:o`@02Ol600So100;o`D01_l200?o0P09o`D0
1Ol500?o0P09oa@0000C00;o3P02o`P00_l500;o2`02oaD00ol500?o0`03o`D00ol400;o1`02o`L0
0_l900?o1@03o`D00_l400;o1P02o`H00_l400;o1004o`@00_l500?o1P02o`H00_l200?o1@03o`@0
0_l400Co1004o`D00_l300?o1@03o`H00_l600;o0P03o`D00ol700;o2`02o`H00_l200?o1@03o`H0
0_l400;o1004o`D00_l300?o1@03o`P00_l900;o1@03o`D00_l400Co0P03o`@00ol600;o1@03o`<0
0ol400?o4`0001<00_l>00;o4002o`X00_lE00;o1`02o`<00_l700;o1002o`L00_l700;o2@02o`L0
0_l400;o1P02o`D00_l600;o1002o`@01?l400;o1@02o`L00_l600;o0P02o`L00_l400;o1004o`@0
0_l700;o0`02o`L00_l600;o1P02o`800_l700;o1`02o`/00_l600;o0P02o`L00_l500;o1P02o`<0
0_l700;o0`02o`L00_l800;o2@02o`H00_l500;o1004o`800_l600;o1P02o`D00_l400;o1P02oa<0
000C00;o3P02oa000_l:00;o5@02o`L00_l200;o2@02o`<00_l300;o0P02o`L00_l800;o2@02o`<0
0_l600;o1@02o`H00_l400;o0`05o`@00_l400;o2002o`H00_l00`3oo`0900;o0`02o`<01Ol300?o
1`02o`800_l900;o1@02o`H00_l200;o1`02o`L00_l;00;o1P02o`040?ooo`h00_l600;o0P03o`L0
0_l200;o2@02o`L00_l900;o1P02o`D00_l300Go0P02o`H00_l600;o1002o`D00_l600;o4`0001<0
0_l>00;o4002o`X00_lM00?o0P02o`T00_l300;o0P03o`800_l700;o2002o`T00_l300;o1P02o`D0
0_l600;o1002o`<00_l00`3oo`0400;o0`03o`P00_l600;o00<0ool02@02o`<00_l300;o00<0ool0
0`02o`@01ol00`3oo`0900;o1@02o`H00_l:00?o1`02o`/00_l600;o00<0ool03`02o`H00_l200;o
1007o`030?oo00T00_l700;o2@02o`H00_l500;o0`02o`030?oo00800_l600;o1P03o`800ol500;o
1P02oa<0000C00;o3P02o`l00_l;00;o6007o`<00_l900;o0`02o`8000?o0?l00P02o`L00_l800;o
2@02o`<00_l600;o1@02o``00_l200?o00<0ool01007o`T00_l900;o2@02o`<00_l200?o00<0ool0
0`02o`@01ol00`3oo`0900;o1@02o`d01ol800;o2`02o`T00_l?00;o1P02o`800_l400Oo00<0ool0
2@02o`L00ol800;o1@03o`D00_l200?o00<0ool02P02o`H01ol>00;o4`0001<00_l>00;o3004o``0
0_lF00Oo1@02o`T00_l300;o00@0ool00_l00`3oo`0700;o2002o`T00_l300;o1P02o`D00_l<00;o
0P02o`800_l400Wo1`02o`T00_l900;o0`02o`800_l200;o0`02o``00_l900;o1@02o`/01ol:00;o
2`02o`T00_l?00;o1P02o`800_l<00;o2@02o`H01?l800Wo1P02o`800_l200;o2P02o`H01Ol@00;o
4`0001@00_l=00;o3003o``00_lF00?o2P02o`T00_l300;o00<0ool00P001?l0ool200;o0`02o`<0
0_l300;o2@02o`<00_l600;o1@02o``00_l00`3oo`0300;o1002o`D00ol600;o2@02o`T00_l300;o
00<0ool00`02o`<00_l<00;o2@02o`D00_l:00?o3`02o`/00_l900;o3`02o`H00_l200;o3002o`T0
0_l500Ko1`08o`L00_l00`3oo`0300;o2P02o`H00_l0103oool?00;o4`0001@00_l=00;o3P02o`/0
0_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0ool200;o0`02o`<00_l300;o2@02o`<0
0_l600;o1@02o``01Ol300;o1002o`H00_l600;o2@03o`P00_l300Go0`02o`<00_l800;o0P03o`P0
0_l500;o2P02o`L000?o00001P02o`/00_l900?o1`02o`D00_l600;o0P02o`P00_l200?o2002o`D0
0_l200;o1`02o`@00ol600Go0`02o`X00_l600;o0P03o`h00_lC00005003o``00_l?00;o2P02oaH0
0_l600;o1002o`L00_l400Co0`04o`800_l300;o0`02o`@00_l700;o1002o`H00_l500;o3004o`@0
0_l400;o1P02o`H00_l:00;o1`02o`@01?l400;o1002o`H00ol300;o1`02o`H00_l:00;o1P02o`P0
0_l;00;o2P02o`L00_l500;o1P02o`<00_l600?o0`02o`L00_l500?o0`02o`H00_l500;o1P04o`@0
0_l:00;o1P02o`<00ol=00;o4`0001D00_l<00;o3`02o`T00_lG00?o1003o`@00ol500?o1004o`@0
0ol200;o0`02o`<00_l400?o1@03o`@00_l600;o1@02o``01?l400;o1002o`D00ol600;o2`02o`D0
0_l500Co1002o`@00ol400Co1002o`D00_l700;o2P03o`@00ol800;o2`02o`X00ol500?o1@02o`H0
0_l300?o1004o`@00_l500;o1P02o`@00_l600;o1003o`H01?l400;o2P02o`H00_l400?o3002oa<0
000F00;o1`03o`030?oo00T00_l300?o2002oaT02Ol500Wo1004o`D01?l00`3oo`0:o`D02Ol400Co
1004o`030?oo00Ko2004o`801_l00`3oo`09o`@02?l800Wo1004o`801_l400[o1009o`@02?l800Wo
100:o`@02?l800[o1004o`@01?l300[o1009o`@01Ol200Go0P0:o`H01?l200Ko100:o`030?oo00?o
0`05o`D02_l@00005`000ol0000500Ko2@07o`T000?o00006P05o`030?l000H01Ol600Co1@04o`03
0?oo00[o1`05o`H01?l400Co00<0ool01_l800?o0`06o`030?oo00Oo1P08o`X01Ol600?o0`06o`H0
1Ol00`3oo`0600Go1P08o`X01Ol00`3o000300[o1008o`X01Ol00`3oo`0400Co1004o`D01Ol00`3o
o`0600Go1P05o`801Ol200Wo1`03o`<01_l400[o00<0ool00ol300Go1@0:oa00000R00?o2`04ool0
aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(14\\) SOMTNULNRLQNGQLRILCVGQYBNJKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00omZ00;o1003ofP0
000E00;o:002ojT02_lQ00[oJ@0:ofL0000D00;o:P02ojT01Ol200;o8P05o`800_mZ00Go0P02ofL0
000D00;o:P02ojT000?o0000:0000ol0001`0003o`0006d0000D00;o2@09o`T01_l900;o5P02o`03
0?oo00?o2@05o`H01Ol300Go0`08o`H01_l300;o1`04o`D03Ol300Ko0`02o`801Ol600?o00<0ool0
2ol500Go1P06o`<00_l700Ko2005o`H03Ol00`3oo`03o`H00ol00`3oo`08o`@03Ol500Go2`02o`/0
1_l800Go2008o`@02_l600Ko0`02o`@01_l600Go1P02o`@01_lE00004`02o`X02Ol900Ko2P02oaD0
2_l500Wo1005o`<01Ol300So1P06o`800ol500So0`0=o`<01_l200?o0P05o`D01?l00`3oo`0;o`<0
2Ol400Ko0P03o`D02_l400Wo100=o`030?oo00?o1@04o`030?oo00So100=o`<02Ol800Co200:o`@0
2Ol600So100;o`D01_l200?o0P09o`D01Ol500?o0P09oa@0000C00;o3P02o`h00_l<00;o5@03o`D0
0ol300?o1@03o`@00_l700;o1`02o`X00_l400Co1@02o`@00_l600;o1P02o`@00_l400Co1002o`D0
0ol600;o1P02o`800ol500?o1002o`@01?l400Co1@02o`<00ol500?o1P02o`H00_l300;o1@03o`L0
0_l;00;o1P02o`800ol500?o1`04o`L01?l500;o0`03o`D00ol800;o2@02o`D00ol500;o1004o`80
0ol400?o1P02o`D00ol300?o1003oa<0000C00;o3P02o`h00_l<00;o5@02o`L00_l300;o1`02o`@0
0_l700;o1`02o`X00_l400Co1002o`H00_l500;o1P02o`@00_l400Co1002o`D00_l700;o1P02o`80
0_l700;o1002o`@01?l400;o1`02o`<00_l700;o1P02o`H00_l300;o1@02o`P00_l;00;o1P02o`80
0_l700;o1`04o`L00_l700;o0`02o`L00_l800;o2@02o`H00_l500;o1004o`800_l600;o1P02o`D0
0_l400;o1P02oa<0000C00;o3P02o`P02_l:00;o5@02o`L00_l200;o2@02o`<00_l300;o0P02o`L0
0_l:00;o0`05o`@00_l600;o1@02o`H00_l400;o0`05o`@00_l400;o2002o`H00_l00`3oo`0900;o
0`02o`<01Ol300?o1`02o`800_l900;o1@02o`H00_l300;o1002o`T00_l;00;o1P02o`040?ooo`l0
0_l200;o1@03o`L00_l200;o2@02o`L00_l900;o1P02o`D00_l300Go0P02o`H00_l600;o1002o`D0
0_l600;o4`0001<00_l>00;o200:o`X00_lM00?o0P02o`T00_l300;o0P03o`800_l700;o2P02o`<0
0_l00`3oo`0400;o1P02o`D00_l600;o1002o`<00_l00`3oo`0400;o0`03o`P00_l600;o00<0ool0
2@02o`<00_l300;o00<0ool00`02o`@01ol00`3oo`0900;o1@02o`H00_l300;o0`03o`T00_l;00;o
1P02o`030?oo01000_l200;o1@02o`@01ol00`3oo`0900;o1`02o`T00_l600;o1@02o`<00_l00`3o
o`0200;o1P02o`H00ol200?o1@02o`H00_lC00004`02o`h00_l800;o1002o``00_lH00Oo0`02o`T0
0_l300;o0P000ol0o`0200;o1`02o`X00_l200?o00<0ool01002o`H00_l500;o3002o`800ol00`3o
o`0400Oo2@02o`T00_l900;o0`02o`800ol00`3oo`0300;o1007o`030?oo00T00_l500;o2`07o`X0
0_l;00;o2@02o`l00ol200?o1002o`@01ol00`3oo`0900;o1`03o`P00_l500?o1@02o`800ol00`3o
o`0:00;o1P07o`h00_lC00004`02o`h00_l900;o0`02o``00_lF00Oo1@02o`T00_l300;o00@0ool0
0_l00`3oo`0700;o2P02o`800_l200;o1002o`H00_l500;o3002o`800_l200;o1009o`L00_l900;o
2@02o`<00_l200;o0P02o`<00_l<00;o2@02o`D00_l;00Wo2002o`/00_l900;o3`02o`@00_l400;o
3002o`T00_l600Co2009o`H00_l200;o0P02o`X00_l600Go4002oa<0000D00;o3@02o`X000Co0000
0_l;00;o5P03o`X00_l900;o0`02o`030?oo008000Co0?oo0P02o`<00_l300;o1@02o`030?oo00<0
0_l400;o1P02o`D00_l<00;o00<0ool00`02o`@00_l500?o1P02o`T00_l900;o0`02o`030?oo00<0
0_l300;o3002o`T00_l500;o2`02o`D00ol700;o2`02o`T00_l?00;o1002o`@00_l<00;o2@02o`D0
1_l700So1`02o`030?oo00<00_l:00;o1P02o`040?ooo`l00_lC00005002o`d00_l:00;o0P02o`/0
0_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0ool200;o0`02o`<00_l500Go0`02o`@0
0_l600;o1@02o``01Ol300;o1002o`H00_l600;o2@03o`P00_l300Go0`02o`<00_l800;o0P03o`P0
0_l500;o2`02o`H00_l700;o2`02o`T00ol700;o1002o`H00_l300;o2002o`800ol800;o1@02o`80
0_l700;o1003o`H01Ol300;o2P02o`H00_l200?o3P02oa<0000D00?o3002o`/000?o00000_l;00;o
5P02o`H00_l400;o1`02o`@01?l300Co0P02o`<00_l300;o1@04o`@00_l400;o1P02o`D00_l<00Co
1002o`@00_l600;o1P02o`X00_l700;o1004o`@00_l400;o1P03o`<00_l700;o1P02o`/00_l600;o
1`02o`/00_l:00;o1`02o`@00_l600;o1002o`H00ol300;o1`02o`D00ol300;o1P02o`D00_l600Co
1002o`X00_l600;o0`03o`d00_lC00005@02o``00_l<0004o`3oo`X00_lG00?o1003o`@00ol500?o
1004o`@00ol200;o0`02o`<00_l500Co1002o`@00_l600;o1@02o``01?l400;o1002o`D00ol600;o
2`02o`D00_l500Co1002o`@00ol400Co1002o`D00_l700;o2`02o`D00ol700;o2`02o`X00ol500?o
0`03o`H00ol300?o1004o`@00_l500;o1P02o`@00_l600;o1003o`H01?l400;o2P02o`H00_l400?o
3002oa<0000F00;o1`03o`030?oo00`01?l900;o6@09o`D02Ol400Co1@04o`030?oo00[o1004o`80
1_l200Co1004o`030?oo00Ko2004o`801_l00`3oo`09o`@02?l800Wo1004o`801_l400[o1009o`@0
2?l600_o100:o`@02?l800[o0P06o`801_l300[o1009o`@01Ol200Go0P0:o`H01?l200Ko100:o`03
0?oo00?o0`05o`D02_l@00005`000ol0000500Ko3@03o`T000?o00006P05o`030?l000H01Ol600Co
1@04o`030?oo00[o1003o`<01_l200Co1004o`030?oo00Ko2003o`<01_l00`3oo`07o`H02?l:00Go
1P03o`<01_l600Go00<0ool01P05o`H02?l600Wo1P0:o`@02?l:00Go00<0ool00P06o`801_l500Go
00<0ool01P05o`H01Ol200Go0P09o`L00ol300Ko100:o`030?oo00?o0`05o`D02_l@00008P03o`d0
0ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(15\\) SOMSNULNRLQOGQLRILCVGQZBNKKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00omZ00;o1003ofP0
000E00;o:002ojT02_lQ00[oJ@0:ofL0000D00;o:P02ojT01Ol200;o8P05o`800_mZ00Go0P02ofL0
000D00;o:P02ojT000?o0000:0000ol0001`0003o`0006d0000D00;o2@09o`L01Ol<00;o5P02o`03
0?oo00?o2@05o`H01Ol300Go0P02o`030?oo00?o1`06o`<00_l700Co1@0=o`<01_l300;o0P05o`H0
0ol00`3oo`0;o`D01Ol900Go2P06o`P01Ol600go00<0ool00ol600?o00<0ool02?l400go1@05o`/0
0_l;00Ko2005o`L02_l300[o1P06o`<00_l200Go1P02o`030?oo00?o1P02o`@01_lE00004`02o`X0
2Ol500Wo2`02oaD02_l500Wo1005o`<01Ol200[o1@06o`800ol500So0`0=o`<01_l200?o0P05o`D0
1?l00`3oo`0;o`<02Ol500Wo1P0:o`@02Ol400go00<0ool00ol500Co00<0ool02?l400go0`09o`P0
1?l800[o1009o`D02_l300_o1@06o`800ol200Go1@03o`030?oo00?o1@03o`802OlD00004`02o`h0
0_l800;o1@02o`/00_lE00?o1@03o`<00ol500?o1002o`L00_l300?o1@03o`D00_l400Co1@02o`@0
0_l600;o1P02o`@00_l400Co1002o`D00ol600;o1P02o`800ol500?o0`03o`D00ol400Co1@02o`<0
0ol500?o1P02o`H00_l300;o1@03o`L00_l;00;o1P02o`800ol500?o1`04o`L01?l500;o0`03o`D0
0ol500;o1@02o`D00_l500?o1@02o`@01?l400;o1@03o`@00_l500?o0`03o`@00olC00004`02o`h0
0_l@00;o2P02oaD00_l700;o0`02o`L00_l400;o1`02o`<00_l700;o1@02o`@01?l400;o1P02o`D0
0_l600;o1002o`@01?l400;o1@02o`L00_l600;o0P02o`L00_l300;o1`02o`@00_l700;o0`02o`L0
0_l600;o1P02o`<00_l500;o2002o`/00_l600;o0P02o`L00_l700Co1`02o`L00_l300;o1`02o`D0
0ol400;o1@02o`H00_l500;o1004o`@00_l500;o1@02o`D00_l400;o1P02oa<0000C00;o3P02oa00
0_l:00;o5@02o`L00_l200;o2@02o`<00_l300;o0P02o`<00_l700;o1@02o`<01Ol400;o1P02o`D0
0_l600;o1002o`<01Ol400;o1002o`P00_l600;o00<0ool02@02o`030?oo00T00_l200?o1`02o`80
0_l900;o1@02o`H00_l300;o1002o`T00_l;00;o1P02o`040?ooo`l00_l200;o1@03o`L00_l200;o
2@02o`D00ol300;o1@02o`H00_l500;o0`05o`@00_l400;o1P02o`@00_l500;o1P02oa<0000C00;o
3P02oa000_l:00;o7@03o`800_l900;o0`02o`800ol200;o2`03o`D00_l300;o00<0ool01002o`H0
0_l500;o1P02o`@00_l300;o00<0ool01002o`<00ol800;o1P02o`030?oo00T00_l00`3oo`0900;o
0P02o`@01ol00`3oo`0900;o1@02o`H00_l300;o0`03o`T00_l;00;o1P02o`030?oo01000_l200;o
1@02o`@01ol00`3oo`0900;o1P02o`<00_l500;o1P02o`D00_l300;o00<0ool01003o`800ol600?o
0P03o`D00_l600;o4`0001<00_l>00;o4002o`X00_lH00Oo0`02o`T00_l300;o0P000ol0o`0200;o
1P07o`H00_l200?o00<0ool01002o`H00_l500;o3002o`800ol00`3oo`0400Oo2@02o`T00_l900;o
00<0ool02@02o`800_l400Oo00<0ool02@02o`D00_l;00Oo2P02o`/00_l900;o3`03o`800ol400;o
1007o`030?oo00T00_l600?o2@02o`D00ol500;o0P03o`030?oo00@01ol700Oo3P02oa<0000C00;o
3P02o`T00_l400;o2`02oaH01ol500;o2@02o`<00_l0103oo`02o`030?oo00@01ol800;o0P02o`80
0_l400;o1P02o`D00_l<00;o0P02o`800_l400Wo1`02o`T00_l900;o00<0ool02@02o`800_l<00;o
2@02o`D00_l;00Wo2002o`/00_l900;o3`02o`@00_l400;o3002o`T00_l700?o2009o`H00_l200;o
0P02o`@01Ol900Go4002oa<0000D00;o3@02o`T02?l:00;o5P03o`X00_l900;o0`02o`030?oo0080
00Co0?oo0`03o`d00_l00`3oo`0300;o1002o`H00_l500;o3002o`030?oo00<00_l400;o1@03o`H0
0_l900;o2@02o`030?oo00T00_l200;o3002o`T00_l500;o2`02o`D00ol700;o2`02o`T00_l?00;o
1002o`@00_l<00;o2@02o`<00_l300;o2008o`L00_l00`3oo`0300;o1002o`040?ooo`P00_l0103o
ool?00;o4`0001@00_l=00;o2@07o`/00_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0
ool300;o1`000ol0000400Go0`02o`@00_l600;o1@02o``01Ol300;o1002o`H00_l600;o2@03o`P0
0_l00`3oo`0900;o0P02o`P00_l200?o2002o`D00_l;00;o1P02o`L00_l;00;o2@03o`L00_l400;o
1P02o`<00_l800;o0P03o`P00_l300;o0`03o`L00_l400?o1P05o`<00_l400;o0P03o`L00_l200?o
3P02oa<0000D00?o3002o`T00_l@00;o5P02o`H00_l400;o1`02o`@01?l300Co0`02o`H00_l600Co
1002o`@00_l600;o1@02o``01?l400;o1002o`H00_l600;o2P02o`L00_l300;o1`02o`@00_l600?o
0`02o`L00_l600;o2`02o`H00_l700;o2`02o`X00_l700;o1002o`H00_l400;o1P03o`<00_l700;o
1002o`@00ol600;o1@02o`H01?l400;o1002o`<00ol600;o0`03o`d00_lC00005@02o``00_l900;o
3`02oaL00ol400?o1003o`D00ol400Co1003o`<00ol400?o1P04o`@00_l400;o1P02o`D00_l<00Co
1002o`@00_l500?o1P02o`/00_l500;o1003o`D00ol400?o1004o`@00_l500;o1`02o`/00_l500?o
1`02o`/00_l:00?o1@03o`<00ol600?o0`03o`@01?l400;o1@02o`D00_l500;o1P02o`@00ol600Co
1002o`@00_l400?o1@02o`@00ol<00;o4`0001H00_l700?o00<0ool02@02o`h00_lI00Wo1@09o`@0
1?l500Co0`09o`D01?l200Ko0P04o`@01?l00`3oo`06o`P01?l200Ko00<0ool02Ol400So2009o`D0
2Ol600[o1009o`@02?l600_o100:o`@02?l800[o0P06o`801_l300[o1009o`D02_l300[o1P04o`80
1_l00`3oo`03o`<01Ol00`3oo`03o`<01Ol500[o400001L000?o00001@06o`T02?l80003o`0001X0
1Ol00`3o000600Go1P04o`D01?l500Go00<0o`001003o`<01_l200Co1004o`030?oo00Ko2003o`<0
1_l00`3oo`07o`H02?l:00Go2@05o`X01Ol00`3oo`0600Go1P08o`H02Ol600[o1008o`X01Ol00`3o
o`0200Ko0P06o`D01Ol00`3oo`0600Go1`0:o`<02Ol700?o0`06o`030?oo00?o0`05o`030?oo00?o
0`05o`D02_l@00008P03o`T02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(16\\) SOMSNULNRLQOGRLRILCVGQZBMKKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo2004o``00_lF00;o00<0ool00ol900Go1P05o`<01Ol200;o00<0ool0
0ol700Ko0`02o`L01?l500go0`06o`<00_l200Go1P03o`030?oo00_o1@05o`T01Ol:00Ko1005o`H0
0ol00`3oo`0;o`030?oo00?o1P03o`030?oo00So100=o`D01Ol;00;o2`06o`P01Ol700[o0`0:o`D0
1Ol300Go00<0ool00ol600;o00<0ool00ol600;o1006oaD0000C00;o2P09o`L01ol;00;o5@0:o`D0
2Ol400Go0`05o`802_l500Ko0P03o`D02?l300go0`06o`800ol200Go1@04o`030?oo00_o0`09o`D0
2Ol600[o0P05o`D01?l00`3oo`0;o`030?oo00?o1@04o`030?oo00So100=o`<02Ol800Co200:o`@0
2Ol500[o0`0;o`@01Ol300Go00<0ool00ol500?o00<0ool00ol500?o0P09oa@0000C00;o3P02o`T0
0_l400;o2`02oaD00ol500?o0`03o`D00ol400;o1`02o`<00ol500?o1@02o`@01?l500;o1002o`H0
0_l600;o1002o`@01?l400;o1@03o`H00_l600;o0P03o`D00ol300?o1@03o`@01?l500;o1002o`D0
0ol600;o1P02o`<00_l500?o1`02o`/00_l600;o0P03o`D00ol700Co1`04o`D00_l300?o1@03o`D0
0_l500;o1@02o`D00ol400;o1`02o`@00_l500?o1002o`D00ol300?o1003oa<0000C00;o3P02o`P0
0_l600;o2P02oaD00_l700;o0`02o`L00_l400;o1`02o`<00_l700;o1@02o`@01?l400;o1P02o`D0
0_l600;o1002o`@01?l400;o1@02o`L00_l600;o0P02o`L00_l300;o1`02o`@00_l700;o1002o`D0
0_l700;o1P02o`<00_l500;o2002o`/00_l600;o0P02o`L00_l700Co1`02o`L00_l300;o1`02o`D0
0ol400;o1@02o`H00_l400;o1`02o`@00_l500;o1@02o`D00_l400;o1P02oa<0000C00;o3P02o`P0
0_l600;o2P02oaD00_l700;o0P02o`T00_l300;o0`02o`800_l300;o1`02o`D00_l300Go1002o`H0
0_l500;o1P02o`@00_l300Go1002o`@00_l800;o1P02o`030?oo00T00_l00`3oo`0900;o0P03o`L0
0_l400;o1002o`P00_l600;o0`02o`@00_l900;o2`02o`H00_l0103oool?00;o0P02o`D00ol700;o
0P02o`T00_l500?o0`02o`D00_l600;o1002o`<00_l200;o1002o`@00_l600;o1002o`D00_l600;o
4`0001<00_l>00;o2002o`H00_l:00;o7@03o`800_l900;o0`02o`800ol200;o2`03o`D00_l300;o
00<0ool01002o`H00_l500;o1P02o`@00_l300;o00<0ool01002o`<00ol800;o1P02o`030?oo00T0
0_l00`3oo`0900;o0P02o`@01ol300;o0`03o`P00_l600;o0`02o`<00ol900;o2`02o`H00_l00`3o
o`0@00;o0P02o`D00_l400Oo00<0ool02@02o`H00_l300;o1@02o`H00_l400;o0P03o`800_l400?o
0P03o`H00ol200?o1@02o`H00_lC00004`02o`h00_l800;o1P02o`X00_lH00Oo0`02o`T00_l300;o
0P000ol0o`0200;o1P07o`H00_l200?o00<0ool01002o`H00_l500;o3002o`800ol00`3oo`0400Oo
2@02o`T00_l900;o00<0ool02@02o`800_l400Oo0`07o`T00_l;00Oo2P02o`/00_l900;o3`03o`80
0ol400;o1007o`030?oo00T00_l600?o2@02o`D00ol400;o0P000ol0o`0200;o1007o`L01ol>00;o
4`0001<00_l>00;o2003o`@00_l;00;o5P07o`D00_l900;o0`02o`040?oo00;o00<0ool01007o`P0
0_l200;o0P02o`@00_l600;o1@02o``00_l200;o0P02o`@02Ol700;o2@02o`T00_l00`3oo`0900;o
0P02o`h02Ol700;o2`09o`P00_l;00;o2@02o`l00_l400;o1002o``00_l900;o1`03o`P02Ol500;o
00@0ool00_l00`3oo`0400Go2@05oa000_lC00005002o`d00_l800Wo2P02oaH00ol:00;o2@02o`<0
0_l00`3oo`020004o`3oo`<00ol=00;o00<0ool00`02o`@00_l600;o1@02o``00_l00`3oo`0300;o
1002o`D00ol600;o2@02o`T00_l00`3oo`0900;o0P02o`h00_l500?o1P02o`/00_l500?o1`02o`/0
0_l900;o3`02o`@00_l400;o3002o`T00_l300;o0`02o`P02?l600;o00<0ool00P001?l0ool400;o
00@0oooo2002o`040?ooo`l00_lC00005002o`d00_l800;o00<0ool00_l<00;o5P02o`L000Co0000
0_l900;o0`02o`030?l0008000Co0?oo0`02o`L000?o00001005o`<00_l400;o1P02o`D00_l<00Go
0`02o`@00_l600;o1P02o`T00ol800;o00<0ool02@02o`800_l800;o1002o`H00_l600;o2`02o`H0
0_l700;o2`02o`T00ol700;o1002o`H00_l300;o2002o`800ol800;o0`02o`<00ol700;o1003o`D0
0_l00`3o00020004o`3oo`@00_l200?o1`02o`800ol>00;o4`0001@00ol<00;o2@02oa000_lF00;o
1P02o`@00_l700;o1004o`<01?l300;o1P02o`H01?l400;o1002o`H00_l500;o3004o`@00_l400;o
1P02o`H00_l:00;o1`02o`<00_l700;o1002o`H00ol400;o1P02o`H00_l;00;o1P02o`L00_l;00;o
2P02o`L00_l400;o1P02o`@00_l600?o0`02o`L00_l400;o1003o`H00_l500;o1@04o`<01?l400;o
0`03o`H00_l300?o3@02oa<0000E00;o3002o`T00ol>00;o5`03o`@00ol400?o1@03o`@01?l400?o
0`03o`@00ol600Co1002o`@00_l600;o1@02o``01?l400;o1002o`D00ol600;o2`02o`D00_l400?o
1@03o`@00ol400Co1002o`D00ol600;o2`02o`D00ol700;o2`02o`X00ol500?o0`03o`H00ol300?o
1004o`@00_l500;o1@02o`D00_l600;o1003o`D01?l400?o1002o`@00ol500;o1003o``00_lC0000
5P02o`L00ol00`3oo`0:00?o3002oaT02Ol500Wo1004o`D01?l300Wo1@04o`801_l200Co1004o`03
0?oo00Ko2004o`801_l00`3oo`09o`@02?l800Wo1@09o`H02_l200_o1008o`H02ol400[o1008o`P0
2_l200Ko0P06o`<02_l400Wo1@0:o`<02_l500Co1@04o`030?oo00?o0`05o`030?oo00?o0`05o`D0
2_l@00005`000ol0000500Ko2`07o`L000?o00006P05o`030?l000H01Ol600Co1@04o`D01Ol00`3o
000400?o0`06o`801?l400Co00<0ool01_l800?o0`06o`030?oo00Oo1P08o`X01Ol900Go2P05o`03
0?oo00802Ol600So1P09o`H02_l400So2P05o`030?oo00801_l200Ko1@05o`030?oo00H01Ol700[o
0`09o`H01?l500Co00<0ool00ol300Go00<0ool00ol300Go1@0:oa00000R00?o3@05ool0``000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(17\\) SOMRNULORLQOFRLRILCVGQZCLKKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo2002o`h00_lF00;o00<0ool00ol900Go1P05o`<01Ol00`3oo`03o`H0
0ol200Ko0`02o`L01?l500go1P05o`D01Ol600?o00<0ool02ol500Go2@05o`H01ol700Go1P03o`03
0?oo00_o00<0ool00ol600?o00<0ool02?l400go1@05o`/00_l;00Ko2005o`L02_l700Go1P0=o`03
0?oo00?o1P02o`030?oo00?o1P02o`801Ol600;o400001<00_l:00Wo2002o`l00_lE00[o1@09o`@0
1Ol300Go00<0ool00ol500Co0P06o`800ol500So0`0=o`@02Ol300Go1@04o`030?oo00_o0`09o`D0
2Ol400Oo1`05o`D01?l00`3oo`0;o`030?oo00?o1@04o`030?oo00So100=o`<02Ol800Co200:o`@0
2Ol500[o1@09o`@03Ol00`3oo`03o`D00ol00`3oo`03o`D00ol200Go1@03oa00000C00;o3P02o``0
0_l>00;o5@03o`D00ol300?o1@03o`@00_l700;o1002o`D00ol500;o1004o`D00_l400;o1P02o`H0
0_l300?o1@03o`@00_l500?o1P02o`H00_l200?o1@03o`<00ol500?o1@02o``00_l500?o1P02o`H0
0_l300;o1@03o`L00_l;00;o1P02o`800ol500?o1`04o`L01?l500;o0`03o`D00ol500;o1@02o`@0
0ol500?o1P02o`H00_l300;o1@03o`@00_l500?o1@02o`D00olA00004`02o`h00_l<00;o3P02oaD0
0_l700;o0`02o`L00_l400;o1`02o`@00_l500;o1P02o`@01?l400;o1P02o`D00_l600;o0`02o`L0
0_l400;o1@02o`L00_l600;o0P02o`L00_l300;o1`02o`D00_l<00;o1@02o`L00_l600;o0`02o`D0
0_l800;o2`02o`H00_l200;o1`02o`L01?l700;o1`02o`<00_l700;o1@03o`@00_l400;o1`02o`H0
0_l600;o0`02o`D00_l500;o1@02o`H00_l500;o4P0001<00_l>00;o3002o`h00_lE00;o1`02o`80
0_l900;o0`02o`<00_l200;o1002o`@00_l700;o0`05o`@00_l600;o1@02o`H00_l200;o2@02o`<0
0_l400;o2002o`H00_l00`3oo`0900;o00<0ool02@02o`@00_l200;o2002o`@00_l800;o1P02o`<0
0_l400;o2@02o`/00_l600;o00@0oooo3`02o`800_l500?o1`02o`800_l900;o1@03o`<00_l300?o
3`02o`H00_l300;o1002o`H00_l400;o1`02o`@00_lC00004`02o`h00_l=0003o`0000`00_lM00?o
0P02o`T00_l300;o0P03o`800_l400;o0`03o`L00_l300;o00<0ool01002o`H00_l500;o1P02o`80
0_l900;o0`02o`<00ol800;o1P02o`030?oo00T00_l00`3oo`0900;o1002o`800_l800;o0`03o`P0
0_l600;o0`02o`<00ol900;o2`02o`H00_l00`3oo`0@00;o0P02o`D00_l400Oo00<0ool02@02o`H0
0_l300;o0`02oa000_l600;o0`03o`800ol600?o0P03o`L00ol200?o4`0001<00_l>00;o3@02o`d0
0_lH00Oo0`02o`T00_l300;o0P000ol0o`0200;o1007o`P00_l200?o00<0ool01002o`H00_l500;o
2P02o`T00_l300Oo2@02o`T00_l900;o00<0ool02@02o`@01_l800Oo2@02o`/01ol:00;o2`02o`T0
0_l?00?o0P03o`@00_l400Oo00<0ool02@02o`H00ol700;o4002o`/01ol700Oo2007oa@0000C00;o
3P02o`d00_l=00;o5P07o`D00_l900;o0`02o`040?oo00;o00<0ool01009o`H00_l200;o0P02o`@0
0_l600;o1@02o`X00_l900;o0`09o`L00_l900;o2@02o`030?oo00T00_l400Ko2009o`L00_l;00Wo
2002o`/00_l900;o3`02o`@00_l400;o3002o`T00_l700?o1P02oa000_l;00Go2@05o`X01OlF0000
5002o`d00_l>0003o`0000X00_lF00?o2P02o`T00_l300;o00<0ool00P001?l0ool400;o1@03o`D0
0_l00`3oo`0300;o1002o`H00_l500;o2P02o`T00_l300;o1@03o`H00_l900;o2@02o`030?oo00T0
0_l400;o0P02o`P00_l500?o1P02o`/00_l500?o1`02o`/00_l900;o3`02o`@00_l400;o3002o`T0
0_l300;o0`02o`H00_l@00;o2`02o`040?ooo`P00_l0103oool900;o00@0oooo5@0001@00_l=00;o
3P02o`/00_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0ool400;o1P02o`D01Ol300;o
1002o`H00_l500;o2P02o`T00_l300;o1P02o`H00_l900?o2002o`030?oo00T00_l400;o0P02o`80
0_l400;o1P02o`H00_l;00;o1P02o`L00_l;00;o2@03o`L00_l400;o1P02o`<00_l800;o0P03o`P0
0_l300;o0`03o`D00ol700;o1P02o`/00_l200?o1`02o`800ol800;o0P03oa@0000D00?o3002o`h0
0_l;00;o5P02o`H00_l400;o1`02o`@01?l300Co1002o`H00_l500Co1002o`@00_l600;o1@02o`/0
0_l700;o1002o`H00_l600;o2P02o`L00_l300;o1`02o`D00_l600;o1002o`H00_l600;o2`02o`H0
0_l700;o2`02o`X00_l700;o1002o`H00_l400;o1P03o`<00_l700;o1002o`@00ol500;o1`02o`H0
0_l;00;o0`03o`H00_l300?o1`02o`<00olC00005@02o``00_l?0003o`0000P00_lG00?o1003o`@0
0ol500?o1004o`@00ol400;o1@03o`D01?l400;o1002o`H00_l500;o2`03o`D00ol400;o1@03o`H0
0_l;00;o1@02o`@00ol500?o1@02o`H00_l400;o1@03o`H00_l;00;o1@03o`L00_l;00;o2P03o`D0
0ol300?o1P03o`<00ol400Co1002o`D00_l500;o1@02o`D00ol500?o1P02o`/00_l400?o1@02o`@0
0ol600;o1003oa80000F00;o1`03o`030?oo00P00_l500;o2002oaT02Ol500Wo1004o`D01?l00`3o
o`09o`D01?l200Ko0P04o`@01?l00`3oo`06o`T02Ol300_o1008o`P02Ol500Wo100<o`802ol400So
1P0;o`@02_l400So200:o`801_l200Ko0`0:o`@02Ol500[o1@0:o`<02?l600Go0`05o`030?oo00?o
0`05o`801Ol300Go400001L000?o00001@06o`P02Ol80003o`0001X01Ol00`3o000600Go1P04o`D0
1?l00`3oo`07o`L00ol300Ko0P04o`@01?l00`3oo`06o`/01Ol500Wo1P08o`X01Ol900Go1P0<o`80
2Ol600So1P09o`H02_l400So2P05o`030?oo00801_l200Ko1@05o`030?oo00H01Ol700[o1`05o`03
0?oo00<02?l600Go0`05o`030?oo00?o0`05o`801Ol300Go400002800ol800Woo`340000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(18\\) SOMRNULORLQOFRMRILCVGQZCLKKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo2004o``00_lF00;o00<0ool00ol900Go1P05o`<01Ol00`3oo`03o`H0
0ol200Ko0`02o`L01?l500go1P05o`D01Ol600?o00<0ool02ol500Go2@05o`H01ol700Go1P03o`03
0?oo00?o0`05o`030?oo00?o1P03o`030?oo00So100=o`D01Ol;00;o2`06o`P01Ol700[o1`05o`H0
3Ol00`3oo`03o`H00_l00`3oo`03o`H00_l200Go1P02oa00000C00;o2P09o`H02?l;00;o5@0:o`D0
2Ol400Go0`05o`030?oo00?o1@04o`801_l200?o1@08o`<03Ol400Wo0`05o`D01?l00`3oo`0;o`<0
2Ol500Wo1007o`L01Ol500Co00<0ool00ol300Go00<0ool00ol500Co00<0ool02?l400go0`09o`P0
1?l800[o1009o`D02_l500Wo100=o`030?oo00?o1@03o`030?oo00?o1@03o`801Ol500?o400001<0
0_l>00;o2003o`@00ol:00;o5@03o`D00ol300?o1@03o`@00_l700;o1002o`D00ol500;o1004o`D0
0_l400;o1P02o`H00_l300?o1@03o`@00_l500?o1P02o`H00_l200?o1@03o`<00ol500?o1@02o``0
0_l500?o1002o`L00_l400;o1@03o`L00_l;00;o1P02o`800ol500?o1`04o`L01?l500;o0`03o`D0
0ol500;o1@02o`@00ol500?o1P02o`H00_l300;o1@03o`@00_l500?o1@02o`D00olA00004`02o`h0
0_l800;o1P02o`X00_lE00;o1`02o`<00_l700;o1002o`L00_l400;o1@02o`H00_l400Co1002o`H0
0_l500;o1P02o`<00_l700;o1002o`D00_l700;o1P02o`800_l700;o0`02o`L00_l500;o3002o`D0
0_l500;o1`02o`@00_l500;o2002o`/00_l600;o0P02o`L00_l700Co1`02o`L00_l300;o1`02o`D0
0ol400;o1002o`L00_l600;o1P02o`<00_l500;o1@02o`D00_l600;o1@02oa80000C00;o3P02o`P0
0_l600;o2P02oaD00_l700;o0P02o`T00_l300;o0`02o`800_l400;o1002o`L00_l300Go1002o`H0
0_l500;o1P02o`800_l900;o0`02o`@00_l800;o1P02o`030?oo00T00_l00`3oo`0900;o1002o`80
0_l800;o1002o`H00_l300;o0P02o`@00_l400;o2@02o`/00_l600;o00@0oooo3`02o`800_l500?o
1`02o`800_l900;o1@03o`<00_l300?o3`02o`H00_l300;o1002o`H00_l400;o1`02o`@00_lC0000
4`02o`h00_l800;o1P02o`X00_lM00?o0P02o`T00_l300;o0P03o`800_l400;o0`03o`L00_l300;o
00<0ool01002o`H00_l500;o1P02o`800_l900;o0`02o`<00ol800;o1P02o`030?oo00T00_l00`3o
o`0900;o1002o`800_l800;o0`03o`H00_l200?o0P02o`@00_l300?o2@02o`/00_l600;o00<0ool0
4002o`800_l500;o1007o`030?oo00T00_l600;o0`02o`<00_l@00;o1P02o`<00ol200?o1P03o`80
0ol700?o0P03oa<0000C00;o3P02o`T00_l400;o2`02oaP01ol300;o2@02o`<00_l20003o`3o0080
0_l400Oo2002o`800ol00`3oo`0400;o1P02o`D00_l:00;o2@02o`<01ol900;o2@02o`T00_l00`3o
o`0900;o1006o`P01ol700;o0P000ol0o`0200;o1007o`X00_l;00;o2@02o`l00ol200?o1002o`@0
1ol00`3oo`0900;o1P03o`L00_l@00;o2`07o`L01ol800Oo500001<00_l>00;o2P07o`/00_lF00Oo
1@02o`T00_l300;o00@0ool00_l00`3oo`0400Wo1P02o`800_l200;o1002o`H00_l500;o2P02o`T0
0_l300Wo1`02o`T00_l900;o00<0ool02@02o`@01_l800Wo1@02o`040?oo00;o00<0ool01009o`P0
0_l;00;o2@02o`l00_l400;o1002o``00_l900;o1`03o`H00_l@00;o2`05o`T01Ol:00Go5P0001@0
0_l=00;o2P06o`/00_lF00?o2P02o`T00_l300;o00<0ool00P001?l0ool400;o1@03o`D00_l00`3o
o`0300;o1002o`H00_l500;o2P02o`T00_l300;o1@03o`H00_l900;o2@02o`030?oo00T00_l400;o
0P02o`P00_l500?o1002o`030?oo008000Co0?oo1002o`D00ol700;o2`02o`T00_l?00;o1002o`@0
0_l<00;o2@02o`<00_l300;o1P02oa000_l;00;o00@0oooo2002o`040?ooo`T00_l0103ooolE0000
5002o`d00_l900;o1002o`X00_lF00;o1`001?l00002o`T00_l300;o00<0o`000P001?l0ool400;o
1P02o`D01Ol300;o1002o`H00_l500;o2P02o`T00_l300;o1P02o`H00_l900?o2002o`030?oo00T0
0_l400;o0P02o`800_l400;o1P02o`@00_l00`3o00020004o`3oo`@00_l600;o1`02o`/00_l900?o
1`02o`@00_l600;o0`02o`P00_l200?o2002o`<00_l300?o1@03o`L00_l600;o2`02o`800ol700;o
0P03o`P00_l200?o500001@00ol<00;o2002o`H00_l900;o5P02o`H00_l400;o1`02o`@01?l300Co
1002o`H00_l500Co1002o`@00_l600;o1@02o`/00_l700;o1002o`H00_l600;o2P02o`L00_l300;o
1`02o`D00_l600;o1002o`H00_l400Co0`04o`@00_l600;o1`02o`/00_l:00;o1`02o`@00_l600;o
1002o`H00ol300;o1`02o`@00_l400?o1@02o`L00_l600;o2`02o`<00ol600;o0`03o`L00_l300?o
4`0001D00_l<00;o2002o`H00_l800;o5`03o`@00ol400?o1@03o`@01?l400?o1002o`D00ol500Co
1002o`@00_l600;o1@02o`/00ol500?o1002o`D00ol600;o2`02o`D00_l400?o1@03o`D00_l600;o
1002o`D00ol400Co1003o`@00_l500?o1`02o`/00_l:00?o1@03o`<00ol600?o0`03o`@01?l400;o
1@02o`D00_l500;o1@03o`D00ol600;o2`02o`@00ol500;o1003o`H00_l400?o4P0001H00_l700?o
00<0ool02003o`@00ol700;o6@09o`D02Ol400Co1@04o`030?oo00Wo1@04o`801_l200Co1004o`03
0?oo00Ko2@09o`<02ol400So2009o`D02Ol400co0P0;o`@01?l500Co00<0ool02Ol400[o1008o`P0
2_l200Ko0P06o`<02_l400Wo1@0:o`D02_l300So1P05o`<01Ol00`3oo`03o`<01Ol200Go0`05oa00
000G0003o`0000D01_l900So20000ol0000J00Go00<0o`001P05o`H01?l500Co00<0ool01ol700?o
0`06o`801?l400Co00<0ool01_l;00Go1@09o`H02?l:00Go2@05o`H03?l200Wo1P04o`D01?l00`3o
o`07o`H02_l400So2P05o`030?oo00801_l200Ko1@05o`030?oo00H01Ol700[o1`05o`030?oo00<0
2?l600Go0`05o`030?oo00?o0`05o`801Ol300Go400002800ol:00Koo`350000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(19\\) SONRNULPRLQOFRMRILCWFQ CLKKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l900Wo1@05o`h00_lF00;o00<0ool00ol900Go1`06o`<00_l200Go1P03o`80
1_l300;o1`04o`D03Ol200So1P05o`H00ol00`3oo`0;o`D01Ol900Go1P07o`L01Ol600?o00<0ool0
0ol300Go00<0ool00ol600?o00<0ool02?l400go1@05o`P00_l400;o1007o`/01OlH00Go1P0=o`03
0?oo00?o1P02o`030?oo00?o1P02o`803Ol@00004`02o`X02Ol500Oo3@02oaD02_l500Wo1@06o`80
0ol200Go1@04o`801_l200?o1@08o`<03Ol200So1P05o`D01?l00`3oo`0;o`<02Ol500Wo1007o`L0
1Ol500Co00<0ool00ol300Go00<0ool00ol500Co00<0ool02?l400go0`09o`H00_l400;o1007o`T0
2OlD00Wo100=o`030?oo00?o1@03o`030?oo00?o1@03o`803Ol@00004`02o`h00_l=00?o3002oaD0
0ol500?o0`03o`D00ol500;o1004o`@00_l500?o1@02o`@01?l500;o1002o`H00_l600;o1002o``0
0_l500?o1P02o`H00_l200?o1@03o`<00ol500?o1@02o``00_l500?o1002o`L00_l400;o1@03o`L0
0_l;00;o1P02o`800ol500?o1003o`@00ol500;o2`03o`D00olB00?o1@03o`H00_l600;o0`02o`D0
0ol400;o1@03o`H00_l600;o400001<00_l>00;o3P03o`/00_lE00;o1`02o`<00_l700;o1@02o`@0
1?l400;o1@02o`H00_l400Co1002o`H00_l500;o1P02o`@00_l<00;o1@02o`L00_l600;o0P02o`L0
0_l300;o1`02o`D00_l<00;o1@02o`D00_l700;o1002o`D00_l800;o2`02o`H00_l200;o1`02o`@0
1?l300?o1@02o`/00_l700;o4P02o`L00_l600;o1P02o`<00_l500;o1@02o`D00_l700;o1P02oa00
000C00;o3P02o`l00_l;00;o5@02o`L00_l200;o2@02o`@00_l300Go1002o`@00_l700;o0`05o`@0
0_l600;o1@02o`H00_l400;o3002o`@00_l800;o1P02o`030?oo00T00_l00`3oo`0900;o1002o`80
0_l800;o1002o`H00_l300;o0P02o`@00_l400;o2@02o`/00_l600;o00@0oooo3@04o`801?l500;o
0P02o`H00_l900;o4003o`l00_l600;o0`02o`@00_l600;o1002o`P00_l600;o400001<00_l>00;o
2`04o`030?oo00X00_lM00?o0P02o`T00_l400;o0`02o`030?oo00@00_l300?o1`02o`<00_l00`3o
o`0400;o1P02o`D00_l600;o1007o`L00_l300?o2002o`H00_l00`3oo`0900;o00<0ool02@02o`@0
0_l200;o2002o`<00ol600;o0P03o`800_l400;o0`03o`T00_l;00;o1P02o`030?oo00h00_l0103o
0004o`D00_l200;o1P02o`T00_l@00;o4002o`H00_l300?o0P03o`H00ol200?o2002o`H00_l@0000
4`02o`h00_l900Wo2P02oaP01ol300;o2@02o`@00_l200?o00<0ool01007o`P00_l200?o00<0ool0
1002o`H00_l500;o3009o`D01ol900;o2@02o`T00_l00`3oo`0900;o1006o`P01ol700;o0P000ol0
o`0200;o1007o`X00_l;00;o2@02o`h00_l01P3o003o00;o1@06o`H00_l900;o4002oa000_l;00Oo
1`07o`T00_lH00004`02o`h00_l900;o1003o`X00_lF00Oo1@02o`T00_l400;o0P02o`800_l400Wo
1P02o`800_l200;o1002o`H00_l500;o3002o`D00ol400Wo1`02o`T00_l900;o00<0ool02@02o`@0
1_l800Wo1@02o`040?oo00;o00<0ool01009o`P00_l;00;o2@02o`h00_l00`3oo`02o`030?oo00D0
1_l600;o2@02oa000_l@00;o2`05o`T01Ol;00;o600001@00_l=00;o2002o`H00_l900;o5P03o`X0
0_l900;o1002o`030?oo00<00_l400;o1@03o`D00_l00`3oo`0300;o1002o`H00_l500;o3002o`H0
0_l400;o1@03o`H00_l900;o2@02o`030?oo00T00_l400;o0P02o`P00_l500?o1002o`030?oo0080
00Co0?oo1002o`D00ol700;o2`02o`T00_l>00;o00<0ool00_l00`3oo`0500;o0P02o`H00_l900;o
4002oa000_l;00;o00@0oooo2002o`040?ooo`X00_lH00005002o`d00_l800;o1P02o`T00_lF00;o
1`001?l00002o`T00_l400Go0`02o`@00_l600;o1@05o`<00_l400;o1P02o`D00_l<00;o1P02o`@0
0_l600;o1P02o`T00ol800;o00<0ool02@02o`@00_l200;o0P02o`@00_l600;o1002o`030?l00080
00Co0?oo1002o`H00_l700;o2`02o`T00ol700;o0`02o`<00_l300;o1002o`800_l200;o0P03o`P0
0_l@00?o1`02o`H00_l;00;o0P03o`L00_l200?o2@02oaP0000D00?o3002o`P00_l600;o2@02oaH0
0_l600;o1002o`L00_l500Co1002o`@00_l600;o1@04o`@00_l400;o1P02o`D00_l<00;o1P02o`@0
0_l600;o1P02o`X00_l700;o0`02o`L00_l500;o1P02o`@00_l600;o1004o`<01?l400;o1P02o`L0
0_l;00;o2P02o`L00_l300;o0`02o`<00_l400;o1P02o`<00_l700;o4P02o`L00_l600;o2`02o`<0
0ol600;o0`03o`P00_lH00005@02o``00_l800;o1P000ol0000700;o5`03o`@00ol400?o1@03o`D0
1?l400;o1002o`D00ol500Co1002o`@00_l600;o1@02o``00_l500?o1002o`D00ol600;o2`02o`D0
0_l400?o1@03o`D00_l600;o1002o`D00ol400Co1003o`@00_l500?o1`02o`/00_l:00?o1@03o`<0
0_l800;o1002o`H00_l400;o1@02oa<00ol500?o1P02o`/00_l400?o1@02o`@00ol700;o600001H0
0_l700?o00<0ool02@02o`@00_l800;o6@09o`D02Ol500Co0P06o`030?oo00Wo1@04o`801_l200Co
1004o`030?oo00Ko1`0;o`<02ol400So2009o`D02Ol400co0P0;o`@01?l500Co00<0ool02Ol400[o
1008o`P02_l200Ko0P06o`030?oo00[o1009oa@02_l300So1P05o`<01Ol00`3oo`03o`<01Ol200So
5@0001L000?o00001@06o`T01ol90003o`0001X01Ol00`3o000600Go1`03o`<01_l00`3oo`07o`L0
0ol300Ko0P04o`@01?l00`3oo`06o`L02Ol500Wo1P08o`X01Ol900Go1P0<o`802Ol600Co1@04o`03
0?oo00Oo1P0:o`@02?l:00Go00<0ool00P06o`801_l00`3oo`0:o`H01OlH00Go00<0ool00`08o`H0
1Ol300Go00<0ool00ol300Go0P08oaD0000R00?o2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(20\\) SONRNULPRLQOFRNRILCWFQ CLKKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oU@02o`@00omX00005@02obP0
0_nY00[oU00:ofL0000D00;o:P02ojT01Ol200;oU@05o`800_mW00005002obX00_nY0003o`0009/0
00?o0000K@0001@00_l800[o2004o``00_lF00;o00<0ool00ol900Go1`06o`<00_l200Go1P03o`80
1_l300;o1`04o`D03Ol200So1P05o`H00ol00`3oo`0;o`D01Ol900Go1P07o`L01Ol600?o0P06o`<0
0_l200Go1P03o`030?oo00So100=o`D01Ol800;o1002o`@01ol;00Go6005o`H03Ol00`3oo`03o`H0
0_l00`3oo`03o`H00_l200go400001<00_l900[o1`06o``00_lE00[o1@09o`D01_l200?o0P05o`D0
1?l200Ko0P03o`D02?l300go0P08o`H01Ol500Co00<0ool02ol300Wo1@09o`@01ol700Go1@04o`80
1_l200?o0P05o`D01?l00`3oo`08o`@03Ol300Wo1P02o`@00_l400Oo2@09oa@02Ol400go00<0ool0
0ol500?o00<0ool00ol500?o0P0=oa00000C00;o2P02o`D00_l600?o0P03o`/00_lE00?o1@03o`<0
0ol500?o1@02o`@01?l400;o1@03o`D00_l400Co1@02o`@00_l600;o1P02o`@00_l<00;o1@03o`H0
0_l600;o0P03o`D00ol300?o1@03o`D00_l<00;o1@03o`D00_l400Co1002o`D00ol700;o2`02o`H0
0_l200?o1@03o`@00ol400?o1@02o`/00ol500?o4P03o`D00ol600;o1P02o`<00_l500?o1002o`D0
0ol600;o1P02oa00000C00;o2`03o`/00_l400;o2`02oaD00_l700;o0`02o`L00_l500;o1004o`@0
0_l500;o1P02o`@01?l400;o1P02o`D00_l600;o1002o``00_l500;o1`02o`H00_l200;o1`02o`<0
0_l700;o1@02o``00_l500;o1P02o`@01?l400;o1@02o`P00_l;00;o1P02o`800_l700;o1004o`<0
0ol500;o2`02o`L00_lB00;o1`02o`H00_l600;o0`02o`D00_l500;o1@02o`L00_l600;o400001<0
0_l<00?o2@02o`H00_l:00;o5@02o`L00_l200;o2@02o`@00_l300Go1002o`@00_l700;o0`05o`@0
0_l600;o1@02o`H00_l400;o3002o`@00_l800;o1P02o`030?oo00T00_l00`3oo`0900;o1002o`80
0_l800;o1002o`L00_l300Go1002o`@00_l900;o2`02o`H00_l0103oool=00Co0P04o`D00_l200;o
1P02o`T00_l@00?o3`02o`H00_l300;o1002o`H00_l400;o2002o`H00_l@00004`02o`d00ol800;o
1P02o`X00_lM00?o0P02o`T00_l400;o0`02o`030?oo00@00_l300?o1`02o`<00_l00`3oo`0400;o
1P02o`D00_l600;o1007o`L00_l300?o2002o`H00_l00`3oo`0900;o00<0ool02@02o`@00_l200;o
2002o`<00ol700;o0`02o`030?oo00@00_l300?o2@02o`/00_l600;o00<0ool03P02o`040?l000Co
1@02o`800_l600;o2@02oa000_l@00;o1P02o`<00ol200?o1P03o`800ol800;o1P02oa00000C00;o
3P03o`L00_l600;o2P02oaP01ol300;o2@02o`@00_l200?o00<0ool01007o`P00_l200?o00<0ool0
1002o`H00_l500;o3009o`D01ol900;o2@02o`T00_l00`3oo`0900;o1006o`P01ol800;o0P03o`03
0?oo00@01ol:00;o2`02o`T00_l>00;o00H0o`00o`02o`D01_l600;o2@02oa000_l@00;o2`07o`L0
1ol900;o600001<00_l?00?o1P02o`H00_l:00;o5P07o`D00_l900;o1002o`800_l200;o1009o`H0
0_l200;o0P02o`@00_l600;o1@02o``00_l500?o1009o`L00_l900;o2@02o`030?oo00T00_l400Ko
2009o`H00_l200;o0P02o`@02Ol800;o2`02o`T00_l>00;o00<0ool00_l00`3oo`0500Ko1P02o`T0
0_l@00;o4002o`/01Ol900Go2`02oaP0000D00;o3`02o`H00_l600;o2@02oaH00ol:00;o2@02o`@0
0_l00`3oo`0300;o1002o`D00ol500;o00<0ool00`02o`@00_l600;o1@02o``00_l600;o1002o`D0
0ol600;o2@02o`T00_l00`3oo`0900;o1002o`800_l800;o1@03o`D00_l00`3oo`0300;o1002o`D0
0ol700;o2`02o`T00_l>00;o00<0ool00_l00`3oo`0500;o0P02o`H00_l900;o4002oa000_l;00;o
00@0oooo2002o`040?ooo`X00_lH00005002oa000_l500;o1P02o`T00_lF00;o1`001?l00002o`T0
0_l400Go0`02o`@00_l600;o1@05o`<00_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1P02o`T0
0ol800;o00<0ool02@02o`@00_l200;o0P02o`@00_l600;o1@05o`<00_l400;o1P02o`L00_l;00;o
2@03o`L00_l300;o0`02o`<00_l400;o0P02o`800_l200?o2002oa000ol700;o1P02o`/00_l200?o
1`02o`800ol900;o600001@00ol?00;o1@02o`H00_l900;o5P02o`H00_l400;o1`02o`D01?l400;o
1002o`H00_l500Co1002o`@00_l600;o1@02o``00_l600;o1002o`H00_l600;o2P02o`L00_l300;o
1`02o`D00_l600;o1002o`H00_l500Co1002o`@00_l600;o1`02o`/00_l:00;o1`02o`<00_l300;o
0`02o`@00_l600;o0`02o`L00_lB00;o1`02o`H00_l;00;o0`03o`H00_l300?o2002oaP0000E00;o
2002o`D00_l600;o1002o`T00_lG00?o1003o`@00ol500?o1@04o`@00_l400;o1@03o`D01?l400;o
1002o`H00_l500;o3002o`D00ol400;o1@03o`H00_l;00;o1@02o`@00ol500?o1@02o`H00_l400;o
1@03o`D01?l400;o1002o`D00ol700;o2`02o`X00ol500?o0`02o`P00_l400;o1P02o`@00_l500;o
4`03o`D00ol600;o2`02o`@00ol500;o1003o`L00_lH00005P02o`L00ol300?o1P03o`800ol800;o
6@09o`D02Ol500Co0P06o`030?oo00Wo1@04o`801_l200Co1004o`030?oo00Ko1`0;o`<02ol400So
2009o`D02Ol400co0P0;o`D01?l200Ko00<0ool02Ol400[o1008o`P02_l200Ko0P06o`030?oo00[o
1009oa@02_l300So1P05o`<01Ol00`3oo`03o`<01Ol200So5@0001L000?o00001P07o`P01_l90003
o`0001X01Ol00`3o000600Go1`03o`<01_l00`3oo`07o`L00ol300Ko0P04o`@01?l00`3oo`06o`L0
2Ol500Wo1P08o`X01Ol900Go1P0<o`802Ol700?o0`06o`030?oo00Oo1P0:o`@02?l:00Go00<0ool0
0P06o`801_l00`3oo`0:o`H01OlH00Go00<0ool00`08o`H01Ol300Go00<0ool00ol300Go0P08oaD0
000Q00Go2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(21\\) RONRNULPRMQOFRORILCWFR CLKKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o200:o`H0
2Ol900;o5@05o`H00ol400Go1`06o`<00_l200Go1P03o`801_l300;o1`04o`D03Ol200So1P05o`H0
0ol00`3oo`03o`<01Ol500Go2@05o`H01ol700Go1P03o`D01Ol500Go1P03o`030?oo00So100=o`D0
1Ol800;o1002o`@01ol700Go1P03oa<01Ol600go00<0ool00ol600;o00<0ool00ol600;o0P0=oa00
000C00;o2@0:o`H02Ol:00;o5005o`D01?l200Wo1@06o`800ol200Go1@04o`801_l200?o1@08o`<0
3Ol200So1P05o`D01?l00`3oo`03o`<01Ol300Wo1@09o`@01ol700Go1@04o`<02Ol300Go1@04o`03
0?oo00So100=o`<02Ol600;o1002o`@01ol700Go1@04oa402Ol400go00<0ool00ol500?o00<0ool0
0ol500?o0P0=oa00000C00;o2P02o`D00_l:00;o3@02oaH00_l500?o0`03o`D00ol500;o1004o`@0
0_l500?o1@02o`@01?l500;o1002o`H00_l600;o1002o``00_l500?o1002o`L00_l300?o1@03o`<0
0ol500?o1@02o``00_l500?o1003o`D00ol400;o1@03o`L00_l;00;o1P02o`800ol500?o1003o`@0
0ol500;o3002o`D00olB00?o1@03o`H00_l600;o0`02o`D00ol400;o1@03o`H00_l600;o400001<0
0_l;00?o3`02o`d00_lF00;o1@02o`@00_l700;o1@02o`@01?l400;o1@02o`H00_l400Co1002o`H0
0_l500;o1P02o`@00_l<00;o1@02o`D00_l700;o0`02o`L00_l300;o1`02o`D00_l<00;o1@02o`D0
0_l700;o1002o`D00_l800;o2`02o`H00_l200;o1`02o`@01?l300?o1@02o``00_l500;o4`02o`L0
0_l600;o1P02o`<00_l500;o1@02o`D00_l700;o1P02oa00000C00;o3003o`h00_l=00;o5P02o`@0
0_l400;o2@02o`@00_l300Go1002o`@00_l700;o0`05o`@00_l600;o1@02o`H00_l400;o3002o`@0
0_l600;o0`02o`800_l200;o2@02o`030?oo00T00_l400;o0P02o`P00_l400;o1@02o`T00_l300;o
1002o`T00_l;00;o1P02o`040?ooo`d01?l200Co1@02o`800_l800;o1002oa<00ol?00;o1P02o`<0
0_l400;o1P02o`@00_l800;o1P02oa00000C00;o3@03o`d00_l=00;o5P02o`<00ol400;o2@02o`@0
0_l300;o00<0ool01002o`<00ol700;o0`02o`030?oo00@00_l600;o1@02o`H00_l400Oo1`02o`<0
0ol600;o0P03o`800_l200;o2@02o`030?oo00T00_l400;o0P02o`P00_l300?o1@02o`T00_l300;o
0`03o`T00_l;00;o1P02o`030?oo00h00_l0103o0004o`D00_l200;o2002o`<00olC00;o4002o`H0
0_l300?o0P03o`H00ol200?o2002o`H00_l@00004`02o`h00ol<00;o3@02oaH01ol500;o2@02o`@0
0_l200?o00<0ool01007o`P00_l200?o00<0ool01002o`H00_l500;o3009o`D01ol700;o0P000ol0
o`0200;o0P02o`T00_l00`3oo`0900;o1006o`P01ol600;o2@02o`<01ol:00;o2`02o`T00_l>00;o
00H0o`00o`02o`D01_l800Oo5002oa000_l;00Oo1`07o`T00_lH00004`02o`l00ol;00;o3@02oaH0
2Ol300;o2@02o`@00_l200;o0P02o`@02Ol600;o0P02o`800_l400;o1P02o`D00_l<00;o1@03o`@0
2Ol500;o00@0ool00_l00`3oo`0200;o2@02o`030?oo00T00_l400Ko2009o`@00_l900;o0`09o`P0
0_l;00;o2@02o`h00_l00`3oo`02o`030?oo00D01_l800Wo4P02oa000_l;00Go2@05o`/00_lH0000
5002o`l00_l;00;o3002oaL00_l500?o0P02o`T00_l400;o00<0ool00`02o`@00_l500?o1@02o`03
0?oo00<00_l400;o1P02o`D00_l<00;o1P02o`@00_l500?o1002o`030?oo008000Co0?oo0P02o`T0
0_l00`3oo`0900;o1002o`800_l800;o1@03o`<00_l900;o0`02o`D00ol700;o2`02o`T00_l>00;o
00<0ool00_l00`3oo`0500;o0P02o`P00_l500?o4@02oa000_l;00;o00@0oooo2002o`040?ooo`X0
0_lH00005002oa000_l:00;o3002oaL00_l600;o0P02o`T00_l400Go0`02o`@00_l600;o1@05o`<0
0_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1002o`030?l0008000Co0?oo0P03o`P00_l00`3o
o`0900;o1002o`800_l200;o1002o`H00_l300;o2@02o`<00_l600;o1`02o`/00_l900?o1`02o`<0
0_l300;o0`02o`@00_l200;o0P02o`@00_l600;o4@03o`L00_l600;o2`02o`800ol700;o0P03o`T0
0_lH00005003o`l00_l:00;o3002oaL00_l600;o0`02o`L00_l500Co1002o`@00_l600;o1@04o`@0
0_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1004o`<01?l300;o1`02o`<00_l700;o1@02o`H0
0_l400;o1P02o`@00_l700;o1002o`H00_l700;o2`02o`X00_l700;o0`02o`<00_l300;o1002o`H0
0_l400;o1P02oa800_l700;o1P02o`/00_l300?o1P02o`<00ol800;o600001D00_l800;o1@02o`X0
0_l;00;o6002o`D00ol300?o1@03o`D01?l400;o1002o`D00ol500Co1002o`@00_l600;o1@02o``0
0_l500?o1002o`D00ol400Co1003o`@00_l500;o1003o`D00ol500;o1P02o`@00_l500?o1003o`D0
0ol400;o1@03o`L00_l;00;o2P03o`D00ol300;o2002o`@00_l600;o1002o`D00olB00?o1@03o`H0
0_l;00;o1003o`D00_l400?o1`02oaP0000F00;o1`03o`<00ol600?o00<0ool02P02oaL02ol500Wo
1@04o`801_l00`3oo`09o`D01?l200Ko0P04o`@01?l00`3oo`06o`L02ol300_o1004o`D01?l300Wo
1@09o`@03?l200_o1P09o`<02ol400[o1008o`P02_l200Ko0P06o`030?oo00[o0P0;oa@02_l300So
1P05o`<01Ol00`3oo`03o`<01Ol200So5@0001L000?o00001P07o`L01_l:0003o`0001H02Ol900Go
1`03o`<01_l00`3oo`07o`L00ol300Ko0P04o`@01?l00`3oo`06o`L02Ol500Wo1P04o`D01?l500Go
2@05o`H03?l200Wo2P05o`D02Ol600[o1008o`X01Ol00`3oo`0200Ko0P06o`030?oo00[o0P09oaP0
1Ol00`3oo`0300So1P05o`<01Ol00`3oo`03o`<01Ol200So5@0002401Ol;00?oo`360000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(22\\) RNNRNULPRMQPFRORILCWFR CLKKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o200:o`D0
2_l900;o5@05o`H00ol00`3oo`04o`<00_l400Ko0`02o`801Ol600?o0P06o`<00_l700Co1@0=o`80
2?l600Go1P03o`030?oo00?o0`05o`D01Ol500So1`07o`L01Ol600?o1@05o`D01Ol600?o00<0ool0
2?l400go1@05o`P00_l400;o1007o`L01Ol600?o4`05o`H03Ol00`3oo`03o`H00_l00`3oo`03o`H0
0_l200go400001<00_l900[o1@0:o`X00_lD00Go1@04o`030?oo00Co0P03o`@01_l200?o0P05o`D0
1?l200Ko0P03o`D02?l300go0P08o`H01Ol500Co00<0ool00ol300Go0`09o`<02?l700Oo1`05o`D0
1?l300Wo0`05o`D01?l00`3oo`08o`@03Ol300Wo1P02o`@00_l400Oo1`05o`D01?lA00Wo100=o`03
0?oo00?o1@03o`030?oo00?o1@03o`803Ol@00004`02o`X00_l500;o1P02o`D00_l:00;o5P02o`D0
0ol400;o1004o`D00_l400Co1002o`D00ol500;o1004o`D00_l400;o1P02o`H00_l400;o3002o`D0
0ol400;o1`02o`<00ol500?o1002o`d00_l<00;o1@03o`@00ol500?o1002o`D00ol700;o2`02o`H0
0_l200?o1@03o`@00ol400?o1@02o``00_l500?o4P03o`D00ol600;o1P02o`<00_l500?o1002o`D0
0ol600;o1P02oa00000C00;o2`03o``00ol?00;o5P02o`D00_l500;o1004o`D00_l400Co1002o`D0
0_l600;o1004o`@00_l600;o1@02o`H00_l400;o3002o`D00_l500;o1`02o`<00_l700;o1002o`d0
0_l<00;o1@02o`D00_l700;o1002o`D00_l800;o2`02o`H00_l200;o1`02o`@01?l300?o1@02o``0
0_l500;o4`02o`L00_l600;o1P02o`<00_l500;o1@02o`D00_l700;o1P02oa00000C00;o3003o``0
0ol>00;o5P02o`@00_l600;o0`05o`D00_l300Go1002o`@00_l700;o0`05o`@00_l600;o1@02o`H0
0_l400;o3002o`@00_l600;o0`02o`800_l200;o2@02o`<00_l=00;o0P02o`P00_l400;o1@02o`T0
0_l300;o1002o`T00_l;00;o1P02o`040?ooo`d01?l200Co1@02o`800_l800;o1002oa<00ol?00;o
1P02o`<00_l400;o1P02o`@00_l800;o1P02oa00000C00;o3@03o``00ol=00;o5P02o`<00ol600;o
0`02o`030?oo00D00_l300;o00<0ool01002o`<00ol700;o0`02o`030?oo00@00_l600;o1@02o`H0
0_l400Oo1`02o`<00ol600;o0P03o`800_l200;o2@02o`<01ol800;o0P02o`P00_l300?o1@02o`T0
0_l300;o0`03o`T00_l;00;o1P02o`030?oo00h00_l0103o0004o`D00_l200;o2002o`<00olC00;o
4002o`H00_l300?o0P03o`H00ol200?o2002o`H00_l@00004`02o`h00ol<00?o3002oaH01ol700;o
0P03o`030?oo00D00_l200?o00<0ool01007o`P00_l200?o00<0ool01002o`H00_l500;o3009o`D0
1ol700;o0P000ol0o`0200;o0P02o`T00_l300Wo1P06o`P01ol600;o2@02o`<01ol:00;o2`02o`T0
0_l>00;o00H0o`00o`02o`D01_l800Oo5002oa000_l;00Oo1`07o`T00_lH00004`02o`l00ol<00?o
2`02oaH02Ol500;o0P02o`800_l500;o0P02o`800_l400Wo1P02o`800_l200;o1002o`H00_l500;o
3002o`D00ol400Wo1@02o`040?oo00;o00<0ool00P02o`T00_l300;o1@03o`D01_l800Wo1002o`T0
0_l300Wo2002o`/00_l900;o3P02o`030?oo00;o00<0ool01@06o`P02OlB00;o4002o`/01Ol900Go
2`02oaP0000D00;o3`02o`d00_l:00;o5`02o`D00ol400;o00<0ool00`02o`D00_l00`3oo`0300;o
1002o`D00ol500;o00<0ool00`02o`@00_l600;o1@02o``00_l600;o1002o`D00ol400;o00<0ool0
0P001?l0ool200;o2@02o`<00_l600;o1@02o`800_l800;o1@03o`<00_l900;o0`02o`D00ol700;o
2`02o`T00_l>00;o00<0ool00_l00`3oo`0500;o0P02o`P00_l500?o4@02oa000_l;00;o00@0oooo
2002o`040?ooo`X00_lH00005002oa000_l=00;o2@02oaL00_l600;o1005o`<00_l500Go0`02o`@0
0_l600;o1@05o`<00_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1002o`030?l0008000Co0?oo
0P03o`P00_l300;o1P02o`D00_l200;o0P02o`@00_l600;o0`02o`T00_l300;o1P02o`L00_l;00;o
2@03o`L00_l300;o0`02o`<00_l400;o0P02o`800_l400;o1P02oa400ol700;o1P02o`/00_l200?o
1`02o`800ol900;o600001@00ol?00;o3@02o`T00_lG00;o1P02o`@01?l400;o1@04o`@00_l400;o
1P02o`D01?l400;o1002o`H00_l500;o3002o`H00_l400;o1P02o`@01?l300Co0`02o`L00_l400;o
1P02o`D00_l600;o1002o`H00_l400;o1`02o`@00_l600;o1`02o`/00_l:00;o1`02o`<00_l300;o
0`02o`@00_l600;o1002o`H00_lB00;o1`02o`H00_l;00;o0`03o`H00_l300?o2002oaP0000E00;o
2002o`D00_l600;o1@02o`P00_lH00;o1@03o`@01?l400;o1@04o`@00_l400;o1@03o`D01?l400;o
1002o`H00_l500;o3002o`D00ol400;o1@03o`@01?l400?o1002o`D00_l500;o1@03o`D00_l600;o
1002o`D00ol400?o1@03o`@00_l500?o1`02o`/00_l:00?o1@03o`<00_l800;o1002o`H00_l400;o
1@03oa800ol500?o1P02o`/00_l400?o1@02o`@00ol700;o600001H00_l700?o0`03o`H00ol300?o
1`02oaL02ol400Co0P06o`<01?l200Ko00<0ool02Ol500Co0P06o`801?l400Co00<0ool01_l700_o
0`0;o`@01?l500Co0`09o`<02ol400co0P0;o`H02Ol300_o100:o`@02?l800[o0P06o`801_l00`3o
o`0:o`802olD00[o0`08o`H01Ol300Go00<0ool00ol300Go0P08oaD0000G0003o`0000H01ol800Oo
20000ol0000F00Wo1P03o`<01_l300?o0`06o`030?oo00Oo1`03o`<01_l200Co1004o`030?oo00Ko
1`09o`D02Ol600Co1@04o`D01Ol500Wo1P0<o`802Ol:00Go1@09o`H02_l400So2P05o`030?oo0080
1_l200Ko00<0ool02_l200Wo6005o`030?oo00<02?l600Go0`05o`030?oo00?o0`05o`802?lE0000
8@05o`X01Ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(23\\) RMNRNULPRMQPFRORILCWFR CLLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o200:o`L0
1Ol<00;o5@05o`H02?l300Go0`06o`<00_l200Go1P03o`801_l300;o1`04o`D03Ol200So1P05o`H0
0ol00`3oo`03o`<01Ol500Go1@08o`L01ol700Go1P03o`D01Ol500Go1P03o`030?oo00So100=o`D0
1Ol800;o1002o`@01ol700Go1P03oa<01Ol600go00<0ool02ol00`3oo`03o`H00_l200go400001<0
0_l900[o1@09o`/00_lD00Go1@09o`<01Ol300Ko0P03o`801Ol500Co0P06o`800ol500So0`0=o`80
2?l600Go1@04o`030?oo00?o0`05o`<02Ol300So1`07o`L01Ol500Co0`09o`<01Ol500Co00<0ool0
2?l400go0`09o`H00_l400;o1007o`L01Ol500Co4@09o`@03Ol00`3oo`0;o`030?oo00?o1@03o`80
3Ol@00004`02o`X00_l500;o1@02o`D00_l;00;o5P02o`D00ol300;o1`02o`D00_l400Co1002o`D0
0ol500;o1004o`D00_l400;o1P02o`H00_l400;o3002o`D00ol400;o1`02o`<00ol500?o1002o`d0
0_l<00;o1@03o`@00ol500?o1002o`D00ol700;o2`02o`H00_l200?o1@03o`@00ol400?o1@02o``0
0_l500?o4P03o`D00ol600;o1P02o`@00_l600;o0`02o`D00ol600;o1P02oa00000C00;o2`03oa80
0_l:00;o5P02o`D00_l400;o1`02o`D00_l400Co1002o`D00_l600;o1004o`@00_l600;o1@02o`H0
0_l400;o3002o`D00_l500;o1`02o`<00_l700;o1002o`d00_l<00;o1@02o`D00_l700;o1002o`D0
0_l800;o2`02o`H00_l200;o1`02o`@01?l300?o1@02o``00_l500;o4`02o`L00_l600;o1P02o`@0
0_l600;o0`02o`D00_l700;o1P02oa00000C00;o3003oa400_l:00;o5P02o`@00_l500;o0`02o`80
0_l500;o0`05o`@00_l400;o1`02o`<01Ol400;o1P02o`D00_l600;o1002o``00_l400;o1P02o`<0
0_l200;o0P02o`T00_l300;o3@02o`800_l800;o1002o`D00_l900;o0`02o`@00_l900;o2`02o`H0
0_l0103oool=00Co0P04o`D00_l200;o2002o`@00_lC00?o3`02o`H00_l400;o1P02o`<00_l400;o
2002o`H00_l@00004`02o`d00ol@00;o2P02oaH00_l300?o1@02o`800ol200;o1@02o`<00_l00`3o
o`0400;o0`03o`L00_l300;o00<0ool01002o`H00_l500;o1P02o`@01ol700;o0`03o`H00_l200?o
0P02o`800_l900;o0`07o`P00_l200;o2002o`<00ol500;o2@02o`<00_l300?o2@02o`/00_l600;o
00<0ool03P02o`040?l000Co1@02o`800_l800;o0`03oa<00_l@00;o1P02o`@00_l600;o0`03o`80
0ol800;o1P02oa00000C00;o3P03o`h00_l;00;o5P07o`H00_l20003o`3o00800_l500;o0P03o`03
0?oo00@01ol800;o0P03o`030?oo00@00_l600;o1@02o``02Ol500Oo1`02o`8000?o0?l00P02o`80
0_l900;o0`09o`H01_l800Oo1P02o`T00_l300Oo2P02o`/00_l900;o3P02o`060?l00?l00_l500Ko
2007oa@00_l@00;o3002o`/01ol900;o600001<00_l?00?o2P04o``00_lF00Wo1002o`040?oo00;o
00<0ool01@02o`800_l200;o1009o`H00_l200;o0P02o`@00_l600;o1@02o``00_l500?o1009o`D0
0_l0103oo`02o`030?oo00800_l900;o0`02o`D00ol500Ko2009o`@00_l900;o0`09o`P00_l;00;o
2@02o`h00_l00`3oo`02o`030?oo00D01_l800Wo4P02oa000_l<00;o2`05o`/00_lH00005002o`l0
0_l:00?o3002oaL00_l500?o0`02o`030?oo008000Co0?oo1@02o`030?oo00<00_l400;o1@03o`D0
0_l00`3oo`0300;o1002o`H00_l500;o3002o`H00_l400;o1@03o`@00_l00`3oo`020004o`3oo`80
0_l900;o0`02o`H00_l500;o0P02o`P00_l500?o0`02o`T00_l300;o1@03o`L00_l;00;o2@02o`h0
0_l00`3oo`02o`030?oo00D00_l200;o2002o`D00olA00;o4002o``00_l;00;o00@0oooo2P02oaP0
000D00;o4002o`/00_l;00;o5`02o`H00_l300;o00<0o`000P001?l0ool500Go0`02o`@00_l600;o
1@05o`<00_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1002o`030?l0008000Co0?oo0P03o`P0
0_l300;o1P02o`D00_l200;o0P02o`@00_l600;o0`02o`T00_l300;o1P02o`L00_l;00;o2@03o`L0
0_l300;o0`02o`<00_l400;o0P02o`800_l400;o1P02oa400ol700;o1P02o``00_l;00;o0P03o`T0
0_lH00005003o`l00_l<00;o2P02oaL00_l600;o0`04o`<01?l500Co1002o`@00_l600;o1@04o`@0
0_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o1004o`<01?l300;o1`02o`@00_l600;o1@02o`H0
0_l400;o1P02o`@00_l700;o1002o`H00_l700;o2`02o`X00_l700;o0`02o`<00_l300;o1002o`H0
0_l400;o1P02oa800_l700;o1P02o``00_l;00;o0`03o`P00_lH00005@02o`P00_l500;o3002o`T0
0_lH00;o1@03o`<01?l400?o1@04o`@00_l400;o1@03o`D01?l400;o1002o`H00_l500;o3002o`D0
0ol400;o1@03o`@01?l400?o1002o`D00_l500;o1@03o`D00_l600;o1002o`D00ol400?o1@03o`@0
0_l500?o1`02o`/00_l:00?o1@03o`<00_l800;o1002o`H00_l400;o1@03oa800ol500?o1P02o``0
0_l;00;o1003o`L00_lH00005P02o`L00ol300?o1P02o`<00ol800;o5`0;o`<01?l500Co0`04o`80
1_l00`3oo`09o`D01?l200Ko0P04o`@01?l00`3oo`06o`L02ol300_o1004o`D01?l300Wo0`0;o`@0
3?l200_o1P09o`<02ol400[o1008o`P02_l200Ko0P06o`030?oo00[o0P0;oa@02_l300So1P08o`H0
1Ol300Go0P08oaD0000G0003o`0000H01ol700Oo2@000ol0000F00Wo1@04o`D01?l300?o0`06o`03
0?oo00Oo1`03o`<01_l200Co1004o`030?oo00Ko1`09o`D02Ol600Co1@04o`D01Ol500Wo1P0<o`80
2Ol:00Go1@09o`H02_l400So2P05o`030?oo00801_l200Ko00<0ool02_l200Wo6005o`030?oo00<0
2?l600So1P05o`<01Ol200So5@0002401Ol:00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(24\\) RNNQNULPRMQPFRORILCXER CKLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02odD00_l400?oG002o`@00ooo00L0000E00;o
:002od@02_mK00[oo`0600005002obX00_m400Go0P02oe`01Ol200;oo`0600005002obX00_m40003
o`00068000?o0000o`0<00005002o`P02_l900Ko2@02oaD01Ol600?o00<0ool01?l300;o1006o`<0
0_l600Go1`06o`<00_l700Co1@0=o`802?l600Go1P03o`030?oo00?o0`05o`D01Ol500So1`07o`L0
1Ol600?o1@05o`D01Ol600?o00<0ool02?l400go1@05o`H01Ol200Go0P0<o`801Ol600?o4`05o`H0
1Ol600;o00<0ool02ol00`3oo`03o`H00_l200go400001<00_l900[o2@06o`X00_lD00Go1@04o`03
0?oo00Co0P03o`@01_l200?o1009o`D01_l200?o1@08o`<03Ol200So1P05o`D01?l00`3oo`03o`<0
1Ol300Wo0`08o`L01ol700Go1@04o`<02Ol300Go1@04o`030?oo00So100=o`<02Ol400Go0P05o`80
3?l200Go1@04oa402Ol400Go1@03o`030?oo00_o00<0ool00ol500?o0P0=oa00000C00;o2P02o`D0
0_l;00;o3002oaH00_l500?o1002o`@01?l500;o1004o`<00ol500?o1@02o`@01?l500;o1002o`H0
0_l600;o1002o``00_l500?o1002o`L00_l300?o1@03o`@00_l=00;o3002o`D00ol400?o1@03o`@0
0_l500?o1`02o`/00_l600;o0P03o`D00ol400?o1003o`D00_l600;o1002o`D00olB00?o1@03o`D0
0_l500?o1@02o`H00_l300;o1@03o`H00_l600;o400001<00_l;00?o4002o``00_lF00;o1@02o`D0
0_l400Co1@02o`@01?l300;o1`02o`D00_l400Co1002o`H00_l500;o1P02o`@00_l<00;o1@02o`D0
0_l700;o0`02o`L00_l400;o3@02o``00_l500;o1@02o`L00_l400;o1@02o`P00_l;00;o1P02o`80
0_l700;o1@03o`800ol600;o1P02o`@00_l500;o4`02o`L00_l500;o1@02o`H00_l600;o0`02o`D0
0_l700;o1P02oa00000C00;o3003o`T02_l:00;o5P02o`@00_l600;o0`05o`D00_l300Go0P02o`T0
0_l400;o0`05o`@00_l600;o1@02o`H00_l400;o3002o`@00_l600;o0`02o`800_l200;o2@02o`<0
0_l=00;o0P02o`P00_l400;o1@02o`T00_l300;o1002o`T00_l;00;o1P02o`040?ooo`l00_l200;o
1`02o`800_l200;o1002o`@00_lC00?o3P02o`@00_l700;o1P02o`<00_l400;o2002o`H00_l@0000
4`02o`d00ol800[o2P02oaH00_l300?o1P02o`<00_l00`3oo`0500;o0`02o`030?oo00800_l900;o
1002o`<00_l00`3oo`0400;o1P02o`D00_l600;o1007o`L00_l300?o1P02o`800ol200;o0P02o`T0
0_l300Oo2002o`800_l800;o0`03o`D00_l900;o0`02o`<00ol900;o2`02o`H00_l00`3oo`0A00Co
2002o`800_l800;o0`03oa<00_l?00?o0P03o`L00_l600;o0`03o`800ol800;o1P02oa00000C00;o
3P03o`L00_l400;o3002oaH01ol700;o0P03o`030?oo00D00_l200?o00<0ool00P02o`T00_l400;o
0P03o`030?oo00@00_l600;o1@02o``02Ol500Oo1`02o`8000?o0?l00P02o`800_l900;o0`09o`H0
1_l800Oo1P02o`T00_l300Oo2P02o`/00_l900;o4@04o`P01_l800Oo5002o`l01ol800;o2`07o`T0
0_lH00004`02o`l00ol700;o0`02o``00_lF00Wo1@02o`800_l200;o1@02o`800_l200;o0P02o`T0
0_l400;o0P02o`800_l400;o1P02o`D00_l<00;o1@03o`@02Ol500;o00@0ool00_l00`3oo`0200;o
2@02o`<00_l500?o1@06o`P02Ol400;o2@02o`<02Ol800;o2`02o`T00_lA00?o2@06o`P02OlB00;o
3`05o`X00_l;00Go2`02oaP0000D00;o3`02o`P000Co00000_l;00;o5`02o`D00ol400;o00<0ool0
0`02o`D00_l00`3oo`0300;o0P02o`T00_l400;o00<0ool00`02o`@00_l600;o1@02o``00_l600;o
1002o`D00ol400;o00<0ool00P001?l0ool200;o2@02o`<00_l600;o1@02o`800_l800;o1@03o`<0
0_l900;o0`02o`D00ol700;o2`02o`T00_lA00Co2002o`800_l800;o1@03oa400_l?00;o00@0oooo
2@02o`/00_l0103oool:00;o600001@00_l@00;o1`02o`800_l;00;o5`02o`H00_l400Go0`02o`D0
1Ol300;o0P03o`P00_l400Go0`02o`@00_l600;o1@02o``00_l600;o1002o`H00_l400;o00<0o`00
0P001?l0ool200?o2002o`<00_l600;o1@02o`800_l200;o1002o`H00_l300;o2@02o`<00_l600;o
1`02o`/00_l900?o1`02o`H01_l700;o0P02o`800_l400;o1P02oa400ol700;o1@02o`800ol800;o
2`02o`800ol900;o600001@00ol?00;o20000ol00002o`/00_lG00;o1P02o`@01?l400;o1@04o`@0
0_l300;o1`02o`D01?l400;o1002o`H00_l500;o3002o`H00_l400;o1P02o`@01?l300Co0`02o`L0
0_l400;o1P02o`D00_l600;o1002o`H00_l400;o1`02o`@00_l600;o1`02o`/00_l:00;o1`02o`D0
0ol200?o1P02o`H00_l400;o1P02oa800_l700;o1@02o`<00ol700;o2`02o`<00ol800;o600001D0
0_l800;o1@02o`T000Co0?oo2P02oaP00_l500?o1004o`@00_l500Co1002o`@00_l500;o1P04o`@0
0_l400;o1P02o`D00_l<00;o1@03o`@00_l500?o1004o`@00ol400;o1@02o`D00_l500?o1@02o`H0
0_l400;o1@03o`@00ol500?o1002o`D00ol700;o2`02o`X00ol500?o1@02o`@00_l600;o1P02o`@0
0_l500?o4P03o`D00ol500;o1003o`H00_l;00;o1003o`L00_lH00005P02o`L00ol300?o2@04o`T0
0_lG00_o1004o`801_l300Co0P06o`<02Ol500Co0P06o`801?l400Co00<0ool01_l700_o0`0;o`@0
1?l500Co0`09o`<02ol400co0P0;o`H02Ol300_o100:o`@02?l800[o0`05o`801Ol200co0P0;oa@0
2_l300Go0`05o`030?oo00Ko1P05o`<01Ol200So5@0001L000?o00001P07o`/00ol90003o`0001H0
2Ol600?o0`06o`<00ol300Ko1@05o`L00ol300Ko0P04o`@01?l00`3oo`06o`L02Ol500Wo1P04o`D0
1?l500Go1@09o`H03?l200Wo2P05o`D02Ol600[o1008o`X01Ol00`3oo`0300Go0P05o`803?l200Wo
6005o`030?oo00<01Ol300Go00<0ool01_l600Go0`05o`802?lE00008@05o``00ooo0<D0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(25\\) RMNQNULPRMQPFRORJLCXES CKLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02odD00_l400?oG002o`@00ooo00L0000E00;o
:002od@02_mK00[oo`0600005002obX00_m400Go0P02oe`01Ol200;oo`0600005002obX00_m40003
o`00068000?o0000o`0<00005002o`P02_l700Go3002oaD01Ol600So0`05o`<01_l300;o1P05o`L0
1_l300;o1`04o`D03Ol200So1P05o`H00ol00`3oo`03o`<01Ol500Go1@08o`L01ol700Go1P03o`D0
1Ol500Go1P03o`801_l700go1@05o`H01Ol200Go0P0<o`<00_l00`3oo`03oaP01Ol600Go1P02o`03
0?oo00_o00<0ool00ol600;o0P0=oa00000C00;o2@0:o`D02Ol;00;o5005o`D02Ol300Go0`06o`80
0ol400Wo1@06o`800ol500So0`0=o`802?l600Go1@04o`030?oo00?o0`05o`<02Ol300So1`07o`L0
1Ol500Co0`09o`<01Ol500go1P0=o`<02Ol400Go0P05o`803?l300[o5009o`@01Ol500?o00<0ool0
2ol00`3oo`03o`D00ol200go400001<00_l:00;o1@02o`D00_l500;o2`02oaH00_l500?o0`02o`L0
0_l500;o1004o`<00ol500?o1@02o`@01?l500;o1002o`H00_l600;o1002o``00_l500?o1002o`L0
0_l300?o1@03o`@00_l=00;o3002o`D00ol400?o1@03o`@00_l500?o0P03o`@00ol800;o1P02o`80
0ol500?o1003o`@00ol500;o1P02o`<00ol500?o4P03o`D00ol500;o1@03o`D00_l600;o0`02o`D0
0ol600;o1P02oa00000C00;o2`03oa800_l:00;o5P02o`D00_l400;o1`02o`D00_l400Co0`02o`L0
0_l500;o1004o`@00_l600;o1@02o`H00_l400;o3002o`D00_l500;o1`02o`<00_l700;o1002o`d0
0_l<00;o1@02o`D00_l700;o1002o`D00_l300;o1P02o`P00_l600;o0P02o`L00_l500?o0P03o`H0
0_l600;o0`02o`L00_lB00;o1`02o`D00_l500;o1P02o`H00_l300;o1@02o`L00_l600;o400001<0
0_l<00?o4@02o`X00_lF00;o1002o`D00_l300;o0P02o`D00_l300Go0P02o`T00_l400;o0`05o`@0
0_l600;o1@02o`H00_l400;o3002o`@00_l600;o0`02o`800_l200;o2@02o`<00_l=00;o0P02o`P0
0_l400;o1@02o`T00_l300;o1002o`@00_l600;o2002o`H00_l0103oool?00;o0P02o`L00_l200;o
0P02o`<00_l700;o4@03o`h00_l400;o1`02o`H00_l300;o1002o`P00_l600;o400001<00_l=00?o
4002o`X00_lF00;o0`03o`D00_l200?o0P02o`D00_l300;o00<0ool00P02o`T00_l400;o0`02o`03
0?oo00@00_l600;o1@02o`H00_l400Oo1`02o`<00ol600;o0P03o`800_l200;o2@02o`<01ol800;o
0P02o`P00_l300?o1@02o`T00_l300;o0`03o`@00_l600;o2002o`H00_l00`3oo`0A00Co2002o`80
0_l?00?o4@02o`l00ol200?o1`02o`H00_l300?o0P03o`P00_l600;o400001<00_l>00?o3`02o`X0
0_lF00Oo1P02o`8000?o0?l00P02o`D00_l200?o00<0ool00P02o`T00_l400;o0P03o`030?oo00@0
0_l600;o1@02o``02Ol500Oo1`02o`8000?o0?l00P02o`800_l900;o0`09o`H01_l800Oo1P02o`T0
0_l300Oo3@02o`P00_l900;o4@04o`P01_l:00Oo4P02o`l01ol800;o2`07o`T00_lH00004`02o`l0
0ol700;o1002o`/00_lF00Wo1002o`040?oo00;o00<0ool01@02o`800_l200;o0P02o`T00_l400;o
0P02o`800_l400;o1P02o`D00_l<00;o1@03o`@02Ol500;o00@0ool00_l00`3oo`0200;o2@02o`<0
0_l500?o1@06o`P02Ol400;o2@02o`<02Ol;00;o2002o`T00_lA00?o2@06o`P01olD00;o3`05o`X0
0_l;00Go2`02oaP0000D00;o3`02o`L02?l:00;o5`02o`D00ol300;o00<0ool00P001?l0ool500;o
00<0ool00`02o`800_l900;o1002o`030?oo00<00_l400;o1P02o`D00_l<00;o1P02o`@00_l500?o
1002o`030?oo008000Co0?oo0P02o`T00_l300;o1P02o`D00_l200;o2002o`D00ol300;o2@02o`<0
0_l500?o2P02o`P00_l900;o4@04o`P00_l200;o1`03oaT00_l?00;o00@0oooo2@02o`/00_l0103o
ool:00;o600001@00_l@00;o1P07o`/00_lG00;o1P02o`<00_l00`3o00020004o`3oo`D01Ol300;o
0P03o`P00_l400Go0`02o`@00_l600;o1@02o``00_l600;o1002o`H00_l400;o00<0o`000P001?l0
ool200?o2002o`<00_l600;o1@02o`800_l200;o1002o`H00_l300;o2@02o`<00_l600;o2P02o`P0
0_l900?o1`02o`H01_l700;o0P02o`800_l300;o1`000ol0000@00?o1`02o`D00_l200?o2002o`/0
0_l200?o2@02oaP0000D00?o3`02o`H00_l@00;o5`02o`H00_l300Co0`04o`D01?l400;o0`02o`L0
0_l500Co1002o`@00_l600;o1@02o``00_l600;o1002o`H00_l400Co0`04o`<00_l700;o1002o`H0
0_l500;o1P02o`@00_l600;o1002o`L00_l400;o1P02o`X00_l800;o2P02o`L00_l500?o0P03o`H0
0_l600;o0`02o`H00_lC00;o1`02o`D00_l300?o1`02o`/00_l300?o2002oaP0000E00;o2002o`D0
0_l600;o3`02oaP00_l500?o0`04o`@00ol500Co1002o`@00_l500;o1P04o`@00_l400;o1P02o`D0
0_l<00;o1@03o`@00_l500?o1004o`@00ol400;o1@02o`D00_l500?o1@02o`H00_l400;o1@03o`@0
0ol500?o1002o`D00ol:00;o2002o`X00ol500?o1@02o`@00_l600;o1P02o`<00ol400?o4`03o`D0
0ol500;o1003o`H00_l;00;o1003o`L00_lH00005P02o`L00ol300?o1P02o`h00_lG00_o0`04o`D0
1?l300Co0P06o`<02Ol500Co0P06o`801?l400Co00<0ool01_l700_o0`0;o`@01?l500Co0`09o`<0
2ol400co0P0;o`H02Ol300_o1P0:o`802?l800[o0`05o`801Ol200co1009oa@02_l300Go0`05o`03
0?oo00Ko1P05o`<01Ol200So5@0001L000?o00001P07o`L02?l80003o`0001H02Ol500Co1@04o`<0
0ol300Ko1@05o`L00ol300Ko0P04o`@01?l00`3oo`06o`L02Ol500Wo1P04o`D01?l500Go1@09o`H0
3?l200Wo2P05o`D02Ol800[o0P08o`X01Ol00`3oo`0300Go0P05o`803?l600Go00<0o`005@05o`03
0?oo00<01Ol300Go00<0ool01_l600Go0`05o`802?lE00008@05o`P02?oo0<@0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(26\\) RMOQNULPRMQPFRPQJLCXES CKLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02odD00_l400?oG002o`@00olo00;o1003okh0
000E00;o:002od@02_mK00[o?P0:okd0000D00;o:P02od@01Ol200;oG005o`800_lo00Go0P02okd0
000D00;o:P02od@000?o0000HP000ol000150003o`000<<0000D00;o200:o`P01?l<00;o5@05o`H0
2?l300Go1P05o`T01Ol700Ko0`02o`L01?l500go0P08o`H01Ol600?o00<0ool00ol300Go1@05o`D0
2?l700Oo1`05o`H00ol00`3oo`06o`X01Ol700Ko1`0=o`D01Ol600Go0P05o`803?l300;o00<0ool0
0olH00Go1P05o`H00_l00`3oo`0;o`030?oo00?o1P02o`803Ol@00004`02o`T02_l700Oo2`02oa@0
1Ol500Wo0`05o`@02Ol500Wo1@06o`800ol500So0`0=o`802?l600Go1@04o`030?oo00?o0`05o`<0
2Ol300So1`07o`L01Ol500Co00<0ool01_l800Wo0`09o`H03Ol300Wo1005o`801Ol200co0`0:oa@0
2Ol400Go1@03o`030?oo00_o00<0ool00ol500?o0P0=oa00000C00;o2P02o`D00_l600;o1002o`/0
0_lF00;o1@03o`<00_l700;o1003o`D00ol300?o1@03o`D00_l400Co1@02o`@00_l600;o1P02o`@0
0_l<00;o1@03o`@00_l700;o0`03o`D00ol400;o3@02o``00_l500?o1@02o`/00ol500?o0P03o`@0
0ol800;o1P02o`800ol500?o1003o`@00ol500;o1P02o`<00ol500?o4P03o`D00ol500;o1@03o`D0
0_l600;o0`02o`D00ol600;o1P02oa00000C00;o2`03o`X00_l600;o2P02oaH00_l500;o1002o`L0
0_l400;o1`02o`<00_l700;o1@02o`@01?l400;o1P02o`D00_l600;o1002o``00_l500;o1@02o`L0
0_l300;o1`02o`@00_l=00;o3002o`D00_l600;o2`02o`L00_l200;o1P02o`P00_l600;o0P02o`L0
0_l500?o0P03o`H00_l600;o0`02o`L00_lB00;o1`02o`D00_l500;o1P02o`H00_l300;o1@02o`L0
0_l600;o400001<00_l<00?o2@02o`H00_l:00;o5P02o`@00_l500;o0`02o`800_l300;o2@02o`03
0?oo00T00_l400;o0`05o`@00_l600;o1@02o`H00_l400;o3002o`@00_l600;o0`02o`800_l200;o
2@02o`<00_l=00;o0P02o`P00_l400;o1`02o`X00_l900;o00<0ool01P02o`P00_l600;o00@0oooo
3`02o`800_l700;o0P02o`800_l300;o1`02oa400ol>00;o1002o`L00_l600;o0`02o`@00_l800;o
1P02oa00000C00;o3@03o`P00_l600;o2P02oaH00_l300?o1@02o`800ol200;o0`02o`T00_l00`3o
o`0900;o1002o`<00_l00`3oo`0400;o1P02o`D00_l600;o1007o`L00_l300?o1P02o`800ol200;o
0P02o`T00_l300Oo2002o`800_l800;o0`03o`L01ol500;o2@02o`030?oo00H00_l800;o1P02o`03
0?oo01401?l800;o0P02o`l00olA00;o3`03o`800ol700;o1P02o`<00ol200?o2002o`H00_l@0000
4`02o`h00ol700;o1P02o`X00_lF00Oo1P02o`8000?o0?l00P02o`<00_l900;o00<0ool02@02o`@0
0_l200?o00<0ool01002o`H00_l500;o3009o`D01ol700;o0P000ol0o`0200;o0P02o`T00_l300Wo
1P06o`P01ol800Wo0`02o`T00_l900;o2002o`T00_lA00Co2006o`X01olB00;o3`07o`P00_l;00Oo
2@02oaP0000C00;o3`03o`H00ol400;o2`02oaH02Ol400;o00@0ool00_l00`3oo`0300;o2@02o`03
0?oo00T00_l400;o0P02o`800_l400;o1P02o`D00_l<00;o1@03o`@02Ol500;o00@0ool00_l00`3o
o`0200;o2@02o`<00_l500?o1@06o`P02Ol600;o1@03o`800_l900;o2@02o`P00_l900;o4@03o`T0
1_l800Oo5002o`l01Ol:00;o2`05o`/00_lH00005002o`l00_l600Wo2P02oaL00_l500?o0`02o`03
0?oo008000Co0?oo0`02o`T00_l00`3oo`0900;o1002o`030?oo00<00_l400;o1P02o`D00_l<00;o
1P02o`@00_l500?o1002o`030?oo008000Co0?oo0P02o`T00_l300;o1P02o`D00_l200;o2002o`D0
0ol500;o1P02o`800_l900;o2@02o`P00_l900;o4@04o`P00_l200;o1`03oaT00_l?00;o00@0oooo
2@02o`/00_l0103oool:00;o600001@00_l@00;o1@02o`030?oo00;o3002oaL00_l600;o0`02o`03
0?l0008000Co0?oo0`02o`T00_l0103oool800;o1005o`<00_l400;o1P02o`D00_l<00;o1P02o`@0
0_l600;o1002o`030?l0008000Co0?oo0P03o`P00_l300;o1P02o`D00_l200;o0P02o`@00_l600;o
1@02o`H00_l200?o2002o`T00_l800;o2@03o`L00_l600Ko1`02o`800_l200;o0`02o`L000?o0000
4003o`L00_l500;o0P03o`P00_l;00;o0P03o`T00_lH00005003o`l00_l600;o4002oaL00_l600;o
0`04o`<01?l400;o1`02o`<00_l700;o1@04o`@00_l400;o1P02o`D00_l<00;o1P02o`@00_l600;o
1004o`<01?l300;o1`02o`@00_l600;o1@02o`H00_l400;o1P02o`D00_l600;o0`02o`L00_l:00;o
2002o`X00_l700;o1@03o`800ol600;o1P02o`<00_l600;o4`02o`L00_l500;o0`03o`L00_l;00;o
0`03o`P00_lH00005@02o`P00_l500;o1P03o`h00_lH00;o1@03o`<01?l400?o1003o`D00ol400;o
1@02o`H01?l400;o1002o`H00_l500;o3002o`D00ol400;o1@03o`@01?l400?o1002o`D00_l500;o
1@03o`D00_l600;o1002o`D00ol500;o1@03o`@00_l500;o2`02o`P00_l:00?o1@03o`D00_l400;o
1P02o`H00_l300?o1003oa<00ol500?o1@02o`@00ol600;o2`02o`@00ol700;o600001H00_l700?o
0`03o`L00ol<00;o5`0;o`<01?l500Co1009o`D02Ol500Co0P06o`801?l400Co00<0ool01_l700_o
0`0;o`@01?l500Co0`09o`<02ol400co0P0;o`@02ol500Wo1P0:o`802?l800[o0`05o`801Ol200co
1009oa@02_l300Go0`05o`030?oo00Ko1P05o`<01Ol200So5@0001L000?o00001P07o`T01ol70003
o`0001H02Ol500Co1@04o`H01Ol900Go1`03o`<01_l200Co1004o`030?oo00Ko1`09o`D02Ol600Co
1@04o`D01Ol500Wo1P0<o`802Ol600Wo2@05o`P02_l200So2P05o`030?oo00<01Ol200Go0P0<o`H0
1Ol00`3o000E00Go00<0ool00`05o`<01Ol00`3oo`06o`H01Ol300Go0P08oaD0000Q00Go3005ool0
``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(27\\) RMOPNTLPRMQPFRPQJKCXDS CKLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o?`02o`@00onn00005@02obP0
0_nY00[o?P0:okd0000D00;o:P02ojT01Ol200;o?`05o`800_nm00005002obX00_nY0003o`0004D0
00?o0000``0001@00_l800[o2002o`h00_lE00Go1P08o`<01Ol600Go1@08o`P01_l300;o1008o`@0
3Ol200So1P05o`H00ol00`3oo`03o`<01Ol500Go1@08o`L01ol700Go1P03o`030?oo00Ko2P05o`L0
1_l700Go1P02o`D01Ol600Go0P05o`<02?l600;o00<0ool00olH00Go1P05o`H00_l00`3oo`0;o`03
0?oo00?o1P02o`803Ol@00004`02o`T02_l800;o3`02oa@01Ol500Wo0`05o`@02Ol300So2006o`80
0ol400So100=o`802?l600Go1@04o`030?oo00?o0`05o`<02Ol300So1`07o`L01Ol500Co00<0ool0
1_l800Wo0`09o`H01Ol500?o0`09o`@01Ol200Go0`0:o`@02_lD00Wo1005o`D00ol00`3oo`0;o`03
0?oo00?o1@03o`803Ol@00004`02o`X00_l500;o2@02o`h00_lF00;o1@03o`<00_l700;o1003o`D0
0ol400;o3@02o`@01?l700;o2P02o`H00_l400;o3002o`D00ol400;o1`02o`<00ol500?o1002o`d0
0_l<00;o1@03o`D00_l;00?o1@03o`800ol400?o1`02o`D00ol300?o1@03o`@00ol400?o1@02o`@0
1?l300?o1@03oa800ol500?o1@02o`D00ol500;o1P02o`<00_l500?o1P02o`H00_l@00004`02o`/0
0ol>00;o3P02oaH00_l500;o1002o`L00_l400;o1`02o`@00_l=00;o1004o`L00_l:00;o1P02o`@0
0_l<00;o1@02o`D00_l700;o0`02o`L00_l400;o3@02o``00_l500;o1P02o`/00_l700;o0P02o`H0
0_l700;o1@02o`@00_l700;o1@03o`800ol600;o1P02o`<00_l700;o4P02o`L00_l500;o1@02o`H0
0_l600;o0`02o`D00_l700;o1P02oa00000C00;o3003o`d00_l>00;o5P02o`@00_l500;o0`02o`80
0_l300;o2@02o`<00_l=00;o0`05o`L00_l:00;o1P02o`@00_l<00;o1002o`H00_l300;o0P02o`80
0_l900;o0`02o`d00_l200;o2002o`@00_l700;o2P02o`T00_l00`3oo`0600;o1`02o`@00_l400?o
3`02o`800_l700;o1`02o`800_l700;o4@03o`h00_l400;o1`02o`H00_l300;o1002o`P00_l600;o
400001<00_l=00?o3@000ol0000<00;o5P02o`<00ol500;o0P03o`800_l300;o2@02o`<01ol800;o
0`02o`030?oo00L00_l:00;o1P02o`@01ol700;o0`03o`H00_l200?o0P02o`800_l900;o0`07o`P0
0_l200;o2002o`<00ol700Oo1@02o`T00_l00`3oo`0600;o1`03o`800ol400;o4@04o`P00_l700;o
2P03oa400_l?00?o0P03o`L00_l600;o0`03o`800ol800;o1P02oa00000C00;o3P03o``00_l=00;o
5P07o`H00_l20003o`3o00800_l300;o2@02o`<02Ol600;o0P03o`030?oo00L00_l:00;o3009o`D0
1ol700;o0P000ol0o`0200;o0P02o`T00_l300Wo1P06o`P01ol800Wo0`02o`T00_l900;o1`07o`D0
0_lA00Co2002o`L00_l500Oo4P02o`l01ol800;o2`07o`T00_lH00004`02o`l00ol;00;o3@02oaH0
2Ol400;o00@0ool00_l00`3oo`0300;o2@02o`<00_l500?o1@02o`800_l200;o1`02o`X00_l<00;o
1@03o`@02Ol500;o00@0ool00_l00`3oo`0200;o2@02o`<00_l500?o1@06o`P02Ol600;o1@03o`80
0_l900;o2@02o`L01Ol700;o4@03o`T00_l700;o0`07oa@00_l?00Go2P02o`/01Ol;00;o600001@0
0_l?00;o30000ol0000:00;o5`02o`D00ol300;o00<0ool00P001?l0ool300;o2@02o`<00_l600;o
1@02o`030?oo00<00_l200;o0`02o`<00_l500;o3002o`H00_l400;o1@03o`@00_l00`3oo`020004
o`3oo`800_l900;o0`02o`H00_l500;o0P02o`P00_l500?o1@02o`H00_l200;o2@02o`T00_l700;o
00@0oooo1P02oa401?l800;o1`02o`800olI00;o3`02o`040?ooo`T00_l;00;o00@0oooo2P02oaP0
000D00;o4002o`/00_l;00;o5`02o`H00_l300;o00<0o`000P001?l0ool300;o2@02o`<00_l600;o
1@05o`<00_l200;o0`02o`<00_l500;o3002o`H00_l400;o1P02o`@00_l00`3o00020004o`3oo`80
0ol800;o0`02o`H00_l500;o0P02o`800_l400;o1P02o`D00_l600;o0P03o`P00_l900;o1`02o`80
0ol500?o1`02o`H01_l700;o1`02o`800_l70003o`0001000ol700;o1@02o`800ol800;o2`02o`80
0ol900;o600001@00ol?00;o2`02o`/00_lG00;o1P02o`<01?l300Co1002o`L00_l400;o1P02o`D0
1?l400;o0P02o`<00_l300;o1@02o``00_l600;o1002o`H00_l400Co0`04o`<00_l700;o1002o`H0
0_l500;o1P02o`@00_l600;o1@02o`H00_l300;o1`02o`X00_l700;o0`03o`D00_l700;o1@03o`80
0ol600;o1P02o`<00_l600;o4`02o`L00_l500;o0`03o`L00_l;00;o0`03o`P00_lH00005@02o`P0
0_l500;o30000ol0000800;o6002o`D00ol300Co1003o`@00ol500?o1002o`D00ol500Co1002o`80
0_l300;o0`02o`D00_l<00;o1@03o`@00_l500?o1004o`@00ol400;o1@02o`D00_l500?o1@02o`H0
0_l400;o1@03o`D00_l500?o1002o`D00_l;00;o1`02o`@00ol400?o1@03o`D00_l400;o1P02o`@0
1?l300?o1003oa<00ol500?o1@02o`@00ol600;o2`02o`@00ol700;o600001H00_l700?o0`03o`D0
0_l500;o2002oaL02ol300Co1@04o`@02Ol300_o1@04o`801_l00`3oo`0:o`802?l700_o0`0;o`@0
1?l500Co0`09o`<02ol400co0P0;o`@02ol500Wo1P0:o`801Ol300Go0`0:o`<01Ol200Go0`0:o`D0
2OlD00[o0`05o`<01Ol00`3oo`06o`H01Ol300Go0P08oaD0000G0003o`0000H01ol600Wo20000ol0
000F00Wo1@04o`D01?l600Go1@09o`L00ol300Ko00<0ool02_l200So1`09o`D02Ol600Co1@04o`D0
1Ol500Wo1P0<o`802Ol600Wo2@05o`P02_l200Go0`05o`D01Ol00`3oo`0300Go0P05o`<02?l900Go
00<0o`005@05o`030?oo00<01Ol300Go00<0ool01_l600Go0`05o`802?lE00008@05o`L02Ooo0<@0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(28\\) RMOPNTLPRMQQFRPQJKCXDS CJLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o1@02o`@00ola00;o1003okh0
000E00;o:002ojT02_l400[o<00:okd0000D00;o:P02ojT01Ol200;o1@05o`800_la00Go0P02okd0
000D00;o:P02ojT000?o00002`000ol0000g0003o`000<<0000D00;o200:o`P01?l<00;o5@05o`H0
2?l300Go1P05o`D02?l800Ko0`02o`@02?l400go0P08o`H01Ol600?o00<0ool00ol300Go1@05o`T0
1Ol600Oo1`05o`H00ol00`3oo`06o`X01Ol700Ko1`05o`H00_l500Go1P05o`801Ol300So1P02o`03
0?oo00?o6005o`P01_l600go00<0ool00ol600;o0P0=oa00000C00;o2@0:o`H02?l;00;o5005o`D0
2Ol300Go1009o`<02?l800Ko0P03o`@02?l400go0P08o`H01Ol500Co00<0ool00ol300Go0`09o`D0
2Ol400Oo1`05o`D01?l00`3oo`06o`P02Ol300Wo1P05o`D00ol300Wo1005o`801Ol300[o100:oa@0
2Ol400Wo1@0=o`030?oo00?o1@03o`803Ol@00004`02o`X00_l500;o1@03o`@00ol:00;o5P02o`D0
0ol300;o1`02o`@00ol500?o1002o`d00_l400Co1`02o`X00_l600;o1002o``00_l500?o1002o`L0
0_l300?o1@03o`<00ol500?o1@02o``00_l500?o1@02o`/00ol500?o0P03o`@00ol700;o1@03o`<0
0ol500?o1003o`@00ol500;o1004o`<00ol500?o4P03o`D00ol300?o1003o`L00_l600;o0`02o`D0
0ol600;o1P02oa00000C00;o2`03o`X00_l600;o2P02oaH00_l500;o1002o`L00_l400;o1`02o`@0
0_l=00;o1004o`L00_l:00;o1P02o`@00_l<00;o1@02o`D00_l700;o0`02o`L00_l300;o1`02o`D0
0_l<00;o1@02o`H00_l;00;o1`02o`800_l600;o1`02o`D00_l400;o1`02o`D00ol200?o1P02o`H0
0_l300;o1`02oa800_l700;o0`02o`H00_l700;o1P02o`<00_l500;o1`02o`H00_l@00004`02o``0
0ol900;o1P02o`X00_lF00;o1002o`D00_l300;o0P02o`<00_l900;o0`02o`d00_l300Go1`02o`X0
0_l600;o1002o``00_l400;o1P02o`<00_l200;o0P02o`T00_l00`3oo`0900;o1002o`800_l800;o
1002o`L00_l:00;o2@02o`030?oo00H00_l700;o1002o`@00ol?00;o0P02o`L00_l700;o0P02o`L0
0_lA00?o3002o`H00_l700;o1P02o`<00_l400;o2002o`H00_l@00004`02o`d00ol800;o1P02o`X0
0_lF00;o0`03o`D00_l200?o0P02o`<00_l900;o0`07o`P00_l300;o00<0ool01`02o`X00_l600;o
1007o`L00_l300?o1P02o`800ol200;o0P02o`T00_l00`3oo`0900;o1002o`800_l800;o0`03o`L0
1ol500;o2@02o`030?oo00H00_l700?o0P03o`@00_lA00Co2002o`L00_l:00?o4@02o`d00_l600;o
1`02o`H00_l300?o0P03o`P00_l600;o400001<00_l>00?o2002o`@00_l;00;o5P07o`H00_l20003
o`3o00800_l300;o2@02o`<02Ol600;o0P03o`030?oo00L00_l:00;o3009o`D01ol700;o0P000ol0
o`0200;o0P02o`T00_l00`3oo`0900;o1006o`P01ol800Wo0`02o`T00_l900;o1`07o`D00_lA00Co
2002o`L00_l500Oo4P02oaD00_l700;o2`07o`T00_lH00004`02o`l00ol800Oo2`02oaH02Ol400;o
00@0ool00_l00`3oo`0300;o2@02o`<00_l500?o1@02o`800_l200;o1`02o`X00_l<00;o1@03o`@0
2Ol500;o00@0ool00_l00`3oo`0200;o2@02o`030?oo00T00_l400Ko2009o`H00_l500?o0P02o`T0
0_l900;o1`05o`L00_lA00?o2@02o`L00_l300Oo5002oaD00_l700;o2`05o`/00_lH00005002o`l0
0_l800Ko2`02oaL00_l500?o0`02o`030?oo008000Co0?oo0`02o`T00_l300;o1P02o`D00_l00`3o
o`0300;o0P02o`<00_l300;o1@02o``00_l600;o1002o`D00ol400;o00<0ool00P001?l0ool200;o
2@02o`030?oo00T00_l400;o0P02o`P00_l500?o1@02o`H00_l200;o2@02o`T00_l700;o00@0oooo
1P02oa401?l800;o1`02o`800olI00;o5@02o`L00_l;00;o00@0oooo2P02oaP0000D00;o4002o`H0
0_l400;o2P02oaL00_l600;o0`02o`030?l0008000Co0?oo0`02o`T00_l300;o1P02o`D01Ol300;o
0P02o`<00_l300;o1@02o``00_l600;o1002o`H00_l400;o00<0o`000P001?l0ool200?o2002o`04
0?ooo`P00_l400;o0P02o`800_l400;o1P02o`D00_l600;o0P03o`P00_l900;o1`02o`800ol500?o
1`02o`H01_l700;o1`02o`800_l70003o`0001000ol700;o2`02o`L00_l;00;o0P03o`T00_lH0000
5003o`l00_l500;o1P02o`T00_lG00;o1P02o`<01?l300Co1002o`L00_l400;o1P02o`D01?l400;o
0P02o`<00_l300;o1@02o``00_l600;o1002o`H00_l400Co0`04o`<00_l700;o0`02o`L00_l500;o
1P02o`@00_l600;o1@02o`H00_l300;o1`02o`X00_l700;o0`03o`D00_l700;o1@03o`800ol600;o
1P02o`<00_l600;o4`02o`L00_l;00;o1`02o`/00_l300?o2002oaP0000E00;o2002o`D00_l500;o
1P02o`P00_lH00;o1@03o`<01?l400?o1003o`D00ol400;o1@03o`D01?l400;o0P02o`<00_l300;o
1@02o``00_l500?o1002o`D00ol400Co1003o`@00_l500;o1@02o`D00_l600;o1P02o`@00_l500?o
1@02o`D00ol400;o1@02o`/00_l700;o1003o`@00ol500?o1@02o`@00_l600;o1004o`<00ol400?o
4`03o`D00ol;00;o1`02o`/00_l400?o1`02oaP0000F00;o1`03o`<00ol500?o1003o`L00_lG00_o
0`04o`D01?l400Wo0`0;o`D01?l200Ko00<0ool02_l200So1`0;o`<02ol400Co1@04o`<02Ol500Wo
100<o`802ol400_o1@09o`H02_l200Go0`05o`<02_l300Go0P05o`<02_l500Wo500:o`H02_l00`3o
o`06o`H01Ol300Go0P08oaD0000G0003o`0000H01ol700So20000ol0000F00Wo1@04o`D01?l600Go
1@09o`L00ol300Ko00<0ool02_l200So1`09o`D02Ol600Co1@04o`D01Ol900Go1P0<o`802Ol600Wo
2@05o`P02_l200Go0`05o`D01Ol00`3oo`0300Go0P05o`<02?l900Go00<0o`005@05o`030?oo00H0
2_l00`3oo`06o`H01Ol300Go0P08oaD0000Q00Go2@06ool0a@000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(29\\) RMOPNTLPSMQQFSPQJKCXDT CJLKL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o1@02o`@00ola00;o1003okh0
000E00;o:002ojT02_l400[o<00:okd0000D00;o:P02ojT01Ol200;o1@05o`800_la00Go0P02okd0
000D00;o:P02ojT000?o00002`000ol0000g0003o`000<<0000D00;o200:o`D01Ol>00;o5@05o`H0
2?l300Go1P05o`D02?l800Ko0`02o`@02?l400go0P08o`L00_l00`3oo`03o`H01Ol300Go1@05o`T0
1Ol600Oo2002o`030?oo00?o1P08o`X01Ol700Ko1`05o`H00_l500Go1P05o`801Ol300So1`08oaL0
1Ol800Ko1P0=o`030?oo00?o1P02o`803Ol@00004`02o`T02_l500Oo3@02oa@01Ol500Wo0`05o`@0
2Ol300So2006o`800ol400So100=o`802?l700[o1005o`<01Ol300Wo1@09o`@01ol800[o1008o`P0
2Ol300Wo1P05o`D00ol300Wo1005o`801Ol300[o1@08oaD02Ol400Wo1@0=o`030?oo00?o1@03o`80
3Ol@00004`02o`X00_l500;o2P03o``00_lF00;o1@03o`<00_l700;o1003o`D00ol400;o3@02o`@0
1?l700;o2P02o`H00_l400;o2`03o`D00ol400;o1`02o`<00ol500?o0`03o`D00ol500;o2`03o`D0
0ol500;o2`03o`D00ol200?o1003o`L00_l500?o0`03o`D00ol400?o1003o`D00_l400Co1`02oaL0
0ol500?o0`03o`@00ol700;o1P02o`<00_l500?o1P02o`H00_l@00004`02o`/00ol@00?o2`02oaH0
0_l500;o1002o`L00_l400;o1`02o`@00_l=00;o1004o`L00_l:00;o1P02o`@00_l;00;o1`02o`@0
0_l700;o0`02o`L00_l300;o1`02o`D00_l;00;o1`02o`D00_l;00;o1`02o`800_l600;o1`02o`D0
0_l400;o1`02o`D00ol200?o1P02o`H00_l700;o5`02o`L00_l300;o1P02o`L00_l600;o0`02o`D0
0_l700;o1P02oa00000C00;o3003oa000_l;00;o5P02o`@00_l500;o0`02o`800_l300;o2@02o`<0
0_l=00;o0`05o`L00_l:00;o1P02o`@00_l;00;o1`02o`@00_l300;o0P02o`800_l900;o00<0ool0
2@02o`@00_l200;o1`02o`L00_l500;o2P02o`T00_l00`3oo`0600;o1`02o`@00_l400?o3`02o`80
0_l700;o1`02o`H00_lF00?o3002o`H00_l700;o1P02o`<00_l400;o2002o`H00_l@00004`02o`d0
0ol;00Co00<0ool02P02oaH00_l300?o1@02o`800ol200;o0`02o`T00_l300Oo2002o`<00_l00`3o
o`0700;o2P02o`H00_l400Oo3P03o`@00_l200?o0P02o`800_l900;o00<0ool02@02o`@00_l200;o
3`03o`D01ol500;o2@02o`030?oo00H00_l700?o0P03o`@00_lA00Co2002o`L00_l600;o5P02o`d0
0_l600;o1`02o`H00_l300?o0P03o`P00_l600;o400001<00_l>00?o2009o`X00_lF00Oo1P02o`80
00?o0?l00P02o`<00_l900;o0`09o`H00_l200?o00<0ool01`02o`X00_l<00Wo1`07o`D00_l20003
o`3o00800_l200;o2@02o`030?oo00T00_l400Ko2P07o`H02Ol300;o2@02o`T00_l700Oo1@02oa40
1?l800;o1`02o`H00_lF00;o5@02o`L00_l;00Oo2@02oaP0000C00;o3`03o`L00_l400?o2P02oaH0
2Ol400;o00@0ool00_l00`3oo`0300;o2@02o`<00_l500?o1@02o`800_l200;o1`02o`X00_l<00;o
1@03o`@01ol700;o00@0ool00_l00`3oo`0200;o2@02o`030?oo00T00_l400Ko2007o`P00_l500?o
0P02o`T00_l900;o1`05o`L00_lA00?o2@02o`L00_l600;o5P02oaD00_l700;o2`05o`/00_lH0000
5002o`l00_l600;o1P02o`T00_lG00;o1@03o`<00_l00`3oo`020004o`3oo`<00_l900;o0`02o`H0
0_l500;o00<0ool00`02o`800_l300;o0`02o`D00_l<00;o1P02o`<00ol<00;o00<0ool00P001?l0
ool200;o2@02o`030?oo00T00_l400;o0P02o`L00ol=00;o1P02o`800_l900;o2@02o`L00_l0103o
ool600;o4@04o`P00_l700;o00<0ool00`02o`<00_lA00;o5@02o`L00_l;00;o00@0oooo2P02oaP0
000D00;o4002o`D00_l600;o2@02oaL00_l600;o0`02o`030?l0008000Co0?oo0`02o`T00_l300;o
1P02o`D01Ol300;o0P02o`<00_l300;o1@02o``00_l600;o0`02o`L000?o00000`02o`030?l00080
00Co0?oo0P03o`P00_l0103oool800;o1002o`800_l200;o0`02o`L000?o00001002o`H00_l200?o
2002o`T00_l700;o0P03o`D00ol700;o1P06o`L00_l700;o00<0ool00`02o`<00_lA00?o1`02o`/0
0_l700;o2`02o`800ol900;o600001@00ol?00;o1@02o`H00_l900;o5`02o`H00_l300Co0`04o`@0
0_l700;o1002o`H00_l500Co1002o`800_l300;o0`02o`D00_l<00;o1P02o`<00_l600;o1@04o`<0
1?l300;o1`02o`<00_l700;o1@02o`H00_l300;o1P02o`H00_l600;o0`02o`L00_l:00;o1`02o`<0
0ol500;o1`02o`D00ol200?o1P02o`H00_l200;o0`02o`<00_lB00;o1`02o`/00_l700;o2`02o`<0
0ol800;o600001D00_l800;o1@02o`D00_l60003o`0000L00_lH00;o1@03o`<01?l400?o1003o`D0
0ol400;o1@03o`D01?l400;o0P02o`<00_l300;o1@02o``00_l500?o0`03o`@00ol500Co1003o`@0
0_l500;o1@02o`D00_l600;o1P02o`<00ol400?o1P02o`D00ol400;o1@02o`/00_l700;o1003o`@0
0ol500?o1@02o`@00_l600;o1004o`800_l300;o0`02oa800ol500?o2`02o`L00_l;00;o1003o`L0
0_lH00005P02o`L00ol300?o1P02o`@00_l800;o5`0;o`<01?l500Co1009o`<02ol500Co0P06o`03
0?oo00[o0P08o`L02ol500Wo1004o`D01?l300Wo1@09o`@03?l400Wo100;o`D02Ol600[o0P05o`<0
1Ol300[o0`05o`801Ol300[o0`0<oa<02_l600[o00<0ool01_l600Go0`05o`802?lE00005`000ol0
000600Oo1`07o`T000?o00005P09o`D01?l500Co1P05o`D02Ol700?o0`06o`030?oo00[o0P08o`L0
2Ol900Go00<0o`000`04o`D01?l500Go2@05o`H03?l600Go00<0o`000`09o`T01Ol800[o0P05o`<0
1Ol500Go00<0ool00`05o`801Ol300So1@0<oaD01Ol00`3oo`0600[o00<0ool01_l600Go0`05o`80
2?lE00008@05o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(30\\) RMOPNSLQSMQRFSPQJKCXDT CJLKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00olo00;o1003okh0
000E00;o:002ogh02_lQ00[o?P0:okd0000D00;o:P02ogh01Ol200;o8P05o`800_lo00Go0P02okd0
000D00;o:P02ogh000?o0000:0000ol000150003o`000<<0000D00;o2P05o`/01?l<00;o5@05o`H0
2?l300Go1P05o`D02?l800Ko0`02o`<00_l00`3oo`03o`D03Ol600Go1P02o`030?oo00?o1P05o`<0
1Ol500Go1@05o`H00ol00`3oo`05o`P00_l00`3oo`03o`H02?l:00Go1`06o`L01Ol600;o1@05o`H0
1Ol200Go0`08o`L02?lG00Go2006o`H03Ol00`3oo`03o`H00_l200Go1P02oa00000C00;o2@09o`P0
1_l<00;o5005o`D02Ol300Go1009o`<02?l800Ko0P03o`<02_l300go1009o`@02_l400Go0`05o`<0
2Ol300Go1@04o`030?oo00Go200:o`@02?l800Wo0`09o`H01Ol500?o0`09o`@01Ol200Go0`0:o`D0
2?lE00Wo1009o`D03Ol00`3oo`03o`D00ol200Go1@03oa00000C00;o2@02o`D00_l700?o0P03o`/0
0_lF00;o1@03o`<00_l700;o1003o`D00ol400;o3@02o`@01?l300?o1@03o`D00_l600;o0`03o`D0
0ol300?o1@03o`@00_l700;o0`03o`D00ol400;o1@03o`D00_l;00?o1@03o`D00_l;00?o1@03o`80
0ol400?o1`02o`D00ol300?o1@03o`@00ol400?o1@02o`@01?l700;o5`03o`D00ol300?o1003o`L0
0_l600;o0`02o`D00ol500;o1@03oa40000C00;o4@02o`H00_l400;o2`02oaH00_l500;o1002o`L0
0_l400;o1`02o`@00_l=00;o1004o`<00_l700;o1@02o`H00_l300;o1`02o`<00_l700;o1002o`L0
0_l300;o1`02o`@00_l500;o1P02o`/00_l700;o1@02o`/00_l700;o0P02o`H00_l700;o1@02o`@0
0_l700;o1@03o`800ol600;o1P02o`L00_lG00;o1`02o`<00_l600;o1`02o`H00_l300;o1@02o`H0
0_l500;o4P0001<00_lA00;o1@02o`H00_l:00;o5P02o`@00_l500;o0`02o`800_l300;o2@02o`<0
0_l=00;o0`05o`<00_l700;o1@02o`H00_l200;o2@02o`800_l700;o1002o`<00_l200;o0P02o`T0
0_l300;o1002o`L00_l200;o1`02o`L00_l500;o2P02o`T00_l00`3oo`0600;o1`02o`@00_l400?o
3`02o`800_l700;o1`02o`H00_lF00?o3002o`H00_l700;o1P02o`<00_l400;o1`02o`@00_lC0000
4`02oa400_l500;o1P02o`X00_lF00;o0`03o`D00_l200?o0P02o`<00_l900;o0`07o`P00_l300;o
00<0ool02`03o`D00_l600;o0P02o`T00_l:00?o1002o`800ol200;o0P02o`T00_l300;o0`03o`L0
0_l200;o3`03o`D01ol500;o2@02o`030?oo00H00_l700?o0P03o`@00_lA00Co2002o`L00_l600;o
5P02o`d00_l600;o1`02o`H00_l300?o0P03o`L00ol200?o4`0001<00_l@00;o1P02o`H00_l:00;o
5P07o`H00_l20003o`3o00800_l300;o2@02o`<02Ol600;o0P03o`030?oo00H01ol600;o2P02o`T0
0_l500Oo1@02o`8000?o0?l00P02o`800_l900;o0`07o`P01_l:00Oo1P09o`<00_l900;o2@02o`L0
1ol500;o4@04o`P00_l700;o1P02oaH00_lE00;o1`02o`/01ol800Oo500001<00_l=00Co1`02o`H0
0_l:00;o5P09o`@00_l0103oo`02o`030?oo00<00_l900;o0`02o`D00ol500;o0P02o`800_l400Oo
2002o`X00_l900;o0`07o`L00_l0103oo`02o`030?oo00800_l900;o0`09o`H01_l800Oo2002o`D0
0ol200;o2@02o`T00_l700Go1`02oa400ol900;o1`02o`H00_lF00;o5@02o`L00_l;00Go2P05oaH0
000D00;o3003o`P00_l600;o2@02oaL00_l500?o0`02o`030?oo008000Co0?oo0`02o`T00_l300;o
1P02o`D00_l00`3oo`0300;o0`03o`d00_l:00;o2@02o`800ol<00;o00<0ool00P001?l0ool200;o
2@02o`<00_l500?o1@02o`800_l700?o3@02o`H00_l200;o2@02o`T00_l700;o00@0oooo1P02oa40
1?l800;o1`02o`030?oo00<00_l300;o4@02oaD00_l700;o2`02o`040?ooo`T00_l0103ooolE0000
5002o`h00_l700;o1P02o`T00_lG00;o1P02o`<00_l00`3o00020004o`3oo`<00_l900;o0`02o`H0
0_l500Go0`02o`<00_l70003o`0000@00_l:00?o2002o`800_l70003o`0000<00_l00`3o00020004
o`3oo`800ol800;o0`02o`H00_l500;o0P02o`800_l300;o1`000ol0000400;o1P02o`800ol800;o
2@02o`L00_l200?o1@03o`L00_l600Ko1`02o`L00_l00`3oo`0300;o0`02oa400ol700;o2`02o`L0
0_l;00;o0P03o`P00_l200?o500001@00ol>00;o1P02o`H00_l900;o5`02o`H00_l300Co0`04o`@0
0_l700;o1002o`H00_l500Co1002o`<00_l600;o1P02o`/00_l700;o0`02o`H00_l500Co0`04o`<0
0_l700;o1002o`H00_l500;o1P02o`<00_l600;o1P02o`H00_l300;o1`02o`X00_l700;o0`03o`D0
0_l700;o1@03o`800ol600;o1P02o`800_l300;o0`02oa800_l700;o2`02o`L00_l;00;o0`03o`L0
0_l300?o4`0001D00_l>00;o1`02o`@00_l900;o6002o`D00ol300Co1003o`@00ol500?o1002o`D0
0ol500Co1002o`<00ol400?o1P02o``00_l500;o1003o`@00ol500Co1003o`@00_l500;o1@02o`D0
0ol500;o1P02o`<00ol400?o1P02o`D00ol400;o1@02o`/00_l700;o1003o`@00ol500?o1@02o`@0
0_l600;o1004o`800_l300;o0`02oa800ol500?o2`02o`L00_l;00;o1003o`H00_l400?o4P0001H0
0_l700;o0`03o`L00ol200?o2002oaL02ol300Co1@04o`@02Ol300_o1@04o`801_l300Wo0`08o`T0
2Ol500Wo1004o`D01?l300Wo0`0;o`@03?l400Wo100;o`D02Ol600[o0P05o`<01Ol300[o0`05o`80
1Ol300[o0`0<oa<02_l600[o00<0ool01_l600Go0`05o`801Ol300Go400001L000?o00001@07o`T0
1_l90003o`0001H02Ol500Co1@04o`H01Ol500Wo1`03o`<01_l500Go00<0o`000P08o`/01Ol900Go
00<0o`000`04o`D01?l500Go1@09o`H03?l600Go00<0o`000`09o`T01Ol800[o0P05o`<01Ol500Go
00<0ool00`05o`801Ol300So1@0<oaD01Ol00`3oo`0600[o00<0ool01_l600Go0`05o`801Ol300Go
400002401?l;00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(31\\) QMOPNSLQSMQRFSQQJLCXDT CJLKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oG002o`@00olR00;o1003oc40
0_l400?o1@02o`@00onn00005@02obP00_lI00[oF`0:ob402_l`00[o100:okd0000D00;o:P02oaT0
1Ol200;oG005o`800_lR00Go0P02oc401Ol200;o1@05o`800_nm00005002obX00_lI0003o`000680
00?o0000:0000ol0000g0003o`0000/000?o0000``0001@00_l:00Go2@09o`T00_lI00Go1@05o`<0
1Ol600Go1@08o`P01_l300;o0`02o`030?oo00?o1@0=o`H01Ol600;o00<0ool00ol600Go0`05o`D0
1Ol500Go1P03o`030?oo00Go2002o`030?oo00?o2P05o`T01Ol700Ko1`0=o`D01Ol600Go0P05o`<0
2?l700So5`05o`P01_l600go00<0ool00ol600;o0P05o`H00_l@00004`02o`T02Ol700Wo2P02oaH0
2Ol300Go0`05o`@02Ol300So2006o`800ol300[o0`0=o`@02Ol400[o1005o`<01Ol300Wo0`05o`D0
1?l00`3oo`05o`P02_l600Wo1@09o`<02Ol600go0`09o`@01Ol200Go0`0:o`D02?lE00Wo1009o`D0
3Ol00`3oo`03o`D00ol200Go1@03oa00000C00;o2@02o`D00_l;00;o3@02oaD00ol500?o0`02o`L0
0_l400?o1@03o`@00_l=00;o1004o`<00ol500?o1@02o`H00_l300?o1@03o`<00ol500?o1002o`L0
0_l300?o1@03o`@00_l500?o1@02o`/00ol500?o1003o`D00ol300?o1@03o`800ol400?o2002o`H0
0_l200?o1@03o`@00ol400?o1@02o`@01?l700;o5`03o`D00ol300?o1003o`L00_l600;o0`02o`D0
0ol500;o1@03oa40000C00;o4@02o`X00_l=00;o5@02o`L00_l300;o1`02o`@00_l700;o1002o`d0
0_l400Co0`02o`L00_l500;o1P02o`<00_l700;o0`02o`L00_l400;o1`02o`<00_l700;o1002o`D0
0_l600;o2`02o`L00_l400;o1`02o`<00_l700;o0P02o`H00_l800;o1P02o`800_l700;o1@03o`80
0ol600;o1P02o`L00_lG00;o1`02o`<00_l600;o1`02o`H00_l300;o1@02o`H00_l500;o4P0001<0
0_lA00;o2P02o`d00_lD00;o2@02o`800_l300;o0P02o`<00_l900;o0`02o`d00_l300Go0`02o`L0
0_l500;o1P02o`800_l900;o0P02o`L00_l400;o0`02o`800_l200;o2@02o`<00_l400;o1`02o`80
0_l700;o1`02o`<00_l900;o00<0ool02@02o`030?oo00H00_l800;o1P02o`040?ooo`l00_l200;o
1`02o`L00_l600;o5P03o``00_l600;o1`02o`H00_l300;o1002o`L00_l400;o4`0001<00_lA00;o
2P02o`d00_lD00;o2@02o`800_l200?o0P02o`<00_l900;o0`07o`P00_l300;o00<0ool02`03o`D0
0_l600;o0P02o`T00_l:00?o1002o`800ol200;o0P02o`T00_l300;o0`03o`L00_l200;o3`03o`<0
0_l900;o00<0ool02@02o`030?oo00H00_l800;o1P02o`030?oo01401?l800;o1`02o`H00_lF00;o
3@02o`H00_l700;o1P02o`<00ol200?o1`03o`800olC00004`02oa000_l;00;o3@02oa@00_l900;o
0P02o`8000?o0?l00P02o`<00_l900;o0`09o`H00_l200?o00<0ool01P07o`H00_l:00;o2@02o`D0
1ol500;o0P000ol0o`0200;o0P02o`T00_l300Oo2006o`X01ol400;o2@02o`030?oo00T00_l900;o
2002o`T00_lA00Co2002o`L00_l600;o5P02oaD00_l700;o2`07o`P01olD00004`02o`d01?l<00;o
3@02oa@00_l900;o0P02o`040?oo00;o00<0ool00`02o`T00_l300;o1@03o`D00_l200;o0P02o`@0
1ol800;o2P02o`T00_l300Oo1`02o`040?oo00;o00<0ool00P02o`T00_l300Wo1P06o`P01ol600;o
2@02o`030?oo00T00_l900;o2002o`T00_lA00?o2@02o`L00_l600;o5P02oaD00_l700;o2`05o`X0
1OlF00005002o``00ol=00;o3002oaD00_l900;o0P02o`030?oo008000Co0?oo0`02o`T00_l300;o
1P02o`D00_l00`3oo`0300;o0`03o`d00_l:00;o2@02o`800ol<00;o00<0ool00P001?l0ool200;o
2@02o`<00_l500?o1@02o`800_l700?o2`02o`T00_l00`3oo`0900;o2@02o`P00_l900;o4@04o`P0
0_l700;o00<0ool00`02o`<00_lA00;o5@02o`L00_l;00;o00@0oooo2@02o`040?oooaD0000D00;o
3P02o``00_l<00;o5@03o`P00_l200;o00<0o`000P001?l0ool300;o2@02o`<00_l600;o1@05o`<0
0_l300;o1`000ol0000400;o2P03o`P00_l200;o1`000ol0000300;o00<0o`000P001?l0ool200?o
2002o`<00_l600;o1@02o`800_l200;o0`02o`L000?o00000P03o`P00_l0103oool800;o2@02o`P0
0_l900?o1`02o`H01_l700;o1`02o`030?oo00<00_l300;o4@03o`L00_l;00;o1`02o`/00_l200?o
2002o`800olD00005003o`h00_l;00;o3002oaH00_l700;o0`04o`<01?l400;o1`02o`@00_l600;o
1@04o`@00_l300;o1P02o`H00_l;00;o1`02o`<00_l600;o1@04o`<01?l300;o1`02o`@00_l600;o
1@02o`H00_l300;o1P02o`D00_l700;o0`02o`L00_l:00;o2002o`X00_l700;o1@03o`800ol600;o
1P02o`800_l300;o0`02oa800_l700;o2`02o`L00_l;00;o0`03o`L00_l300?o4`0001D00_l>00;o
2`02o`/00_lH00;o1@02o`@01?l400?o1003o`D00ol400;o1@03o`D01?l400;o0`03o`@00ol600;o
3002o`D00_l400?o1003o`D01?l400?o1002o`D00_l500;o1@03o`D00_l600;o0`03o`@00ol600;o
1@02o`D00_l500;o2`02o`P00_l:00?o1@03o`D00_l400;o1P02o`@01?l200;o0`02o`<00_lB00?o
1@03o`/00_l700;o2`02o`@00ol600;o1003oa80000F00;o1`02o`<00ol700?o00<0ool02P02oaT0
2Ol300Co1@04o`@02Ol300_o1@04o`801_l300Wo0`08o`T02Ol500Wo1004o`D01?l300Wo0`0;o`@0
3?l400Wo1P09o`D02Ol600[o0P08o`P02_l300Go0P05o`<02_l300co4`0:o`H02_l00`3oo`06o`H0
1Ol300Go0P05o`<01Ol@00005`000ol0000500Oo2006o`X000?o00006P05o`D01?l500Co1P05o`D0
2Ol700?o0`06o`D01Ol00`3o000200So2`05o`T01Ol00`3o000300Co1@04o`D01Ol500Wo1P0<o`H0
1Ol00`3o000700Go2@05o`P02_l200So2P05o`030?oo00<01Ol200Go0`08o`D03?lE00Go00<0ool0
1P0:o`030?oo00Ko1P05o`<01Ol200Go0`05oa00000Q00Co3003ool0aP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(32\\) QMOPNSLQSMQRFSRQJLCXDU CJLKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oG002o`@00olR00;o1003ocl0
0_l400?o_P0001D00_lX00;o6@0:oe/02_lQ00[o?P0:okd0000D00;o:P02oaT01Ol200;oG005o`80
0_lR00Go0P02ocl01Ol200;o_@0001@00_lZ00;o6@000ol0001R0003o`0002P000?o0000A@000ol0
003300005002o`X01Ol800[o2@02oaT01Ol500Go0`05o`H01Ol500So2006o`<00_l300;o00<0ool0
0ol500go1P05o`H00_l00`3oo`03o`H01Ol300Go1@05o`D01Ol600?o00<0ool01Ol800;o00<0ool0
0ol600Go1P03o`@01Ol700Ko1`0=o`D01Ol600Go0P05o`<02?l:00Co6005o`P01_l600go00<0ool0
0ol600;o0P05o`H00_l@00004`02o`T02Ol600[o2P02oaH02Ol300Go0`05o`@02Ol300So2006o`80
0ol300[o0`0=o`@02Ol400[o1005o`<01Ol300Wo0`05o`D01?l00`3oo`05o`P02_l400Go1@04o`80
2Ol300Wo1P0=o`<02Ol400Go0P05o`<02_l600So5009o`@02Ol500go00<0ool00ol500?o0P05o`D0
0ol@00004`02o`T00_l500;o1`02o`D00_l:00;o5@03o`D00ol300;o1`02o`@00ol500?o1002o`d0
0_l400Co0`03o`D00ol500;o1P02o`<00ol500?o0`03o`D00ol400;o1`02o`<00ol500?o1002o`D0
0ol500;o2`03o`D00ol500;o1@03o`<00ol500?o0P03o`@00ol800;o1P02o`800ol500?o1003o`@0
0ol500;o1004o`D00_l400;o4`03o`D00ol300?o1003o`L00_l600;o0`02o`D00ol500;o1@03oa40
000C00;o4@02o`L00ol?00;o5@02o`L00_l300;o1`02o`@00_l700;o1002o`d00_l400Co0`02o`L0
0_l500;o1P02o`<00_l700;o0`02o`L00_l400;o1`02o`<00_l700;o1002o`D00_l600;o2`02o`L0
0_l500;o1@02o`@00_l700;o0P02o`H00_l800;o1P02o`800_l700;o1@03o`800ol600;o1P02o`@0
0_l600;o4P02o`L00_l300;o1P02o`L00_l600;o0`02o`D00_l600;o1@02oa80000C00;o4@02o`P0
0ol>00;o5002o`T00_l200;o0`02o`800_l300;o2@02o`<00_l=00;o0`05o`<00_l700;o1@02o`H0
0_l200;o2@02o`800_l700;o1002o`<00_l200;o0P02o`T00_l300;o1002o`L00_l200;o1`02o`L0
0_l500;o1002o`@00_l900;o00<0ool01P02o`P00_l600;o00@0oooo3`02o`800_l700;o1`02o`<0
0_l600;o4@03o``00_l600;o1`02o`H00_l300;o1002o`L00_l400;o4`0001<00_lA00;o2@03o`d0
0_lD00;o2@02o`800_l200?o0P02o`<00_l900;o0`07o`P00_l300;o00<0ool02`03o`D00_l600;o
0P02o`T00_l:00?o1002o`800ol200;o0P02o`T00_l300;o0`03o`L00_l200;o3`03o`D00_l300?o
1002o`T00_l00`3oo`0600;o2002o`H00_l00`3oo`0A00Co2002o`L00_l300;o1P02oa400_l=00;o
1P02o`L00_l600;o0`03o`800ol700?o0P03oa<0000C00;o4002o`/00ol<00;o5002o`T00_l200;o
0P000ol0o`0200;o0`02o`T00_l300Wo1P02o`800ol00`3oo`0600Oo1P02o`X00_l900;o1@07o`D0
0_l20003o`3o00800_l200;o2@02o`<01ol800Ko2P07o`H01ol500;o2@02o`T00_l800;o2@02oa40
1?l800;o1`02o`<00_l600;o4@02oaD00_l700;o2`07o`P01olD00004`02o`d01?l=00?o2`02oa@0
0_l900;o0P02o`040?oo00;o00<0ool00`02o`T00_l300;o1@03o`D00_l200;o0P02o`@01ol800;o
2P02o`T00_l300Oo1`02o`040?oo00;o00<0ool00P02o`T00_l300Wo1P06o`P01ol800Wo0`02o`T0
0_l900;o2002o`T00_lA00?o2@02o`L00_l300;o1P02oa400_lE00;o1`02o`/01Ol:00Go5P0001@0
0_l<00?o3`02o`X00_lE00;o2@02o`800_l00`3oo`020004o`3oo`<00_l900;o0`02o`H00_l500;o
00<0ool00`02o`<00ol=00;o2P02o`T00_l200?o3002o`030?oo008000Co0?oo0P02o`T00_l300;o
1@03o`D00_l200;o1`03o`d00_l500?o0P02o`T00_l900;o2002o`T00_lA00Co2002o`L00_l300;o
1P02oa400_lE00;o1`02o`/00_l0103oool900;o00@0oooo5@0001@00_l>00;o3`02o`T00_lE00?o
2002o`800_l00`3o00020004o`3oo`<00_l900;o0`02o`H00_l500Go0`02o`<00_l70003o`0000@0
0_l:00?o2002o`800_l70003o`0000<00_l00`3o00020004o`3oo`800ol800;o0`02o`H00_l500;o
0P02o`800_l300;o1`000ol0000400;o1P02o`800ol800;o2@02o`P00_l900?o1`02o`H01_l700;o
1`02o`<00_l600;o4@03o`L00_l;00;o1`02o`/00_l200?o2002o`800olD00005003o`h00_l>00;o
2@02oaH00_l700;o0`04o`<01?l400;o1`02o`@00_l600;o1@04o`@00_l300;o1P02o`H00_l;00;o
1`02o`<00_l600;o1@04o`<01?l300;o1`02o`@00_l600;o1@02o`H00_l300;o1P02o`H00_l600;o
0`02o`L00_l:00;o2002o`X00_l700;o1@03o`800ol600;o1P02o`@00_l600;o4P02o`L00_l;00;o
1`02o`/00_l300?o1`02o`<00olC00005@02o`h00_l700;o1@02o`P00_lH00;o1@02o`@01?l400?o
1003o`D00ol400;o1@03o`D01?l400;o0`03o`@00ol600;o3002o`D00_l400?o1003o`D01?l400?o
1002o`D00_l500;o1@03o`D00_l600;o0`03o`@00ol600;o1@03o`@00_l500;o2`02o`P00_l:00?o
1@03o`D00_l400;o1P02o`@01?l400;o1P02oa800ol500?o2`02o`L00_l;00;o1003o`H00_l400?o
4P0001H00_l700;o0`03o`L00ol300?o1`02oaT02Ol300Co1@04o`@02Ol300_o1@04o`801_l300Wo
0`08o`T02Ol500Wo1004o`D01?l300Wo0`0;o`@03?l400Wo100;o`D02Ol600[o0P08o`P02_l300Go
0P05o`<02_l400Co1004oa802_l600[o00<0ool01_l600Go0`05o`801Ol300Go400001L000?o0000
1@07o`T01ol80003o`0001X01Ol500Co1@04o`H01Ol500Wo1`03o`<01_l500Go00<0o`000P08o`/0
1Ol900Go00<0o`000`04o`D01?l500Go1@09o`H03?l600Go00<0o`000`09o`T01Ol800[o0P08o`X0
1Ol00`3oo`0300Go0P05o`<02?l600Co1004oa@01Ol00`3oo`0600[o00<0ool01_l600Go0`05o`80
1Ol300Go400002401?l;00Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(33\\) QMOONSMQTMQRFSSPJLCXDUZCKLKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oG002o`@00olR00;o1003ool0
1`0001D00_lX00;o6@0:oe/02_lQ00[oo`0600005002obX00_lI00Go0P02oe`01Ol200;o8P05o`80
0_oo00H0000D00;o:P02oaT000?o0000HP000ol0000X0003o`000?l0300001@00_l:00Go2P05o``0
0_lI00Go1@05o`<01Ol600Go2@05o`L01_l300;o0`02o`030?oo00?o1@05o`<01Ol600Go1`08o`D0
1Ol300Go1@05o`D01Ol600?o00<0ool01Ol800;o00<0ool00ol700;o00<0ool00ol500So2006o`L0
3Ol500Go1P05o`801Ol300So2P04o`L02_l700Go1P05o`H00_l00`3oo`0;o`030?oo00?o1P02o`80
1Ol600;o400001<00_l900Wo1P09o`/00_lF00Wo0`05o`<01Ol400Wo1@09o`D01_l200?o0`0:o`<0
1Ol300Go1009o`D02?l500Go0`05o`<02Ol300Go1@04o`030?oo00Go200:o`D02_l300So1P09o`H0
3Ol300Wo1005o`801Ol300[o1P08o`D02_l500Wo1005o`D00ol00`3oo`0;o`030?oo00?o1@03o`80
1Ol500?o400001<00_l900;o1@02o`H00_l500;o2`02oaD00ol500?o0`02o`L00_l400?o1@03o`<0
0ol500?o1@02o`@01?l300?o1@03o`<00_l700;o1003o`D00ol700;o2@02o`L00_l300?o1@03o`@0
0_l500?o1@02o`/00ol500?o1003o`D00ol400;o2P03o`@00ol800;o1P02o`800ol500?o1003o`@0
0ol500;o1004o`D00_l400;o1P02o`D00_l400?o1@03o`D00_l500?o1@02o`H00_l300;o1@03o`D0
0_l500?o4@0001<00_lA00;o3@02o`X00_lE00;o1`02o`<00_l700;o1002o`L00_l300;o1`02o`D0
0_l400Co0`02o`L00_l300;o1`02o`@00_l700;o1`02o`T00_l700;o0`02o`L00_l400;o1@02o`H0
0_l;00;o1`02o`@00_l700;o1002o`X00_l600;o2002o`H00_l200;o1`02o`D00ol200?o1P02o`H0
0_l400;o1P02o`D00ol400;o1002o`L00_l500;o1@02o`H00_l600;o0`02o`D00_l600;o1@02oa80
000C00;o4@02o`d00_l:00;o5002o`T00_l200;o0`02o`800_l300;o2@02o`030?oo00T00_l400;o
0`05o`<00_l700;o0`02o`<00_l200;o0`02o`T00_l600;o2@02o`<00_l200;o0P02o`T00_l300;o
1002o`L00_l200;o1`02o`L00_l400;o1`02o`@00_l:00;o1P02o`P00_l600;o00@0oooo3`02o`80
0_l700;o1`02o`<00_l600;o1P03o`<00_l300?o3P02o`@00_l700;o1P02o`<00_l400;o1`02o`@0
0_lC00004`02oa400_l=00;o2P02oa@00_l900;o0P02o`800ol200;o0`02o`T00_l00`3oo`0900;o
1002o`<00_l00`3oo`0;00?o0`02o`800ol200;o0`02o`T00_l600;o2@02o`800ol200;o0P02o`T0
0_l300;o0`03o`L00_l200;o3`03o``00ol400Oo1@02o`H00_l800;o1P02o`030?oo01401?l800;o
1`02o`<00_l600;o1`02o`<00_l300;o3`03o`800ol700;o1P02o`<00ol200?o1`03o`800olC0000
4`02oa000_l=00;o2`02oa@00_l900;o0P02o`8000?o0?l00P02o`<00_l900;o00<0ool02@02o`@0
0_l200?o00<0ool01P07o`@00_l20003o`3o00800_l300;o2@02o`H00_l900;o0P000ol0o`0200;o
0P02o`T00_l300Oo2006o`X01ol800Oo1@09o`/00_l800;o2@02oa401?l800;o1`02o`<00_l600;o
1`03o`L00_l?00Oo2002o`/01ol800Oo500001<00_l=00Co2`04o``00_lD00;o2@02o`800_l0103o
o`02o`030?oo00<00_l900;o00<0ool02@02o`@00_l200;o0P02o`@01ol600;o00@0ool00_l00`3o
o`0300;o2@02o`H00_l900;o00@0ool00_l00`3oo`0200;o2@02o`<02Ol600Ko2007o`P01ol700;o
1@03o`X00_l800;o2@02oa400ol900;o1`02o`<00_l600;o2003o`H00_l?00Go2P02o`/01Ol:00Go
5P0001@00_l<00?o3003o``00_lE00;o2@02o`800_l00`3oo`020004o`3oo`<00_l900;o00<0ool0
2@02o`@00_l00`3oo`0300;o0`03o`/00_l00`3oo`020004o`3oo`<00_l900;o00<0ool00`02o`<0
0_l400;o00<0ool00P001?l0ool200;o2@02o`<00_l500?o1@02o`800_l700?o3003o``00_l600;o
2P02o`P00_l900;o4@04o`P00_l700;o0`02o`H00_l400;o0`02o`H00_l?00;o00@0oooo2@02o`/0
0_l0103oool900;o00@0oooo5@0001@00_l>00;o3@02o`/00_lE00?o2002o`800_l00`3o00020004
o`3oo`<00_l900;o00<0ool02@02o`@01Ol300;o0`02o`L000?o00000P02o`030?l0008000Co0?oo
0`03o`P00_l00`3oo`0300;o0`02o`@00_l00`3o00020004o`3oo`800ol800;o0`02o`H00_l500;o
0P02o`800_l300;o1`000ol0000300;o1`000ol0000300;o1P02o`X00_l800;o2@03o`L00_l600Ko
1`02o`L00_l300;o1P02o`@00_l300?o1@03o`L00_l500;o0P03o`P00_l;00;o0P03o`P00_l200?o
500001@00ol>00;o3@02o`X00_lF00;o1`02o`<01?l300Co1002o`L00_l300;o1`02o`D01?l400;o
0`02o`H00_l400Co0`04o`@00_l700;o0P02o`<00_l300;o1004o`<01?l300;o1`02o`@00_l600;o
1@02o`H00_l300;o1P02o`D00_l600;o1@02o`H00_l:00;o2002o`X00_l700;o1@03o`800ol600;o
1P02o`@00_l600;o1002o`@00ol500;o1`02o`D00_l300?o1`02o`/00_l300?o1`02o`<00olC0000
5@02o`h00_l=00;o2@02oaP00_l500;o1004o`@00ol400?o1@03o`<00ol500?o1@04o`@00_l300?o
1003o`@01?l400?o1@02o`D00_l300;o0`02o`<00_l400Co1003o`@00_l500;o1@02o`D00ol500;o
1P02o`<00ol400?o1@03o`@00ol500;o1@03o`X00_l800;o2P03o`D00ol500;o1002o`H00_l400Co
1002o`H00_l400;o1@02o`D00ol500?o1@02o`@00ol600;o2`02o`@00ol600;o1003oa80000F00;o
1`02o`<00ol700;o0`03o`P00_lI00Wo0`04o`D01?l400Wo1@09o`D01?l200Ko0`09o`<01?l500Co
1009o`<03?l300Co1@04o`<02Ol300_o100<o`@02Ol600Wo0`0;o`H02_l200So200:o`<01Ol200Go
0`0:o`@01?l400Co0`0:o`D02_l300Go0`05o`030?oo00Ko1P05o`<01Ol200Go0`05oa00000G0003
o`0000D01ol800Oo2@000ol0000J00Go1@04o`D01?l600Go2@05o`L00ol300Ko1@05o`030?l00080
1?l500Co1P05o`D03?l300Co1@04o`D01Ol500Wo1P0<o`H01Ol00`3o000700Go00<0o`000P09o`P0
2_l200So2P05o`030?oo00<01Ol200Go0`08o`H01?l400Co0`0:o`L01Ol00`3oo`0300Go0`05o`03
0?oo00Ko1P05o`<01Ol200Go0`05oa00000Q00Co2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(34\\) QMOONSMQTMQRFSSPJLCXDUZCJLKK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oG002o`@00olR00;o1003ool0
1`0001D00_lX00;o6@0:oe/02_lQ00[oo`0600005002obX00_lI00Go0P02oe`01Ol200;o8P05o`80
0_oo00H0000D00;o:P02oaT000?o0000HP000ol0000X0003o`000?l0300001@00_l:00Go3006o`T0
0_lI00Go1@05o`<01Ol600Go2@05o`L01_l300;o0`02o`030?oo00?o1@05o`<01Ol600Go1`08o`D0
1Ol300Go1@05o`D01Ol600?o00<0ool01Ol800;o00<0ool00ol700;o00<0ool00ol500So2006o`L0
3Ol500Go1P05o`801Ol300So2P04o`L02_l700Go2006o`H03Ol00`3oo`03o`H00_l200Go1P02oa00
000C00;o2@09o`X01_l:00;o5P09o`<01Ol300Go1009o`D02Ol500Ko0P03o`<02_l300Go0`05o`@0
2Ol500So1@05o`<01Ol300Wo0`05o`D01?l00`3oo`05o`P02_l500[o0`08o`H02Ol600go0`09o`@0
1Ol200Go0`0:o`H02?l500[o1@09o`@02Ol500go00<0ool00ol500?o0P05o`D00ol@00004`02o`T0
0_l500;o3002o``00_lE00?o1@03o`<00_l700;o1003o`D00ol300?o1@03o`D00_l400Co0`03o`D0
0ol300;o1`02o`@00ol500?o1`02o`T00_l700;o0`03o`D00ol400;o1@03o`D00_l;00?o1@03o`@0
0ol500?o1002o`X00ol400?o2002o`H00_l200?o1@03o`@00ol400?o1@02o`@01?l500;o1002o`H0
0_l500;o1003o`D00ol300?o1003o`L00_l600;o0`02o`D00ol500;o1@03oa40000C00;o4@02o`/0
0_l<00;o5@02o`L00_l300;o1`02o`@00_l700;o0`02o`L00_l500;o1004o`<00_l700;o0`02o`L0
0_l400;o1`02o`L00_l900;o1`02o`<00_l700;o1002o`D00_l600;o2`02o`L00_l400;o1`02o`@0
0_l:00;o1P02o`P00_l600;o0P02o`L00_l500?o0P03o`H00_l600;o1002o`H00_l500?o1002o`@0
0_l700;o0`02o`H00_l700;o1P02o`<00_l500;o1P02o`D00_lB00004`02oa400_l500[o2P02oa@0
0_l900;o0P02o`<00_l200;o0`02o`T00_l00`3oo`0900;o1002o`<01Ol300;o1`02o`<00_l300;o
0P02o`<00_l900;o1P02o`T00_l300;o0P02o`800_l900;o0`02o`@00_l700;o0P02o`L00_l700;o
1002o`L00_l400;o2P02o`H00_l800;o1P02o`040?ooo`l00_l200;o1`02o`L00_l300;o1P02o`H0
0ol300;o0`03o``00_l600;o1`02o`H00_l300;o1002o`L00_l400;o4`0001<00_lA00;o1@0:o`X0
0_lD00;o2@02o`800_l200?o0P02o`<00_l900;o00<0ool02@02o`@00_l300;o00<0ool02`03o`<0
0_l200?o0P02o`<00_l900;o1P02o`T00_l200?o0P02o`800_l900;o0`02o`<00ol700;o0P02o`l0
0ol<00?o1007o`D00_l600;o2002o`H00_l00`3oo`0A00Co2002o`L00_l300;o1P02o`L00_l300;o
0`02o`d00_l600;o1`02o`H00_l300?o0P03o`L00ol200?o4`0001<00_l@00;o1P02o`@00_l<00;o
5002o`T00_l200;o0P000ol0o`0200;o0`02o`T00_l00`3oo`0900;o1002o`800ol00`3oo`0600Oo
1002o`8000?o0?l00P02o`<00_l900;o1P02o`T00_l20003o`3o00800_l200;o2@02o`<01ol800Ko
2P07o`P01ol500Wo2`02o`P00_l900;o4@04o`P00_l700;o0`02o`H00_l700?o1`02oaD00_l700;o
2`07o`P01olD00004`02o`d01?l800;o0`02o``00_lD00;o2@02o`800_l0103oo`02o`030?oo00<0
0_l900;o00<0ool02@02o`@00_l200;o0P02o`@01ol600;o00@0ool00_l00`3oo`0300;o2@02o`H0
0_l900;o00@0ool00_l00`3oo`0200;o2@02o`<02Ol600Ko2007o`P01ol700;o1@03o`X00_l800;o
2@02oa400ol900;o1`02o`<00_l600;o2003o`H00_lE00;o1`02o`/01Ol:00Go5P0001@00_l<00?o
2P001?l00002o`/00_lE00;o2@02o`800_l00`3oo`020004o`3oo`<00_l900;o00<0ool02@02o`@0
0_l00`3oo`0300;o0`03o`/00_l00`3oo`020004o`3oo`<00_l900;o00<0ool00`02o`<00_l400;o
00<0ool00P001?l0ool200;o2@02o`<00_l500?o1@02o`800_l700?o3003o``00_l600;o2P02o`P0
0_l900;o4@04o`P00_l700;o0`02o`H00_l400;o0`02o`H00_lE00;o1`02o`/00_l0103oool900;o
00@0oooo5@0001@00_l>00;o2@02o`800_l;00;o5@03o`P00_l200;o00<0o`000P001?l0ool300;o
2@02o`030?oo00T00_l400Go0`02o`<00_l70003o`0000800_l00`3o00020004o`3oo`<00ol800;o
00<0ool00`02o`<00_l400;o00<0o`000P001?l0ool200?o2002o`<00_l600;o1@02o`800_l200;o
0`02o`L000?o00000`02o`L000?o00000`02o`H00_l:00;o2002o`T00ol700;o1P06o`L00_l700;o
0`02o`H00_l400;o0`03o`D00ol700;o2`02o`L00_l;00;o0P03o`P00_l200?o500001@00ol>00;o
2@000ol00002o`/00_lF00;o1`02o`<01?l300Co1002o`L00_l300;o1`02o`D01?l400;o0`02o`H0
0_l400Co0`04o`@00_l700;o0P02o`<00_l300;o1004o`<01?l300;o1`02o`@00_l600;o1@02o`H0
0_l300;o1P02o`D00_l600;o1@02o`H00_l:00;o2002o`X00_l700;o1@03o`800ol600;o1P02o`@0
0_l600;o1002o`@00ol500;o1`02o`/00_l700;o2`02o`<00ol700;o0`03oa<0000E00;o3P02o`X0
00Co0?oo2P02oaP00_l500;o1004o`@00ol400?o1@03o`<00ol500?o1@04o`@00_l300?o1003o`@0
1?l400?o1@02o`D00_l300;o0`02o`<00_l400Co1003o`@00_l500;o1@02o`D00ol500;o1P02o`<0
0ol400?o1@03o`@00ol500;o1@03o`X00_l800;o2P03o`D00ol500;o1002o`H00_l400Co1002o`H0
0_l400;o1@02o`D00ol500?o2`02o`L00_l;00;o1003o`H00_l400?o4P0001H00_l700;o0`03o`X0
1?l900;o6@09o`<01?l500Co1009o`D02Ol500Co0P06o`<02Ol300Co1@04o`@02Ol300co0`04o`D0
1?l300Wo0`0;o`@03?l400Wo1P09o`<02ol600[o0P08o`P02_l300Go0P05o`<02_l400Co1004o`<0
2_l500[o1P0:o`030?oo00Ko1P05o`<01Ol200Go0`05oa00000G0003o`0000D01ol<00?o2@000ol0
000J00Go1@04o`D01?l600Go2@05o`L00ol300Ko1@05o`030?l000801?l500Co1P05o`D03?l300Co
1@04o`D01Ol500Wo1P0<o`H01Ol00`3o000700Go00<0o`000P09o`P02_l200So2P05o`030?oo00<0
1Ol200Go0`08o`H01?l400Co0`0:o`L01Ol00`3oo`0600[o00<0ool01_l600Go0`05o`801Ol300Go
400002401?l=00?oo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(35\\) QMONNSMQTMQSFSSPJLBXDUZCJLKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oG002o`@00olR00;o1003ool0
1`0001D00_lX00;o6@0:oe/02_lQ00[oo`0600005002obX00_lI00Go0P02oe`01Ol200;o8P05o`80
0_oo00H0000D00;o:P02oaT000?o0000HP000ol0000X0003o`000?l0300001@00_l:00Go2P05o``0
0_lI00Go1@05o`<01Ol600Go1P06o`<00_l400Ko0`02o`<00_l00`3oo`03o`D01Ol300Go1P05o`L0
2?l500Go0`05o`D01Ol600;o00<0ool00ol600Oo2002o`030?oo00?o1`02o`030?oo00?o1@08o`P0
1_l700go00<0ool02?l500Go0P05o`<02?l:00Co1`0:o`L01Ol800Ko1P0=o`030?oo00?o1P02o`@0
1_lE00004`02o`T02Ol600Wo2`02oaH02Ol300Go0`05o`@02Ol400Ko0P03o`@01_l200?o0`0:o`<0
1Ol300Go1009o`D02?l500Go0`05o`<02Ol400[o1007o`P02_l500[o0`08o`H02Ol600go00<0ool0
2Ol400Go0P05o`<02_l600So1@0:o`D02Ol400Wo1@0=o`030?oo00?o1@03o`802OlD00004`02o`T0
0_l500;o1P02o`D00_l;00;o5@03o`D00ol300;o1`02o`@00ol500?o1002o`@01?l500;o1004o`<0
0ol500?o0`02o`L00_l400?o1@03o`L00_l900;o1`02o`<00ol500?o0`03o`D00ol500;o2`03o`D0
0ol400?o1@03o`@00_l:00?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D00_l400Co1@02o`@0
0_l600;o1@02o`@00ol500?o0`03o`@00ol700;o1P02o`<00_l500?o0`03o`@00olC00004`02oa40
0_l=00;o2P02oaD00_l700;o0`02o`L00_l400;o1`02o`@00_l400Co1@02o`@01?l300;o1`02o`<0
0_l700;o1002o`L00_l700;o2@02o`L00_l300;o1`02o`<00_l700;o1@02o`/00_l700;o1002o`L0
0_l400;o2P02o`H00_l800;o1P02o`<00_l600;o1@03o`800ol600;o1P02o`@00_l600;o1@03o`@0
0_l400;o1`02o`<00_l600;o1`02o`H00_l300;o1@02o`@00_l600;o4`0001<00_lA00;o3@02o`X0
0_lD00;o2@02o`800_l300;o0P02o`<00_l900;o0`02o`<01Ol500;o0`05o`<00_l700;o0`02o`<0
0_l200;o0`02o`T00_l600;o2@02o`<00_l200;o0P02o`T00_l200;o1`02o`D00_l200;o1`02o`L0
0_l400;o1`02o`@00_l:00;o1P02o`P00_l600;o0`02o`H00_l600;o0P02o`L00_l700;o0`02o`H0
0_l600?o0`02o`<00ol<00;o1P02o`L00_l600;o0`02o`@00_l500;o1P02oa<0000C00;o4@02o`d0
0_l:00;o5002o`T00_l200;o0P03o`800_l300;o2@02o`<00_l300;o00<0ool01@02o`<00_l00`3o
o`0;00?o0`02o`800ol200;o0`02o`T00_l600;o2@02o`800ol200;o0P02o`T00_l:00?o1@02o`80
0_l?00?o3003o`@01ol500;o1P02o`P00_l600;o0`02o`H00_l700Co2002o`L00_l300;o1P02o`L0
0_l300;o0`02o`d00_l600;o1`02o`H00_l300?o0P03o`D00_l600;o4`0001<00_l@00;o3P02o`X0
0_lD00;o2@02o`800_l20003o`3o00800_l300;o2@02o`<00_l200?o00<0ool01@02o`800ol00`3o
o`0600Oo1002o`8000?o0?l00P02o`<00_l900;o1P02o`T00_l20003o`3o00800_l200;o2@02o`D0
1ol600Ko2P07o`P01ol500Wo2`02o`P00_l;00;o1@03o`L01?l800;o1`02o`<00_l600;o1`03o`L0
0_lE00;o1`02o`/01ol>00;o4`0001<00_l=00Co2002o`@00_l;00;o5002o`T00_l200;o00@0ool0
0_l00`3oo`0300;o2@02o`<00_l200;o0P02o`D00_l200;o0P02o`@01ol600;o00@0ool00_l00`3o
o`0300;o2@02o`H00_l900;o00@0ool00_l00`3oo`0200;o2@02o`<01ol800Ko2007o`P01ol700;o
1@03o`X00_l800;o2`09o`P00ol900;o1`02o`<00_l600;o2003o`H00_lE00;o1`02o`/01Ol@00;o
4`0001@00_l<00?o2@08o`X00_lE00;o2@02o`800_l00`3oo`020004o`3oo`<00_l900;o0`02o`03
0?oo00<00_l500;o00<0ool00`02o`<00ol;00;o00<0ool00P001?l0ool300;o2@02o`030?oo00<0
0_l300;o1002o`030?oo008000Co0?oo0P02o`T00_l200?o3@02o`800_l700?o3003o``00_l600;o
2P02o`P00_l;00So2@04o`P00_l700;o0`02o`H00_l400;o0`02o`H00_lE00;o1`02o`/00_l0103o
ool?00;o4`0001@00_l>00;o2007o`/00_lE00?o2002o`800_l00`3o00020004o`3oo`<00_l900;o
0`05o`<00_l500Go0`02o`<00_l70003o`0000800_l00`3o00020004o`3oo`<00ol800;o00<0ool0
0`02o`<00_l400;o00<0o`000P001?l0ool200?o2002o`800_l70003o`0000@00_l200;o0P02o`<0
0_l70003o`0000<00_l70003o`0000<00_l600;o2P02o`P00_l;00;o1003o`L01_l700;o1`02o`<0
0_l600;o1002o`<00ol500?o1`02o`/00_l700;o2`02o`800ol>00;o4`0001@00ol>00;o1`02oa00
0_lF00;o1`02o`<01?l300Co1002o`L00_l400Co1002o`D01?l400;o0`02o`H00_l400Co0`04o`@0
0_l700;o0P02o`<00_l300;o1004o`<01?l300;o1`02o`<00_l600;o1P02o`H00_l300;o1P02o`D0
0_l600;o1@02o`H00_l:00;o2002o`/00_l500;o1P03o`800ol600;o1P02o`@00_l600;o1002o`@0
0ol500;o1`02o`/00_l700;o2`02o`<00ol=00;o4`0001D00_l>00;o1`02o`l00_lH00;o1@02o`@0
1?l400?o1003o`D00ol400Co1002o`D01?l400;o0`03o`@00ol400Co1003o`D00_l500;o0`02o`<0
0_l300;o1004o`@00ol400;o1@02o`@00ol400?o1P02o`H00_l300?o1003o`D00ol400?o1@02o`D0
0ol:00;o2002o`/00_l400?o1P02o`@00_l600;o1004o`@00_l600;o1002o`D00_l500?o1@03o`/0
0_l700;o2`02o`@00ol<00;o4`0001H00_l700;o0`03o`L00_l>00;o6@09o`<01?l500Co1009o`@0
1?l200Ko0`04o`801_l300Wo0`04o`D01?l400Wo0`0<o`<01?l500Co0`09o`D02Ol400co1009o`H0
2Ol300_o1P0:o`802?l600[o1@05o`801Ol300[o1004o`@01?l300[o1@0:o`H02_l00`3oo`06o`H0
1Ol300Go1@0:oa00000G0003o`0000D01ol800So20000ol0000J00Go1@04o`D01?l600Go1P03o`<0
1_l300?o0`06o`D01Ol00`3o000200Co1@04o`H01Ol500co0`04o`D01?l500Go2@05o`030?l000<0
3?l600Go00<0o`001`05o`030?l000802Ol800[o0P08o`H02Ol600Go0P05o`<02?l600Co1004o`<0
2_l700Go00<0ool01P0:o`030?oo00Ko1P05o`<01Ol500[o400002401?l900Soo`340000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(36\\) PMONNSMQTMQSFSTPJLBXDUZCILKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`X01Ol;00Co3002oaD02?l600Go0`05o`H01Ol600Ko0`02o`@0
1_l300;o0`02o`030?oo00?o1@05o`<01Ol600Go1`08o`D01Ol300Go1@05o`H00_l00`3oo`03o`H0
1ol800;o00<0ool00ol800So1008o`P01_l700go00<0ool02?l500Go0P05o`<02?l:00Co1`0:o`L0
1Ol700[o0`0=o`030?oo00?o1P02o`@01_lE00004`02o`T02Ol800Oo2`02oa@02?l600Go0`05o`@0
2Ol400Ko0P03o`@01_l200?o0`0:o`<01Ol300Go1009o`D02?l500Go0`05o`<02Ol400[o1007o`P0
2_l600So1008o`H02Ol600go00<0ool02Ol400Go0P05o`<02_l600So1@0:o`D02Ol500[o0`0=o`03
0?oo00?o1@03o`802OlD00004`02o`T00_l500;o1`02o`@00_l;00;o5P02o`/00_l700;o1003o`D0
0ol400;o1004o`D00_l400Co0`03o`D00ol300;o1`02o`@00ol500?o1`02o`T00_l700;o0`03o`D0
0ol300?o1@03o`D00_l;00?o1@03o`P00_l900;o2P03o`@00ol800;o1P02o`<00_l500?o1003o`@0
0ol500;o1004o`D00_l400;o1P02o`D00_l400?o1@03o`P00_l:00;o1P02o`<00_l500?o0`03o`@0
0olC00004`02oa400_l500;o1P02o`X00_lF00;o2`02o`L00_l400;o1`02o`@00_l400Co1@02o`@0
1?l300;o1`02o`<00_l700;o1002o`L00_l700;o2@02o`L00_l300;o1`02o`<00_l700;o1@02o`/0
0_l700;o2002o`T00_l:00;o1P02o`P00_l600;o0`02o`H00_l500?o0P03o`H00_l600;o1002o`H0
0_l500?o1002o`@00_l700;o2002o`X00_l600;o0`02o`D00_l400;o1P02oa<0000C00;o4@02o`D0
0_l600;o2P02oaH00_l;00;o0`02o`800_l300;o2@02o`<00_l300Go1@02o`<01Ol300;o1`02o`<0
0_l300;o0P02o`<00_l900;o1P02o`T00_l300;o0P02o`800_l900;o0P02o`L00_l500;o0P02o`L0
0_l700;o2002o`T00_l:00;o1P02o`P00_l600;o0`02o`H00_l600;o0P02o`L00_l700;o0`02o`H0
0_l600?o0`02o`<00olA00;o2P02o`H00_l300;o1002o`D00_l600;o4`0001<00_lA00;o1@02o`H0
0_l:00;o5P07o`H00_l200?o0P02o`<00_l900;o0`02o`<00_l00`3oo`0500;o0`02o`030?oo00/0
0ol300;o0P03o`800_l300;o2@02o`H00_l900;o0P03o`800_l200;o2@02o`X00ol500;o0P02o`l0
0ol800;o2@07o`D00_l600;o2002o`H00_l300;o1P02o`L01?l800;o1`02o`<00_l600;o1`02o`<0
0_l300;o4P02o`X00_l600;o0`03o`800ol500;o1P02oa<0000C00;o4002o`H00_l600;o2P02oaH0
2Ol400;o0P000ol0o`0200;o0`02o`T00_l300;o0P03o`030?oo00D00_l200?o00<0ool01P07o`@0
0_l20003o`3o00800_l300;o2@02o`H00_l900;o0P000ol0o`0200;o0P02o`T00_l500Oo1P06o`X0
1ol900;o2@09o`/00_l800;o2`02o`D00ol700Co2002o`L00_l300;o1P02o`L00ol700;o4P02o`X0
0_l;00Oo3P02oa<0000C00;o3@04o`L00ol400;o2`02oaH00_l500?o0`02o`040?oo00;o00<0ool0
0`02o`T00_l300;o0P02o`800_l500;o0P02o`800_l400Oo1P02o`040?oo00;o00<0ool00`02o`T0
0_l600;o2@02o`040?oo00;o00<0ool00P02o`T00_l300Oo2006o`P01ol;00;o2@02o`D00ol:00;o
2002o`/02Ol800?o2@02o`L00_l300;o1P02o`P00ol600;o4P02o`X00_l;00Go4002oa<0000D00;o
3003o`P02Ol:00;o5`02o`H00_l300;o00<0ool00P001?l0ool300;o2@02o`<00_l00`3oo`0300;o
1@02o`030?oo00<00_l300?o2`02o`030?oo008000Co0?oo0`02o`T00_l00`3oo`0300;o0`02o`@0
0_l00`3oo`020004o`3oo`800_l900;o0P03o`d00_l200;o1`03o`/00_l300;o0`02o`@00_l600;o
2P02o`P00_l;00So2@04o`P00_l700;o0`02o`H00_l400;o0`02o`H00_lB00;o2P02o`/00_l0103o
ool?00;o4`0001@00_l>00;o1`02o`030?oo00;o3002oaL00_l600;o0`02o`030?l0008000Co0?oo
0`02o`T00_l300Go0`02o`D01Ol300;o0`02o`L000?o00000P02o`030?l0008000Co0?oo0`03o`P0
0_l00`3oo`0300;o0`02o`@00_l00`3o00020004o`3oo`800ol800;o0P02o`L000?o00001002o`80
0_l200;o0`02o`L000?o00000P02o`<00_l300;o1002o`H00_l:00;o2002o`/00_l400?o1`06o`L0
0_l700;o0`02o`H00_l400;o0`03o`D00ol700;o2002o`X00_l;00;o0P03o`h00_lC00005003o`h0
0_l700;o4002oaL00_l600;o0`04o`<01?l400;o1`02o`@01?l400;o1@04o`@00_l300;o1P02o`@0
1?l300Co1002o`L00_l200;o0`02o`<00_l400Co0`04o`<00_l700;o0`02o`H00_l600;o1P02o`<0
0_l600;o1002o`<00_l300;o1002o`H00_l:00;o2002o`/00_l500;o1P03o`800ol600;o1P02o`@0
0_l600;o1002o`@00ol500;o1`02o`P00_l:00;o2`02o`<00ol=00;o4`0001D00_l>00;o1`03o`h0
0_lH00;o1@03o`<01?l400?o1003o`D00ol400Co1002o`D01?l400;o0`03o`@00ol400Co1003o`D0
0_l500;o0`02o`<00_l300;o1004o`@00ol400;o1@02o`@00ol400?o1P02o`H00_l300?o1003o`@0
0_l300;o0`02o`@00_l500?o2P02o`P00_l;00;o1003o`H00_l400;o1P02o`@01?l400;o1P02o`@0
0_l500;o1@03o`D00ol800;o2P02o`/00_l400?o3002oa<0000F00;o1`02o`<00ol800?o3002oaL0
2ol300Co1@04o`@02Ol400Co0P06o`<01?l200Ko0`09o`<01?l500Co1009o`<03?l300Co1@04o`<0
2Ol500Wo100<o`@02Ol400co0P0;o`H02_l200So1P0:o`D01Ol200Go0`0:o`@01?l400Co0`0:o`D0
2_l400[o0`08o`H01Ol300Go1@0:oa00000G0003o`0000D01ol:00Oo1`000ol0000F00Wo1@04o`D0
1?l600Go1P03o`<01_l300?o0`06o`D01Ol00`3o000200Co1@04o`H01Ol500co0`04o`D01?l500Go
2@05o`030?l000<03?l600Go00<0o`000`0<o`802Ol800[o0P08o`H02Ol600Go0P05o`<02?l600Co
1004o`<02_l700Go00<0ool0100:o`<02?l600Go0`05o`D02_l@00008@04o`d01Ooo0<<0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(37\\) PMONNSMQUMQTESUPJLBXDUZCILKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`X01Ol;00;o3P02oaD02?l600Go0`05o`H01Ol600Ko0`02o`@0
1_l300;o0`02o`030?oo00?o1@05o`<01Ol600Go2P04o`H01Ol300Go1@05o`L02?l500co0`02o`03
0?oo00?o2`04o`D02?l800Ko1`0=o`030?oo00So1@05o`801Ol300So2P04o`L02_l700Go1`0:o`<0
3Ol00`3oo`03o`H00_l400Ko5@0001<00_l900Wo2@02o`l00_lD00So1P05o`<01Ol400Wo1006o`80
0ol400Ko0P03o`<02_l300Go0`05o`@02Ol600So1005o`<01Ol300Wo1@08o`D03?l300[o1`08o`<0
2?l600Wo1P0=o`030?oo00Wo1005o`801Ol300[o1P08o`D02_l500Wo1@0:o`<03Ol00`3oo`03o`D0
0ol200Wo500001<00_l900;o1@02o`X00_l>00;o5P02o`/00_l700;o1003o`D00ol400;o1004o`D0
0_l400Co0`03o`D00ol300;o1`02o`@00ol500?o1@02o`@00_l500;o1`02o`<00ol500?o1`02o`X0
0_l600;o0`03o`D00ol600;o1002o`D00_l:00?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D0
0_l400Co1@02o`@00_l600;o1@02o`@00ol500?o2002o`X00_l600;o0`02o`D00ol300?o1003oa<0
000C00;o4@02o`T00_l>00;o5P02o`/00_l700;o1002o`L00_l400;o1004o`D00_l400Co0`02o`L0
0_l300;o1`02o`@00_l700;o1002o`H00_l400;o1`02o`<00_l700;o1`02o`X00_l600;o0`02o`L0
0_l500;o1P02o`@00_l:00;o1P02o`P00_l600;o0`02o`H00_l500?o0P03o`H00_l600;o1002o`H0
0_l500?o1002o`@00_l700;o2002o`X00_l600;o0`02o`D00_l400;o1P02oa<0000C00;o4@02o`T0
0_l>00;o5P02o`/00_l300;o0P02o`<00_l900;o0`02o`<01Ol500;o0`05o`<00_l700;o0`02o`<0
0_l200;o0`02o`T00_l300;o1P02o`@00_l300;o0P02o`800_l900;o1P02o`X00_l200;o0P02o`<0
0_l700;o1@02o`H00_l400;o2P02o`H00_l800;o1P02o`<00_l600;o1P02o`800_l700;o1`02o`<0
0_l600;o1P03o`<00_l300?o4@02o`X00_l600;o0`02o`@00_l500;o1P02oa<0000C00;o4@02o`X0
00?o00003002oaH01ol600;o0P03o`800_l300;o2@02o`<00_l300;o00<0ool01@02o`<00_l00`3o
o`0;00?o0`02o`800ol200;o0`02o`T00_l300;o1P02o`@00_l200?o0P02o`800_l900;o1P02o`X0
0_l200;o3`03o`D00_l600;o1007o`D00_l600;o2002o`H00_l300;o1P02o`L01?l800;o1`02o`<0
0_l600;o1`02o`<00_l300;o4P02o`X00_l600;o0`03o`800ol500;o1P02oa<0000C00;o4002o`/0
0_l=00;o5P09o`@00_l20003o`3o00800_l300;o2@02o`<00_l200?o00<0ool01@02o`800ol00`3o
o`0600Oo1002o`8000?o0?l00P02o`<00_l900;o0`02o`H00_l400;o0P000ol0o`0200;o0P02o`T0
0_l600;o2P06o`X01ol600;o1P02o`@02Ol;00;o2002o`/00_l500?o1`04o`P00_l700;o0`02o`H0
0_l700?o1`02oa800_l:00;o2`07o`h00_lC00004`02o`d01?l<00;o3@02oaH00_l500?o0`02o`04
0?oo00;o00<0ool00`02o`T00_l300;o0P02o`800_l500;o0P02o`800_l400Oo1P02o`040?oo00;o
00<0ool00`02o`T00_l300;o1P02o`@00_l0103oo`02o`030?oo00800_l900;o1P02o`X01_l800Oo
2002o`H00_l400;o1@03o`X00_l800;o2`09o`P00ol900;o1`02o`<00_l600;o2003o`H00_lB00;o
2P02o`/01Ol@00;o4`0001@00_l<00?o3P000ol0000:00;o5`02o`H00_l300;o00<0ool00P001?l0
ool300;o2@02o`<00_l00`3oo`0300;o1@02o`030?oo00<00_l300?o2`02o`030?oo008000Co0?oo
0`02o`T00_l300;o1P02o`@00_l00`3oo`020004o`3oo`800_l900;o00<0ool00`02o`<00_l500;o
0P02o`L00ol=00;o1P02o`@00_l600;o2P02o`P00_l;00So2@04o`P00_l700;o0`02o`H00_l400;o
0`02o`H00_lB00;o2P02o`/00_l0103oool?00;o4`0001@00_l>00;o3@02o`/00_lG00;o1P02o`<0
0_l00`3o00020004o`3oo`<00_l900;o0`05o`<00_l500Go0`02o`<00_l70003o`0000800_l00`3o
00020004o`3oo`<00ol800;o0`02o`H00_l400;o00<0o`000P001?l0ool200?o2002o`030?oo00<0
0_l300;o1@02o`800_l200;o0`02o`L000?o00001002o`H00_l400;o1P02o`X00_l800;o2`02o`@0
0ol700Ko1`02o`L00_l300;o1P02o`@00_l300?o1@03o`L00_l800;o2P02o`/00_l200?o3P02oa<0
000D00?o3P02o``00_l;00;o5`02o`H00_l300Co0`04o`@00_l700;o1004o`@00_l500Co1002o`<0
0_l600;o1004o`<01?l400;o1`02o`@00_l600;o1004o`<01?l300;o1`02o`800_l300;o0`02o`D0
0_l600;o0`02o`H00_l600;o1P02o`@00_l600;o2P02o`P00_l;00;o1@02o`H00ol200?o1P02o`H0
0_l400;o1P02o`@00_l400?o1@02o`L00_l800;o2P02o`/00_l300?o3@02oa<0000E00;o3P02o`d0
00?o00002002oaP00_l500?o0`04o`@00ol400?o1@03o`@01?l400;o1@04o`@00_l300?o1003o`@0
1?l400?o1@02o`D00_l500;o1P02o`@01?l400?o1002o`D00_l300;o0`02o`<00_l500;o1P02o`<0
0ol400?o1P02o`H00_l400;o1@03o`X00_l800;o2`02o`@00ol600;o1002o`H00_l400Co1002o`H0
0_l400;o1@02o`D00ol500?o2002o`X00_l;00;o1003o``00_lC00005P02o`L00_l300?o1P02o`D0
0_l800;o5`0;o`<01?l500Co1009o`@01?l200Ko0`04o`801_l300Wo0`04o`D01?l400Wo1004o`@0
1?l200Co1@04o`<02Ol300co0`0<o`@02Ol500Co1004o`030?oo00Wo1P0:o`802?l600[o1@05o`80
1Ol300[o1004o`@01?l300[o1@0:o`@02_l300So1P05o`<01Ol500[o400001L000?o00001@07o`L0
2Ol80003o`0001H02Ol500Co1@04o`H01Ol600?o0`06o`<00ol300Ko1@05o`030?l000801?l500Co
1P05o`H01?l400Co0P04o`D01?l500Go1@0<o`<03?l600Go00<0o`001004o`@01?l00`3oo`07o`P0
2_l200So1P09o`H01Ol200Go0`08o`H01?l400Co0`0:o`L01Ol00`3oo`0400[o0`08o`H01Ol300Go
1@0:oa00000Q00Co2009ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(38\\) PLONNSMQULQTESUPKLBXDUYCHLKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`X01Ol;00Co3002oaD02?l600go1P05o`H01_l300;o1006o`<0
0_l300;o00<0ool00ol500Go0`05o`H01Ol:00Co1P0=o`D01Ol700So1@0<o`<00_l00`3oo`03o`/0
1?l500So1P05o`H00_l200go00<0ool02?l500Go0P05o`<02?l:00Co2008o`P01Ol700Co0`04o`80
3Ol00`3oo`03o`H00_l400Ko5@0001<00_l900Wo1`08o`/00_lD00So1P0=o`@02Ol400Ko0P03o`@0
1_l200?o0`0:o`<01Ol300Go1009o`H02?l400go0`09o`D02?l500co0`0:o`L02?l300So1P05o`D0
0ol200go00<0ool02Ol400Go0P05o`<02_l600So1P08o`H02Ol500Co0`04o`803Ol00`3oo`03o`D0
0ol200Wo500001<00_l900;o1@02o`H00ol400?o2P02oaH00_l=00;o1P02o`<00ol500?o1002o`@0
1?l500;o1004o`<00ol500?o0`02o`L00_l400?o1@03o`D00_l400;o1`02o`H00_l200?o1@03o`L0
0_l:00;o1P02o`<00ol500?o1P02o`@00_l500;o3002o`D00ol600;o1P02o`<00_l500?o1003o`@0
0ol500;o1004o`D00_l400;o2@02o`P00ol500?o1@02o`D00_l600;o1P02o`<00_l500?o0`03o`@0
0olC00004`02oa400_l500;o1P02o`X00_lF00;o3@02o`H00_l300;o1`02o`@00_l400Co1@02o`@0
1?l300;o1`02o`<00_l700;o1002o`L00_l400;o1P02o`H00_l600;o0P02o`L00_l700;o2P02o`H0
0_l300;o1`02o`D00_l600;o1002o``00_l500;o1`02o`H00_l300;o1P02o`D00ol200?o1P02o`H0
0_l400;o1P02o`P00_l800;o1`02o`D00_l500;o1P02o`H00_l300;o1@02o`@00_l600;o4`0001<0
0_lA00;o1@02o`H00_l:00;o5P02o`d00_l600;o0P02o`T00_l300;o0`05o`D00_l300Go0`02o`L0
0_l300;o0`02o`800_l300;o2@02o`<00_l600;o1P02o`H00_l00`3oo`0900;o1P02o`X00_l200;o
0P02o`<00_l700;o1@02o`H00_l400;o3002o`@00_l800;o1P02o`<00_l600;o1P02o`800_l700;o
1`02o`<00_l600;o2002o`L00ol>00;o1@02o`H00_l600;o0`02o`@00_l500;o1P02oa<0000C00;o
4@02o`D00_l600;o2P02oaH01ol800;o1P02o`800_l900;o0`02o`<00_l00`3oo`0500;o0`02o`03
0?oo00/00ol300;o0P03o`800_l300;o2@02o`<00_l600;o1P02o`H00_l00`3oo`0900;o1P02o`X0
0_l200;o3`03o`D00_l600;o1007o`L00ol200?o2002o`H00_l300;o1P02o`L01?l800;o1`02o`<0
0_l600;o2002o`L00_l?00;o1@02o`H00_l600;o0`03o`800ol500;o1P02oa<0000C00;o4002o`L0
0_l400;o2`02oaH02Ol600;o2P02o`T00_l300;o0P03o`030?oo00D00_l200?o00<0ool01P07o`@0
0_l20003o`3o00800_l300;o2@02o`<00_l600;o1P02o`T00_l900;o1P02o`X01_l:00Oo1P02o`H0
0_l400Wo1@07o`T00_l;00;o1@03o`L01?l800;o1`02o`<00_l600;o2003o`H00_l?00;o1@02o`H0
0_l;00Oo3P02oa<0000C00;o3@04o`T01ol;00;o5P02o`D00ol500;o2P02o`T00_l300;o0P02o`80
0_l500;o0P02o`800_l400Oo1P02o`040?oo00;o00<0ool00`02o`T00_l300;o1P02o`H00_l900;o
2@02o`H00_l:00Ko2007o`P00_l600;o1002o`D00ol400Go2`02o`/02Ol800?o2@02o`L00_l300;o
1P02o`L01?l600;o3`09o`H00_l;00Go4002oa<0000D00;o3003o`X01_l;00;o5`02o`H00_l500;o
2P02o`T00_l300;o00<0ool00`02o`D00_l00`3oo`0300;o0`03o`/00_l00`3oo`020004o`3oo`<0
0_l900;o0`02o`H00_l600;o2@02o`T00_l00`3oo`0300;o0`02o`D00_l200;o1`03o`d00_l600;o
1002o`H00_l400;o00@0oooo2P02o`/02?l900Co2002o`L00_l300;o1P02o`H01_l500;o3`09o`H0
0_l;00;o00@0oooo3`02oa<0000D00;o3P02o`P00_l400;o2P02oaL00_l600;o1@02o`X00_l900;o
0`05o`<00_l500Go0`02o`<00_l70003o`0000800_l00`3o00020004o`3oo`<00ol800;o0`02o`H0
0_l600;o2@03o`P00_l00`3oo`0300;o0`02o`D00_l200;o0P02o`<00_l70003o`0000@00_l600;o
1002o`H00_l400;o0P03o`T00_l;00;o1003o`L01_l700;o1`02o`<00_l600;o1P02o`800_l500?o
1`02o`D00_l500;o1P02o`/00_l200?o3P02oa<0000D00?o3P02o`H00_l600;o2@02oaL00_l600;o
1@02o`/00_l700;o1004o`@00_l500Co1002o`<00_l600;o1004o`<01?l400;o1`02o`@00_l600;o
1P02o`X00_l700;o0P02o`<00_l300;o1@02o`H00_l300;o1P02o`H00_l600;o1002o`H00_l400;o
0`03o`P00_l;00;o1@02o`H00ol200?o1P02o`H00_l400;o1P02o`D00ol300;o1@02o`L00_l500;o
1@02o`H00_l;00;o0`03o`d00_lC00005@02o`h00_l600;o1P02o`P00_lH00;o1@03o`D00_l;00?o
1@03o`@01?l400;o1@04o`@00_l300?o1003o`@01?l400?o1@02o`D00_l500;o1P02o`H00_l;00;o
1@02o`<00_l300;o0`02o`D00_l600;o0`03o`@00ol600;o1P02o`@00_l500?o1002o`@00ol700;o
2`02o`@00ol600;o1002o`H00_l400Co1002o`H00_l500;o1002o`D00ol500?o1@02o`D00_l600;o
2`02o`@00ol<00;o4`0001H00_l700;o0`03o`H00ol400?o1`02oaL02ol300So2@09o`@01?l200Ko
0`04o`801_l300Wo0`04o`D01?l400Wo1004o`@01?l200So2009o`<03?l300co1009o`D01?l400Co
00<0ool02Ol300Go0`05o`802?l600[o1@05o`801Ol300[o1004o`@01?l200Go0P05o`@02_l400Co
0`04o`802?l600Go0`05o`D02_l@00005`000ol0000500Oo2008o`P000?o00005P09o`D02?l;00Go
1P03o`<01_l300?o0`06o`D01Ol00`3o000200Co1@04o`H01Ol600Co1004o`802?l:00Go1@0<o`<0
3?l600Go00<0o`001004o`@01?l00`3oo`07o`D01Ol300Go0P08o`H02Ol600Go0P05o`<02?l600Co
1004o`801Ol200Go1P05o`030?oo00@01?l300Co0P08o`H01Ol300Go1@0:oa00000Q00Co2P06ool0
a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(39\\) OLONMSMQULQTESUPKLBXDUYCHMKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`X01Ol800Go3P02oaT01Ol500go1P05o`H01_l300;o0`05o`<0
1Ol200;o00<0ool00ol500Go0`05o`H01Ol:00Co1P0=o`D01Ol700So1@0<o`<00_l00`3oo`03o`/0
1?l500So1P05o`H00_l200go00<0ool02?l500Go0P05o`<02?l:00Co2008o`P01Ol700Co0`04o`80
1Ol300Go00<0ool00ol600;o1006oaD0000C00;o2@09o`H01ol=00;o5P09o`<03Ol400Wo1006o`80
0ol300Go0`05o`802_l300Go0`05o`@02Ol600So100=o`<02Ol500So1@0<o`<02_l700So0`08o`H0
1Ol500?o0P0=o`030?oo00Wo1005o`801Ol300[o1P08o`H02?l600Wo1@04o`<01?l200Go0`05o`03
0?oo00?o1@03o`802OlD00004`02o`T00_l500;o2`03o``00_lE00?o1@03o`D00_l600;o0`03o`D0
0ol400;o1004o`@00_l700;o0`03o`D00ol300;o1`02o`@00ol500?o1@02o`@00_l700;o1P02o`80
0ol500?o1`02o`X00_l600;o0`03o`D00ol600;o1002o`D00_l<00;o1@03o`H00_l600;o0`02o`D0
0ol400?o1003o`D00_l400Co1@02o`@00_l900;o2003o`D00ol500;o1@02o`@00_l700;o1002o`D0
0ol300?o1003oa<0000C00;o4@02o`/00ol;00;o5@02o`L00_l500;o1P02o`<00_l700;o1002o`@0
1?l400;o1`02o`<00_l700;o0`02o`L00_l400;o1`02o`@00_l600;o1P02o`H00_l200;o1`02o`L0
0_l:00;o1P02o`<00_l700;o1@02o`H00_l400;o3002o`D00_l700;o1P02o`<00_l600;o1@03o`80
0ol600;o1P02o`@00_l600;o2002o`P00_l700;o1@02o`D00_l400;o1`02o`@00_l500;o1002o`H0
0_lC00004`02oa400_l<00;o2`02oa@00_l900;o1002o`H00_l200;o2@02o`<00_l300Go1002o`<0
0_l200;o0`02o`L00_l300;o0`02o`800_l300;o2@02o`<00_l600;o1P02o`H00_l00`3oo`0900;o
1P02o`X00_l200;o0P02o`<00_l700;o1@02o`H00_l400;o3002o`@00_l800;o1P02o`<00_l600;o
1P02o`800_l700;o1`02o`<00_l600;o2002o`L00ol>00;o1@02o`@00_l300;o0P02o`@00_l400;o
1@02o`H00_lC00004`02oa400_l800Co00<0ool02P02oa@00_l900;o1002o`H00_l200;o2@02o`<0
0_l300;o00<0ool01002o`800ol200;o2`03o`<00_l200?o0P02o`<00_l900;o0`02o`H00_l600;o
1P02o`030?oo00T00_l600;o2P02o`800_l?00?o1@02o`H00_l400Oo1`03o`800ol800;o1P02o`<0
0_l600;o1`04o`P00_l700;o0`02o`H00_l800;o1`02o`l00_l500;o1002o`800ol200;o1003o`80
0ol500;o1P02oa<0000C00;o4002o`L02Ol:00;o5002o`T00_l400;o2P02o`T00_l300;o0P03o`03
0?oo00@00_l20003o`3o00800_l600Oo1002o`8000?o0?l00P02o`<00_l900;o0`02o`H00_l600;o
2@02o`T00_l600;o2P06o`X01ol600;o1P02o`@02Ol500Oo2@02o`/00_l500?o1`04o`P00_l700;o
0`02o`H00_l800?o1P02o`l00_l500;o1002o`8000?o0?l00P02o`@01ol>00;o4`0001<00_l=00Co
2002o`@00ol:00;o5002o`T00_l400;o2P02o`T00_l300;o0P02o`800_l400;o00@0ool00_l00`3o
o`0400Oo1P02o`040?oo00;o00<0ool00`02o`T00_l300;o1P02o`H00_l900;o2@02o`H00_l:00Ko
2007o`P00_l600;o1002o`D00ol400Go2`02o`/02Ol800?o2@02o`L00_l300;o1P02o`L01?l600;o
3`09o`@00_l0103oo`02o`030?oo00@01Ol@00;o4`0001@00_l<00?o2002o`H00_l900;o5@02o`T0
0_l400;o2P02o`T00_l300;o00<0ool00`02o`@00_l00`3oo`020004o`3oo`<00ol;00;o00<0ool0
0P001?l0ool300;o2@02o`<00_l600;o1P02o`T00_l900;o00<0ool00`02o`<00_l500;o0P02o`L0
0ol=00;o1P02o`@00_l600;o1002o`040?ooo`X00_l;00So2@04o`P00_l700;o0`02o`H00_l600Ko
1@02o`l02Ol400;o00<0ool00P001?l0ool400;o00@0oooo3`02oa<0000D00;o3P02o`L00_l600;o
2@02oaD00_l900;o1002o`X00_l900;o0`05o`<00_l400;o00<0o`000P001?l0ool300;o1`000ol0
000200;o00<0o`000P001?l0ool300?o2002o`<00_l600;o1P02o`T00ol800;o00<0ool00`02o`<0
0_l500;o0P02o`800_l300;o1`000ol0000400;o1P02o`@00_l600;o1002o`800ol900;o2`02o`@0
0ol700Ko1`02o`L00_l300;o1P02o`H00_l200;o1@03o`L00_l500;o1@02o`@00_l00`3o00020004
o`3oo`@00_l200?o3P02oa<0000D00?o3P02o`H00_l600;o2@02oaH00_l700;o1@02o`/00_l700;o
1004o`@00_l400Co0`04o`<00_l600;o1004o`<01?l400;o1`02o`@00_l600;o1P02o`X00_l700;o
0P02o`<00_l300;o1@02o`H00_l300;o1P02o`H00_l600;o1002o`H00_l400;o0`03o`P00_l;00;o
1@02o`H00ol200?o1P02o`H00_l400;o1P02o`D00ol300;o1@02o`L00_l500;o1@02o`@01?l300Co
1002o`<00ol=00;o4`0001D00_l>00;o1P02o`H000?o00001`02oaL00ol500?o1@02o`/00ol500?o
1004o`@00_l400Co1003o`<00ol400?o1004o`@00ol500;o1@02o`D00_l600;o1P02o`/00_l500;o
0`02o`<00_l300;o1@02o`H00_l300?o1003o`H00_l600;o1002o`D00ol400;o1003o`L00_l;00;o
1003o`H00_l400;o1P02o`@01?l400;o1P02o`D00_l400;o1@03o`D00ol500;o1@02o`@01?l400?o
1002o`@00ol<00;o4`0001H00_l700;o0`03o`L00_l400;o2002oaT02Ol300So2@09o`@01?l200Ko
0P04o`D01?l300Wo0`04o`D01?l400Wo1004o`@01?l200So2009o`<03?l300co1009o`D01?l400Co
00<0ool02Ol300Go0`05o`802?l600[o1@05o`801Ol300[o1004o`@01?l200Go0P05o`@02_l400Co
0`04o`801?l500Co00<0ool00ol300Go1@0:oa00000G0003o`0000D01ol800Oo2@000ol0000J00Go
1@08o`/01Ol600?o0`06o`801?l500Co1@05o`030?l000801?l500Co1P05o`H01?l400Co0P08o`X0
1Ol500co0`0<o`H01Ol00`3o000400Co1004o`030?oo00Oo1@05o`<01Ol200So1P09o`H01Ol200Go
0`08o`H01?l400Co0P05o`801Ol600Go00<0ool01004o`<01?l200Co1@04o`030?oo00?o0`05o`D0
2_l@00008@04o`/01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(40\\) OLONMSMQULQTESVPKLBXDUYCGNKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l800Co3002oaT01Ol500go1P05o`H01_l300;o0`05o`<0
1Ol200;o00<0ool00ol500Go0`05o`H01Ol:00Co1P0=o`D01Ol700So1@0<o`<00_l00`3oo`03o`/0
0_l700So1P05o`H00_l200go00<0ool02?l500Go0P05o`<02?l:00Co2008o`P01Ol:00Ko1@06o`<0
0_l200Go1P02o`@01_lE00004`02o`d01_l700Ko3002oaH02Ol300go1009o`@01_l200?o0`05o`<0
1Ol200[o0`05o`<01Ol400Wo1P08o`@03Ol300Wo1@08o`D03?l300[o2004o`H02?l600Go1@03o`80
3Ol00`3oo`09o`@01Ol200Go0`0:o`H02?l600So1P09o`H02_l300Ko0P03o`801Ol500?o0P09oa@0
000C00;o3`02o`P00ol200?o2`02oaD00ol500?o1@02o`H00_l300?o1@03o`@00_l400Co1002o`L0
0_l300?o1@03o`<00_l700;o1003o`D00ol500;o1002o`L00_l600;o0P03o`D00ol700;o2P02o`H0
0_l300?o1@03o`L01?l800;o3002o`D00ol600;o1P02o`<00_l500?o1003o`@00ol500;o1004o`D0
0_l400;o2@02o`P00ol500?o1004o`D00_l400;o1004o`@00_l500?o0`03o`@00olC00004`02o`l0
0_l800;o1002o`/00_lE00;o1`02o`D00_l600;o0`02o`L00_l400;o1004o`@00_l700;o0`02o`L0
0_l300;o1`02o`@00_l700;o1002o`H00_l600;o1P02o`800_l700;o1`02o`X00_l600;o0`02o`L0
0_l700Co2002o``00_l500;o1`02o`H00_l300;o1P02o`D00ol200?o1P02o`H00_l400;o1P02o`P0
0_l800;o1`02o`@00_l700;o1002o`@01?l400;o1@02o`@00_l600;o4`0001<00_l900[o1@02o`H0
0_l:00;o5002o`T00_l400;o1P02o`800_l900;o0`02o`<01Ol400;o0`02o`800_l300;o1`02o`<0
0_l300;o0P02o`<00_l900;o0`02o`H00_l600;o1P02o`030?oo00T00_l600;o2P02o`800_l200;o
0`02o`L00_l600;o0P02o`L00_l<00;o1002o`P00_l600;o0`02o`H00_l600;o0P02o`L00_l700;o
0`02o`H00_l800;o1`03o``00ol700;o1002o`<01Ol400;o1002o`D00_l600;o4`0001<00_l900[o
1@02o`H00_l:00;o5002o`T00_l400;o1P02o`800_l900;o0`02o`<00_l00`3oo`0400;o0P03o`80
0_l;00?o0`02o`800ol200;o0`02o`T00_l300;o1P02o`H00_l600;o00<0ool02@02o`H00_l:00;o
0P02o`l00ol600;o0P02o`L01ol700?o0P03o`P00_l600;o0`02o`H00_l700Co2002o`L00_l300;o
1P02o`P00_l700;o3@02o`@01ol300;o0`02o`030?oo00@00ol200?o1@02o`H00_lC00004`02o`T0
0_l400;o1`02o`H00_l:00;o5002o`T00_l400;o2P02o`T00_l300;o0P03o`030?oo00@00_l20003
o`3o00800_l600Oo1002o`8000?o0?l00P02o`<00_l900;o0`02o`H00_l600;o2@02o`T00_l600;o
2P06o`X01ol600?o0P03o`H02Ol500Oo2@02o`/00_l500?o1`04o`P00_l700;o0`02o`H00_l800?o
1P02o`d00_l400Oo0`02o`800ol00`3oo`0400Oo3P02oa<0000C00;o2P02o`<00_l700;o1P02o`X0
0_lD00;o2@02o`@00_l:00;o2@02o`<00_l200;o0P02o`@00_l0103oo`02o`030?oo00@01ol600;o
00@0ool00_l00`3oo`0300;o2@02o`<00_l600;o1P02o`T00_l900;o1P02o`X01_l800Oo2002o`@0
0_l600;o1@03o`@01Ol;00;o2`09o`P00ol900;o1`02o`<00_l600;o1`04o`H00_l=00;o3P02o`80
0_l200;o1005oa000_lC00005002o`X000Co00000_l700;o1P02o`T00_lE00;o2@02o`@00_l:00;o
2@02o`<00_l00`3oo`0300;o1002o`030?oo008000Co0?oo0`03o`/00_l00`3oo`020004o`3oo`<0
0_l900;o0`02o`H00_l600;o2@02o`T00_l00`3oo`0300;o0`02o`D00_l200;o1`03o`d00_l400;o
1P02o`H00_l400;o00@0oooo2P02o`/02?l900Co2002o`L00_l300;o1P02o`H01_l500;o3@02o`h0
0_l00`3oo`0300;o1002o`040?ooo`l00_lC00005002o`X00_l200;o1`02o`H00_l900;o5@02o`T0
0_l400;o2P02o`T00_l300Go0`02o`@00_l00`3o00020004o`3oo`<00_l70003o`0000800_l00`3o
00020004o`3oo`<00ol800;o0`02o`H00_l600;o2@03o`P00_l00`3oo`0300;o0`02o`D00_l200;o
0P02o`<00_l70003o`0000<00_l600;o1@02o`H00_l400;o0P03o`T00_l;00;o1003o`L01_l700;o
1`02o`<00_l600;o1P02o`800_l500?o1`02o`<00_l800;o1005o`<00_l400;o0P03o`h00_lC0000
5003o`X000?o00000_l700;o1P02o`T00_lF00;o1`02o`D00_l;00;o1`02o`@01?l400;o1004o`<0
1?l300;o1P02o`@01?l300Co1002o`L00_l400;o1P02o`H00_l:00;o1`02o`800_l300;o0`02o`D0
0_l600;o0`02o`H00_l500;o1P02o`D00_l600;o1002o`<00ol800;o2`02o`D00_l600?o0P03o`H0
0_l600;o1002o`H00_l500?o0`02o`D00_l700;o1002o`H00ol400Co1002o`@00_l300?o3@02oa<0
000E00;o2`001?l0ool800;o1002o`T00_lG00?o1@03o`D00_l;00?o1@03o`@01?l400;o1004o`@0
0ol300?o1003o`@01?l400?o1@02o`D00_l500;o1P02o`H00_l;00;o1@02o`<00_l300;o0`02o`D0
0_l600;o0`03o`@00ol400?o1P03o`@00_l500?o1002o`@00ol700;o2`02o`@00ol600;o1002o`H0
0_l400Co1002o`H00_l500;o1002o`D00ol500?o1003o`@01?l400Co1002o`@00_l400?o3002oa<0
000F00;o2P04o`P00ol200?o2002oaT02Ol300So2@09o`@01?l200Ko0P04o`D01?l300Wo0`04o`D0
1?l400Wo1004o`@01?l200So2009o`<03?l300co1009o`<01_l200Ko00<0ool02Ol300Go0`05o`80
2?l600[o1@05o`801Ol300[o1004o`@01?l200Go0P05o`@02_l500[o0`04o`801_l00`3oo`03o`<0
1Ol500[o400001L000?o00002@03o`T01_l90003o`0001X01Ol500So2`05o`H00ol300Ko0P04o`D0
1?l500Go00<0o`000P04o`D01?l600Go1P04o`@01?l200So2P05o`D03?l300co1P05o`030?l00080
1_l200Ko00<0ool01ol500Go0`05o`802?l600Wo1P05o`801Ol300So1P04o`@01?l200Go0P05o`H0
1Ol00`3oo`0700Go00<0ool00`03o`<01_l00`3oo`03o`<01Ol500[o400002<00ol:00Coo`360000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(41\\) OLOMMSMQVLQTESVPJLBXDUYCFNKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l600Wo2@02oaT01Ol500go1P05o`D01Ol300Go0P05o`<0
1Ol200;o00<0ool00ol500Go0`05o`H01Ol:00;o200=o`D01Ol700So1@0<o`<00_l00`3oo`03o`/0
0_l700So2006o`L03Ol00`3oo`08o`D01Ol200Go0`08o`X01?l800So2005o`H01ol800Ko0`02o`80
1Ol600;o1006oaD0000C00;o3@06o`H02Ol:00;o5P09o`<03Ol400Wo0`05o`<01Ol200Go0`05o`80
2_l300Go0`05o`@02Ol700Co1`0=o`<02Ol500So1@0<o`<02_l800Co1P08o`H02Ol600go00<0ool0
2Ol400Go0P05o`<02_l600So1P08o`H02Ol400Oo2006o`800ol200Go1@03o`802OlD00004`02o`l0
0_l<00;o3@02oaD00ol500?o1@02o`H00_l300?o1@03o`<00_l700;o1002o`L00_l300?o1@03o`<0
0_l700;o1003o`D00ol600Co2P02o`H00_l200?o1@03o`L00_l:00;o1P02o`<00ol500?o1`04o`P0
0_l:00?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D00_l400Co1@02o`@00_l900;o2003o`D0
0ol500;o3002o`@01?l400;o1@03o`<00ol400?o4`0001<00_l?00;o3002o`d00_lE00;o1`02o`D0
0_l600;o0`02o`L00_l300;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`@00_l700;o1P04o`X0
0_l600;o0P02o`L00_l700;o2P02o`H00_l300;o1`02o`L01?l800;o2P02o`H00_l800;o1P02o`<0
0_l600;o1@03o`800ol600;o1P02o`@00_l600;o2002o`P00_l700;o1@02o``00_l400Co1002o`D0
0_l400;o1P02oa<0000C00;o2@0:o`X00_l=00;o5002o`T00_l400;o1P02o`800_l900;o0P02o`<0
0_l200;o1002o`<00_l200;o0`02o`L00_l300;o0`02o`800_l300;o2@02o`@00_l200;o2@02o`H0
0_l00`3oo`0900;o1P02o`X00_l200;o0P02o`<00_l700;o1P02o`800_l700;o2P02o`H00_l800;o
1P02o`<00_l600;o1P02o`800_l700;o1`02o`<00_l600;o2002o`L00ol>00;o0P02o`P00_l300Go
1002o`@00_l500;o1P02oa<0000C00;o2@0:o`X00_l=00;o5002o`T00_l400;o1P02o`800_l900;o
0P02o`800ol200;o1002o`800ol200;o2`03o`<00_l200?o0P02o`<00_l900;o1002o`800_l900;o
1P02o`030?oo00T00_l600;o2P02o`800_l?00?o1P02o`800_l700Oo1@02o`H00_l800;o1P02o`<0
0_l600;o1`04o`P00_l700;o0`02o`H00_l800;o1`02o`l00_l200;o2002o`<00_l00`3oo`0400?o
0P03o`D00_l600;o4`0001<00_l900;o1002o``00_l=00;o5002o`T00_l400;o2P02o`T00_l200;o
0P000ol0o`0200;o1002o`8000?o0?l00P02o`H01ol400;o0P000ol0o`0200;o0`02o`T00_l300?o
0P03o`P00_l900;o2@02o`H00_l:00Ko2P07o`H00ol200?o1P09o`/00_l800;o2`02o`D00ol700Co
2002o`L00_l300;o1P02o`P00ol600;o3`06o`P00_l200?o00<0ool01007o`h00_lC00004`02o`X0
0_l300;o3002o`d00_lD00;o2@02o`@00_l:00;o2@02o`800_l0103oo`02o`030?oo00@00_l0103o
o`02o`030?oo00@01ol600;o00@0ool00_l00`3oo`0300;o2@02o`<00_l400;o2002o`T00_l900;o
1P02o`X01_l800Oo2002o`@00_l600;o1@03o`X00_l800;o2`09o`P00ol900;o1`02o`<00_l600;o
1`04o`H00_l?00Ko2002o`800_l200;o1005oa000_lC00005002o`X000Co00000_l<00;o3002oaD0
0_l900;o1002o`X00_l900;o0P02o`030?oo008000Co0?oo1002o`030?oo008000Co0?oo0`03o`/0
0_l00`3oo`020004o`3oo`<00_l900;o0`02o`@00_l800;o2@02o`T00_l00`3oo`0300;o0`02o`D0
0_l200;o1`03o`d00_l400;o1P02o`H00_l:00;o2002o`/02?l900Co2002o`L00_l300;o1P02o`H0
1_l500;o3`02o`800_l800;o00<0ool00`02o`@00_l0103oool?00;o4`0001@00_l:00;o0P02o``0
0_l<00;o5@02o`T00_l400;o2P02o`T00_l200;o00<0o`000P001?l0ool400;o00<0o`000P001?l0
ool300;o1`000ol0000200;o00<0o`000P001?l0ool300?o2002o`800_l600;o1`02o`T00ol800;o
00<0ool00`02o`<00_l500;o0P02o`800_l300;o1`000ol0000300;o1P02o`D00_l600;o2P02o`P0
0_l;00;o1003o`L01_l700;o1`02o`<00_l600;o1P02o`800_l500?o1`02o`D00_l200;o0P02o`@0
1Ol300;o1002o`800ol>00;o4`0001@00ol:0003o`0000;o3002o``00_lF00;o1`02o`D00_l;00;o
1`02o`<01?l300Co1004o`<01?l300;o1P02o`@01?l300Co1002o`L00_l300;o1P02o`L00_l:00;o
1`02o`800_l300;o0`02o`D00_l600;o0`02o`H00_l500;o1P02o`D00_l600;o2P02o`P00_l;00;o
1@02o`H00ol200?o1P02o`H00_l400;o1P02o`D00ol300;o1@02o`L00_l500;o1P02o`@01?l400;o
1002o`<00ol=00;o4`0001D00_l;0004o`3oo``00_l;00;o5`03o`D00ol500;o2`03o`D00ol300Co
1003o`@01?l400?o0`03o`@00ol400Co1003o`D00_l500;o0`03o`H00ol600;o2`02o`D00_l300;o
0`02o`<00_l500;o1P02o`<00ol400?o1003o`H00ol400;o1@03o`X00_l800;o2`02o`@00ol600;o
1002o`H00_l400Co1002o`H00_l500;o1002o`D00ol500?o1@02o`H00_l400Co1002o`@00_l400?o
3002oa<0000F00;o2P04o`P00ol00`3oo`0:00;o6@09o`<02?l900Wo0`04o`D01?l200Co1@04o`<0
2Ol300Co1@04o`@02Ol200Ko0P06o`802?l800Wo0`0<o`<03?l400Wo0`06o`801_l00`3oo`09o`H0
2_l200So1P0:o`D01Ol200Go0`0:o`@01?l400Co0P05o`801Ol400[o0`0<o`<01?l200Ko00<0ool0
0ol300Go1@0:oa00000G0003o`0000T00ol800Ko2P000ol0000J00Go1@08o`/01Ol500Co1@04o`80
1?l500Co1@05o`030?l000801?l500Co1P05o`@01_l200Ko0P08o`X01Ol500co0`0<o`H01Ol00`3o
000200Ko0P06o`030?oo00Oo200:o`802?l600Wo1P05o`801Ol300So1P04o`@01?l200Go0P05o`H0
1Ol00`3oo`0300co0`03o`<01_l00`3oo`03o`<01Ol500[o400002<00ol;00?oo`360000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(42\\) OLOMMSMQVKQUESVOJLBXDUYCFNKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l500[o2@02oaT01Ol500go1P05o`D01Ol300Go0P05o`<0
1Ol200;o00<0ool00ol500Go0`05o`H01Ol:00;o2005o`H00_l500Go2P04o`H03?l300;o00<0ool0
0ol;00;o2`05o`L01_l700go00<0ool02?l500Go0P05o`<02?l:00Co2008o`P01Ol600Oo2006o`<0
0_l200Go1P02o`@01_lE00004`02o`d01_l500[o2P02oaH02Ol300go1009o`<01Ol300Go0P05o`<0
1Ol200[o0`05o`<01Ol400Wo1`04o`L01Ol500?o0`09o`H02?l400co0`0:o`P01?l800Wo0`09o`H0
3Ol00`3oo`09o`@01Ol200Go0`0:o`H02?l600So1P09o`@01ol800Ko0P03o`801Ol500?o0P09oa@0
000C00;o3`02o`P00_l500;o2P02oaD00ol500?o1@02o`H00_l300?o1@03o`<00_l700;o1002o`L0
0_l300?o1@03o`<00_l700;o1003o`D00ol600Co2@02o`D00ol300?o1@03o`D00_l400;o1P02o`H0
0_l300?o1@03o`L01?l700?o1@03o`800ol400?o2002o`H00_l300;o1@03o`@00ol400?o1@02o`@0
1?l500;o1002o`T00_l800?o1@03o`D00_l<00;o1004o`@00_l500?o0`03o`@00olC00004`02o`l0
0_l900?o3`02oaD00_l700;o1@02o`H00_l300;o1`02o`<00_l700;o1002o`L00_l300;o1`02o`<0
0_l700;o1002o`L00_l600Co2@02o`D00_l400;o1`02o`@00_l600;o1@02o`H00_l300;o1`02o`L0
1?l700;o1`02o`800_l600;o2002o`H00_l300;o1P02o`D00ol200?o1P02o`H00_l400;o1P02o`P0
0_l800;o1`02o`D00_l<00;o1004o`@00_l500;o1002o`H00_lC00004`02o`T02_l800?o3P02oa@0
0_l900;o1002o`H00_l200;o2@02o`800_l300;o0P02o`@00_l300;o0P02o`<00_l700;o0`02o`<0
0_l200;o0`02o`T00_l400;o0P02o`P00_l400;o1002o`T00_l300;o1P02o`D00_l200;o0P02o`<0
0_l700;o1P02o`800_l500;o2@02o`030?oo00H00_l800;o1P02o`<00_l600;o1P02o`800_l700;o
1`02o`<00_l600;o2002o`L00ol>00;o0P02o`P00_l300Go1002o`@00_l500;o1P02oa<0000C00;o
2@0:o`T00ol=00;o5002o`T00_l400;o1P02o`800_l900;o0P02o`800ol200;o1002o`800ol200;o
2`03o`<00_l200?o0P02o`<00_l900;o1002o`800_l800?o0P03o`@00_l900;o0`02o`H00_l500;o
0P02o`l00ol600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l700Co2002o`L0
0_l300;o1P02o`P00_l700;o3`02o`800_l800;o0`02o`030?oo00@00ol200?o1@02o`H00_lC0000
4`02o`T00_l400;o3003o``00_lD00;o2@02o`@00_l:00;o2@02o`800_l20003o`3o00800_l400;o
0P000ol0o`0200;o1P07o`@00_l20003o`3o00800_l300;o2@02o`<00ol200?o1`07o`D00_l900;o
0`02o`H00_l500Ko2P07o`H00ol200?o1002o`T00_l900;o2002o`/00_l500?o1`04o`P00_l700;o
0`02o`H00_l800?o1P02o`l01_l800;o0P03o`030?oo00@01ol>00;o4`0001<00_l:00;o0`02o`d0
0ol;00;o5002o`T00_l400;o2P02o`T00_l200;o00@0ool00_l00`3oo`0400;o00@0ool00_l00`3o
o`0400Oo1P02o`040?oo00;o00<0ool00`02o`T00_l300;o1002o`L01Ol700;o2@02o`<00_l600;o
1@06o`P01ol800;o1002o`@00_l900;o2@02o`P00_l;00Wo2003o`T00_l700;o0`02o`H00_l700Co
1P02o`l01_l800;o0P02o`800_l400Go4002oa<0000D00;o2P001?l00002o`h00_l:00;o5@02o`T0
0_l400;o2P02o`T00_l200;o00<0ool00P001?l0ool400;o00<0ool00P001?l0ool300?o2`02o`03
0?oo008000Co0?oo0`02o`T00_l300;o1002o`L00_l0103oool600;o2@02o`<00_l600;o1@02o`80
0_l700?o3@02o`@00_l400;o2@02o`T00_l800;o2`08o`T01?l800;o1`02o`<00_l600;o1P06o`D0
0_l?00;o0P02o`P00_l00`3oo`0300;o1002o`040?ooo`l00_lC00005002o`X00_l200;o3`02o`T0
0_lE00;o2@02o`@00_l:00;o2@02o`800_l00`3o00020004o`3oo`@00_l00`3o00020004o`3oo`<0
0_l70003o`0000800_l00`3o00020004o`3oo`<00ol800;o0P02o`H00_l600;o0P03o`D00ol800;o
0`02o`H00_l500;o0P02o`800_l300;o1`000ol0000300;o1P02o`<00_l900;o2@02o`P00_l;00;o
1003o`L01_l700;o1`02o`<00_l600;o1P02o`800_l500?o1`02o`D00_l200;o0P02o`@01Ol300;o
1002o`800ol>00;o4`0001@00ol:0003o`0000;o3`02o`T00_lF00;o1`02o`D00_l;00;o1`02o`<0
1?l300Co1004o`<01?l300;o1P02o`@01?l300Co1002o`L00_l300;o1P02o`H00_l300?o1@02o`L0
0_l400;o1P02o`D00_l600;o0`02o`H00_l500;o1P02o`@00_l700;o2P02o`P00_l;00;o1@02o`H0
0ol200?o1P02o`H00_l400;o1P02o`D00ol300;o1@02o`L00_l500;o1P02o`@01?l400;o1002o`<0
0ol=00;o4`0001D00_l;0004o`3oo`P00_l500;o2002oaL00ol500?o1@02o`/00ol500?o0`04o`@0
0ol400Co1003o`<00ol400?o1004o`@00ol500;o1@02o`<00ol600?o1@02o`@00ol500;o1@02o`D0
0_l600;o1@02o`H00_l300?o1003o`@00ol600?o0`03o`D00ol:00;o2002o`/00_l400?o1P02o`@0
0_l600;o1004o`@00_l600;o1@02o`@00_l500?o1@03o`D00_l600;o1004o`@00_l400;o1003o``0
0_lC00005P02o`X01?l800?o0`03o`L00_lI00Wo0`08o`T02Ol300Co1@04o`801?l500Co0`09o`<0
1?l500Co1009o`801_l200Ko0P05o`<01Ol300Wo1004o`@01?l200co1009o`<01_l200Ko0`09o`H0
2_l200So1P0:o`D01Ol200Go0`0:o`@01?l400Co0P05o`801Ol400[o0`0<o`<01?l200Ko00<0ool0
0ol300Go1@0:oa00000G0003o`0000T00ol900Oo20000ol0000J00Go1@08o`/01Ol500Co1@04o`80
1?l500Co1@05o`030?l000801?l500Co1P05o`@01_l200Ko0P05o`<01Ol500Go1P04o`@01?l200co
1P05o`030?l000801_l200Ko1@05o`P02_l200So1P09o`H01Ol200Go0`08o`H01?l400Co0P05o`80
1Ol600Go00<0ool00`0<o`<00ol300Ko00<0ool00ol300Go1@0:oa00000S00?o2P05ool0a@000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(43\\) OLOMMSMQWKQUESVOJLBXDUYCFOKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l700Go3002oaT01Ol500go1P05o`D01Ol300Go0P05o`<0
1Ol200;o00<0ool00ol500Go0`05o`H01Ol700;o1002o`D01Ol600;o1@05o`X01?l600co0`02o`03
0?oo00?o2`02o`/01Ol700Ko1`0=o`030?oo00So1@05o`801Ol300So2P04o`P02?l800Go1P07o`/0
1Ol500Go1P02o`@01_lE00004`02o`d01_l500Wo2`02oaH02Ol300go1009o`<01Ol300Go0P05o`<0
1Ol200[o0`05o`<01Ol400Wo1@02o`@00_l500Go1@03o`<02Ol600So100<o`<02_l800Co2009o`<0
2Ol600go00<0ool02Ol400Go0P05o`<02_l600So1P08o`H02Ol400Oo2@09o`<01Ol500?o0P09oa@0
000C00;o3`02o`L00_l500;o2`02oaD00ol500?o1@02o`H00_l300?o1@03o`<00_l700;o1002o`L0
0_l300?o1@03o`<00_l700;o1003o`D00ol300?o1003o`H00_l500?o0`03o`D00ol500;o1002o`H0
0_l600;o0`03o`D00ol700Co1`03o`D00ol200?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D0
0_l400Co1@02o`@00_l900;o2003o`D00ol500;o2`03o`D00ol400;o1@03o`<00ol400?o4`0001<0
0_l?00;o3`02o`X00_lE00;o1`02o`D00_l600;o0`02o`L00_l300;o1`02o`@00_l700;o0`02o`L0
0_l300;o1`02o`@00_l700;o0`04o`<00ol600;o1@02o`@00_l700;o1002o`H00_l500;o1P02o`<0
0_l700;o1`04o`L00_l700;o0P02o`H00_l800;o1P02o`<00_l600;o1@03o`800ol600;o1P02o`@0
0_l600;o2002o`P00_l700;o1@02o`/00_l700;o1002o`D00_l400;o1P02oa<0000C00;o2@0:o`d0
0_l:00;o5002o`T00_l400;o1P02o`800_l900;o0P02o`<00_l200;o1002o`<00_l200;o0`02o`L0
0_l300;o0`02o`800_l300;o2@02o`801?l200Co1P02o`@00_l400;o2@02o`<00_l600;o1@02o`80
0_l200;o0`02o`L00_l600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l600;o
0P02o`L00_l700;o0`02o`H00_l800;o1`03o`h00_l200;o1P02o`T00_l300;o1002o`D00_l600;o
4`0001<00_l900[o3@02o`X00_lD00;o2@02o`@00_l600;o0P02o`T00_l200;o0P03o`800_l400;o
0P03o`800_l;00?o0`02o`800ol200;o0`02o`T00_l200;o00@0o`001?l600?o0P03o`@00_l900;o
0`02o`H00_l500;o0P02o`l00ol600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H0
0_l700Co2002o`L00_l300;o1P02o`P00_l700;o3`02o`800_l600;o2@02o`<00ol200?o1@02o`H0
0_lC00004`02o`T00_l400;o3P02o`/00_lD00;o2@02o`@00_l:00;o2@02o`800_l20003o`3o0080
0_l400;o0P000ol0o`0200;o1P07o`@00_l20003o`3o00800_l300;o2@02o`800_l01P3o003o00;o
1P07o`D00_l900;o0`02o`H00_l500Ko2P07o`H00ol200?o1002o`T00_l900;o2002o`/00_l500?o
1`04o`P00_l700;o0`02o`H00_l800?o1P02o`l01_l600;o2@02o`<01ol>00;o4`0001<00_l:00;o
0`02o`/01?l<00;o5002o`T00_l400;o2P02o`T00_l200;o00@0ool00_l00`3oo`0400;o00@0ool0
0_l00`3oo`0400Oo1P02o`040?oo00;o00<0ool00`02o`T00_l200;o00<0ool00_l00`3oo`0600Go
1`02o`T00_l300;o1P02o`D01_l800Oo2002o`@00_l400;o2@02o`T00_l800;o2`09o`P00ol900;o
1`02o`<00_l600;o1`04o`H00_l?00Ko1P02o`T00_l300Go4002oa<0000D00;o2P001?l00002o`/0
0ol<00;o5@02o`T00_l400;o2P02o`T00_l200;o00<0ool00P001?l0ool400;o00<0ool00P001?l0
ool300?o2`02o`030?oo008000Co0?oo0`02o`T00_l200;o00<0ool00_l00`3oo`0600;o00@0oooo
1P02o`T00_l300;o1P02o`D00_l200;o1`03o`d00_l400;o1002o`T00_l900;o2002o`/02?l900Co
2002o`L00_l300;o1P02o`H01_l500;o3`02o`800_l600;o2@02o`<00_l0103oool?00;o4`0001@0
0_l:00;o0P02o`d00_l;00;o5@02o`T00_l400;o2P02o`T00_l200;o00<0o`000P001?l0ool400;o
00<0o`000P001?l0ool300;o1`000ol0000200;o00<0o`000P001?l0ool300?o2002o`030?oo00<0
0_l300;o1@02o`800ol500?o2002o`<00_l600;o1@02o`800_l200;o0`02o`L000?o00000`02o`H0
0_l300;o2@02o`T00_l800;o2`02o`@00ol700Ko1`02o`L00_l300;o1P02o`H00_l200;o1@03o`L0
0_l500;o0P02o`800_l200;o2@02o`<00_l200?o3P02oa<0000D00?o2P000ol00002o`h00_l:00;o
5P02o`L00_l500;o2`02o`L00_l300Co0`04o`@01?l300Co0`02o`H00_l400Co0`04o`@00_l700;o
0P02o`<00_l300;o1@02o`<00ol500;o1`02o`@00_l600;o1@02o`H00_l300;o1P02o`D00_l600;o
1002o`L00_l:00;o2002o`/00_l500;o1P03o`800ol600;o1P02o`@00_l600;o1@03o`<00_l500;o
1`02o`D00_l600;o0`02o`L00_l400;o0`03o`d00_lC00005@02o`/000Co0?oo3P02o`T00_lG00?o
1@03o`D00_l;00?o1@03o`<01?l400?o1004o`@00ol300?o1003o`@01?l400?o1@02o`D00_l300;o
2002o`D00_l400?o1@02o`D00_l500;o1P02o`D00_l600;o0`03o`@00ol400?o1P03o`<00ol500?o
2P02o`P00_l;00;o1003o`H00_l400;o1P02o`@01?l400;o1P02o`D00_l400;o1@03o`D00ol500;o
1P02o`<00ol500?o1002o`@00ol<00;o4`0001H00_l:00Co2002o`<00ol800;o6@09o`<02?l900Wo
0`04o`D01?l200Co1@04o`<02Ol300Co1@04o`@02Ol200Ko0P06o`801Ol300Go0`09o`@01?l400Co
0P0<o`@02Ol300Ko0P06o`<02Ol600[o0P08o`H02_l500Go0P05o`<02_l400Co1004o`801Ol200Go
100:o`<03?l400Wo0`05o`<01Ol500[o400001L000?o00002@03o`P01ol90003o`0001X01Ol500So
2`05o`D01?l500Co0P04o`D01?l500Go00<0o`000P04o`D01?l600Go1006o`801_l200Go0`05o`D0
1Ol600Co1004o`803?l600Go00<0o`000P06o`801_l500Go200:o`802?l600Wo1P05o`801Ol300So
1P04o`@01?l200Go0P05o`H01Ol00`3oo`0300co1P05o`D01Ol300Go1@0:oa00000S00?o2P04ool0
aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(44\\) OKPMMSMQWKQUESVOJLBXDUYCFOKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l900Ko2@02oaT01Ol500Go1P02o`802?l600Go0`05o`80
1Ol300Go0P02o`030?oo00?o1@05o`<01Ol600Go1`02o`@00_l500Go1P02o`D01Ol:00Co1P0<o`<0
0_l00`3oo`03o`/00_l;00Go1`06o`L03Ol00`3oo`08o`D01Ol200Go0`08o`X01?l800So2005o`H0
1ol;00Go1@05o`H00_l400Ko5@0001<00_l=00Ko2@06o`X00_lF00Wo0`05o`D00ol200So1P05o`<0
1Ol200Go0`05o`802_l300Go0`05o`@02Ol500;o1002o`D01Ol500?o0`09o`H02?l400co0`0:o`P0
1?l800Wo0`09o`H03Ol00`3oo`09o`@01Ol200Go0`0:o`H02?l600So1P09o`@01ol900Wo0`05o`D0
0ol200Wo500001<00_l?00;o3@02o``00_lE00?o1@03o`@00_l500?o1@02o`/00_l700;o1002o`L0
0_l300?o1@03o`<00_l700;o1003o`D00ol300?o1003o`H00_l500?o0`03o`D00ol500;o1002o`H0
0_l600;o0`03o`D00ol700Co1`03o`D00ol200?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D0
0_l400Co1@02o`@00_l900;o2003o`D00ol500;o2`03o`D00ol400;o1@03o`<00ol400?o4`0001<0
0_l?00;o3@02o``00_lE00;o1`02o`@00_l500;o1P02o`/00_l700;o1002o`L00_l300;o1`02o`<0
0_l700;o1002o`L00_l300Co0`03o`H00_l500;o1002o`L00_l400;o1P02o`D00_l600;o0`02o`L0
0_l700Co1`02o`L00_l200;o1P02o`P00_l600;o0`02o`H00_l500?o0P03o`H00_l600;o1002o`H0
0_l800;o2002o`L00_l500;o2`02o`L00_l400;o1@02o`@00_l600;o4`0001<00_l900[o1@0:o`X0
0_lD00;o2@02o`<00_l400;o1`02o`/00_l300;o0P02o`@00_l300;o0P02o`<00_l700;o0`02o`<0
0_l200;o0`02o`T00_l200Co0P04o`H00_l400;o1002o`T00_l300;o1P02o`D00_l200;o0P02o`<0
0_l700;o1P02o`800_l500;o2@02o`030?oo00H00_l800;o1P02o`<00_l600;o1P02o`800_l700;o
1`02o`<00_l600;o2002o`L00ol>00;o0P02o`H00_l900;o0`02o`@00_l500;o1P02oa<0000C00;o
2@0:o`D02_l:00;o5002o`T00_l300?o0P03o`L01ol600;o0P03o`800_l400;o0P03o`800_l;00?o
0`02o`800ol200;o0`02o`T00_l200;o00@0o`001?l600?o0P03o`@00_l900;o0`02o`H00_l500;o
0P02o`l00ol600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l700Co2002o`L0
0_l300;o1P02o`P00_l700;o3`02o`800_l600;o2@02o`<00ol200?o1@02o`H00_lC00004`02o`T0
0_l400;o1`02o`@00_l<00;o5002o`T00_l300Oo2009o`@00_l20003o`3o00800_l400;o0P000ol0
o`0200;o1P07o`@00_l20003o`3o00800_l300;o2@02o`800_l01P3o003o00;o1P07o`D00_l900;o
0`02o`H00_l500Ko2P07o`H00ol200?o1002o`T00_l900;o2002o`/00_l500?o1`04o`P00_l700;o
0`02o`H00_l800?o1P02o`l01_l600;o2@02o`<01ol>00;o4`0001<00_l:00;o0`02o`P00_l300;o
3002oa@00_l900;o0`05o`X00_l500?o0`02o`040?oo00;o00<0ool01002o`040?oo00;o00<0ool0
1007o`H00_l0103oo`02o`030?oo00<00_l900;o0P02o`030?oo00;o00<0ool01P05o`L00_l900;o
0`02o`H00_l500Ko2007o`P00_l400;o1002o`T00_l900;o2002o`/02Ol800?o2@02o`L00_l300;o
1P02o`L01?l600;o3`06o`H00_l900;o0`05oa000_lC00005002o`X000Co00000_l90004o`0000;o
2`02oaD00_l900;o0`02o`040?ooo`T00_l600;o0`02o`030?oo008000Co0?oo1002o`030?oo0080
00Co0?oo0`03o`/00_l00`3oo`020004o`3oo`<00_l900;o0P02o`030?oo00;o00<0ool01P02o`04
0?ooo`H00_l900;o0`02o`H00_l500;o0P02o`L00ol=00;o1002o`@00_l900;o2@02o`P00_l;00So
2@04o`P00_l700;o0`02o`H00_l600Ko1@02o`l00_l200;o1P02o`T00_l300;o00@0oooo3`02oa<0
000D00;o2P02o`800_l900;o0P02o`/00_lE00;o2@02o`<00_l200?o2002o`H00_l300;o00<0o`00
0P001?l0ool400;o00<0o`000P001?l0ool300;o1`000ol0000200;o00<0o`000P001?l0ool300?o
2002o`030?oo00<00_l300;o1@02o`800ol500?o2002o`<00_l600;o1@02o`800_l200;o0`02o`L0
00?o00000`02o`H00_l300;o2@02o`T00_l800;o2`02o`@00ol700Ko1`02o`L00_l300;o1P02o`H0
0_l200;o1@03o`L00_l500;o0P02o`800_l200;o2@02o`<00_l200?o3P02oa<0000D00?o2P000ol0
0002o`X000?o00000_l;00;o5P02o`L00_l400;o0`03o`L00_l600;o0`04o`<01?l400Co0`04o`<0
0_l600;o1004o`<01?l400;o1`02o`800_l300;o0`02o`D00_l300?o1@02o`L00_l400;o1P02o`D0
0_l600;o0`02o`H00_l500;o1P02o`@00_l700;o2P02o`P00_l;00;o1@02o`H00ol200?o1P02o`H0
0_l400;o1P02o`D00ol300;o1@02o`L00_l500;o1P02o`<00_l700;o1002o`<00ol=00;o4`0001D0
0_l;0004o`3oo`/000Co0?oo2P02oaL00ol500?o1002o`@00ol600;o1@03o`<01?l400?o1004o`@0
0ol300?o1003o`@01?l400?o1@02o`D00_l300;o2002o`D00_l400?o1@02o`D00_l500;o1P02o`D0
0_l600;o0`03o`@00ol400?o1P03o`<00ol500?o2P02o`P00_l;00;o1003o`H00_l400;o1P02o`@0
1?l400;o1P02o`D00_l400;o1@03o`D00ol500;o1P02o`<00ol500?o1002o`@00ol<00;o4`0001H0
0_l:00Co2`04o`T00_lI00Wo0`05o`<01Ol200_o0`04o`D01?l200Co1@04o`<02Ol300Co1@04o`@0
2Ol200Ko0P06o`801Ol300Go0`09o`@01?l400Co0P0<o`@02Ol300Ko0P06o`<02Ol600[o0P08o`H0
2_l500Go0P05o`<02_l400Co1004o`801Ol200Go100:o`<03?l400Wo0`05o`<01Ol500[o400001L0
00?o00002@03o``00ol90003o`0001X01Ol500Go0`05o`802Ol500Co1@04o`801?l500Co1@05o`03
0?l000801?l500Co1P05o`@01_l200Ko0P05o`<01Ol500Go1P04o`@01?l200co1P05o`030?l00080
1_l200Ko1@05o`P02_l200So1P09o`H01Ol200Go0`08o`H01?l400Co0P05o`801Ol600Go00<0ool0
0`0<o`H01Ol500Go0`05o`D02_l@00008`03o``00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(45\\) OKPMMSMQXKQUESVOJLBXDVYCFOKJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l700Go3002oaT01Ol500Go1P02o`802?l600Go0`05o`80
1Ol300Go0P02o`030?oo00?o1@05o`<01Ol600Go1@05o`801Ol300Go1P02o`D01Ol:00Co1P0<o`<0
0_l00`3oo`03o`/00_l;00Go1`06o`L03Ol00`3oo`08o`D01Ol200Go0`08o`X00_l:00So2005o`H0
1ol;00Go1@05o`H00_l400Ko5@0001<00_l=00Ko1@09o`/00_lF00Wo0`05o`D00ol200So1P05o`<0
1Ol200Go0`05o`802_l300Go0`05o`@02Ol300Go0P05o`<01Ol500?o0`09o`H02?l400co0`0:o`P0
1?l800Wo0`09o`H03Ol00`3oo`09o`@01Ol200Go0`0:o`L01?l900So1P09o`@01ol900Wo0`05o`D0
0ol200Wo500001<00_l?00;o1`02o`D00_l;00;o5@03o`D00ol400;o1@03o`D00_l;00;o1`02o`@0
0_l700;o0`03o`D00ol300;o1`02o`@00ol500?o0`03o`@00ol600;o1@03o`<00ol500?o1@02o`@0
0_l600;o1P02o`<00ol500?o1`04o`L00ol500?o0P03o`@00ol800;o1P02o`<00_l500?o1003o`@0
0ol500;o1004o`H01?l<00;o2003o`D00ol500;o2`03o`D00ol400;o1@03o`<00ol400?o4`0001<0
0_l?00;o3`02o`X00_lE00;o1`02o`@00_l500;o1P02o`/00_l700;o1002o`L00_l300;o1`02o`<0
0_l700;o1002o`L00_l400?o0P03o`L00_l500;o1002o`L00_l400;o1P02o`D00_l600;o0`02o`L0
0_l700Co1`02o`L00_l200;o1P02o`P00_l600;o0`02o`H00_l500?o0P03o`H00_l600;o1P04o``0
0_l800;o1`02o`D00_l;00;o1`02o`@00_l500;o1002o`H00_lC00004`02o`T02_l=00;o2P02oa@0
0_l900;o0`02o`@00_l700;o2`02o`<00_l200;o1002o`<00_l200;o0`02o`L00_l300;o0`02o`80
0_l300;o2@02o`@00_l200;o2002o`@00_l400;o2@02o`<00_l600;o1@02o`800_l200;o0`02o`L0
0_l600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l600;o0P02o`L00_l700;o
1002o`800_l;00;o1`03o`h00_l200;o1P02o`T00_l300;o1002o`D00_l600;o4`0001<00_l900[o
3@02o`X00_lD00;o2@02o`<00ol200?o1`07o`H00_l200?o0P02o`@00_l200?o0P02o`/00ol300;o
0P03o`800_l300;o2@02o`D01?l900?o0P03o`@00_l900;o0`02o`H00_l500;o0P02o`l00ol600;o
0P02o`D00_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l700Co2002o`L00_l400;o0P02o`/0
0_l700;o3`02o`800_l600;o2@02o`<00ol200?o1@02o`H00_lC00004`02o`T00_l400;o3`02o`X0
0_lD00;o2@02o`<01ol800Wo1002o`8000?o0?l00P02o`@00_l20003o`3o00800_l600Oo1002o`80
00?o0?l00P02o`<00_l900;o1@04o`T01ol500;o2@02o`<00_l600;o1@06o`X01ol600?o0P03o`@0
0_l900;o2@02o`P00_l;00;o1@03o`L01?l800;o1`02o`<00ol200?o2P03o`H00_l?00Ko1P02o`T0
0_l300Oo3P02oa<0000C00;o2P02o`<00_l800;o1002o`/00_lD00;o2@02o`<01Ol:00;o1@03o`<0
0_l0103oo`02o`030?oo00@00_l0103oo`02o`030?oo00@01ol600;o00@0ool00_l00`3oo`0300;o
2@02o`D00ol:00Go1`02o`T00_l300;o1P02o`D01_l800Oo2002o`@00_l400;o2@02o`T00_l800;o
2`09o`P00ol900;o1`02o`<00_l400;o2@04o`H00_l?00Ko1P02o`T00_l300Go4002oa<0000D00;o
2P001?l00002o`P02?l:00;o5@02o`T00_l300;o00@0oooo2@02o`H00_l300;o00<0ool00P001?l0
ool400;o00<0ool00P001?l0ool300?o2`02o`030?oo008000Co0?oo0`02o`T00_l500Co2@02o`04
0?ooo`H00_l900;o0`02o`H00_l500;o0P02o`L00ol=00;o1002o`@00_l900;o2@02o`P00_l;00So
2@04o`P00_l700;o0`02o`@00_l800Ko1@02o`l00_l200;o1P02o`T00_l300;o00@0oooo3`02oa<0
000D00;o2P02o`800_l800Oo2`02oaD00_l900;o0`02o`800ol800;o1P02o`<00_l00`3o00020004
o`3oo`@00_l00`3o00020004o`3oo`<00_l70003o`0000800_l00`3o00020004o`3oo`<00ol800;o
1006o`P00_l200?o1@03o`P00_l300;o1P02o`D00_l200;o0P02o`<00_l70003o`0000<00_l600;o
0`02o`T00_l900;o2002o`/00_l400?o1`06o`L00_l700;o0P02o`H00_l700;o0P02o`D00ol700;o
1@02o`800_l200;o0P02o`T00_l300;o0P03o`h00_lC00005003o`X000?o00000_l800;o4002oaH0
0_l700;o1002o`<00ol700;o1P02o`<01?l300Co1004o`<01?l300;o1P02o`@01?l300Co1002o`L0
0_l400?o0P03o`L00_l300?o1@02o`L00_l400;o1P02o`D00_l600;o0`02o`H00_l500;o1P02o`@0
0_l700;o2P02o`P00_l;00;o1@02o`H00ol200?o1P02o`H00_l300;o1P02o`H00ol300;o1@02o`L0
0_l500;o1P02o`<00_l700;o1002o`<00ol=00;o4`0001D00_l;0004o`3oo`P00_l?00;o5`03o`D0
0ol400;o1003o`H00_l500?o0`04o`@00ol400Co1003o`<00ol400?o1004o`@00ol500;o1@02o`D0
0_l400;o1`02o`@00ol500;o1@02o`D00_l600;o1@02o`H00_l300?o1003o`@00ol600?o0`03o`D0
0ol:00;o2002o`/00_l400?o1P02o`@00_l600;o1004o`800ol600?o1@02o`@00_l500?o1@03o`D0
0_l600;o0`03o`D00ol400;o1003o``00_lC00005P02o`X01?l800;o3P02oaT02Ol300Go0`05o`80
2ol300Co1@04o`801?l500Co0`09o`<01?l500Co1009o`<01Ol200Go0`05o`<01Ol300Wo1004o`@0
1?l200co1009o`<01_l200Ko0`09o`H02_l200So1P0:o`D01Ol200Go0`0:o`801_l200Ko0P05o`80
1Ol400[o0`0<o`@02Ol300Go0`05o`D02_l@00005`000ol0000900?o2008o`P000?o00006P05o`D0
1Ol300Go0P09o`D01?l500Co0P04o`D01?l500Go00<0o`000P04o`D01?l600Go1@05o`801Ol300Go
0`05o`D01Ol600Co1004o`803?l600Go00<0o`000P06o`801_l500Go200:o`802?l600Wo1P05o`80
1Ol300So1006o`801_l200Go0P05o`H01Ol00`3oo`0300co1P05o`D01Ol300Go1@0:oa00000S00?o
2008ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(46\\) OKPMMSMQXKQUFSVOJLBXDVYCFOJJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l800Co3002oaT01Ol500Go1P02o`802?l600Go0`05o`80
1Ol300Go0P02o`030?oo00?o1@05o`<01Ol600Go1@05o`801Ol300Go1P02o`D01Ol:00Co1P07o`P0
0_l00`3oo`03o`/00_l;00Go1`06o`L03Ol00`3oo`08o`D01Ol200Go0`08o`X00_l:00So2005o`H0
1ol;00Go1`06o`T01_lE00004`02o`d01_l700Oo2`02oaH02Ol300Go1@03o`802?l600Go0`05o`80
1Ol300Go0P0:o`<01Ol300Go1009o`<01Ol200Go0`05o`D00ol300Wo1P08o`@01ol800[o2004o`P0
2Ol300Wo1P0=o`030?oo00Wo1005o`801Ol300[o1`04o`T02?l600Wo1007o`T02Ol300Wo1P09oa@0
000C00;o3`02o`P00_l400;o2`02oaD00ol500?o1002o`D00ol500;o2`02o`L00_l400;o1`02o`<0
0ol500?o0`02o`L00_l400?o1@03o`<00ol400?o1P02o`D00ol300?o1@03o`D00_l400;o1P02o`/0
0ol500?o1`04o`L00ol500?o0P03o`@00ol800;o1P02o`<00_l500?o1003o`@00ol500;o1004o`H0
1?l<00;o2003o`D00ol500;o2`03o`D00ol200?o1003o`D00ol400?o4`0001<00_l?00;o1`02o`H0
0_l:00;o5@02o`L00_l400;o1@02o`H00_l;00;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`@0
0_l700;o1003o`800ol700;o1@02o`@00_l700;o1002o`H00_l500;o2`02o`L00_l700Co1`02o`L0
0_l200;o1P02o`P00_l600;o0`02o`H00_l500?o0P03o`H00_l600;o1P04o``00_l800;o1`02o`D0
0_l;00;o1`02o`800_l600;o1@02o`H00_lC00004`02o`T02_l500;o1P02o`X00_lD00;o2@02o`<0
0_l400;o1`02o`/00_l300;o0P02o`@00_l300;o0P02o`<00_l700;o0`02o`<00_l200;o0`02o`T0
0_l400;o0P02o`P00_l400;o1002o`T00_l300;o1P02o`D00_l200;o1`02o`L00_l600;o0P02o`D0
0_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l600;o0P02o`L00_l700;o1002o`800_l;00;o
1`03o`h00_l200;o1P02o`T00_l00`3oo`0600;o1@02o`H00_lC00004`02o`T02_l500;o1P02o`X0
0_lD00;o2@02o`<00ol200?o1`07o`H00_l200?o0P02o`@00_l200?o0P02o`/00ol300;o0P03o`80
0_l300;o2@02o`D01?l900?o0P03o`@00_l900;o0`02o`H00_l500;o0P02o`l00ol600;o0P02o`D0
0_l900;o00<0ool01P02o`P00_l600;o0`02o`H00_l700Co2002o`L00_l400;o0P02o`/00_l700;o
3`02o`800_l600;o2@02o`030?oo00H00_l500;o1P02oa<0000C00;o2@02o`@00_l700;o1P02o`X0
0_lD00;o2@02o`<01ol800Wo1002o`8000?o0?l00P02o`@00_l20003o`3o00800_l600Oo1002o`80
00?o0?l00P02o`<00_l900;o1@04o`T01ol500;o2@02o`<00_l600;o1@06o`X01ol600?o0P03o`@0
0_l900;o2@02o`P00_l;00;o1@03o`L01?l800;o1`02o`<00ol200?o2P03o`H00_l?00Ko1P02o`T0
0_l900;o3@02oa<0000C00;o2P02o`<00_l700?o1002o`/00_lD00;o2@02o`<01Ol:00;o1@03o`<0
0_l0103oo`02o`030?oo00@00_l0103oo`02o`030?oo00@01ol600;o00@0ool00_l00`3oo`0300;o
2@02o`D00ol:00Go1`02o`T00_l300;o1P02o`D01_l800Oo2002o`@00_l400;o2@02o`T00_l800;o
2`09o`P00ol900;o1`02o`<00_l400;o2@04o`H00_l?00Ko1P02o`T00_l900;o3@02oa<0000D00;o
2P001?l00002o`L02Ol:00;o5@02o`T00_l300;o00@0oooo2@02o`H00_l300;o00<0ool00P001?l0
ool400;o00<0ool00P001?l0ool300?o2`02o`030?oo008000Co0?oo0`02o`T00_l500Co2@02o`04
0?ooo`H00_l900;o0`02o`H00_l500;o0P02o`L00ol=00;o1002o`@00_l900;o2@02o`P00_l;00So
2@04o`P00_l700;o0`02o`@00_l800Ko1@02o`l00_l200;o1P02o`T00_l900;o3@02oa<0000D00;o
2P02o`800_l700;o00<0ool00_l<00;o5@02o`T00_l300;o0P03o`P00_l600;o0`02o`030?l00080
00Co0?oo1002o`030?l0008000Co0?oo0`02o`L000?o00000P02o`030?l0008000Co0?oo0`03o`P0
0_l400Ko2002o`800ol500?o2002o`<00_l600;o1@02o`800_l200;o0`02o`L000?o00000`02o`H0
0_l300;o2@02o`T00_l800;o2`02o`@00ol700Ko1`02o`L00_l200;o1P02o`L00_l200;o1@03o`L0
0_l500;o0P02o`800_l200;o2@02o`T00_l=00;o4`0001@00ol:0003o`0000;o2002oa000_lF00;o
1`02o`@00_l300?o1`02o`H00_l300Co0`04o`@01?l300Co0`02o`H00_l400Co0`04o`@00_l700;o
1003o`800ol700;o0`03o`D00_l700;o1002o`H00_l500;o1P02o`<00_l600;o1@02o`H00_l400;o
1`02o`X00_l800;o2`02o`D00_l600?o0P03o`H00_l600;o0`02o`H00_l600?o0`02o`D00_l700;o
1@02o`H00_l300;o1`02o`X00_l=00;o4`0001D00_l;0004o`3oo`P00ol>00;o5`03o`D00ol400;o
1003o`H00_l500?o0`04o`@00ol400Co1003o`<00ol400?o1004o`@00ol500;o1@02o`D00_l400;o
1`02o`@00ol500;o1@02o`D00_l600;o1@02o`H00_l300?o1003o`@00ol600?o0`03o`D00ol:00;o
2002o`/00_l400?o1P02o`@00_l600;o1004o`800ol600?o1@02o`@00_l500?o1@03o`D00_l600;o
0`03o`D00ol:00;o3@02oa<0000F00;o2P04o`T00ol<00;o6@09o`<01Ol300Go0P0;o`<01?l500Co
0P04o`D01?l300Wo0`04o`D01?l400Wo0`05o`801Ol300Go0`05o`<02Ol400Co1004o`803?l400Wo
0`06o`801_l300Wo1P0:o`802?l600[o1@05o`801Ol300[o0P06o`801_l200Go0P05o`@02_l300co
1009o`H02_l500[o400001L000?o00002@03o`X01ol70003o`0001X01Ol500Go0`05o`802Ol500Co
1@04o`801?l500Co1@05o`030?l000801?l500Co1P05o`D01Ol200Go0`05o`<01Ol500Go1P04o`@0
1?l200co1P05o`030?l000801_l200Ko1@05o`P02_l200So1P09o`H01Ol200Go0`08o`@01_l200Ko
0P05o`801Ol600Go00<0ool00`0<o`H01Ol800[o1@0:oa00000S00?o3005ool0``000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(47\\) OKPMMSMQXKQUFSVOJLBXDVYCFPIJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l800;o3P02oaT01Ol500Go1P02o`802?l600Go0`05o`80
1Ol300Go0P02o`030?oo00?o1@05o`<01Ol600Go1@05o`801Ol300Go1P02o`D01Ol:00Co1P07o`P0
0_l00`3oo`03o`/00_l;00Go1`06o`L03Ol00`3oo`08o`D01Ol200Go0`08o`X00_l:00So2005o`H0
1ol700So1`0:o`H01_lE00004`02o`d01_l800;o3`02oaH02Ol300Go1@03o`802?l600Go0`05o`80
1Ol300Go0P0:o`<01Ol300Go1009o`<01Ol200Go0`05o`D00ol300Wo1P08o`@01ol800[o2004o`P0
2Ol300Wo1P0=o`030?oo00Wo1005o`801Ol300[o1`04o`T02?l600Wo1007o`L02?l700[o1009oa@0
000C00;o3`02o`/00_l>00;o5@03o`D00ol400;o1@03o`D00_l;00;o1`02o`@00_l700;o0`03o`D0
0ol300;o1`02o`@00ol500?o0`03o`@00ol600;o1@03o`<00ol500?o1@02o`@00_l600;o2`03o`D0
0ol700Co1`03o`D00ol200?o1003o`P00_l600;o0`02o`D00ol400?o1003o`D00_l400Co1P04o``0
0_l800?o1@03o`D00_l<00;o3`02o`P00ol400?o4`0001<00_l?00;o2`02o`h00_lE00;o1`02o`@0
0_l500;o1P02o`/00_l700;o1002o`L00_l300;o1`02o`<00_l700;o1002o`L00_l400?o0P03o`L0
0_l500;o1002o`L00_l400;o1P02o`D00_l;00;o1`02o`L01?l700;o1`02o`800_l600;o2002o`H0
0_l300;o1P02o`D00ol200?o1P02o`H00_l600Co3002o`P00_l700;o1@02o``00_l?00;o2002o`H0
0_lC00004`02o`T02_l900;o3P02oa@00_l900;o0`02o`@00_l700;o2`02o`<00_l200;o1002o`<0
0_l200;o0`02o`L00_l300;o0`02o`800_l300;o2@02o`@00_l200;o2002o`@00_l400;o2@02o`<0
0_l600;o1@02o`800_l700;o1`02o`H00_l200;o1@02o`T00_l00`3oo`0600;o2002o`H00_l300;o
1P02o`H00_l200;o1`02o`L00_l400;o0P02o`/00_l700?o3P02o`800_l800;o3`02o`P00_l600;o
4`0001<00_l900[o2P000ol0000<00;o5002o`T00_l300?o0P03o`L01ol600;o0P03o`800_l400;o
0P03o`800_l;00?o0`02o`800ol200;o0`02o`T00_l500Co2@03o`800ol400;o2@02o`<00_l600;o
1@02o`800_l?00?o1P02o`800_l500;o2@02o`030?oo00H00_l800;o1P02o`<00_l600;o1`04o`P0
0_l700;o1002o`800_l;00;o1`02o`l00_l200;o2007o`X00_l800;o1P02oa<0000C00;o2@02o`@0
0_l<00;o3@02oa@00_l900;o0`07o`P02Ol400;o0P000ol0o`0200;o1002o`8000?o0?l00P02o`H0
1ol400;o0P000ol0o`0200;o0`02o`T00_l500Co2@07o`D00_l900;o0`02o`H00_l500Ko2P07o`H0
0ol200?o1002o`T00_l900;o2002o`/00_l500?o1`04o`P00_l700;o0`03o`800ol:00?o1P02o`l0
1_l800Wo2002oa000_lC00004`02o`X00_l300;o3002o`d00_lD00;o2@02o`<01Ol:00;o1@03o`<0
0_l0103oo`02o`030?oo00@00_l0103oo`02o`030?oo00@01ol600;o00@0ool00_l00`3oo`0300;o
2@02o`D00ol:00Go1`02o`T00_l300;o1P02o`D01_l800Oo2002o`@00_l400;o2@02o`T00_l800;o
2`09o`P00ol900;o1`02o`<00_l400;o2@04o`H00_l?00Ko2002o`D00ol700;o4002oa<0000D00;o
2P001?l00002o`d000?o00002P02oaD00_l900;o0`02o`040?ooo`T00_l600;o0`02o`030?oo0080
00Co0?oo1002o`030?oo008000Co0?oo0`03o`/00_l00`3oo`020004o`3oo`<00_l900;o1@04o`T0
0_l0103oool600;o2@02o`<00_l600;o1@02o`800_l700?o3@02o`@00_l400;o2@02o`T00_l800;o
2`08o`T01?l800;o1`02o`<00_l400;o2006o`D00_l?00;o0P02o`P00_l600;o1`02oa000_lC0000
5002o`X00_l200;o3@02o`/00_lE00;o2@02o`<00_l200?o2002o`H00_l300;o00<0o`000P001?l0
ool400;o00<0o`000P001?l0ool300;o1`000ol0000200;o00<0o`000P001?l0ool300?o2002o`@0
1_l800;o0P03o`D00ol800;o0`02o`H00_l500;o0P02o`800_l300;o1`000ol0000300;o1P02o`<0
0_l900;o2@02o`P00_l;00;o1003o`L01_l700;o1`02o`800_l600;o1`02o`800_l500?o1`02o`D0
0_l200;o0P02o`@00_l600;o1`02oa000_lC00005003o`X000?o00000_l=00;o2`02oaH00_l700;o
1002o`<00ol700;o1P02o`<01?l300Co1004o`<01?l300;o1P02o`@01?l300Co1002o`L00_l400?o
0P03o`L00_l300?o1@02o`L00_l400;o1P02o`D00_l600;o0`02o`H00_l500;o1P02o`@00_l700;o
2P02o`P00_l;00;o1@02o`H00ol200?o1P02o`H00_l300;o1P02o`H00ol300;o1@02o`L00_l500;o
1P02o`@00_l600;o1`02oa000_lC00005@02o`/000Co0?oo3P000ol0000800;o5`03o`D00ol400;o
1003o`H00_l500?o0`04o`@00ol400Co1003o`<00ol400?o1004o`@00ol500;o1@02o`D00_l400;o
1`02o`@00ol500;o1@02o`D00_l600;o1@02o`H00_l300?o1003o`@00ol600?o0`03o`D00ol:00;o
2002o`/00_l400?o1P02o`@00_l600;o1004o`800ol600?o1@02o`@00_l500?o1@03o`D00_l600;o
1002o`D00ol700;o4002oa<0000F00;o2P04o`L00_l500;o2002oaT02Ol300Go0`05o`802ol300Co
1@04o`801?l500Co0`09o`<01?l500Co1009o`<01Ol200Go0`05o`<01Ol300Wo1004o`@01?l200co
1009o`<01_l200Ko0`09o`H02_l200So1P0:o`D01Ol200Go0`0:o`801_l200Ko0P05o`801Ol400[o
0`0<o`802ol400[o1`0:oa00000G0003o`0000T00ol700Wo20000ol0000J00Go1@05o`<01Ol200Wo
1@04o`D01?l200Co1@04o`D01Ol00`3o000200Co1@04o`H01Ol500Go0P05o`<01Ol300Go1@05o`H0
1?l400Co0P0<o`H01Ol00`3o000200Ko0P06o`D01Ol800[o0P08o`H02Ol600Go0P05o`<02?l400Ko
0P06o`801Ol200Go1P05o`030?oo00<03?l200Wo1P0:o`L02_l@00008`03o`L02Ooo0<@0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(48\\) OKPMMRMQXKQVFSVOJLBXDVXCFPIJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l800Co3002oaT01Ol500Go1P02o`802?l600Go0`05o`80
1Ol300Go00<0ool00ol600So0`05o`H01Ol500Go0P05o`<01Ol600;o1@05o`X00_l800Oo2002o`03
0?oo00?o2`02o`/01Ol700Ko1`0=o`030?oo00So1@05o`801Ol300So2P02o`P01Ol200Go1P05o`H0
1ol700So1`0:o`H01_lE00004`02o`d01_l600So2`02oaH02Ol300Go1@03o`802?l600Go0`05o`80
1Ol300Go00<0ool00ol500Wo0`05o`@02Ol300Go0P05o`<01Ol500?o0`09o`L01?l700Oo200:o`P0
1?l800Wo0`09o`H03Ol00`3oo`09o`@01Ol200Go0`0:o`L01?l700Go0P05o`@02Ol400Oo1`08o`L0
2_l400Wo500001<00_l?00;o1`03o`@00ol:00;o5@03o`D00ol400;o1@03o`D00_l;00;o1`02o`@0
0_l700;o1002o`D00ol300;o1`02o`@00ol500?o0`03o`@00ol600;o1@03o`<00ol500?o1P04o`T0
0_l;00?o1@03o`L01?l700?o1@03o`800ol400?o2002o`H00_l300;o1@03o`@00ol400?o1@02o`@0
1?l600Co2003o`@00ol400?o1@03o`D00_l<00;o3`02o`P00ol400?o4`0001<00_l?00;o1`02o`H0
0_l:00;o5@02o`L00_l400;o1@02o`H00_l;00;o1`02o`@00_l700;o1002o`D00_l400;o1`02o`@0
0_l700;o1003o`800ol700;o1@02o`@00_l700;o1P04o`T00_l;00;o1`02o`L01?l700;o1`02o`80
0_l600;o2002o`H00_l300;o1P02o`D00ol200?o1P02o`H00_l600Co2@03o`800ol500;o1`02o`D0
0_l<00;o3`02o`P00_l600;o4`0001<00_l900[o1@02o`H00_l:00;o5002o`T00_l300;o1002o`L0
0_l;00;o0`02o`800_l400;o0`02o`800_l400;o1002o`D00_l300;o0P02o`<00_l900;o1002o`80
0_l800;o1002o`@00_l900;o1002o`800_l800;o0P02o`L00_l700;o1P02o`800_l500;o2@02o`03
0?oo00H00_l800;o1P02o`<00_l600;o1P02o`800_l700;o1`02o`@00_l200;o2@02o`800_l500?o
3P02o`800_l800;o3`02o`P00_l600;o4`0001<00_l900[o1@02o`H00_l:00;o5002o`T00_l300?o
0P03o`L01ol600;o0P03o`800_l400;o0P03o`800_l400;o0`03o`D00_l200?o0P02o`<00_l900;o
1@04o`T00ol200?o1002o`T00_l400;o0P02o`P00_l200;o3`03o`H00_l200;o1@02o`T00_l00`3o
o`0600;o2002o`H00_l300;o1P02o`L01?l800;o1`02o`@00_l200;o2P04o`H00_l?00;o0P02o`P0
1ol:00;o2002o`H00_lC00004`02o`T00_l400;o2002o`@00_l;00;o5002o`T00_l300Oo2009o`@0
0_l20003o`3o00800_l400;o0P000ol0o`0200;o1007o`H00_l20003o`3o00800_l300;o2@02o`D0
1?l900Oo1@02o`T00_l300?o0P03o`L01_l:00Oo1P03o`800ol400;o2@02o`T00_l800;o2`02o`D0
0ol700Co2002o`L00_l300?o0P03o`T01?l600;o3`06o`P02Ol800;o4002oa<0000C00;o2P02o`<0
0_l900Oo2`02oa@00_l900;o0`05o`X00_l500?o0`02o`040?oo00;o00<0ool01002o`040?oo00;o
00<0ool01009o`@00_l0103oo`02o`030?oo00<00_l900;o1@03o`X01Ol700;o2@02o`<00_l400;o
1`06o`P01ol800;o1002o`@00_l900;o2@02o`P00_l;00Wo2003o`T00_l700;o0`02o`@00_l900?o
1`02o`l01_l800;o1@03o`L00_l@00;o4`0001@00_l:0004o`0000;o2@06o`/00_lE00;o2@02o`<0
0_l0103oool900;o1P02o`<00_l00`3oo`020004o`3oo`@00_l00`3oo`020004o`3oo`@00_l500?o
0`02o`030?oo008000Co0?oo0`02o`T00_l500Co2@02o`040?ooo`H00_l900;o0`02o`@00_l700;o
0P02o`L00ol=00;o1002o`@00_l900;o2@02o`P00_l;00So2@04o`P00_l700;o0`02o`@00_l900Co
1P02o`l00_l200;o2002o`H00_l700;o4002oa<0000D00;o2P02o`800_l800;o1002o`X00_lE00;o
2@02o`<00_l200?o2002o`H00_l300;o00<0o`000P001?l0ool400;o00<0o`000P001?l0ool400;o
1P02o`<00_l00`3o00020004o`3oo`<00ol800;o1006o`P00_l200?o1@03o`P00_l200;o1P02o`H0
0_l200;o0P02o`<00_l70003o`0000<00_l600;o0`02o`T00_l900;o2002o`/00_l400?o1`06o`L0
0_l700;o0P02o`H00_l700Ko1@03o`L00_l500;o0P02o`800_l400;o1P02o`L00_l@00;o4`0001@0
0ol:0003o`0000;o1`02o`H00_l900;o5P02o`L00_l400;o0`03o`L00_l600;o0`04o`<01?l400Co
0`04o`@00_l600;o0`04o`<01?l400;o1`02o`@00ol200?o1`02o`<00ol500;o1`02o`<00_l600;o
1P02o`H00_l300;o1P02o`D00_l600;o1002o`L00_l:00;o2002o`/00_l500;o1P03o`800ol600;o
1P02o`<00_l600;o1P03o`800ol500;o1`02o`D00_l600;o1002o`H00_l700;o4002oa<0000E00;o
2`001?l0ool700;o1P02o`P00_lG00?o1@03o`@00_l400?o1P02o`D00ol300Co1003o`@01?l400?o
1002o`D00ol300Co1003o`D00_l500;o1@02o`@00_l700;o1003o`D00_l500;o0`03o`H00ol500;o
1P02o`<00ol400?o1003o`H00ol300?o1@03o`X00_l800;o2`02o`@00ol600;o1002o`H00_l400Co
0P03o`H00ol500;o1002o`D00ol500?o1@02o`H00_l400;o1@03o`L00_l@00;o4`0001H00_l:00Co
1`03o`@00ol700;o6@09o`<01Ol300Go0P0;o`<01?l500Co0P04o`D01?l00`3oo`09o`<01?l500Co
1009o`<01Ol200Go0`05o`<01Ol300Wo0P06o`801_l200co1009o`<01_l200Ko0`09o`H02_l200So
1P0:o`D01Ol200Go0`0:o`801_l200Ko0P05o`801Ol400[o0`0<o`802ol400[o1`0:oa00000G0003
o`0000T00ol800So20000ol0000J00Go1@05o`<01Ol200Wo1@04o`D01?l200Co1@04o`030?oo00Oo
1@04o`D01?l600Go1@05o`801Ol300Go0`05o`D01Ol400Ko0P06o`803?l600Go00<0o`000P06o`80
1_l500Go200:o`802?l600Wo1P05o`801Ol300So1006o`801_l200Go0P05o`H01Ol00`3oo`0300co
0P09o`H02_l700[o400002<00ol900Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(49\\) OJPMMRMQXKQVFSVOJLBXDVXCEPIJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o``01_l500Go3P02oaT01Ol700Ko1`08o`H01Ol300Go0P05o`<0
1Ol00`3oo`03o`H02?l300Go1P05o`D01Ol200Go0`05o`H00_l500Go2P02o`P01ol800;o00<0ool0
0ol;00;o2`05o`L01_l700go00<0ool02?l500Go0P05o`<02?l:00;o2005o`801Ol600Go1P0<o`80
2?l700[o1P06oaD0000C00;o3@06o`D01ol=00;o5P09o`<02Ol600So1P05o`<01Ol200Go0`05o`03
0?oo00?o1@09o`<01Ol400Wo0`05o`801Ol300Go1@03o`<02Ol700Co1`07o`P02_l800Co2009o`<0
2Ol600go00<0ool02Ol400Go0P05o`<02_l700Co1`05o`801Ol400Wo100<o`802?l700[o1009oa@0
000C00;o3`02o``00ol<00;o5@03o`D00ol200?o1003o`L00_l;00;o1`02o`@00_l700;o1002o`D0
0ol300;o1`02o`@00ol500?o0`03o`@00ol600;o1@03o`<00ol500?o1P04o`T00_l;00?o1@03o`L0
1?l700?o1@03o`800ol400?o2002o`H00_l300;o1@03o`@00ol400?o1@02o`@01?l600Co2003o`@0
0ol400?o1@03o`D00_l600;o1002o`l00_l800?o1003oa<0000C00;o3`02o`d00ol;00;o5@02o`L0
0_l200;o1P02o`L00_l;00;o1`02o`@00_l700;o1002o`D00_l400;o1`02o`@00_l700;o1003o`80
0ol700;o1@02o`@00_l700;o1P04o`T00_l;00;o1`02o`L01?l700;o1`02o`800_l600;o2002o`H0
0_l300;o1P02o`D00ol200?o1P02o`H00_l600Co2@03o`800ol500;o1`02o`D00_l600;o1002o`l0
0_l800;o1P02oa<0000C00;o2@0:o``00_l;00;o5002o`T00_l00`3oo`0600;o1`02o`/00_l300;o
0P02o`@00_l300;o0P02o`@00_l400;o1@02o`<00_l200;o0`02o`T00_l400;o0P02o`P00_l400;o
1002o`T00_l400;o0P02o`P00_l200;o1`02o`L00_l600;o0P02o`D00_l900;o00<0ool01P02o`P0
0_l600;o0`02o`H00_l600;o0P02o`L00_l700;o1002o`800_l900;o0P02o`D00ol>00;o0P02o`80
0_l400;o3`02o`P00_l600;o4`0001<00_l900[o2004o`030?oo00X00_lD00;o2@02o`030?oo00H0
0_l700Oo1P02o`800ol200;o1002o`800ol200;o1002o`<00ol500;o0P03o`800_l300;o2@02o`D0
1?l900?o0P03o`@00_l900;o1002o`800_l800;o0P02o`l00ol600;o0P02o`D00_l900;o00<0ool0
1P02o`P00_l600;o0`02o`H00_l700Co2002o`L00_l400;o0P02o`X01?l600;o3`02o`800_l800Oo
2P02o`P00_l600;o4`0001<00_l900;o1002o`P02Ol:00;o5002o`T00_l900;o1`09o`@00_l20003
o`3o00800_l400;o0P000ol0o`0200;o1007o`H00_l20003o`3o00800_l300;o2@02o`D01?l900Oo
1@02o`T00_l300?o0P03o`L01_l:00Oo1P03o`800ol400;o2@02o`T00_l800;o2`02o`D00ol700Co
2002o`L00_l300?o0P03o`T01?l600;o3`06o`P02Ol800;o4002oa<0000C00;o2P02o`<00_l800;o
1003o`X00_lD00;o2@02o`T00_l700;o1@03o`<00_l0103oo`02o`030?oo00@00_l0103oo`02o`03
0?oo00@02Ol400;o00@0ool00_l00`3oo`0300;o2@02o`D00ol:00Go1`02o`T00_l300;o1002o`L0
1_l800Oo2002o`@00_l400;o2@02o`T00_l800;o2`09o`P00ol900;o1`02o`<00_l400;o2@03o`L0
0_l?00Ko2002o`D00ol700;o4002oa<0000D00;o2P001?l00002o`L00_l600;o2@02oaD00_l900;o
2@02o`L00_l600;o0`02o`030?oo008000Co0?oo1002o`030?oo008000Co0?oo1002o`D00ol300;o
00<0ool00P001?l0ool300;o2@02o`D01?l900;o00@0oooo1P02o`T00_l300;o1002o`L00_l200;o
1`03o`d00_l400;o1002o`T00_l900;o2002o`/02?l900Co2002o`L00_l300;o1002o`T01?l600;o
3`02o`800_l800;o1P02o`L00_l@00;o4`0001@00_l:00;o0P02o`L00_l600;o2@02oaD00_l900;o
2@02o`L00_l600;o0`02o`030?l0008000Co0?oo1002o`030?l0008000Co0?oo1002o`H00_l300;o
00<0o`000P001?l0ool300?o2002o`@01_l800;o0P03o`D00ol800;o0P02o`H00_l600;o0P02o`80
0_l300;o1`000ol0000300;o1P02o`<00_l900;o2@02o`P00_l;00;o1003o`L01_l700;o1`02o`80
0_l600;o1`06o`D00ol700;o1@02o`800_l200;o1002o`H00_l700;o4002oa<0000D00?o2P000ol0
0002o`L00_l600;o2@02oaH00_l700;o2P02o`L00_l600;o0`04o`<01?l400Co0`04o`@00_l600;o
0`04o`<01?l400;o1`02o`@00ol200?o1`02o`<00ol500;o1`02o`<00_l600;o1P02o`H00_l300;o
1P02o`D00_l600;o1002o`L00_l:00;o2002o`/00_l500;o1P03o`800ol600;o1P02o`<00_l600;o
1P03o`800ol500;o1`02o`D00_l600;o1002o`H00_l700;o4002oa<0000E00;o2`001?l0ool700;o
1P000ol0000700;o5`03o`D00ol:00;o1`02o`D00ol300Co1003o`@01?l400?o1002o`D00ol300Co
1003o`D00_l500;o1@02o`@00_l700;o1003o`D00_l500;o0`03o`H00ol500;o1P02o`<00ol400?o
1003o`H00ol300?o1@03o`X00_l800;o2`02o`@00ol600;o1002o`H00_l400Co0P03o`H00ol500;o
1002o`D00ol500?o1@02o`H00_l400;o1@03o`L00_l@00;o4`0001H00_l:00Co2002o`@00_l800;o
6@09o`H02_l200_o0`04o`D01?l200Co1@04o`030?oo00Wo0`04o`D01?l400Wo0`05o`801Ol300Go
0`05o`<02Ol200Ko0P06o`803?l400Wo0`06o`801_l300Wo1P0:o`802?l600[o1@05o`801Ol300[o
0P06o`801_l200Go0P05o`@02_l300co0P0;o`@02_l700[o400001L000?o00002@03o`P01ol90003
o`0001X01Ol800[o0P09o`D01?l500Co0P04o`D01?l00`3oo`07o`D01?l500Co1P05o`D01Ol200Go
0`05o`<01Ol500Go1006o`801_l200co1P05o`030?l000801_l200Ko1@05o`P02_l200So1P09o`H0
1Ol200Go0`08o`@01_l200Ko0P05o`801Ol600Go00<0ool00`0<o`802Ol600[o1`0:oa00000S00?o
2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(50\\) OJPMMRMQXKQVFSVOJLBYDVWCEPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`X01Ol;00Co3002oaT01Ol700Ko1`08o`H01Ol300Go0P05o`<0
1Ol00`3oo`03o`H02?l300Go1P05o`D01Ol200Go0`05o`H00_l500Go2P02o`P01ol800;o00<0ool0
0ol;00;o2`05o`L01_l700go00<0ool02?l700So1@08o`X00_l:00;o1002o`P01Ol600co0P08o`L0
1?l300Co1@06oaD0000C00;o2@09o`P01_l<00;o5P09o`<02Ol600So1P05o`<01Ol200Go0`05o`03
0?oo00?o1@09o`<01Ol400Wo0`05o`801Ol300Go1@03o`<02Ol700Co1`07o`P02_l800Co2009o`<0
2Ol600go00<0ool02Ol600So1@0:o`L01?l900;o1002o`H02Ol400co0P08o`L01?l300Co0`09oa@0
000C00;o2@02o`D00_l700?o0P03o`/00_lE00?o1@03o`800ol400?o1`02o`/00_l700;o1002o`L0
0_l400;o1@03o`<00_l700;o1003o`D00ol300?o1003o`H00_l500?o0`03o`D00ol600Co2@02o`/0
0ol500?o1`04o`L00ol500?o0P03o`@00ol800;o1P02o`<00_l500?o2002o`T00_l400Co1P04o`P0
0ol400?o1003o`D00ol500;o1P02o`@00_l<00;o1@02o`@00ol400?o4`0001<00_lA00;o1P02o`@0
0_l;00;o5@02o`L00_l200;o1P02o`L00_l;00;o1`02o`@00_l700;o1002o`D00_l400;o1`02o`@0
0_l700;o1003o`800ol700;o1@02o`@00_l700;o1P04o`T00_l;00;o1`02o`L01?l700;o1`02o`80
0_l600;o2002o`H00_l300;o1P02o`P00_l900;o1P02o`H01?l800Co0`03o`@00_l700;o1@02o`H0
0_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`D00_l600;o2P02oa@00_l900;o00<0ool0
1P02o`L00_l;00;o0`02o`800_l400;o0`02o`800_l400;o1002o`D00_l300;o0P02o`<00_l900;o
1002o`800_l800;o1002o`@00_l900;o1002o`800_l800;o0P02o`L00_l700;o1P02o`800_l500;o
2@02o`030?oo00H00_l800;o1P02o`<00_l600;o2002o`T00_l700;o1002o`800_l700Co0P04o`<0
0ol>00;o0P02o`800_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`D00_l600;o2P02oa@0
0_l900;o00<0ool01P02o`L01ol600;o0P03o`800_l400;o0P03o`800_l400;o0`03o`D00_l200?o
0P02o`<00_l900;o1@04o`T00ol200?o1002o`T00_l400;o0P02o`P00_l200;o3`03o`H00_l200;o
1@02o`T00_l00`3oo`0600;o2002o`H00_l300;o1P02o`P00_l900;o1`02o`@00_l200;o1`02o`04
0?l000Co0`02o`l00_l200;o2007o`L00_l500;o1002o`H00_lC00004`02oa400_l500;o1P02o`X0
0_lD00;o2@02o`T00_l700Wo1002o`8000?o0?l00P02o`@00_l20003o`3o00800_l400Oo1P02o`80
00?o0?l00P02o`<00_l900;o1@04o`T01ol500;o2@02o`<00ol200?o1`06o`X01ol600?o0P03o`@0
0_l900;o2@02o`P00_l;00;o1@03o`P00ol800;o1`02o`<00ol200?o1P02o`060?l00?l00_l300;o
3`06o`P02Ol500;o1@02o``00_lC00004`02o`X00_l400;o1P02o`H00_l:00;o5002o`T00_l900;o
1`02o`D00ol300;o00@0ool00_l00`3oo`0400;o00@0ool00_l00`3oo`0400Wo1002o`040?oo00;o
00<0ool00`02o`T00_l500?o2P05o`L00_l900;o0`02o`@00_l700Ko2007o`P00_l400;o1002o`T0
0_l900;o2002o`/02Ol800Co2002o`L00_l300;o1002o`H00_l00`3oo`02o`030?oo00<00_l?00Ko
2002o`D00ol400Wo3002oa<0000D00;o2@08o`H00_l600;o2@02oaD00_l900;o2@02o`L00_l600;o
0`02o`030?oo008000Co0?oo1002o`030?oo008000Co0?oo1002o`D00ol300;o00<0ool00P001?l0
ool300;o2@02o`D01?l900;o00@0oooo1P02o`T00_l300;o1002o`L00_l200;o1`03o`d00_l400;o
1002o`T00_l900;o2002o`/02?l800Ko1`02o`L00_l300;o1002o`H00_l00`3oo`02o`030?oo00<0
0_l?00;o0P02o`P00_l600;o1009o``00_lC00005002o`T01ol700;o1P02o`T00_lE00;o2@02o`T0
0_l700;o1P02o`<00_l00`3o00020004o`3oo`@00_l00`3o00020004o`3oo`@00_l600;o0`02o`03
0?l0008000Co0?oo0`03o`P00_l400Ko2002o`800ol500?o2002o`800_l600;o1P02o`800_l200;o
0`02o`L000?o00000`02o`H00_l300;o2@02o`T00_l800;o2`02o`@00ol700;o0P02o`L00_l700;o
0P02o`H00_l400;o0`02o`<00_l200?o1`02o`D00_l200;o0P02o`@00_l600;o1002o`D00_l<00;o
4`0001@00ol800;o3002o`H00_l900;o5P02o`L00_l:00;o1`02o`H00_l300Co0`04o`@01?l300Co
1002o`H00_l300Co0`04o`@00_l700;o1003o`800ol700;o0`03o`D00_l700;o0`02o`H00_l600;o
1P02o`<00_l600;o1@02o`H00_l400;o1`02o`X00_l800;o2`02o`D00_l600?o0`02o`H00_l600;o
0`02o`H00_l400;o0`02o`<00_l300;o1`02o`D00_l600;o1002o`H00_l400;o1@02o``00_lC0000
5@02o`P00_l=00;o1002o`T00_lG00?o1@03o`X00_l700;o1@03o`<01?l400?o1004o`@00ol400;o
1@03o`<01?l400?o1@02o`D00_l500;o1002o`L00_l400?o1@02o`D00_l300?o1P03o`D00_l600;o
0`03o`@00ol400?o1P03o`<00ol500?o2P02o`P00_l;00;o1003o`H00_l400;o1P02o`@01?l200?o
1P03o`<00_l800;o0`03o`D00ol500;o1P02o`@00_l500?o1002o`D00_l<00;o4`0001H00_l700;o
3@03o`800ol800;o6@09o`H02_l200_o0`04o`D01?l200Co1@04o`030?oo00Wo0`04o`D01?l400Wo
0`05o`801Ol300Go0`05o`<02Ol200Ko0P06o`803?l400Wo0`06o`801_l300Wo1P0:o`802?l600[o
1@05o`801Ol300[o0P06o`801_l00`3oo`04o`801_l300[o0`0<o`802ol400Co0`04o`H02_l@0000
5`000ol0000500So2006o`T000?o00006P05o`P02_l200Wo1@04o`D01?l200Co1@04o`030?oo00Oo
1@04o`D01?l600Go1@05o`801Ol300Go0`05o`D01Ol400Ko0P06o`803?l600Go00<0o`000P06o`80
1_l500Go200:o`802?l600Wo1P05o`801Ol300So1006o`801_l00`3oo`04o`801_l500Go00<0ool0
0`0<o`802Ol600Co0`04o`H02_l@00007`08o`T01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(51\\) OJPMMRMRXKQVFSWOJLBYDVWCEPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2P05o`T0
2Ol900;o6@05o`L01_l700So1P05o`<01Ol200Go0`05o`030?oo00?o1P08o`<01Ol200Go1P08o`80
1Ol300Go1P02o`D01Ol:00;o2007o`P00_l00`3oo`03o`P00_l400;o2005o`L01_l700go00<0ool0
2?l700So1@08o`X00_l:00;o1002o`P01Ol600co0P08o`L01?l300Co1@06oaD0000C00;o2@09o`L0
2Ol:00;o5P09o`<02Ol600So1P05o`<01Ol200Go0`05o`030?oo00?o1@09o`<01Ol200Go1@09o`80
1Ol300Go1@03o`<02Ol700Co1`07o`P02_l600;o1002o`H02Ol300Wo1P0=o`030?oo00Wo1P08o`D0
2_l700Co2@02o`@00_l600Wo100<o`802?l700Co0`04o`<02OlD00004`02o`T00_l500;o2`02o`d0
0_lE00?o1@03o`800ol400?o1`02o`/00_l700;o1002o`L00_l400;o1@03o`<00_l700;o1@02o`D0
0ol300?o1003o`H00_l500?o0`03o`D00ol600Co2@02o`/00ol500?o1003o`@00ol400?o1@03o`80
0ol400?o2002o`H00_l300;o1@03o`P00_l900;o1004o`H01?l800?o1003o`@00ol500?o1@02o`H0
0_l400;o3002o`D00_l400?o1003oa<0000C00;o4@02o`X00_l=00;o5@02o`L00_l200;o1P02o`L0
0_l;00;o1`02o`@00_l700;o1002o`D00_l400;o1`02o`D00_l500;o1@03o`800ol700;o1@02o`@0
0_l700;o1P04o`T00_l;00;o1`02o`@01?l300?o1002o`L00_l200;o1P02o`P00_l600;o0`02o`H0
0_l800;o2@02o`H00_l600Co2004o`<00ol400;o1`02o`D00_l600;o1002o``00_l500;o1002o`H0
0_lC00004`02oa400_l:00;o3@02oa@00_l900;o00<0ool01P02o`L00_l;00;o0`02o`800_l400;o
0`02o`800_l400;o1002o`D00_l300;o0P02o`D00_l400;o1`02o`800_l800;o1002o`@00_l900;o
1002o`800_l800;o0P02o`L00_l700;o1004o`801?l300;o2@02o`030?oo00H00_l800;o1P02o`<0
0_l600;o2002o`T00_l700;o1002o`800_l700Co0P04o`<00ol>00;o0P02o`800_l400;o3002o`D0
0_l400;o1P02oa<0000C00;o4@02o`X00_l=00;o5002o`T00_l00`3oo`0600;o1`07o`H00_l200?o
0P02o`@00_l200?o0P02o`@00_l300?o1@02o`800ol200;o1@02o`<00ol800Co2@03o`800ol400;o
2@02o`@00_l200;o2002o`800_l?00?o1002o`040?l000Co0`02o`T00_l00`3oo`0600;o2002o`H0
0_l300;o1P02o`P00_l900;o1`02o`@00_l200;o1`02o`040?l000Co0`02o`l00_l200;o2007o`L0
0_l500;o1002o`H00_lC00004`02oa400_l:00;o3@02oa@00_l900;o2@02o`L02Ol400;o0P000ol0
o`0200;o1002o`8000?o0?l00P02o`@01ol600;o0P000ol0o`0200;o1@07o`T01?l900Oo1@02o`T0
0_l300?o0P03o`L01_l:00Oo1@02o`060?l00?l00_l300;o2@02o`T00_l800;o2`02o`D00ol800?o
2002o`L00_l300?o0P03o`H00_l01P3o003o00;o0`02o`l01_l800Wo1@02o`D00_l<00;o4`0001<0
0_l:00;o1002o`/00_l=00;o5002o`T00_l900;o1`02o`D00ol300;o00@0ool00_l00`3oo`0400;o
00@0ool00_l00`3oo`0400Wo1002o`040?oo00;o00<0ool01@09o`L00ol:00Go1`02o`T00_l300;o
1002o`L01_l800Oo1`02o`030?oo00;o00<0ool00`02o`T00_l900;o2002o`/02Ol800Co2002o`L0
0_l300;o1002o`H00_l00`3oo`02o`030?oo00<00_l?00Ko2002o`D00ol400Wo3002oa<0000D00;o
2@08o`/00_l<00;o5@02o`T00_l900;o1`02o`H00_l300;o00<0ool00P001?l0ool400;o00<0ool0
0P001?l0ool400;o1@03o`<00_l00`3oo`020004o`3oo`D00_l500?o1P04o`T00_l0103oool600;o
2@02o`<00_l400;o1`02o`800_l700?o3002o`030?oo00;o00<0ool00`02o`T00_l900;o2002o`/0
2?l800Ko1`02o`L00_l300;o1002o`H00_l00`3oo`02o`030?oo00<00_l?00;o0P02o`P00_l600;o
1009o``00_lC00005002o`T01ol<00;o3002oaD00_l900;o2@02o`L00_l600;o0`02o`030?l00080
00Co0?oo1002o`030?l0008000Co0?oo1002o`H00_l300;o00<0o`000P001?l0ool500;o1P02o`D0
1_l800;o0P03o`D00ol800;o0P02o`H00_l600;o0P02o`800_l300;o1`000ol0000200;o0`02o`<0
0_l200;o2@02o`T00_l800;o2`02o`@00ol700;o0P02o`L00_l700;o0P02o`H00_l400;o0`02o`<0
0_l200?o1`02o`D00_l200;o0P02o`@00_l600;o1002o`D00_l<00;o4`0001@00ol800;o4@02o``0
0_lF00;o1`02o`X00_l700;o1P02o`<01?l300Co1004o`<01?l400;o1P02o`<01?l300Co1@02o`H0
0_l400?o0P03o`L00_l300?o1@02o`L00_l300;o1P02o`H00_l600;o0`02o`H00_l400;o0`02o`<0
0_l300;o1`02o`X00_l800;o2`02o`D00_l600?o0`02o`H00_l600;o0`02o`H00_l400;o0`02o`<0
0_l300;o1`02o`D00_l600;o1002o`H00_l400;o1@02o``00_lC00005@02o`P00_lA00;o2`02oaL0
0ol500?o2P02o`L00_l500?o0`04o`@00ol400Co1003o`@00_l500?o0`04o`@00ol500;o1@03o`@0
0_l400;o1`02o`@00ol500;o1@02o`<00ol600?o1@02o`H00_l300?o1003o`@00_l800;o0`03o`D0
0ol:00;o2002o`/00_l400?o1P02o`@00_l600;o1004o`800ol600?o0`02o`P00_l300?o1@03o`D0
0_l600;o1002o`D00ol400;o1@02o``00_lC00005P02o`L00_l=00?o00<0ool02P02oaT02Ol600[o
0P0;o`<01?l500Co0P04o`D01?l00`3oo`09o`<01?l500Co0P0;o`<01Ol200Go0`05o`<01Ol300Wo
0P06o`801_l200co1009o`<01_l200Ko0`09o`H02_l200So1P0:o`D01Ol200Go0`0:o`801_l200Ko
00<0ool01?l200Ko0`0:o`<03?l200_o1004o`<01?l600[o400001L000?o00001@08o`L01_l:0003
o`0001X01Ol800[o0P09o`D01?l500Co0P04o`D01?l00`3oo`07o`D01?l500Co0P09o`D01Ol200Go
0`05o`<01Ol500Go1006o`801_l200co1P05o`030?l000801_l200Ko1@05o`P02_l200So1P09o`H0
1Ol200Go0`08o`@01_l200Ko00<0ool01?l200Ko1@05o`030?oo00<03?l200Wo1P04o`<01?l600[o
400001l02?l:00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(52\\) NJPMMRMSXKQWFSWOJLCYDVWCEPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2P05o`P0
2_l900;o5P06o`<00_l400Ko1`08o`H01Ol300Go0P05o`<01Ol00`3oo`03o`H02?l300Go0`02o`03
0?oo00?o1@05o`801Ol300Go1P02o`D01Ol700;o1002o`D01ol800;o00<0ool00ol800;o1002o`P0
1Ol700Ko1`0=o`D01Ol800So1@08o`X00_l:00;o1002o`P01Ol600co0P08o`L01?l300Co1@06oaD0
000C00;o2@09o`H02_l:00;o5@06o`800ol200Wo1P08o`H01Ol300Go0P05o`<01Ol00`3oo`03o`D0
2Ol300Go0`0:o`<01Ol200Go0`05o`D00ol300Wo1@02o`@00_l500Oo200:o`H00_l400;o1P09o`<0
2Ol600go0`09o`H02?l500[o1`04o`T00_l400;o1P09o`@03?l200So1`04o`<01?l300Wo500001<0
0_l900;o1@02o`L00_l500;o2P02oaH00_l400Co0P03o`@00ol700;o2`02o`L00_l400;o1`02o`@0
0_l500?o0`02o`L00_l400?o1@03o`<00ol400?o1P02o`D00ol300?o1@03o`<00ol400?o1P02o`/0
0ol500?o1003o`@00ol400?o1@03o`800ol400?o2002o`H00_l200?o1@03o`P00_l900;o1004o`H0
1?l800?o1003o`@00ol500?o1@02o`H00_l400;o3002o`D00_l400?o1003oa<0000C00;o4@02o`L0
0ol?00;o5P02o`@01?l200;o1P02o`L00_l;00;o1`02o`@00_l700;o1002o`D00_l400;o1`02o`@0
0_l700;o1003o`800ol700;o1@02o`@00_l700;o0`04o`<00ol600;o2`02o`L00_l400Co0`03o`@0
0_l700;o0P02o`H00_l800;o1P02o`800_l700;o2002o`T00_l600;o1P04o`P01?l300?o1002o`L0
0_l500;o1P02o`@00_l<00;o1@02o`@00_l600;o4`0001<00_lA00;o2003o`h00_lF00;o0`05o`80
0_l600;o1`02o`/00_l300;o0P02o`@00_l300;o0P02o`@00_l400;o1@02o`<00_l200;o1002o`L0
0_l500;o0P02o`P00_l400;o1002o`T00_l200Co0P04o`H00_l200;o1`02o`L00_l400Co0P04o`<0
0_l900;o00<0ool01P02o`P00_l600;o00@0oooo4@02o`T00_l700;o1002o`800_l700Co0P04o`<0
0ol>00;o0P02o`800_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`T00ol=00;o5P02o`<0
0_l00`3oo`0200;o1P02o`L01ol600;o0P03o`800_l400;o0P03o`800_l400;o0`03o`D00_l200?o
0P02o``00ol600Co2@03o`800ol400;o2@02o`800_l0103o0004o`H00_l200;o3`03o`@00_l0103o
0004o`<00_l900;o00<0ool01P02o`P00_l600;o00<0ool04P02o`T00_l700;o1002o`800_l700;o
00@0o`001?l300;o3`02o`800_l800Oo1`02o`D00_l400;o1P02oa<0000C00;o4@02o`X00ol<00;o
5P02o`800ol00`3oo`0:00;o1`09o`@00_l20003o`3o00800_l400;o0P000ol0o`0200;o1007o`H0
0_l20003o`3o00800_l700Oo1`04o`T01ol500;o2@02o`800_l01P3o003o00;o1P06o`X01ol500;o
00H0o`00o`02o`<00_l900;o2@02o`P00_l900;o4P03o`P00_l700;o0`03o`800ol600;o00H0o`00
o`02o`<00_l?00Ko2009o`D00_l500;o3002oa<0000C00;o2P02o`@00_l<00?o2`02oaH00_l200;o
0P02o`X00_l700;o1@03o`<00_l0103oo`02o`030?oo00@00_l0103oo`02o`030?oo00@02Ol400;o
00@0ool00_l00`3oo`0500Oo2@03o`X01Ol700;o2@02o`800_l00`3oo`02o`030?oo00H01_l800Oo
1`02o`030?oo00;o00<0ool00`02o`T00_l900;o2002o`T00_lA00Co2002o`L00_l300;o1002o`H0
0_l00`3oo`02o`030?oo00<00_l?00Ko2002o`D00ol400Wo3002oa<0000D00;o2@08o`d00_l:00;o
5`02o`030?oo00<00_l:00;o1`02o`H00_l300;o00<0ool00P001?l0ool400;o00<0ool00P001?l0
ool400;o1@03o`<00_l00`3oo`020004o`3oo`@00ol>00Co2@02o`040?ooo`H00_l900;o0P02o`03
0?oo00;o00<0ool01P02o`800_l700?o3002o`030?oo00;o00<0ool00`02o`T00_l900;o2002o`T0
0_l@00Ko1`02o`L00_l300;o1002o`H00_l00`3oo`02o`030?oo00<00_l?00;o0P02o`P00_l600;o
1009o``00_lC00005002o`T01ol?00;o2@02oaL01Ol300;o2P02o`L00_l600;o0`02o`030?l00080
00Co0?oo1002o`030?l0008000Co0?oo1002o`H00_l300;o00<0o`000P001?l0ool400;o1`000ol0
000400Ko2002o`800ol500?o2002o`030?oo00<00_l300;o1@02o`800_l200;o0`02o`L000?o0000
0P02o`<00_l300;o0P02o`T00_l900;o2002o`T00ol700;o1P02o`800_l700;o1`02o`800_l600;o
1002o`<00_l300;o0P03o`L00_l500;o0P02o`800_l400;o1P02o`@00_l500;o3002oa<0000D00?o
2002oa@00_l900;o5`04o`@00_l:00;o1`02o`H00_l300Co0`04o`@01?l300Co1002o`H00_l300Co
0`04o`@00_l600;o1@03o`800ol700;o0`03o`D00_l700;o0P02o`<00_l300;o1@02o`H00_l300;o
1P02o`@00_l300;o0`02o`<00_l700;o2P02o`P00_l:00;o1`02o`D00ol300;o1P02o`H00_l300;o
1P02o`@00_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l500;o3002oa<0000E00;o
2002o`d00_l500;o2002oaP01?l400;o2P02o`L00_l500?o0`04o`@00ol400Co1003o`@00_l500?o
0`04o`@00ol400?o1003o`D00_l400;o1`02o`@00ol500;o1@02o`<00_l800;o1@02o`H00_l300?o
1003o`@00_l800;o0`03o`D00ol:00;o2002o`X00ol500?o1@02o`@00_l600;o1004o`800ol600?o
0`02o`P00_l300?o1@03o`D00_l600;o1002o`D00ol400;o1@02o``00_lC00005P02o`L00_l=00?o
0`03o`L00_lH00Co0P06o`@02_l200_o0`04o`D01?l200Co1@04o`030?oo00Wo0`04o`D01?l400Wo
0`05o`801Ol300Go0`05o`<02Ol200Ko0P06o`803?l400Wo0`06o`801_l300Wo1P0:o`802?l800[o
0`05o`801Ol300[o0P06o`801_l00`3oo`04o`801_l300[o0`0<o`802ol400Co0`04o`H02_l@0000
5`000ol0000500So2007o`P000?o00005`03o`<01_l400[o0P09o`D01?l500Co0P04o`D01?l00`3o
o`07o`D01?l500Co1P05o`030?l000801Ol200Go0`05o`<01Ol500Go1006o`801_l200co1P05o`03
0?l000801_l200Ko1@05o`P02_l200So2P05o`030?oo00<01Ol200Go0`08o`@01_l200Ko00<0ool0
1?l200Ko1@05o`030?oo00<03?l200Wo1P04o`<01?l600[o400001l02?l900Goo`350000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(53\\) NIPMMRMSXKQXFSWOJLCYDVWCEPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2P05o`X0
1Ol<00;o5P06o`<00_l300[o1008o`H01Ol300Go0P05o`<01Ol00`3oo`03o`H02?l300Go0`02o`03
0?oo00?o1@05o`801Ol300Go1P02o`D01Ol500Go0P05o`<01ol800;o00<0ool00ol800;o1002o`P0
1Ol700Ko1`0=o`D01Ol800So1@08o`X00_l:00;o1002o`P01Ol600co0P08o`L01?l300Co1@06oaD0
000C00;o2@09o`H02Ol;00;o5@06o`800ol300[o1008o`H01Ol300Go0P05o`<01Ol00`3oo`03o`D0
2Ol300Go0`0:o`<01Ol200Go0`05o`D00ol300Wo0`05o`801Ol300Oo200:o`H00_l400;o1P09o`<0
2Ol600go0`09o`H02?l500[o1`04o`T00_l400;o1P09o`@03?l200So1`04o`<01?l300Wo500001<0
0_l900;o1@02o`H00_l500;o2`02oaH00_l400Co1`02o`X00_l;00;o1`02o`@00_l700;o1002o`D0
0ol300;o1`02o`@00ol500?o0`03o`@00ol600;o1@03o`<00ol500?o0`03o`@00ol600;o2`03o`D0
0ol400?o1003o`@00ol500?o0P03o`@00ol800;o1P02o`800ol500?o2002o`T00_l400Co1P04o`P0
0ol400?o1003o`D00ol500;o1P02o`@00_l<00;o1@02o`@00ol400?o4`0001<00_lA00;o3@02o`X0
0_lF00;o1004o`L00_l:00;o2`02o`L00_l400;o1`02o`@00_l500;o1002o`L00_l400;o1`02o`@0
0ol200?o1`02o`D00_l400;o1`02o`@00ol200?o1`02o`/00_l700;o1004o`<00ol400;o1`02o`80
0_l600;o2002o`H00_l200;o1`02o`P00_l900;o1P02o`H01?l800Co0`03o`@00_l700;o1@02o`H0
0_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`d00_l:00;o5P02o`<01Ol700;o2P02o`/0
0_l300;o0P02o`@00_l300;o0P02o`@00_l400;o1@02o`<00_l200;o1002o`L00_l500;o0P02o`P0
0_l400;o1002o`T00_l400;o0P02o`P00_l200;o1`02o`L00_l400Co0P04o`<00_l900;o00<0ool0
1P02o`P00_l600;o00@0oooo4@02o`T00_l700;o1002o`800_l700Co0P04o`<00ol>00;o0P02o`80
0_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`d00_l:00;o5P02o`<00_l00`3oo`0700;o
2P07o`H00_l200?o0P02o`@00_l200?o0P02o`@00_l300?o1@02o`800ol200;o3003o`H01?l900?o
0P03o`@00_l900;o1@04o`T00_l200;o3`03o`@00_l0103o0004o`<00_l900;o00<0ool01P02o`P0
0_l600;o00<0ool04P02o`T00_l700;o1002o`800_l700;o00@0o`001?l300;o3`02o`800_l800Oo
1`02o`D00_l400;o1P02oa<0000C00;o4@02o``00_l;00;o5P02o`800ol00`3oo`0700;o2P09o`@0
0_l20003o`3o00800_l400;o0P000ol0o`0200;o1007o`H00_l20003o`3o00800_l700Oo1`04o`T0
1ol500;o2@02o`D01?l900Ko2P07o`D00_l01P3o003o00;o0`02o`T00_l900;o2002o`T00_lB00?o
2002o`L00_l300?o0P03o`H00_l01P3o003o00;o0`02o`l01_l800Wo1@02o`D00_l<00;o4`0001<0
0_l:00;o1002o`X01?l<00;o5P02o`800_l200;o1`02o`X00_l500?o0`02o`040?oo00;o00<0ool0
1002o`040?oo00;o00<0ool01009o`@00_l0103oo`02o`030?oo00D01ol900?o2P05o`L00_l900;o
1@03o`X01_l800Oo1`02o`030?oo00;o00<0ool00`02o`T00_l900;o2002o`T00_lA00Co2002o`L0
0_l300;o1002o`H00_l00`3oo`02o`030?oo00<00_l?00Ko2002o`D00ol400Wo3002oa<0000D00;o
2@08o`X00ol<00;o5`02o`030?oo00<00_l700;o2P02o`H00_l300;o00<0ool00P001?l0ool400;o
00<0ool00P001?l0ool400;o1@03o`<00_l00`3oo`020004o`3oo`@00ol>00Co2@02o`040?ooo`H0
0_l900;o1@04o`T00_l200;o1`03o``00_l00`3oo`02o`030?oo00<00_l900;o2@02o`P00_l900;o
4006o`L00_l700;o0`02o`@00_l600;o00<0ool00_l00`3oo`0300;o3`02o`800_l800;o1P02o`@0
2Ol<00;o4`0001@00_l900Oo3@02o`/00_lG00Go0`02o`L00_l:00;o1P02o`<00_l00`3o00020004
o`3oo`@00_l00`3o00020004o`3oo`@00_l600;o0`02o`030?l0008000Co0?oo1002o`L000?o0000
1006o`P00_l200?o1@03o`P00_l400Ko2002o`800_l200;o0`02o`L000?o00000P02o`<00_l300;o
0P02o`T00_l900;o2002o`T00ol700;o1P02o`800_l700;o1`02o`800_l600;o1002o`<00_l300;o
0P03o`L00_l500;o0P02o`800_l400;o1P02o`@00_l500;o3002oa<0000D00?o2002oa<00_l:00;o
5`04o`@00_l700;o2P02o`H00_l300Co0`04o`@01?l300Co1002o`H00_l300Co0`04o`@00_l600;o
1@03o`800ol700;o0`03o`D00_l700;o1003o`800ol700;o1P02o`<00_l600;o1002o`<00_l300;o
0`02o`L00_l:00;o2002o`X00_l700;o1@03o`<00_l600;o1P02o`<00_l600;o1002o`<00_l300;o
0`02o`L00_l500;o1P02o`@00_l600;o1002o`D00_l<00;o4`0001D00_l800;o4`02o`T00_lH00Co
1002o`L00_l:00;o1@03o`<01?l400?o1004o`@00ol400;o1@03o`<01?l400?o1003o`@00ol500;o
1002o`L00_l400?o1@02o`D00_l500;o1002o`L00_l600;o0`03o`@00ol400;o2002o`<00ol500?o
2P02o`P00_l:00?o1@03o`D00_l400;o1P02o`@01?l200?o1P03o`<00_l800;o0`03o`D00ol500;o
1P02o`@00_l500?o1002o`D00_l<00;o4`0001H00_l700;o3@02o`<00ol800;o6004o`801_l200[o
100;o`<01?l500Co0P04o`D01?l00`3oo`09o`<01?l500Co1009o`<01Ol200Go0`05o`<01Ol300Wo
0`05o`801Ol300co1009o`<01_l200Ko0`09o`H02_l200So200:o`<01Ol200Go0`0:o`801_l200Ko
00<0ool01?l200Ko0`0:o`<03?l200_o1004o`<01?l600[o400001L000?o00001@08o`L01ol90003
o`0001L00ol300Ko0P0:o`@02Ol500Co1@04o`801?l500Co00<0ool01ol500Co1@04o`H01Ol00`3o
000200Go0P05o`<01Ol300Go1@05o`D01Ol200Go0`0<o`H01Ol00`3o000200Ko0P06o`D01Ol800[o
0P08o`X01Ol00`3oo`0300Go0P05o`<02?l400Ko0P06o`030?oo00Co0P06o`D01Ol00`3oo`0300co
0P09o`H01?l300Co1P0:oa00000O00So2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(54\\) NIPMMQMSXJQXFSXOJLCYDVWCEPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?o?`02o`@00ooo00L0000E00;o
:002of402_ln00[oo`0600005002obX00_mQ00Go0P02ocl01Ol200;oo`0600005002obX00_mQ0003
o`0004D000?o0000o`0<00005002o`X01Ol<00Ko2@02oaH01_l300;o0`0:o`@02?l600Go0`05o`80
1Ol300Go1@05o`D01Ol300Go0`02o`030?oo00?o1@05o`801Ol500Ko2P05o`D01Ol200Go0`07o`P0
0_l00`3oo`03o`H01Ol200Go1P05o`L01_l700go1@05o`P02?l500So2P02o`X00_l400;o2005o`H0
3?l200So1`04o`<01?l500Ko5@0001<00_l900Wo2P06o`X00_lE00Ko0P03o`<02_l400So1P05o`<0
1Ol200Go0`05o`<02Ol300Go0`05o`<02_l300Go0P05o`<02Ol700Wo0`05o`801Ol300Oo200:o`@0
1Ol200Go1009o`<02Ol600go0`09o`H02?l500[o1`04o`T00_l400;o1P09o`@03?l200So1`04o`<0
1?l300Wo500001<00_l900;o1@02o``00_l<00;o5P02o`@01?l700;o2P02o`/00_l700;o1002o`L0
0_l300?o1@03o`<00_l700;o1003o`D00ol300?o1003o`@00ol400?o1@03o`D00ol300?o1003o`H0
0_l;00?o1@03o`@00ol400?o1003o`D00ol200?o1003o`P00_l600;o0P03o`D00ol800;o2@02o`@0
1?l600Co2003o`@00ol400?o1@03o`D00_l600;o1002o``00_l500;o1003o`@00olC00004`02oa40
0_l;00;o3002oaH00_l400Co1`02o`X00_l;00;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`@0
0_l700;o1003o`800ol500;o1P02o`D00_l700;o1003o`800ol700;o2`02o`L00_l500?o0P03o`D0
0_l700;o0P02o`H00_l800;o1P02o`800_l700;o2002o`T00_l600;o1P04o`P01?l300?o1002o`L0
0_l500;o1P02o`@00_l<00;o1@02o`@00_l600;o4`0001<00_lA00;o1@0:o`X00_lF00;o0`05o`L0
0_l:00;o2`02o`<00_l200;o1002o`<00_l200;o0P02o`T00_l200;o0`02o`800_l400;o1`02o`D0
0_l200;o1P02o`H00_l400;o2@02o`@00_l200;o2002o`800_l700;o1`02o`H00_l200;o1@02o`T0
0_l00`3oo`0600;o2002o`H00_l0103ooolA00;o2@02o`L00_l400;o0P02o`L01?l200Co0`03o`h0
0_l200;o0P02o`@00_l<00;o1@02o`@00_l600;o4`0001<00_lA00;o1@0:o`X00_lF00;o0`02o`03
0?oo00L00_l:00Oo1P02o`800ol200;o1002o`800ol200;o0P02o`T00_l200;o0P03o`800_l<00?o
1P04o`L00_l600;o1002o`T00_l500Co2@02o`800_l?00?o1`04o`H00_l900;o00<0ool01P02o`P0
0_l600;o00<0ool04P02o`T00_l700;o1002o`800_l700;o00@0o`001?l300;o3`02o`800_l800Oo
1`02o`D00_l400;o1P02oa<0000C00;o4@02o`D00_l400;o3002oaH00_l200?o00<0ool01`02o`X0
2Ol400;o0P000ol0o`0200;o1002o`8000?o0?l00P02o`800_l900;o0P02o`8000?o0?l00P02o`L0
1ol700Co3`02o`@00_l900;o1@04o`T01_l:00Oo2004o`H00_l900;o2@02o`P00_l900;o4P03o`P0
0_l700;o0`03o`800ol600;o00H0o`00o`02o`<00_l?00Ko2009o`D00_l500;o3002oa<0000C00;o
2P02o`@00_l700;o0`02o``00_lF00;o0P02o`800_l700;o2P02o`D00ol300;o00@0ool00_l00`3o
o`0400;o00@0ool00_l00`3oo`0200;o2@02o`800_l0103oo`02o`030?oo00D01ol900?o4002o`@0
0_l900;o1@03o`X01_l800Oo2P03o`L00_l900;o2@02o`P00_l900;o4@04o`P00_l700;o0`02o`@0
0_l600;o00<0ool00_l00`3oo`0300;o3`06o`P00_l500?o1009o``00_lC00005002o`T02?l80004
o`0000;o2`02oaL00_l00`3oo`0300;o1`02o`X00_l600;o0`02o`030?oo008000Co0?oo1002o`03
0?oo008000Co0?oo0P02o`T00_l200;o00<0ool00P001?l0ool400?o3P04o`l00_l400;o2@02o`D0
1?l900;o0P02o`L00ol?00Co1P02o`T00_l900;o2002o`T00_l@00Ko1`02o`L00_l300;o1002o`H0
0_l00`3oo`02o`030?oo00<00_l?00;o0P02o`P00_l600;o1009o``00_lC00005002o`T01ol900;o
0P02o`/00_lG00Go0`02o`L00_l:00;o1P02o`<00_l00`3o00020004o`3oo`@00_l00`3o00020004
o`3oo`800ol800;o0P02o`030?l0008000Co0?oo1002o`L000?o00001006o`h00_l400?o2002o`@0
1_l800;o0P02o`800_l300;o1`000ol0000500Ko1@02o`T00_l900;o2002o`T00ol700;o1P02o`80
0_l700;o1`02o`800_l600;o1002o`<00_l300;o0P03o`L00_l500;o0P02o`800_l400;o1P02o`@0
0_l500;o3002oa<0000D00?o2002o`l000?o00000_l;00;o5`04o`@00_l700;o2P02o`H00_l300Co
0`04o`@01?l300Co0`02o`L00_l300Co0`04o`@00_l600;o1@03o`800ol=00;o1@02o`L00_l400?o
0P03o`L00_l600;o0`02o`H00_l600?o0P03o`D00_l700;o2P02o`P00_l:00;o1`02o`D00ol300;o
1P02o`H00_l300;o1P02o`@00_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l500;o
3002oa<0000E00;o2002oa0000Co0?oo2P02oaP01?l400;o1`02o`X00_l500?o0`04o`@00ol400Co
1003o`@00_l500;o1004o`@00ol400?o1003o`D00_l400;o3@02o`H00_l500;o1@02o`@00_l700;o
1P02o`<00ol400?o1P02o`@00_l500?o1@03o`X00_l800;o2P03o`D00ol500;o1002o`H00_l400Co
0P03o`H00ol300;o2002o`<00ol500?o1@02o`H00_l400;o1@03o`@00_l500;o3002oa<0000F00;o
1`02oa001?l900;o6004o`801_l200[o100;o`<01?l500Co0P04o`D01?l300Wo0`04o`D01?l400Wo
0`05o`801Ol600[o0`09o`<01Ol200Go0`0<o`@02Ol400Go0P05o`@02Ol600[o0P08o`P02_l300Go
0P05o`<02_l200Ko0P06o`030?oo00Co0P06o`<02_l300co0P0;o`@01?l300Co1P0:oa00000G0003
o`0000D02?l;00?o2@000ol0000G00?o0`06o`802_l400Wo1@04o`D01?l200Co1@04o`D01Ol500Co
1@04o`H01Ol00`3o000200Go0P05o`H02_l500Go1@05o`801Ol300co1P05o`030?l000<01Ol200Go
1P05o`P02_l200So2P05o`030?oo00<01Ol200Go0`08o`@01_l200Ko00<0ool01?l200Ko1@05o`03
0?oo00<03?l200Wo1P04o`<01?l600[o400001l02?l;00?oo`350000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(55\\) NIPLMQMSXJQXFSXOJLCYDVWCDPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?o?`02o`@00ooo00L0000E00;o
:002of402_ln00[oo`0600005002obX00_mQ00Go0P02ocl01Ol200;oo`0600005002obX00_mQ0003
o`0004D000?o0000o`0<00005002o`X01Ol:00Go3002oaH01_l300;o0`0:o`@02?l600go0P05o`<0
1Ol500Go1@05o`<01Ol300;o00<0ool00ol500Go0P05o`D01_l:00Go1@05o`801Ol300Oo2002o`03
0?oo00?o1P05o`801Ol600Go1`06o`L03Ol500Go2008o`D02?l:00;o2P02o`@00_l800Go1`08o`D0
2?l700Co0`04o`D01_lE00004`02o`T02Ol600Wo2`02oaD01_l200?o0`0:o`@02?l600go0P05o`<0
1Ol300Wo0`05o`<01Ol300[o0`05o`801Ol300Wo1`09o`<01Ol200Go0`07o`P02_l400Go0P05o`@0
2Ol300Wo1P0=o`<02Ol600So1@0:o`L01?l900;o1002o`H02Ol500[o0`08o`L01?l300Co0`09oa@0
000C00;o2@02o`D00_l600;o1@02o`/00_lF00;o1004o`L00_l:00;o3@02o`H00_l300;o1`02o`<0
0ol500?o0`02o`L00_l400?o1@03o`<00ol400?o1003o`@00ol500?o1@03o`<00ol400?o1P02o`/0
0ol500?o1003o`@00ol400?o1@03o`800ol400?o2002o`H00_l200?o1@03o`P00_l900;o1004o`H0
1?l800?o1003o`@00ol500?o1@02o`@01?l400;o3002o`D00_l400?o1003oa<0000C00;o4@02o`d0
0_l:00;o5P02o`@01?l700;o2P02o`d00_l600;o0`02o`L00_l300;o1`02o`<00_l700;o1002o`L0
0_l400?o0P03o`D00_l600;o1@02o`L00_l400?o0P03o`L00_l;00;o1`02o`D00ol200?o1@02o`L0
0_l200;o1P02o`P00_l600;o0P02o`L00_l800;o2@02o`H00_l600Co2004o`<00ol400;o1`02o`D0
0_l600;o1002o``00_l500;o1002o`H00_lC00004`02oa400_l=00;o2P02oaH00_l300Go1`02o`X0
0_l=00;o1P02o`<00_l300;o0P02o`800_l900;o0P02o`<00_l200;o1002o`L00_l500;o0P02o`H0
0_l600;o1002o`T00_l400;o0P02o`P00_l200;o1`02o`L00_l600;o0P02o`D00_l900;o00<0ool0
1P02o`P00_l600;o00@0oooo4@02o`T00_l700;o1002o`800_l700Co0P04o`<00ol>00;o1`02o`<0
0_l<00;o1@02o`@00_l600;o4`0001<00_lA00;o3@02o`X00_lF00;o0`02o`030?oo00L00_l:00Oo
2002o`H00_l300;o0P03o`800_l200;o2@02o`800_l200?o0P02o``00ol600Co1`02o`H00_l400;o
2@02o`D01?l900;o0P02o`l00ol700Co1P02o`T00_l00`3oo`0600;o2002o`H00_l00`3oo`0B00;o
2@02o`L00_l400;o0P02o`L00_l0103o0004o`<00_l?00;o1`02o`<01ol700;o1@02o`@00_l600;o
4`0001<00_lA00;o3@02o`X00_lF00;o0P03o`030?oo00L00_l:00Wo1P02o`/00_l20003o`3o0080
0_l200;o2@02o`800_l20003o`3o00800_l700Oo1`04o`l00_l400;o2@02o`D01?l900Ko2P07o`P0
1?l600;o2@02o`T00_l800;o2@02oa800ol800;o1`02o`<00ol200?o1P02o`060?l00?l00_l300;o
3`02o`L00_l300Wo1@02o`D00_l<00;o4`0001<00_l:00;o1002o`L00_l400;o2`02oaH00_l200;o
0P02o`L00_l:00;o1@03o`D00_l;00;o00@0ool00_l00`3oo`0200;o2@02o`800_l0103oo`02o`03
0?oo00D01ol900?o4002o`@00_l900;o1@03o`X01_l800Oo2P03o`L00_l900;o2@02o`P00_l900;o
4@04o`P00_l700;o0`02o`@00_l600;o00<0ool00_l00`3oo`0300;o3`02o`L00_l300;o1@03o`@0
2Ol<00;o4`0001@00_l900So1`08o`X00_lG00;o00<0ool00`02o`L00_l:00;o1P02o`D00_l;00;o
00<0ool00P001?l0ool200;o2@02o`800_l00`3oo`020004o`3oo`@00ol>00Co3`02o`@00_l900;o
1@04o`T00_l200;o1`03o`l01?l600;o2@02o`T00_l800;o2@02oa001_l700;o1`02o`<00_l400;o
1P02o`030?oo00;o00<0ool00`02o`l00_l700;o0`02o`H00_l400Wo3002oa<0000D00;o2@07o`P0
1ol;00;o5`05o`<00_l700;o2P02o`H00_l500;o2`02o`030?l0008000Co0?oo0P03o`P00_l200;o
00<0o`000P001?l0ool400;o1`000ol0000400Ko3P02o`@00ol800;o1006o`P00_l200;o0P02o`<0
0_l70003o`0000D01_l500;o2@02o`T00_l800;o2@03o`L00_l600;o0P02o`L00_l700;o0P02o`H0
0_l400;o0`02o`<00_l200?o1`02o`D00_l700;o0`02o`H00_l400;o1@02o``00_lC00005003o`P0
0_l=00;o4002oaL01?l400;o1`02o`X00_l600;o1@02o`/01?l300Co0`02o`L00_l300Co0`04o`@0
0_l600;o1@03o`800ol=00;o1@02o`L00_l400?o0P03o`L00_l600;o0`02o`H00_l600?o0P03o`D0
0_l700;o2P02o`P00_l:00;o1`02o`D00ol300;o1P02o`H00_l300;o1P02o`@00_l300;o0`02o`<0
0_l700;o1@02o`H00_l400;o1P02o`@00_l500;o3002oa<0000E00;o2002o`d00_l?00;o6004o`@0
0_l700;o2P02o`D00ol500;o2`04o`@00ol400;o1@02o`@01?l400?o1003o`@00ol500;o1002o`d0
0_l600;o1@02o`D00_l400;o1`02o`H00_l300?o1003o`H00_l400;o1@03o`D00ol:00;o2002o`X0
0ol500?o1@02o`@00_l600;o1004o`800ol600?o0`02o`P00_l300?o1@03o`D00_l400Co1002o`D0
0ol400;o1@02o``00_lC00005P02o`L00_l=00;o3P02oaP01?l200Ko0P0:o`@02ol300So1`04o`D0
1?l300Wo0`04o`D01?l400Wo0`05o`801Ol600[o0`09o`<01Ol200Go0`0<o`@02Ol400Go0P05o`@0
2Ol600[o0P08o`P02_l300Go0P05o`<02_l200Ko0P06o`030?oo00Co0P06o`<02_l400[o0`0;o`@0
1?l300Co1P0:oa00000G0003o`0000D02?l700So20000ol0000G00?o0`06o`802_l400Wo1@08o`L0
1?l500Co1@05o`D01?l500Co1P05o`030?l000801Ol200Go1P0:o`D01Ol500Go0P05o`<03?l600Go
00<0o`000`05o`801Ol600Go200:o`802?l:00Go00<0ool00`05o`801Ol300So1006o`801_l00`3o
o`04o`801_l500Go00<0ool01008o`D02Ol600Co0`04o`H02_l@00007`08o`L02?oo0<@0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(56\\) NIPKMQMSXJQXFSXOJLCYCWWCDPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?o?`02o`@00ooo00L0000E00;o
:002of402_ln00[oo`0600005002obX00_mQ00Go0P02ocl01Ol200;oo`0600005002obX00_mQ0003
o`0004D000?o0000o`0<00005002o`X01Ol;00Co3002oaH01_l300;o0`0:o`@02?l600Go1P02o`80
1Ol300Go1@05o`D01Ol300Go0`02o`030?oo00?o1@05o`801Ol500Ko2P05o`D01Ol200Go0`07o`P0
0_l00`3oo`03o`H01Ol200Go1P05o`L01_l700go1@05o`P02?l800Go1`02o`@00_l700;o1002o`P0
1Ol700So1@08o`L01?l300Co1@06oaD0000C00;o2@09o`P01ol;00;o5@06o`800ol300[o1008o`H0
1Ol500?o0P05o`<01Ol300Wo0`05o`<01Ol300[o0`05o`801Ol300Wo1`09o`<01Ol200Go0`07o`P0
2_l400Go0P05o`@02Ol300Wo1P0=o`<02Ol600So1P09o`D00_l400;o1`02o`@00_l600Wo1@0:o`<0
2?l700Co0`04o`<02OlD00004`02o`T00_l500;o1`02o`@00_l;00;o5P02o`@01?l700;o2P02o``0
0_l500?o1002o`L00_l300?o1@03o`<00_l700;o1003o`D00ol300?o1003o`@00ol400?o1@03o`D0
0ol300?o1003o`H00_l;00?o1@03o`@00ol400?o1003o`D00ol200?o1003o`P00_l600;o0P03o`D0
0ol800;o2003o`D00ol300?o1003o`D00ol400?o1003o`D00ol500;o1004o`@00_l<00;o1@02o`@0
0ol400?o4`0001<00_lA00;o1@02o`H00_l:00;o5P02o`@01?l700;o2P02o``00_l500;o1@02o`L0
0_l300;o1`02o`<00_l700;o1002o`L00_l400?o0P03o`D00_l600;o1@02o`L00_l400?o0P03o`L0
0_l;00;o1`02o`D00ol200?o1@02o`L00_l200;o1P02o`P00_l600;o0P02o`L00_l800;o2002o`L0
0_l300Co0`03o`D01?l300?o1002o`L00_l500;o1P02o`@00_l<00;o1@02o`@00_l600;o4`0001<0
0_lA00;o1@02o`H00_l:00;o5P02o`<01Ol700;o2P02o``00_l400;o1P02o`<00_l200;o0P02o`T0
0_l200;o0`02o`800_l400;o1`02o`D00_l200;o1P02o`H00_l400;o2@02o`@00_l200;o2002o`80
0_l700;o1`02o`H00_l200;o1@02o`T00_l00`3oo`0600;o2002o`H00_l0103ooolA00;o1`03o``0
1?l200Co1@04o`801?l300?o3P02o`L00_l300;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`D0
0_l600;o2P02oaH00_l300;o00<0ool01`02o`X01ol700?o0P03o`H00_l200?o0P02o`800_l900;o
0P02o`800ol200;o3003o`H01?l700;o1P02o`@00_l900;o1@04o`T00_l200;o3`03o`L01?l600;o
2@02o`030?oo00H00_l800;o1P02o`030?oo01800_l700;o3@02o`040?l000Co1@02o`040?l000Co
0`02o`l00_l700;o0`07o`L00_l500;o1002o`H00_lC00004`02oa400_l500;o1P02o`X00_lF00;o
0P03o`030?oo00L00_l:00Wo1@07o`L00_l20003o`3o00800_l200;o2@02o`800_l20003o`3o0080
0_l700Oo1`04o`l00_l400;o2@02o`D01?l900Ko2P07o`P01?l600;o2@02o`T00_l800;o2@02oa80
0ol600;o3@02o`060?l00?l00_l500;o00H0o`00o`02o`<00_l?00;o1`02o`<02Ol500;o1@02o``0
0_lC00004`02o`X00_l400;o1P03o`@00_l;00;o5P02o`800_l200;o1`02o`X00_l500?o1005o`T0
0_l0103oo`02o`030?oo00800_l900;o0P02o`040?oo00;o00<0ool01@07o`T00ol@00;o1002o`T0
0_l500?o2P06o`P01ol:00?o1`02o`T00_l900;o2002o`T00_lA00Co1P02o`d00_l00`3oo`02o`03
0?oo00D00_l00`3oo`02o`030?oo00<00_l?00;o1`02o`<00_l500?o1009o``00_lC00005002o`T0
2?l600Wo2P02oaL00_l00`3oo`0300;o1`02o`X00_l600;o1002o`040?ooo`P00_l00`3oo`020004
o`3oo`800_l900;o0P02o`030?oo008000Co0?oo1003o`h01?l?00;o1002o`T00_l500Co2@02o`80
0_l700?o3`04o`H00_l900;o2@02o`P00_l900;o4006o`D00_l=00;o00<0ool00_l00`3oo`0500;o
00<0ool00_l00`3oo`0300;o3`02o`L00_l300;o1P02o`@02Ol<00;o4`0001@00_l900Oo1`02o`03
0?oo00;o3002oaL01Ol300;o1`02o`X00_l600;o1002o`800ol700;o00<0o`000P001?l0ool200?o
2002o`800_l00`3o00020004o`3oo`@00_l70003o`0000@01_l>00;o1003o`P00_l400Ko2002o`80
0_l200;o0`02o`L000?o00001@06o`D00_l900;o2@02o`P00_l900?o1`02o`H00_l200;o1@03o`L0
0_l200;o0`02o`<00_l300;o0`02o`<00_l200?o1`02o`D00_l700;o0`02o`H00_l400;o1@02o``0
0_lC00005003o`P00_l=00;o4002oaL01?l400;o1`02o`X00_l600;o1002o`<00ol600Co0`04o`<0
0_l700;o0`04o`<01?l400;o1P02o`D00ol200?o3@02o`D00_l700;o1003o`800ol700;o1P02o`<0
0_l600;o1P03o`800ol500;o1`02o`X00_l800;o2P02o`L00_l500?o0`02o`D00_l700;o0P02o`<0
0_l300;o0`02o`<00_l300;o0`02o`L00_l500;o1P02o`@00_l600;o1002o`D00_l<00;o4`0001D0
0_l800;o3@03o`h00_lH00Co1002o`L00_l:00;o1@03o`@00_l400?o1@04o`@00ol400;o1@02o`@0
1?l400?o1003o`@00ol500;o1002o`d00_l600;o1@02o`D00_l400;o1`02o`H00_l300?o1003o`H0
0_l400;o1@03o`D00ol:00;o2002o`X00ol500?o1@02o`@00_l500?o1@03o`800_l800;o0`02o`P0
0_l300?o1@03o`D00_l400Co1002o`D00ol400;o1@02o``00_lC00005P02o`L00_l>00?o3002oaP0
1?l200Ko0P0:o`@02ol300Go0`05o`801?l500Co0`09o`<01?l500Co1009o`<01Ol200Go1P0:o`<0
2Ol300Go0P05o`<03?l400Wo1005o`801Ol400Wo1P0:o`802?l800[o0`05o`801Ol400[o00<0ool0
1?l200Ko00<0ool01?l200Ko0`0:o`@02_l300_o1004o`<01?l600[o400001L000?o00001@08o`T0
1ol70003o`0001L00ol300Ko0P0:o`@02Ol500Go0`05o`801?l500Co1@05o`D01?l500Co1P05o`03
0?l000801Ol200Go1P0:o`D01Ol500Go0P05o`<03?l600Go00<0o`000`05o`801Ol600Go200:o`80
2?l:00Go00<0ool00`05o`801Ol600Go00@0ool01_l200Ko00<0ool01?l200Ko1@05o`030?oo00@0
2?l500Wo1P04o`<01?l600[o400001l02?l;00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(57\\) NIPKMQLSYJQXFSXOJLCYCXWCDPHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?o?`02o`@00ooo00L0000E00;o
:002of402_ln00[oo`0600005002obX00_mQ00Go0P02ocl01Ol200;oo`0600005002obX00_mQ0003
o`0004D000?o0000o`0<00005002o`X01Ol;00;o3P02oaH01_l300;o0`0:o`@02?l600Go1P02o`80
1Ol300Go1@05o`D03Ol300;o00<0ool00ol700So1`06o`X01Ol500Go0P05o`<01ol800;o00<0ool0
0ol600Go0P05o`H01Ol700Ko1`0=o`D01Ol800So2005o`D01Ol200Go1@02o`@00_l800Go1`08o`D0
2?l700Co0`04o`D01_lE00004`02o`T02Ol900;o3`02oaD01_l200?o0`0:o`@02?l600Go1@03o`80
1Ol300Go0`09o`<03Ol300[o1@08o`D02Ol700Wo0`05o`801Ol300Oo200:o`@01Ol200Go1009o`<0
2Ol600go0`09o`H02?l600Wo0`05o`801Ol500;o1002o`H02Ol500[o0`08o`L01?l300Co0`09oa@0
000C00;o2@02o`D00_l:00;o3P02oaH00_l400Co1`02o`X00_l<00;o1@03o`@00_l700;o0`03o`D0
0ol500;o1P02o`<00ol500?o1`02o`P00ol400?o1@03o`D00ol300?o1003o`H00_l;00?o1@03o`@0
0ol400?o1003o`D00ol200?o1003o`P00_l600;o0P03o`D00ol800;o2003o`D00ol300?o1003o`D0
0ol400?o1003o`D00ol500;o1004o`@00_l<00;o1@02o`@00ol400?o4`0001<00_lA00;o2@02o`h0
0_lF00;o1004o`L00_l:00;o3002o`D00_l500;o1`02o`<00_l700;o1@02o`H00_l300;o1`02o`L0
0_l800;o1P02o`D00_l700;o1003o`800ol700;o2`02o`L00_l500?o0P03o`D00_l700;o0P02o`H0
0_l800;o1P02o`800_l700;o2002o`P00_l700;o1003o`800ol600Co0`03o`@00_l700;o1@02o`H0
0_l400;o3002o`D00_l400;o1P02oa<0000C00;o4@02o`T00_l>00;o5P02o`<01Ol700;o2P02o``0
0_l400;o1P02o`<00_l200;o0P02o`T00_l400;o1P02o`<00_l700;o1`02o`P00_l600;o1002o`T0
0_l400;o0P02o`P00_l200;o1`02o`L00_l600;o0P02o`D00_l900;o00<0ool01P02o`P00_l600;o
00@0oooo4@02o`L00ol>00;o0P02o`L01?l200Co0`03o`h00_l700;o0`02o``00_l500;o1002o`H0
0_lC00004`02oa400_l:0003o`0000`00_lF00;o0`02o`030?oo00L00_l:00Oo1`03o`800ol600;o
0P03o`800_l200;o2@02o`@00_l600;o2`03o`L00_l800;o1P02o`@00_l900;o1@04o`T00_l200;o
3`03o`L01?l600;o2@02o`030?oo00H00_l800;o1P02o`030?oo01800_l700;o4004o`P00_l0103o
0004o`<00_l?00;o1`02o`<01ol700;o1@02o`@00_l600;o4`0001<00_lA00;o2P02o`d00_lF00;o
0P03o`030?oo00L00_l:00Wo1@07o`L00_l20003o`3o00800_l200;o2@02o`@00_l>00Oo2003o`l0
0_l400;o2@02o`D01?l900Ko2P07o`P01?l600;o2@02o`T00_l800;o2@02oa800ol600;o4004o`P0
0_l01P3o003o00;o0`02o`l00_l700;o0`09o`D00_l500;o3002oa<0000C00;o2P02o`@00_l;00;o
3@02oaH00_l200;o0P02o`L00_l:00;o1@03o`@01Ol900;o00@0ool00_l00`3oo`0200;o2@02o`@0
0_l<00Oo2@04o`l00_l400;o2@02o`D00ol:00Ko2007o`X00ol700;o2@02o`T00_l800;o2@02oa40
1?l600;o4003o`T00_l00`3oo`02o`030?oo00<00_l?00;o1`02o`<00_l500?o1009o``00_lC0000
5002o`T02?l<0003o`0000X00_lG00;o00<0ool00`02o`L00_l:00;o1P02o`@00_l0103oool800;o
00<0ool00P001?l0ool200;o2@02o`@00_l;00?o3@06o`h00_l400;o2@02o`D01?l900;o0P02o`L0
0ol?00Co1P02o`T00_l900;o2002o`T00_l@00Ko1@02oa001?l800;o00<0ool00_l00`3oo`0300;o
3`02o`L00_l300;o1P02o`@02Ol<00;o4`0001@00_l900Oo3@02o`/00_lG00Go0`02o`L00_l:00;o
1P02o`@00_l200?o1`02o`030?l0008000Co0?oo0P03o`P00_l400;o2`02o`L000?o00001002o`80
0_l>00;o1003o`P00_l400Ko2002o`800_l200;o0`02o`L000?o00001@06o`D00_l900;o2@02o`P0
0_l900?o1`02o`H00_l200;o1@03o`L00_l500Ko1P02o`<00_l300;o0P03o`L00_l500;o1`02o`<0
0_l600;o1002o`D00_l<00;o4`0001@00ol800;o4P02o`/00_lG00Co1002o`L00_l:00;o1P02o`@0
0_l300?o1P04o`<01?l300;o1`02o`D00_l;00;o1P02o`D00ol300;o3@02o`D00_l700;o1003o`80
0ol700;o1P02o`<00_l600;o1P03o`800ol500;o1`02o`X00_l800;o2P02o`L00_l500?o0`02o`D0
0_l700;o1003o`800ol500;o0`02o`<00_l300;o1`02o`D00_l600;o1002o`H00_l400;o1@02o``0
0_lC00005@02o`P00_lC0003o`0000P00_lH00Co1002o`L00_l:00;o1@03o`@00_l400?o1@04o`@0
0ol400;o1@02o`H00_l;00?o1003o`D00_l400;o3@02o`H00_l500;o1@02o`@00_l700;o1P02o`<0
0ol400?o1P02o`@00_l500?o1@03o`X00_l800;o2P03o`D00ol500;o1002o`D00ol500?o1002o`@0
0_l500;o2002o`<00ol500?o1@02o`@01?l400;o1@03o`@00_l500;o3002oa<0000F00;o1`02o``0
0_l500;o2002oaP01?l200Ko0P0:o`@02ol300Go0`05o`801?l500Co0`09o`<02?l900Wo0`05o`80
1Ol600[o0`09o`<01Ol200Go0`0<o`@02Ol400Go0P05o`@02Ol600[o0P08o`P02_l300Go0P05o`@0
2_l200Go0P05o`801_l200Ko0`0:o`@02_l300_o1004o`<01?l600[o400001L000?o00001@08o`H0
2Ol80003o`0001L00ol300Ko0P0:o`@02Ol500Go0`05o`801?l500Co1@05o`D02?l;00Go00<0o`00
0P05o`801Ol600[o1@05o`D01Ol200Go0`0<o`H01Ol00`3o000300Go0P05o`H01Ol800[o0P08o`X0
1Ol00`3oo`0300Go0P05o`H01Ol00`3oo`0200Go0P05o`801_l200Ko1@05o`030?oo00@02?l500Wo
1P04o`<01?l600[o400001l02?l600Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(58\\) NIPKLQLSYJRXFRXOJLCYCXWCDQHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`0H00;o1003obh0000E00;o
:002of402_oo01L02_l]00005002obX00_mQ00Go0P02ool06005o`800_l]00005002obX00_mQ0003
o`000?l07P000ol0000c00005002o`X01Ol;00Co3002oaH01_l300;o0`0:o`@02?l600Go1P02o`80
3Ol500Go1@0=o`<00_l00`3oo`03o`L02?l700Ko1P05o`H02?l200Go0`07o`L01Ol600?o00<0ool0
0ol200Go1P05o`L01_l700go1@05o`P02?l800Go1@05o`801Ol500;o1002o`P01Ol700So2@05o`H0
1?l300Co1@06oaD0000C00;o2@09o`L02?l;00;o5@06o`800ol300[o1008o`H01Ol500?o0P0=o`<0
2Ol300go0`0:o`D02?l500Wo1@05o`D02Ol200Go0`07o`L01Ol500Co00<0ool00ol200Go1009o`<0
2Ol600go0`09o`H02?l600Wo0`05o`801Ol500;o1002o`H02Ol500[o1@09o`@01?l300Co0`09oa@0
000C00;o2@02o`D00_l600?o1003o`X00_lF00;o1004o`L00_l:00;o3002o`D00ol600;o1P02o`80
0ol500?o1@02o`H00_l300?o1@03o`L00_l800?o1003o`H00_l500?o0`03o`@00ol600;o3002o`D0
0ol400?o1003o`@00ol500?o0P03o`@00ol800;o1P02o`800ol500?o2002o`P00ol500?o0`03o`@0
0ol500?o1003o`@00ol500?o1@02o`@01?l300?o1@03o`@00_l500;o1003o`@00olC00004`02oa40
0_l500;o1P02o`X00_lF00;o1004o`L00_l:00;o3002o`D00_l700;o1P02o`800_l700;o1@02o`H0
0_l300;o1`02o`L00_l800;o1P02o`H00_l500;o1@03o`800ol700;o3002o`D00_l600?o0P03o`D0
0_l700;o0P02o`H00_l800;o1P02o`800_l700;o2002o`P00_l700;o1003o`800ol600Co0`03o`@0
0_l700;o1@02o`H00_l300;o1`02o`@00_l500;o1002o`H00_lC00004`02oa400_l500;o1P02o`X0
0_lF00;o0`05o`L00_l:00;o3002o`@00_l800;o1P02o`030?oo00T00_l400;o1P02o`<00_l700;o
1`02o`P00_l600;o1P02o`@00_l700;o0P02o`P00_l200;o2002o`@00_l800;o0P02o`D00_l900;o
00<0ool01P02o`P00_l600;o00@0oooo4@02o`L00ol>00;o0P02o`L01?l200Co0`03o`h00_l700;o
00<0ool02@02o`<00_l500;o1002o`H00_lC00004`02oa400_l500;o1P02o`X00_lF00;o0`02o`03
0?oo00L00_l:00Oo1`03o`800ol800;o1P02o`030?oo00T00_l400;o1P02o`/00ol700;o2002o`H0
0_l600;o0`03o`P01?l900;o0P02o`P00_l300?o2@04o`H00_l900;o00<0ool01P02o`P00_l600;o
00<0ool04P02o`L00_l@00Co2002o`040?l000Co0`02o`l00_l700;o00<0ool02@02o`<00_l500;o
1002o`H00_lC00004`02oa400_l600;o1002o`/00_lF00;o0P03o`030?oo00L00_l:00Wo1@07o`T0
0_l900;o2@02o`@00_l>00Oo2003o`l00_l600Oo2@04o`T01_l800Oo2P04o`H00_l900;o2@02o`P0
0_l900;o4P03o`H00_l@00Co2002o`060?l00?l00_l300;o3`02o`L00_l00`3oo`0900;o0`02o`D0
0_l<00;o4`0001<00_l:00;o1002o`P01ol;00;o5P02o`800_l200;o1`02o`X00_l500?o1005o`/0
0_l900;o2@02o`@00_l<00Oo2@04o`l00_l600Wo1`03o`X01_l800Wo2003o`L00_l900;o2@02o`P0
0_l900;o4@04o`H00_l@00?o2@02o`030?oo00;o00<0ool00`02o`l00_l700;o00<0ool02@02o`<0
2Ol<00;o4`0001@00_l900So2006o`/00_lG00;o00<0ool00`02o`L00_l:00;o1P02o`@00_l0103o
ool:00;o2@02o`T00_l400;o2`03o`d01_l>00;o1P02o`D00ol600Co2@02o`800_l800;o1@03o`L0
1?l600;o2@02o`T00_l800;o2@02oa001_l500;o4004o`P00_l00`3oo`02o`030?oo00<00_l?00;o
1`02o`030?oo00T00_l300Wo3002oa<0000D00;o2@07o`P00_l400;o2P02oaL01Ol300;o1`02o`X0
0_l600;o1002o`800ol900;o2@03o`P00_l400;o2`02o`L000?o00001002o`800_l>00;o1P02o`H0
0_l500Ko2002o`800_l200;o1002o`H00_l600Ko1@02o`T00_l900;o2002o`T00ol700;o1P02o`80
0_l500?o1`02o`D01_l600;o0`02o`<00_l200?o1`02o`D00_l700;o00@0oooo2002o`<00_l500;o
3002oa<0000D00?o2002o``00_l600;o2@02oaL01?l400;o1`02o`X00_l600;o1002o`<00ol800;o
2P02o`L00_l500;o2`02o`H00_l500?o0`02o`d00_l600;o1P02o`@00ol200?o1`02o`H00_l400;o
1P02o`D00ol200?o1@02o`L00_l:00;o2002o`X00_l700;o1@03o`<00_l500;o1`02o`@00ol200?o
1@02o`<00_l300;o0`02o`L00_l500;o1P02o`<00_l700;o1002o`D00_l<00;o4`0001D00_l800;o
3002o`H00_l800;o6004o`@00_l700;o2P02o`D00ol400;o1003o`L00_l;00;o1@02o`H00_l;00?o
1003o`D00_l400;o3@02o`H00_l500?o1002o`@00_l700;o1P02o`@00_l500?o1@02o`@00_l500?o
1@03o`X00_l800;o2P03o`D00ol500;o1002o`D00ol500?o1002o`@00_l500;o2002o`<00ol500?o
1@02o`@01?l400;o1@02o`D00_l500;o3002oa<0000F00;o1`02o``00ol400?o1`02oaP01?l200Ko
0P0:o`@02ol300Go0`05o`802?l800Wo0`08o`T02Ol300Go0P05o`H02_l00`3oo`09o`<01Ol200Go
0`0<o`802ol400Go0P05o`@02Ol600[o0P08o`P02_l300Go0P05o`@02_l200Go0P05o`801_l200Ko
0`0:o`@02_l500Wo1004o`<01?l600[o400001L000?o00001@08o`L02?l80003o`0001L00ol300Ko
0P0:o`@02Ol500Go0`05o`802?l:00Go1@08o`/01Ol00`3o000200Go0P05o`H02_l00`3oo`07o`D0
1Ol200Go0`0<o`802Ol600Go0P05o`H01Ol800[o0P08o`X01Ol00`3oo`0300Go0P05o`H01Ol00`3o
o`0200Go0P05o`801_l200Ko1@05o`030?oo00@02?l900Go1P04o`<01?l600[o400001l02?l800Ko
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(59\\) NIPJLQLSZJRXFRXOJLCYCXWCDRHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2P05o`P0
1Ol>00;o5P06o`<00_l300[o1008o`P01_l700go1@05o`D03Ol300;o00<0ool00ol600[o1P06o`H0
1Ol600So0P05o`<01ol700Go1P03o`030?oo00?o0P05o`H01Ol700Ko1`0=o`D01Ol800So2005o`D0
1Ol200Go1@02o`@00_l800Go1`08o`D01Ol600?o00<0ool00_l300Co1@06oaD0000C00;o2@09o`H0
1ol=00;o5@06o`800ol300[o1008o`H02Ol600go0`09o`<03Ol300[o100:o`@02Ol500Go1@09o`80
1Ol300Oo1`05o`D01?l00`3oo`03o`801Ol400Wo0`09o`H03Ol300Wo1P08o`H02Ol300Go0P05o`D0
0_l400;o1P09o`D02_l300Go1@04o`030?oo00;o0`04o`<02OlD00004`02o`T00_l500;o2`03o``0
0_lF00;o1004o`L00_l:00;o2P03o`@00ol800;o1P02o`800ol500?o1@02o`H00_l300?o1@03o`@0
0_l500;o1003o`@00ol600;o1@03o`<00ol400?o1P02o``00_l500?o1003o`@00ol400?o1@03o`80
0ol400?o2002o`H00_l200?o1@03o`P00_l800?o1@03o`<00ol400?o1@03o`@00ol400?o1@03o`D0
0_l400Co1002o`D00ol400;o1@02o`@00ol400?o4`0001<00_lA00;o2`03o`/00_lF00;o1004o`L0
0_l:00;o2P02o`H00_l800;o1P02o`800_l700;o1@02o`H00_l300;o1`02o`@00ol400;o1002o`H0
0_l600;o1@02o`D00ol200?o1`02o``00_l500;o1P03o`800ol500;o1`02o`800_l600;o2002o`H0
0_l200;o1`02o`P00_l800;o1`02o`@00ol200?o1P04o`<00ol400;o1`02o`D00_l600;o1002o`D0
0_l500;o1@02o`@00_l600;o4`0001<00_lA00;o3002o`/00_lF00;o0`05o`L00_l:00;o2P02o`H0
0_l800;o1P02o`030?oo00T00_l400;o1P02o`<00_l700;o1@03o`<00_l400;o1P02o`H00_l400;o
1`02o`800_l800;o0P02o`P00_l400;o2002o`800_l500;o2@02o`030?oo00H00_l800;o1P02o`04
0?oooa400_l700?o3P02o`800_l700Co0P04o`<00ol>00;o1`02o`<00_l400;o1P02o`D00_l400;o
1P02oa<0000C00;o4@02o`P01?l00`3oo`0:00;o5P02o`<00_l00`3oo`0700;o2P07o`D00_l600;o
2002o`H00_l00`3oo`0900;o1002o`H00_l;00?o1P02o`<00_l400;o1P02o`H00_l300?o2004o`T0
0_l200;o2002o`<00ol900Co1P02o`T00_l00`3oo`0600;o2002o`H00_l00`3oo`0B00;o1`02oa00
1?l800;o00@0o`001?l300;o3`02o`L00_l300;o0`03o`H00_l500;o1002o`H00_lC00004`02oa40
0_l600Wo2P02oaH00_l200?o00<0ool01`02o`X02Ol;00;o2002o`T00_l900;o1002o`h01ol700?o
4002o`H01ol900Co2@06o`P01ol:00Co1P02o`T00_l900;o2002o`T00_lB00?o1P02oa001?l800;o
00H0o`00o`02o`<00_l?00;o1`02o`<01ol700;o1@02o``00_lC00004`02o`X00_l400;o1`02o`@0
0ol:00;o5P02o`800_l200;o1`02o`X00_l500?o2P02o`P00_l900;o2@02o`@00_l<00Oo2P03o`l0
0_l600Wo1`03o`X01_l800Wo2003o`L00_l900;o2@02o`P00_l900;o4@04o`H00_l@00?o2@02o`03
0?oo00;o00<0ool00`02o`l00_l700;o0`09o`D02Ol<00;o4`0001@00_l900So1P02o`H00_l900;o
5`02o`030?oo00<00_l700;o2P02o`H00_l:00;o2002o`T00_l900;o1002o`/00ol;00;o0`02o`l0
0_l600;o1@03o`H01?l900;o0P02o`P00_l500?o1`04o`H00_l900;o2@02o`P00_l900;o4006o`D0
0_l@00Co2002o`030?oo00;o00<0ool00`02o`l00_l700;o0`02o`D00ol400Wo3002oa<0000D00;o
2@07o`L00_l600;o2@02oaL01Ol300;o1`02o`X00_l600;o2P02o`P00_l900?o2002o`@00_l;00;o
1`000ol0000200;o0`03o`h00_l600;o1P02o`D01_l800;o0P02o`800_l400;o1P02o`H01_l500;o
2@02o`T00_l800;o2@03o`L00_l600;o0P02o`D00ol700;o1@06o`H00_l300;o0`02o`800ol700;o
1@02o`L00_l300;o1P02o`@00_l500;o3002oa<0000D00?o2002o``00_l600;o2@02oaL01?l400;o
1`02o`X00_l600;o2P02o`P00_l:00;o1`02o`D00_l;00;o1P02o`@00_l400?o3@02o`H00_l600;o
1003o`800ol700;o1P02o`@00_l600;o1@03o`800ol500;o1`02o`X00_l800;o2P02o`L00_l500?o
0`02o`D00_l700;o1003o`800ol500;o0`02o`<00_l300;o1`02o`D00_l600;o1002o`H00_l400;o
1@02o``00_lC00005@02o`P00_l<00;o1P000ol0000700;o6004o`@00_l700;o2P02o`D00ol:00;o
2002o`/00_l500;o1P02o`/00ol400?o1002o`D00_l=00;o1P02o`D00ol400;o1002o`L00_l600;o
1002o`D00ol500;o1002o`D00ol500?o2P02o`P00_l:00?o1@03o`D00_l400;o1@03o`D00ol400;o
1002o`D00_l800;o0`03o`D00ol500;o1004o`@00_l500?o1002o`D00_l<00;o4`0001H00_l700;o
3@02o`@00_l800;o6004o`801_l200[o100;o`H02_l200So2009o`<02?l900Wo100:o`L02_l00`3o
o`09o`<01Ol200Go0`0<o`802ol400Go0P05o`@02Ol600[o0P08o`P02_l300Go0P05o`@02_l200Go
0P05o`801_l200Ko0`0:o`@02_l300_o1004o`<01?l600[o400001L000?o00001@08o`L01ol90003
o`0001L00ol300Ko0P0:o`@02Ol800[o0P08o`X01Ol500So2`05o`030?l000<02_l700[o00<0ool0
1ol500Go0P05o`<03?l200Wo1P05o`801Ol600Go200:o`802?l:00Go00<0ool00`05o`801Ol600Go
00<0ool00P05o`801Ol200Ko0P06o`D01Ol00`3oo`0400So1@09o`H01?l300Co1P0:oa00000O00So
2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(60\\) NIPJLQKSZJRXFRYOJLCZCXWCDRHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`/0
1?l<00;o5P06o`<00_l300[o1008o`P01_l700go1@05o`D01Ol600;o0`02o`030?oo00?o1P0:o`H0
1_l600Go1P08o`801Ol300Oo1`05o`H00ol300So2005o`L01_l700go1@05o`L02_l700Go1@05o`80
1Ol500;o1002o`P01Ol700So1@05o`H00ol00`3oo`02o`<01?l500Ko5@0001<00_l;00Oo2006o``0
0_lE00Ko0P03o`<02_l400So1P09o`H03Ol300Wo0`05o`D00ol300[o100:o`@02Ol500Go1@09o`80
1Ol300Oo1`05o`D01?l300So1P09o`<02Ol600go0`09o`D02_l500Wo0`05o`801Ol500;o1002o`H0
2Ol500[o0`05o`D01?l00`3oo`02o`<01?l300Wo500001<00_l:00;o1002o`L00ol200?o2`02oaH0
0_l400Co1`02o`X00_l:00?o1003o`P00_l600;o0P03o`D00ol400;o1@03o`@00ol500?o1002o`D0
0_l400?o1003o`H00_l500?o0`03o`@00ol600;o3002o`D00ol800;o2003o`D00ol200?o1003o`P0
0_l600;o0P03o`D00ol500;o1@02o`@00ol500?o0`03o`@00ol500?o1003o`@00ol500?o1@02o`@0
1?l400;o1@03o`@00_l500;o1003o`@00olC00004`02o`T00_l600;o1P02o`@00_l;00;o5P02o`@0
1?l700;o2P02o`X00_l600;o2002o`H00_l200;o1`02o`@00_l500;o1@02o`L00_l400?o1002o`@0
0_l600;o1P02o`D00_l500?o0P03o`L00_l<00;o1@02o`T00_l800;o1`02o`800_l600;o2002o`H0
0_l200;o1`02o`D00ol400;o1002o`L00_l400?o0P03o`H01?l300?o1002o`L00_l500;o1P02o`@0
0_l500;o1@02o`D00_l400;o1P02oa<0000C00;o2@02o`H00_l500;o1P02o`X00_lF00;o0`05o`L0
0_l:00;o2P02o`H00_l800;o1P02o`030?oo00T00_l300;o1002o`H00_l700;o1@03o`<00_l400;o
1P02o`H00_l400;o1`02o`800_l800;o0P02o`P00_l400;o2P02o`L00_l900;o00<0ool01P02o`P0
0_l600;o00@0oooo3`03o`<00_l300?o3P02o`800_l700Co0P04o`<00ol>00;o1`02o`<00_l400;o
1P02o`D00_l400;o1P02oa<0000C00;o2@02o`H00_l500;o1P02o`X00_lF00;o0`02o`030?oo00L0
0_l:00Oo1@02o`H00_l800;o1P02o`030?oo00T00_l300?o0P03o`h00ol600;o0`02o`@00_l600;o
1P02o`<00ol800Co2@02o`800_l800;o0`03o`X00_l700;o2@02o`030?oo00H00_l800;o1P02o`03
0?oo01400_l300;o0`02oa001?l800;o00@0o`001?l300;o3`02o`L00_l300;o0`03o`H00_l500;o
1002o`H00_lC00004`02o`T00_l600;o1@02o`H00_l:00;o5P02o`800ol00`3oo`0700;o2P09o`/0
0_l800;o2@02o`T00_l300Oo2P07o`L00ol@00;o1P07o`T01?l900Ko2007o`/00ol600;o2@02o`T0
0_l800;o2@02oa400ol700;o4004o`P00_l01P3o003o00;o0`02o`l00_l700;o0`07o`L00_l500;o
3002oa<0000C00;o2@03o`@00_l600;o1P02o`X00_lF00;o0P02o`800_l700;o2P02o`D00ol:00;o
2002o`T00_l900;o0`05o`X01ol:00?o3`02o`H02Ol700?o2P06o`P02Ol800Co1P02o`T00_l900;o
2002o`T00_lB00?o1P02oa000ol900;o00<0ool00_l00`3oo`0300;o3`02o`L00_l300Wo1@09o``0
0_lC00005002o`P02Ol600;o1P02o`T00_lG00;o00<0ool00`02o`L00_l:00;o1P02o`X00_l800;o
2@02o`T00_l300;o00@0oooo2003o`/00_l300;o3`02o`H00_l500?o1P04o`T00_l200;o2002o`D0
0ol600Ko1@02o`T00_l900;o2002o`T00_l>00;o0`02o`H00_l@00Co2002o`030?oo00;o00<0ool0
0`02o`l00_l700;o0`02o`D00ol400Wo3002oa<0000D00;o2002o`030?oo00;o2002o`H00_l900;o
5`05o`<00_l700;o2P02o`H00_l:00;o2002o`T00ol800;o0`02o`800ol700;o1`000ol0000200;o
0`03o`h00_l600;o1P02o`D01_l800;o0P02o`800_l400;o1P02o`H00_l200;o1@02o`T00_l900;o
2002o`T00ol700;o1002o`<00ol500?o1`02o`D01_l600;o0`02o`<00_l200?o1`02o`D00_l700;o
0`02o`H00_l400;o1@02o``00_lC00005003o`P00_l<00;o1P02o`T00_lG00Co1002o`L00_l:00;o
1P02o`X00_l800;o2P02o`L00_l400;o0`03o`H00_l600;o1002o`@00ol=00;o1P02o`H00_l400?o
0P03o`L00_l600;o1002o`H00_l500?o0`02o`D00_l700;o2P02o`P00_l:00;o1`02o`@00_l400?o
1@02o`L00_l400?o0P03o`D00_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l500;o
3002oa<0000E00;o2003o``00_l400;o2@02oaP01?l400;o1`02o`X00_l500?o2P02o`P00_l;00;o
1@02o`D00_l400?o1@03o`@00ol400;o1@02o`d00_l600;o1@03o`@00_l400;o1`02o`H00_l400;o
1@03o`D00_l400;o1@03o`D00ol:00;o2002o`X00ol500?o1002o`D00_l500?o1@03o`@00_l400;o
1@02o`P00_l300?o1@03o`D00_l400Co1002o`D00ol400;o1@02o``00_lC00005P02o`P00ol;00?o
0P03o`P00_lH00Co0P06o`802_l400_o1P0:o`802?l800Wo0`05o`<01Ol400Wo100:o`L02_l00`3o
o`09o`<01Ol200Go0`0<o`802ol400Go0P05o`@02Ol600[o0P08o`P02_l400[o1@0:o`801Ol200Go
0P06o`801_l300[o100:o`<02ol400Co0`04o`H02_l@00005`000ol0000700Oo1`06o`T000?o0000
5`03o`<01_l200[o1009o`P02_l200So2P05o`D01Ol300Go1P05o`030?l000<02_l700[o00<0ool0
1ol500Go0P05o`<03?l200Wo1P05o`801Ol600Go200:o`802?l:00Go00<0ool0100:o`L01Ol00`3o
o`0200Go0P05o`801_l200Ko1@05o`030?oo00@02?l500Wo1P04o`<01?l600[o400002<01Ol800Co
o`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(61\\) NHPILQKSZJRXFRYOJLDZCXWCDRHJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`T0
2Ol900;o5P06o`<00_l300Co0`04o`<02?l700[o100=o`D01Ol500Go1P02o`<00_l00`3oo`03o`H0
2_l600Ko1P05o`H02?l200Go0`07o`L01Ol600?o0`08o`P01Ol700Ko1`0=o`802?l700[o1`05o`D0
1Ol200Go1@02o`@00_l800Go1`08o`D01Ol600?o00<0ool00_l300Co1@06oaD0000C00;o2`07o`L0
2Ol:00;o5@06o`800ol300Co0`04o`<02?l700[o100=o`<02Ol300Go1@03o`<02_l400[o1009o`D0
1Ol500Wo0P05o`<01ol700Go1@04o`<02?l600Wo0`09o`H03Ol200[o1@0:o`D02Ol300Go0P05o`D0
0_l400;o1P09o`D02_l300Go1@04o`030?oo00;o0`04o`<02OlD00004`02o`X00_l400;o2`02o`d0
0_lF00;o1004o`@00_l500;o1P02o`l00_l;00;o1P02o`800ol500?o1002o`D00ol400?o1@03o`@0
0_l500;o1003o`@00ol600;o1@03o`<00ol400?o1P02o``00_l500?o2002o`P00ol500?o0P03o`@0
0ol800;o1P02o`<00_l400Co1@02o`D00_l400?o1@03o`<00ol400?o1@03o`@00ol400?o1@03o`D0
0_l400Co1002o`D00ol400;o1@02o`@00ol400?o4`0001<00_l900;o1P02o`X00_l=00;o5P02o`@0
1?l400;o1@02o`H00_l?00;o2`02o`H00_l200;o1`02o`@00_l500;o1@02o`L00_l400?o1002o`@0
0_l600;o1P02o`D00_l500?o0P03o`L00_l<00;o1@02o`T00_l800;o1`02o`800_l600;o2002o`H0
0_l300;o1P02o`D00ol400;o1002o`L00_l400?o0P03o`H01?l300?o1002o`L00_l500;o1P02o`@0
0_l500;o1@02o`D00_l400;o1P02oa<0000C00;o2@02o`H00_l:00;o3@02oaH00_l300Go1002o`D0
0_l600;o3`02o`/00_l600;o00<0ool02@02o`<00_l400;o1P02o`L00_l500?o0`02o`@00_l600;o
1P02o`@00_l700;o0P02o`P00_l200;o2002o`@00_l:00;o1`02o`T00_l00`3oo`0600;o2002o`H0
0_l300;o1`02o`D00ol300;o0`03o`h00_l200;o1`04o`801?l300?o3P02o`L00_l300;o1002o`H0
0_l500;o1002o`H00_lC00004`02o`T00_l600;o2P02o`d00_lF00;o0`02o`030?oo00@00_l500;o
1P07o`X00_l;00;o1P02o`030?oo00T00_l300?o0P03o`h00ol600;o0`02o`@00_l600;o1P02o`<0
0ol800Co2@02o`800_l800;o0`03o`X00_l700;o2@02o`030?oo00H00_l800;o1P02o`<00_l700;o
1P02o`<00_l300;o4004o`P00_l0103o0004o`<00_l?00;o1`02o`<00_l300?o1P02o`D00_l400;o
1P02oa<0000C00;o2@02o`H00_l:00;o3@02oaH00_l200?o00<0ool01002o`D00_l600Wo2002o`/0
0_l900;o2@02o`<01ol:00Oo1`03oa000_l600Oo2@04o`T01_l800Oo2`03o`H00_l900;o2@02o`P0
0_l;00;o1`02o`H00ol700;o4004o`P00_l01P3o003o00;o0`02o`l00_l700;o0`07o`L00_l500;o
3002oa<0000C00;o2@03o`@00_l;00;o3@02oaH00_l200;o0P02o`@02Ol600;o1@03o`L00_l;00;o
2@02o`T00_l300Go2P07o`X00ol?00;o1P09o`L00ol:00Ko2009o`P01?l600;o2@02o`T00_l800;o
2`02o`L00_l700?o1P02oa000ol900;o00<0ool00_l00`3oo`0300;o3`02o`L00_l300Wo1@09o``0
0_lC00005002o`P02Ol;00;o3002oaL00_l00`3oo`0300;o1009o`H00_l600;o1`02o`/00_l900;o
2@02o`<00_l0103oool800?o2`02o`<00_l?00;o1P02o`D00ol600Co2@02o`800_l800;o1@03o`H0
1_l500;o2@02o`T00_l800;o2`02o`L00_l300;o0`02o`H00_l@00Co2002o`030?oo00;o00<0ool0
0`02o`l00_l700;o0`02o`D00ol400Wo3002oa<0000D00;o2002o`030?oo00;o3@02o``00_lG00Go
0`02o`@00_l500;o1P02o`H00_l700;o2`02o`T00ol800;o0`02o`800ol700;o1`000ol0000200;o
0`03o`h00_l600;o1P02o`D01_l800;o0P02o`800_l400;o1P02o`H00_l200;o1@02o`T00_l900;o
2002o`/00_l700;o0`02o`<00ol500?o1`02o`D01_l600;o0`02o`<00_l200?o1`02o`D00_l700;o
0`02o`H00_l400;o1@02o``00_lC00005003o`P00_lA00;o3002oaL01?l400;o1002o`D00_l600;o
1P02o`L00_l;00;o2P02o`L00_l400;o0`03o`H00_l600;o1002o`@00ol=00;o1P02o`H00_l400?o
0P03o`L00_l600;o1002o`H00_l500?o0`02o`D00_l700;o2P02o`P00_l;00;o1P02o`@00_l400?o
1@02o`L00_l400?o0P03o`D00_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l500;o
3002oa<0000E00;o2003oa000_l;00;o6004o`@00_l400;o1@02o`H00_l500?o1`02o`/00_l;00;o
1@02o`D00_l400?o1@03o`@00ol400;o1@02o`d00_l600;o1@03o`@00_l400;o1`02o`H00_l400;o
1@03o`D00_l400;o1@03o`D00ol:00;o2002o`/00_l400Co1002o`D00_l500?o1@03o`@00_l400;o
1@02o`P00_l300?o1@03o`D00_l400Co1002o`D00ol400;o1@02o``00_lC00005P02o`P00ol;00?o
00<0ool02P02oaP01?l200Ko0P04o`<01?l300_o100:o`@02?l800Wo0`05o`<01Ol400Wo100:o`L0
2_l00`3oo`09o`<01Ol200Go0`0<o`802ol400Go0P05o`@02Ol600[o0P08o`L02_l500[o1@0:o`80
1Ol200Go0P06o`801_l300[o100:o`<02ol400Co0`04o`H02_l@00005`000ol0000700Oo1P06o`X0
00?o00005`03o`<01_l200Co0`04o`<02Ol600[o1008o`X01Ol500Go0`05o`H01Ol00`3o000300[o
1`0:o`030?oo00Oo1@05o`801Ol300co0P09o`H01Ol200Go1P05o`P02_l200So1`08o`L02_l700Go
00<0ool00P05o`801Ol200Ko0P06o`D01Ol00`3oo`0400So1@09o`H01?l300Co1P0:oa00000S00Go
2@03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(62\\) NHQILQJRZJRXFSYOJLDZCXWCDRHK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?o8P02o`@00ooo04l0000E00;o
:002ocH02_lQ00[oo`1>00005002obX00_lf00Go0P02ob801Ol200;oo`1>00005002obX00_lf0003
o`0002P000?o0000o`1D00005002o`/01?l800[o2@02oaH01_l300;o0`04o`<01?l700Go1P0:o`@0
3Ol500Go1`06o`L01Ol600?o00<0ool02?l600Ko1P05o`H02?l200Go0`07o`P00_l00`3oo`03o`P0
2?l800Go1`06o`L03Ol200So1`0:o`L01Ol500Go0P05o`D00_l400;o2005o`L02?l500Go1P03o`03
0?oo00;o0`04o`<01Ol600;o400001<00_l;00Oo1P0:o`X00_lE00Ko0P03o`<01?l300Co1@09o`@0
2_l400go0`09o`<02Ol600Go1@04o`030?oo00So1009o`D01Ol500Wo0P05o`<01ol800[o1P08o`H0
2Ol300Wo1P0=o`802_l500[o1@09o`<01Ol200Go1@02o`@00_l600Wo1@0:o`<01Ol500Co00<0ool0
0_l300Co0`05o`D00ol@00004`02o`X00_l400;o1`02o`D00_l:00;o5P02o`@01?l400;o1@02o`D0
0ol500?o1`02o`/00_l600;o0P03o`D00ol200?o1003o`L00_l500?o1002o`D00_l400?o1003o`H0
0_l500?o0`03o`@00ol600;o2`03o`D00ol800;o2003o`D00ol200?o1003o`P00_l600;o0`02o`@0
1?l500;o1@02o`@00ol500?o0`03o`@00ol500?o1003o`@00ol500?o1@02o`@01?l400;o1@03o`@0
0_l500;o1P02o`D00olA00004`02o`T00_l600;o1`03o`l00_lF00;o1004o`@00_l500;o1@02o`L0
0_l700;o2`02o`H00_l200;o1`02o`800_l600;o1`02o`D00_l500?o1002o`@00_l600;o1P02o`D0
0_l500?o0P03o`L00_l;00;o1`02o`P00_l800;o1`02o`800_l600;o2002o`H00_l300;o1P02o`D0
0ol400;o1002o`L00_l400?o0P03o`H01?l300?o1002o`L00_l500;o1P02o`@00_l500;o1@02o`D0
0_l600;o1@02oa80000C00;o2@02o`H00_l800?o3P02oaH00_l300Go1002o`D00_l400;o2@02o`H0
0_l;00;o1P02o`030?oo00T00_l00`3oo`0600;o1`02o`@00_l700?o0`02o`@00_l600;o1P02o`@0
0_l700;o0P02o`P00_l200;o1`02o`L00_l800;o1`02o`T00_l00`3oo`0600;o2002o`H00_l300;o
1`02o`D00ol300;o0`03o`h00_l200;o1`04o`801?l300?o3P02o`L00_l300;o1002o`H00_l500;o
1P02o`@00_lC00004`02o`T00_l600;o2@03o`d00_lF00;o0`02o`030?oo00@00_l500;o1002o`T0
0_l600;o2`02o`H00_l00`3oo`0900;o00<0ool01P02o`L00_l300?o2002o`<00_l400;o1P02o`H0
0_l300?o2004o`T00_l200;o3`03o`P00_l700;o2@02o`030?oo00H00_l800;o1P02o`<00_l700;o
1P02o`<00_l300;o4004o`P00_l0103o0004o`<00_l?00;o1`02o`<00_l300?o1P02o`D00_l600?o
0P03oa<0000C00;o2@02o`H00_l:00?o3002oaH00_l200?o00<0ool01002o`D00_l400;o2@02o`H0
0_l;00;o2@02o`T00_l900;o1`07o`T00ol@00;o1P07o`T01?l900Ko2P07o`T00ol600;o2@02o`T0
0_l800;o2`02o`L00_l600?o1`02oa001?l800;o00H0o`00o`02o`<00_l?00;o1`02o`<01ol700;o
1@02o`H01olD00004`02o`T00ol400;o3003o`/00_lF00;o0P02o`800_l400Wo1002o`T00_l600;o
2`02o`T00_l900;o2@02o`L02Ol800?o3`02o`H02Ol700?o2P06o`P01ol:00Co1P02o`T00_l900;o
2002o`/00_l700;o1`03o`H00_l@00?o2@02o`030?oo00;o00<0ool00`02o`l00_l700;o0`09o`D0
2Ol600Go5P0001@00_l800Wo3@02o`X00_lG00;o00<0ool00`02o`@02Ol400;o2@02o`H00_l;00;o
2@02o`T00_l900;o1`02o`D00ol300;o0`02o`l00_l600;o1@03o`H01?l900;o0P02o`L00ol>00Ko
1@02o`T00_l900;o2002o`/00_l700;o0`02o`<00_l600;o4004o`P00_l00`3oo`02o`030?oo00<0
0_l?00;o1`02o`<00_l500?o1009o`H00_l0103ooolE00005002o`P00_l00`3oo`02oa000_l900;o
5`05o`<00_l400;o1@02o`@00ol800;o1P02o`/00_l900?o2002o`T00_l700;o1P02o`<00_l300?o
3P02o`H00_l600;o1@06o`P00_l200;o0P02o`<00_l70003o`0000D00_l200;o1@02o`T00_l900;o
2002o`/00_l700;o0`02o`<00ol500?o1`02o`D01_l600;o0`02o`<00_l200?o1`02o`D00_l700;o
0`02o`H00_l400;o1@02o`H00_l200?o500001@00ol800;o5002o`T00_lG00Co1002o`@00_l500;o
1@02o`L00_l700;o2`02o`X00_l700;o2P02o`L00_l600;o0`02o`@00ol=00;o1P02o`H00_l400?o
0P03o`L00_l600;o0`02o`H00_l600?o0`02o`D00_l700;o2P02o`P00_l;00;o1P02o`@00_l400?o
1@02o`L00_l400?o0P03o`D00_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l500;o
1P02o`<00olC00005@02o`P00ol<00;o1@02o`P00_lH00Co1002o`@00_l500;o1P02o`D00_l800;o
2`02o`/00_l500;o2`02o`L00_l500?o0`02o`D00_l=00;o1P02o`D00ol400;o1002o`L00_l600;o
0`03o`@00ol600;o1002o`D00ol500?o2P02o`P00_l;00;o1004o`@00_l500;o1@03o`D00ol400;o
1002o`D00_l800;o0`03o`D00ol500;o1004o`@00_l500?o1002o`D00_l600;o1003oa80000F00;o
2003o`/00ol300?o1`02oaP01?l200Ko0P04o`<01?l500Wo100:o`@02?l800Wo1P0:o`802ol400[o
1`0:o`030?oo00Wo0`05o`801Ol300co1009o`@01Ol200Go1009o`H02_l200So1`0:o`D02_l500[o
0P05o`801Ol200Ko0P06o`<02_l400[o0`0;o`@01?l300Co0`05o`<01Ol@00005`000ol0000700Oo
1`07o`P000?o00005`03o`<01_l200Co0`04o`L01Ol600[o1008o`X01Ol800[o0P09o`H02_l700[o
00<0ool01ol500Go0P05o`<03?l600Go00<0o`000`05o`801Ol600Go200:o`802?l700So1`0:o`L0
1Ol00`3oo`0200Go0P05o`801_l200Ko1@05o`030?oo00@02?l500Wo1P04o`<01?l300Go0`05oa00
000S00Go2005ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(63\\) NHRILQJRZKSYFSYOJLDZCXWCCRHK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`X0
1Ol<00;o5P06o`<00_l300Co0`04o`<01Ol600?o00<0ool02?l400go1@05o`L01_l700Go1P03o`03
0?oo00So1005o`H00_l200;o00<0ool00ol700So1@07o`P00_l00`3oo`03o`P02?l800Go1`06o`L0
3Ol200So1`0:o`L01Ol500Go0P05o`D00_l400;o2005o`X01Ol500Go1P03o`030?oo00;o0`04o`<0
1Ol600;o400001<00_l;00Oo1P09o`/00_lE00Ko0P03o`<01?l300Co0`05o`D01?l00`3oo`08o`@0
3Ol300Wo0`09o`H01Ol500Co00<0ool02?l400Go1@03o`802_l500So1@07o`P02_l600So1P09o`<0
2Ol600go0P0:o`D02_l500Wo0`05o`801Ol500;o1002o`H02Ol600Wo0`05o`D01?l00`3oo`02o`<0
1?l300Go1@03oa00000C00;o2P02o`@00_l600;o1@02o`/00_lF00;o1004o`@00_l500;o1P02o`D0
0ol700;o2`02o`H00_l200?o1@03o`800ol400?o1`02o`D00ol400;o1@02o`H00_l500?o0`03o`D0
0ol700;o2P02o`/00ol500?o2002o`P00ol500?o0P03o`@00ol800;o1P02o`<00_l400Co1@02o`D0
0_l400?o1@03o`<00ol400?o1@03o`@00ol400?o1@03o`@00ol500?o1002o`D00ol400;o1@02o`H0
0_l500?o4@0001<00_l900;o1P02o`d00_l:00;o5P02o`@01?l400;o1@02o`H00_l500;o2002o`/0
0_l600;o0P02o`L00_l200;o1P02o`L00_l500;o1@03o`@00_l600;o1@02o`@00_l700;o1`02o`X0
0_l;00;o1`02o`P00_l800;o1`02o`800_l600;o2002o`H00_l300;o1P02o`D00ol400;o1002o`L0
0_l400?o0P03o`H01?l300?o1002o`L00_l400;o1`02o`@00_l500;o1@02o`D00_l600;o1@02oa80
000C00;o2@02o`H00_l=00;o2P02oaH00_l300Go1002o`D00_l600;o1002o`T00_l;00;o1P02o`03
0?oo00T00_l00`3oo`0600;o1`02o`@00_l700?o0`02o`H00_l400;o1@02o`L00_l700;o2P02o`80
0_l700;o1`02o`P00_l700;o2@02o`030?oo00H00_l800;o1P02o`<00_l700;o1@03o`<00_l300?o
3P02o`800_l700Co0P04o`<00ol<00?o3@02o`@00_l600;o1@02o`H00_l400;o4`0001<00_l900;o
1P02o`d00_l:00;o5P02o`<00_l00`3oo`0400;o1@02o`H00_l300?o2@02o`/00_l600;o00<0ool0
2@02o`030?oo00H00_l700;o0`03o`P00_l300;o1P03o`800ol=00?o1`02o`X00_l200;o3`03o`P0
0_l700;o2@02o`030?oo00H00_l800;o1P02o`<00_l700;o1P02o`<00_l300;o4004o`P00_l0103o
0004o`<00_l=00;o3P02o`<00ol600;o1@02o`H00ol200?o4`0001<00_l900;o1P02o``00_l;00;o
5P02o`800ol00`3oo`0400;o1@02o`H01ol:00;o2`02o`T00_l900;o2@02o`L01ol900?o2P07o`T0
1ol800?o2@06o`X01ol900?o1P02o`T00_l900;o2002o`/00_l700;o1P03o`L00_l@00Co2002o`06
0?l00?l00_l300;o3@02o`h01ol700;o1@02o`H01olD00004`02o`T00ol400;o2P04o``00_lF00;o
0P02o`800_l400Wo1P09o`P00_l;00;o2@02o`T00_l900;o1`09o`P00ol900Go2@07o`T01?l900Ko
2007o`X01?l600;o2@02o`T00_l800;o2`02o`L00_l700?o1P02oa000ol900;o00<0ool00_l00`3o
o`0300;o3@02o`h02Ol500Wo1P05oaH0000D00;o2009o`X00ol<00;o5`02o`030?oo00<00_l400Wo
1P02o`D00ol700;o2`02o`T00_l900;o2@02o`L00_l500?o0`02o`<00_l900;o00@0oooo1`03o`d0
1_l800;o0P02o`L00ol>00Ko1@02o`T00_l900;o2002o`/00_l700;o0`02o`<00_l600;o4004o`P0
0_l00`3oo`02o`030?oo00<00_l=00;o3P02o`D00ol400Wo1P02o`040?oooaD0000D00;o2002o`03
0?oo00;o3P02o`/00_lG00Go0`02o`@00_l500;o1P02o`H00_l700;o2`02o`T00ol800;o2@02o`L0
0_l600;o0`02o`<00ol800;o0P03o`H00_l70003o`0000@00_l200;o2002o`800_l200;o0`02o`L0
00?o00001@02o`800_l500;o2@02o`T00_l800;o2`02o`L00_l300;o0`03o`D00ol700;o1@06o`H0
0_l300;o0`02o`800ol700;o0`03o`L00_l400;o1P02o`@00_l500;o1P02o`800olD00005003o`P0
0_lC00;o2P02oaL01?l400;o1002o`D00_l600;o1P02o`L00_l;00;o2P02o`L00_l:00;o1`02o`H0
0_l300;o1003o`L00_l300?o1@02o`H00_l500?o0`02o`L00_l600;o0`02o`H00_l600?o0`02o`D0
0_l700;o2P02o`P00_l;00;o1P02o`@00_l400?o1@02o`L00_l400?o0P03o`D00_l300;o0`02o`<0
0_l700;o1002o`L00_l400;o1P02o`@00_l500;o1P02o`<00olC00005@02o`P00olB00;o2@02oaP0
1?l400;o1002o`D00_l600;o1@03o`L00_l;00;o2`02o`D00_l;00;o1`02o`D00ol300;o1@02o`L0
0_l400?o1003o`@00ol500;o1002o`L00_l600;o0`03o`@00ol600;o1002o`D00ol500?o2P02o`P0
0_l;00;o1004o`@00_l500;o1@03o`D00ol400;o1002o`D00_l800;o0`03o`D00ol400?o1@03o`@0
0_l500?o1002o`D00_l600;o1003oa80000F00;o2003o`/00_l300?o2002oaP01?l200Ko0P04o`<0
1?l300_o100:o`@02?l800Wo1P0:o`802ol400[o1005o`<01Ol300Wo0`05o`801Ol300co1009o`@0
1Ol200Go1009o`H02_l200So1`0:o`D02_l500[o0P05o`801Ol200Ko0P06o`<02_l500[o0P0;o`@0
1?l300Co0`05o`<01Ol@00005`000ol0000700Oo1P07o`T000?o00005`03o`<01_l200Co0`04o`<0
2Ol600[o1008o`X01Ol800[o0P09o`H02_l400Go0`05o`D01Ol00`3o000200Go0P05o`<03?l600Go
00<0o`000`05o`801Ol600Go200:o`802?l700So1`0:o`L01Ol00`3oo`0200Go0P05o`801_l200Ko
1@05o`030?oo00L01Ol00`3oo`0200Wo1P04o`<01?l300Go0`05oa00000S00Go2004ool0aP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(64\\) NHRHKQJRZKSZFSYOJLDZCXWCCRHK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o``0
1_l900;o5P06o`<00_l300Co0`04o`<01Ol600?o00<0ool00_l300Co0`05o`H00_l500Go1`06o`L0
1Ol600?o00<0ool02?l400Go1P02o`800_l00`3oo`03o`H02_l400Oo2002o`030?oo00?o2008o`P0
1Ol700Ko1`0=o`802?l700[o1`05o`D01Ol200Go1@02o`@00_l800Go2P05o`D01Ol600?o00<0ool0
0_l300Co0`05o`H00_l@00004`02o`/01ol:00Ko2P02oaD01_l200?o0`04o`<01?l300Go1@04o`03
0?oo00;o0`04o`<01Ol500?o0`09o`<02Ol600Go1@04o`030?oo00So1005o`D00ol200[o100:o`@0
1ol800[o1P08o`H02Ol300Wo1P0=o`802_l500[o1@09o`<01Ol200Go1@02o`@00_l600Wo1P09o`<0
1Ol500Co00<0ool00_l300Co0`05o`D00ol@00004`02o`X00_l400;o3002o``00_lF00;o1004o`@0
0_l500;o1P02o`D00ol400;o1@02o`H00_l500?o0`03o`D00ol200?o1003o`L00_l500?o1002o`D0
0_l600;o1@03o`<00ol500?o1002o`D00_l600;o2`03o`D00ol800;o2003o`D00ol200?o1003o`P0
0_l600;o0`02o`@01?l500;o1@02o`@00ol500?o0`03o`@00ol500?o1003o`@00ol500?o1003o`D0
0ol400;o1@03o`@00_l500;o1P02o`D00olA00004`02o`T00_l600;o2`02o``00_lF00;o1004o`@0
0_l500;o1P02o`D00_l500;o1@02o`H00_l500;o1002o`L00_l200;o1P02o`L00_l500;o1@03o`@0
0_l600;o1@02o`@00_l700;o1003o`@00_l600;o2`02o`L00_l800;o2002o`L00_l200;o1P02o`P0
0_l600;o0`02o`H00_l500?o1002o`@00_l700;o1003o`800ol600Co0`03o`@00_l700;o1002o`L0
0_l400;o1@02o`D00_l500;o1P02o`D00_lB00004`02o`T00_l600;o1@0:o`X00_lF00;o0`05o`@0
0_l500;o1P02o`@00_l600;o1@02o`H00_l400;o1002o`T00_l00`3oo`0600;o1`02o`@00_l700?o
0`02o`H00_l400;o1@02o`L00_l500?o0`02o`H00_l200;o1`02o`L00_l800;o1`02o`T00_l00`3o
o`0600;o2002o`H00_l300;o1`02o`D00ol300;o0`03o`h00_l200;o1`04o`801?l300?o3003o`d0
0_l400;o1P02o`D00_l600;o1002oa<0000C00;o2@02o`H00_l500[o2P02oaH00_l300;o00<0ool0
1002o`D00_l600;o0`03o`H00_l500;o1P03o`800ol400;o2@02o`030?oo00H00_l700;o0`03o`P0
0_l300;o1P03o`800ol=00?o1P02o`<00_l600;o0P02o`l00ol800;o1`02o`T00_l00`3oo`0600;o
2002o`H00_l300;o1`02o`H00_l300;o0`02oa001?l800;o00@0o`001?l300;o3@02o`h00_l300?o
1P02o`D00_l600?o0P03oa<0000C00;o2@02o`H00_l500;o1002o``00_lF00;o0P03o`030?oo00@0
0_l500;o1P07o`L00_l500;o1P07o`D00_l900;o2@02o`L01ol900?o2P07o`T01ol700?o2P06o`X0
1ol900?o1P02o`T00_l900;o2002o`/00_l700;o1P03o`L00_l@00Co2002o`060?l00?l00_l300;o
3@02o`h01ol700;o1@02o`H01olD00004`02o`T00ol400;o1`02o`<00_l<00;o5P02o`800_l200;o
1009o`H02Ol500Wo1P05o`L00_l900;o2@02o`L02Ol800?o2@05o`T01ol:00?o2@06o`P01ol:00Co
1P02o`T00_l900;o2002o`/00_l700;o1`03o`H00_l@00?o2@02o`030?oo00;o00<0ool00`02o`d0
0_l>00Wo1@09o`H01OlF00005002o`P02Ol80004o`0000;o2`02oaL00_l00`3oo`0300;o1009o`H0
0_l500?o1009o`H00_l0103oool600;o2@02o`T00_l700;o1@03o`<00_l300;o2@02o`040?ooo`L0
0ol;00;o0`02o`T00_l200;o1`03o`h01_l500;o2@02o`T00_l800;o2`02o`L00_l300;o0`02o`H0
0_l@00Co2002o`030?oo00;o00<0ool00`02o`d00_l>00;o1@03o`@02Ol600;o00@0oooo5@0001@0
0_l800;o00<0ool00_l:00;o0P02o`/00_lG00Go0`02o`@00_l500;o1P02o`H00_l400;o1@02o`H0
0_l200?o1@03o`P00_l900;o1`02o`H00_l300;o0`03o`P00_l200?o1P02o`L000?o00000P02o`<0
0ol800;o0P02o`800_l300;o1`000ol0000500;o0P02o`D00_l900;o2@02o`P00_l;00;o1`02o`<0
0_l300?o1@03o`L00_l500Ko1P02o`<00_l300;o0P03o`L00_l300?o1`02o`@00_l600;o1002o`D0
0_l600;o0P03oa@0000D00?o2002o`l000?o00000_l;00;o5`04o`@00_l400;o1@02o`H00_l600;o
1002o`D00_l600;o0`03o`D00_l700;o2P02o`L00_l600;o0`02o`@00ol700;o0`03o`D00_l600;o
1002o`@00ol700;o1P02o`<00_l600;o1P03o`<00_l500;o1`02o`X00_l800;o2`02o`H00_l400;o
1003o`D00_l700;o1003o`800ol500;o0`02o`<00_l300;o1`02o`@00_l700;o1002o`H00_l400;o
1@02o`H00_l300?o4`0001D00_l800?o3`001?l0ool:00;o6004o`@00_l400;o1@02o`H00_l500?o
1002o`D00_l600;o1003o`D00_l500;o2`02o`L00_l500?o0`02o`D00_l700;o1003o`@00ol400?o
1002o`D00_l700;o1P02o`<00ol400?o1P02o`@00_l500?o1@03o`X00_l800;o2`02o`@01?l400;o
1@02o`D00ol500?o1002o`@00_l500;o2002o`<00ol500?o1003o`D00ol400;o1@03o`@00_l500;o
1P02o`@00olB00005P02o`P00ol>00Co2@02oaP01?l200Ko0P04o`<01?l300_o1004o`<01?l300Go
0`05o`<02Ol600[o0P0;o`@02_l400Go0`05o`<02Ol400[o100<o`@02Ol400Go0P05o`@02Ol600[o
0P08o`L02_l500[o1@0:o`801Ol200Go0P06o`801_l300[o1@0:o`802ol400Co0`04o`<01Ol300Go
400001L000?o00001`07o`X00ol90003o`0001L00ol300Ko0P04o`<01?l300Wo1P04o`<01?l300Go
0`05o`D01Ol800[o0P09o`H02_l400Go0`05o`D01Ol00`3o000300[o100<o`H01Ol00`3o000300Go
0P05o`H01Ol800[o0P08o`L02?l700[o1`05o`030?oo00801Ol200Go0P06o`801_l500Go00<0ool0
1`05o`030?oo00802Ol600Co0`04o`<01Ol300Go400002<01Ol:00?oo`350000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(65\\) NGRHKQJR KSZFSYOJLDZCXWCCRHL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`X0
1Ol<00;o5P06o`<00_l600Ko1@05o`H00ol00`3oo`02o`<01?l300Go1P02o`D01Ol700Ko1`05o`H0
0ol?00Go1P02o`800_l00`3oo`03o`H02_l400Oo2002o`030?oo00?o2008o`P01Ol700Ko1`0=o`80
2?l700[o1`05o`D01Ol200Go1@02o`@00_l800Go2P05o`D01Ol600?o00<0ool00_l300Co0`0=oa00
000C00;o2`07o`H02Ol;00;o5@06o`800ol400[o0`05o`D01?l00`3oo`02o`<01?l300Go1@03o`<0
2Ol300Wo1P05o`D01?l?00Go1@03o`802_l400[o1007o`P02_l600So1P09o`<02Ol600go0P0:o`D0
2_l500Wo0`05o`801Ol500;o1002o`H02Ol600Wo0`05o`D01?l00`3oo`02o`<01?l300go400001<0
0_l:00;o1002o`H00_l500;o2`02oaH00_l400Co0`04o`D00_l500;o1@03o`@00_l500;o1P02o`D0
0ol300?o1@03o`800ol400?o1`02o`D00olC00;o1@03o`<00ol500?o1002o`D00_l600;o2`03o`D0
0ol800;o2003o`D00ol200?o1003o`P00_l600;o0`02o`@01?l500;o1@02o`@00ol500?o0`03o`@0
0ol500?o1003o`@00ol500?o1003o`D00ol400;o1@03o`@00_l500;o1`02o`H00_l@00004`02o`T0
0_l600;o3@02o`X00_lF00;o1004o`<00_l700;o1@02o`D00_l500;o1@02o`H00_l500;o1002o`L0
0_l200;o1P02o`L00_l500;o5002o`D00_l400;o1`02o`@00ol400;o1P02o`/00_l700;o2002o`P0
0_l700;o0P02o`H00_l800;o1P02o`<00_l600;o1@03o`@00_l400;o1`02o`@00ol200?o1P04o`<0
0ol400;o1`02o`@00_l700;o1002o`D00_l500;o1@02o`L00_l600;o400001<00_l900;o1P02o`d0
0_l:00;o5P02o`<01Ol200?o1`02o`D00_l400;o1P02o`D00_l600;o1002o`@00_l900;o00<0ool0
1P02o`L00_l400;o5@02o`@00_l500;o1`02o`D00ol300;o1P02o`800_l700;o1`02o`P00_l700;o
2@02o`030?oo00H00_l800;o1P02o`<00_l700;o1@03o`<00_l300?o3P02o`800_l700Co0P04o`<0
0ol<00?o3@02o`@00_l600;o1@02o`L00_l600;o400001<00_l900;o1P02o`d00_l:00;o5P02o`<0
0_l00`3oo`0200;o1007o`@00_l300?o1P02o`D00_l600?o0P03o`@00_l900;o00<0ool01P02o`L0
0_l300?o5@03o`800ol=00?o1P02o`<00_l600;o0P02o`l00ol800;o1`02o`T00_l00`3oo`0600;o
2002o`H00_l300;o1`02o`H00_l300;o0`02oa001?l800;o00@0o`001?l300;o3@02o`h00_l300?o
1P02o`D00_l700;o1P02oa00000C00;o2@02o`H00_l=00;o2P02oaH00_l200?o00<0ool00P02o`@0
1ol400Oo1`02o`D00_l600Oo1@02o`T00_l900;o1`07oaH01ol900Oo1`03o`X01_l:00Oo2@03o`H0
0_l900;o2@02o`P00_l;00;o1`02o`H00ol700;o4004o`P00_l01P3o003o00;o0`02o`d00_l>00Oo
1`02o`D00_l700;o600001<00_l900?o1002o`L00_l400;o2`02oaH00_l200;o0P02o`800_l?00Wo
1@09o`H01Ol700;o2@02o`T00_l700Wo5005o`T01ol:00?o2@06o`P01ol:00Co1P02o`T00_l900;o
2002o`/00_l700;o1`03o`H00_l@00?o2@02o`030?oo00;o00<0ool00`02o`d00_l>00Wo1@09o`L0
0_lH00005002o`P02Ol700So2P02oaL00_l00`3oo`0300;o0P02o`l00_l500?o1009o`H00_l0103o
ool600;o2@02o`T00_l700;o1@03oa<00_l0103oool700?o2`02o`<00_l900;o0P02o`L00ol>00Ko
1@02o`T00_l900;o2002o`/00_l700;o0`02o`<00_l600;o4004o`P00_l00`3oo`02o`030?oo00<0
0_l=00;o3P02o`D00ol400Wo1`02oaP0000D00;o2002o`030?oo00;o2@07o`/00_lG00Go0`02o`80
0_l800;o1@02o`H00_l400;o1@02o`H00_l200?o1@03o`P00_l900;o1`02o`H00_lC00;o0P03o`H0
0_l70003o`0000800_l300?o2002o`800_l200;o0`02o`L000?o00001@02o`800_l500;o2@02o`T0
0_l800;o2`02o`L00_l300;o0`03o`D00ol700;o1@06o`H00_l300;o0`02o`800ol700;o0`03o`L0
0_l400;o1P02o`@00_l500;o1`02oaP0000D00?o2002o`d00_l@00;o5`04o`@00_l300;o1P03o`D0
0_l600;o1002o`D00_l600;o0`03o`D00_l700;o2P02o`L00_l600;o4`02o`<00ol500;o1P02o`@0
0_l400?o1`02o`H00_l300;o1P02o`H00ol300;o1@02o`L00_l:00;o2002o`/00_l600;o1002o`@0
0ol500;o1`02o`@00ol200?o1@02o`<00_l300;o0`02o`L00_l400;o1`02o`@00_l600;o1002o`D0
0_l700;o600001D00_l800?o3002o`l00_lH00Co1002o`<00ol400Co1@02o`D00ol400;o1@02o`H0
0_l400?o1@02o`D00_l;00;o1`02o`D00olC00;o1003o`@00ol400?o1002o`D00_l700;o1P02o`<0
0ol400?o1P02o`@00_l500?o1@03o`X00_l800;o2`02o`@01?l400;o1@02o`D00ol500?o1002o`@0
0_l500;o2002o`<00ol500?o1003o`D00ol400;o1@03o`@00_l500;o1`02oaP0000F00;o2003o`/0
0_l>00;o6004o`801_l300[o0`0;o`@01?l300Co0`05o`<01Ol300Wo1P0:o`802olB00Go0`05o`<0
2Ol400[o100<o`@02Ol400Go0P05o`@02Ol600[o0P08o`L02_l500[o1@0:o`801Ol200Go0P06o`80
1_l300[o1@0:o`802ol400Co0`04o`<02?lE00005`000ol0000700Oo1P08o`P000?o00005`03o`<0
1_l500Go00<0ool00`09o`H01?l300Co0`05o`<01Ol500Go200:o`802OlD00Go0`05o`D01Ol00`3o
000300[o100<o`H01Ol00`3o000300Go0P05o`H01Ol800[o0P08o`L02?l700[o1`05o`030?oo0080
1Ol200Go0P06o`801_l500Go00<0ool01`05o`030?oo00802Ol600Co0`04o`<02?lE00008`05o`H0
2?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(66\\) NGSHJQJR KSZFSYOJLDZCXWCCRHL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`/0
1?l<00;o5P06o`<00_l600Ko1P02o`030?oo00?o1P04o`<01?l500Ko2P05o`L01_l700Go1P03o`l0
1Ol600;o0P02o`030?oo00?o1P0:o`@01ol800;o00<0ool00ol800So2005o`L01_l700go0P08o`L0
2_l700Go1@05o`801Ol500;o1002o`P01Ol:00Go1@05o`H00ol00`3oo`02o`<01?l300go400001<0
0_l;00Oo2007o`/00_lE00Ko0P03o`@02_l400[o1004o`<01?l300Wo1`09o`<02Ol600Go1@04o`l0
1Ol500?o0P0:o`@02_l400Oo200:o`H02?l600Wo0`09o`H03Ol200[o1@0:o`D02Ol300Go0P05o`D0
0_l400;o1P09o`H02Ol300Go1@04o`030?oo00;o0`04o`<03Ol@00004`02o`X00_l400;o1`02o`@0
0_l;00;o5P02o`@01?l300Co1@02o`@00ol500?o1002o`D00_l400?o1003o`D00ol500?o0P03o`@0
0ol700;o1@03oa<00_l500?o0`03o`D00ol400;o1@02o`H00_l;00?o1@03o`P00_l800?o1@03o`80
0ol400?o2002o`H00_l300;o1004o`D00_l500;o1003o`D00ol300?o1003o`D00ol400?o1003o`D0
0ol400?o1@03o`@00_l500?o1002o`D00_l700;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X0
0_lF00;o1004o`<00_l700;o1002o`L00_l400;o1@02o`@00_l600;o1@02o`L00_l200;o1P02o`L0
0_l500;o5002o`D00_l400;o1`02o`@00ol400;o1P02o`/00_l700;o2002o`P00_l700;o0P02o`H0
0_l800;o1P02o`<00_l600;o1@03o`@00_l400;o1`02o`@00ol200?o1P04o`<00ol400;o1`02o`@0
0_l700;o1002o`D00_l500;o1@02o`L00_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaH0
0_l300Go0P03o`L00_l400;o1`02o`@00_l500;o1002o`H00_l400;o2@02o`030?oo00H00_l700;o
1002oaD00_l400;o1@02o`L00_l500?o0`02o`H00_l200;o1`02o`L00_l800;o1`02o`T00_l00`3o
o`0600;o2002o`H00_l300;o1`02o`D00ol300;o0`03o`h00_l200;o1`04o`801?l300?o3003o`d0
0_l400;o1P02o`D00_l700;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X00_lF00;o0`02o`03
0?oo00800_l400Oo2`03o`@00_l500;o1002o`H00_l400;o2@02o`030?oo00H00_l700;o0`03oaD0
0ol200?o3@03o`H00_l300;o1P02o`800_l?00?o2002o`L00_l900;o00<0ool01P02o`P00_l600;o
0`02o`L00_l600;o0`02o`<00_l@00Co2002o`040?l000Co0`02o`d00_l>00;o0`03o`H00_l500;o
1`02o`H00_l@00004`02o`T00_l600;o1@02o`H00_l:00;o5P02o`800ol00`3oo`0200;o1007o`H0
1ol500;o1@02o``00_l400;o2@02o`T00_l700Oo5P07o`T01ol700?o2P06o`X01ol900?o1P02o`T0
0_l900;o2002o`/00_l700;o1P03o`L00_l@00Co2002o`060?l00?l00_l300;o3@02o`h01ol700;o
1@02o`L00_lH00004`02o`T00ol400;o1P03o`@00_l;00;o5P02o`800_l200;o0P02o`l01ol700Wo
3002o`@00_l900;o2@02o`L02OlD00Go2@07o`X00ol900Ko2007o`X01?l600;o2@02o`T00_l800;o
2`02o`L00_l700?o1P02oa000ol900;o00<0ool00_l00`3oo`0300;o3@02o`h02Ol500Wo1`02oaP0
000D00;o2009o`H02Ol:00;o5`02o`030?oo00<00_l200;o3P03o``02Ol<00;o1002o`T00_l900;o
1`02o`D00olC00;o00@0oooo1`03o`/00_l300;o2@02o`800_l700?o3P06o`D00_l900;o2@02o`P0
0_l;00;o1`02o`<00_l300;o1P02oa001?l800;o00<0ool00_l00`3oo`0300;o3@02o`h00_l500?o
1009o`L00_lH00005002o`P00_l00`3oo`02o`P00_l00`3oo`02o``00_lG00Go0`02o`800_l800;o
1002o`L000?o00000`02o`D00_l<00;o1003o`P00_l900;o1`02o`H00_lC00;o0P03o`H00_l70003
o`0000800_l300?o2002o`800_l200;o0`02o`L000?o00001@02o`800_l500;o2@02o`T00_l800;o
2`02o`L00_l300;o0`03o`D00ol700;o1@06o`H00_l300;o0`02o`800ol700;o0`03o`L00_l400;o
1P02o`@00_l500;o1`02oaP0000D00?o2002o`d00_l@00;o5`04o`@00_l300;o1P03o`@00_l600;o
1@02o`D00_l<00;o1@02o`L00_l:00;o1`02o`H00_lC00;o0`03o`D00_l600;o1002o`@00ol700;o
1P02o`<00_l600;o1P03o`<00_l500;o1`02o`X00_l800;o2`02o`H00_l400;o1003o`D00_l700;o
1003o`800ol500;o0`02o`<00_l300;o1`02o`@00_l700;o1002o`H00_l400;o1@02o`L00_lH0000
5@02o`P00ol<00?o3P02oaP01?l400;o0`03o`@01?l400?o1003o`D00_l500;o3002o`H00_l500;o
2`02o`L00_l500?o4`02o`@00ol400?o1003o`@00_l500;o1`02o`H00_l300?o1003o`H00_l400;o
1@03o`D00ol:00;o2002o`/00_l400Co1002o`D00_l500?o1@03o`@00_l400;o1@02o`P00_l300?o
1@03o`@00ol500?o1002o`D00ol400;o1@02o`L00_lH00005P02o`P00ol<00?o3002oaP01?l200Ko
0`0:o`D02Ol400Co0`04o`H02_l300Wo1P0:o`802olB00Go0`05o`<02Ol400[o100<o`@02Ol400Go
0P05o`@02Ol600[o0P08o`L02_l500[o1@0:o`801Ol200Go0P06o`801_l300[o1@0:o`802ol400Co
0`04o`<02?lE00005`000ol0000700Oo2007o`L000?o00005`03o`<01_l500Go00<0ool01`05o`03
0?l000<01?l300Co1P0:o`D01Ol800[o0P09oa@01Ol300Go1@05o`030?l000<02_l400co1P05o`03
0?l000<01Ol200Go1P05o`P02_l200So1`08o`L02_l700Go00<0ool00P05o`801Ol200Ko0P06o`D0
1Ol00`3oo`0700Go00<0ool00P09o`H01?l300Co0`08oaD0000S00Go2P05ool0``000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(67\\) NGSHJQKR JTZFSYOJLDZCYWCCSHL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2`04o`/0
0_l>00;o5P06o`<00_l600Ko1P02o`030?oo00?o1P04o`<01?l500Ko2P05o`D01Ol600;o0P05o`H0
0olA00Ko2008o`D02_l400Oo2002o`030?oo00?o2008o`P01Ol700Ko1`0=o`802?l700[o1`05o`L0
2?l700;o1002o`P01Ol:00Go1P02o`030?oo00?o1P04o`<01?l300go400001<00_l;00Oo2@02o`l0
0_lE00Ko0P03o`@02_l400[o1004o`<01?l300Wo1`09o`<01Ol500?o0P05o`D01?l?00Wo1`08o`D0
2_l400Oo200:o`H02?l600Wo0`09o`H03Ol200[o1@0:o`D02Ol500So1`02o`@00_l600Wo1P09o`@0
2_l400Co0`04o`<03Ol@00004`02o`X00_l400;o2P02o`h00_lF00;o1004o`<01?l500;o1003o`D0
0ol400;o1@02o`@00ol400?o1@03o`D00ol400;o1@03o`D00_l500?o4@03o`@00ol900;o2@02o`D0
0_l600;o2`03o`D00ol800;o2003o`D00ol200?o1003o`P00_l600;o0`02o`@01?l500;o1@02o`@0
0ol500?o1`02o`T00ol400?o1003o`D00ol400?o1@03o`<00ol500?o1002o`D00_l700;o1P02oa00
000C00;o2@02o`H00_l900;o3P02oaH00_l400Co0`02o`L00_l400;o1`02o`@00_l500;o1002o`H0
0_l500;o1`02o`@00_l500;o1P02o`D00_lB00;o1P02o`T00_l900?o1002o`H00_l;00;o1`02o`P0
0_l800;o1`02o`800_l600;o2002o`H00_l300;o1P02o`D00ol400;o1002o`L00_l700;o2@04o`<0
0ol400;o1`02o`@00_l700;o0`02o`L00_l400;o1@02o`L00_l600;o400001<00_l900;o1P02o`T0
0_l>00;o5P02o`<01Ol200?o1`02o`@00_l700;o1002o`D00_l400;o1P02o`@00_l900;o0`02o`@0
0_l700;o1002oa<00_l600;o2@02o`X00ol300;o1P02o`800_l700;o1`02o`P00_l700;o2@02o`03
0?oo00H00_l800;o1P02o`<00_l700;o1@03o`<00_l300?o4002o`T01?l200Co0`03o``00ol<00;o
1`02o`@00_l500;o1`02o`H00_l@00004`02o`T00_l600;o2P000ol0000<00;o5P02o`<00_l00`3o
o`0200;o1007o`/00ol400;o1@02o`@00_l600;o1002o`T00_l300?o0P03o`L00_l300?o4`02o`H0
0_l900;o2`02o`<00_l600;o0P02o`l00ol800;o1`02o`T00_l00`3oo`0600;o2002o`H00_l300;o
1`02o`H00_l300;o0`02oa400_l900;o00@0o`001?l300;o3@02oaD00ol400;o1@02o`L00_l600;o
400001<00_l900;o1P02o`X00_l=00;o5P02o`800ol00`3oo`0200;o1007o`H01ol500;o1@02o``0
0_l400;o2@02o`<01ol800Oo7002o`T00_l;00?o2P06o`X01ol900?o1P02o`T00_l900;o2002o`/0
0_l700;o1P03o`L00_lA00?o2002o`060?l00?l00_l300;o3@02oa001ol500;o1@02o`L00_lH0000
4`02o`T00ol400;o2`02o`d00_lF00;o0P02o`800_l200;o3`07o`L02Ol<00;o1002o`T00_l300Go
2P09oaX00_l900;o3003o`T01_l800Oo2P04o`H00_l900;o2@02o`P00_l;00;o1`02o`L00ol600;o
4004o`P00_l00`3oo`02o`030?oo00<00_l=00;o3P07o`L02Ol700;o600001@00_l800Wo30000ol0
000:00;o5`02o`030?oo00<00_l200;o3P03o``02Ol<00;o1002o`T00_l300;o00@0oooo2@02o`D0
0olI00;o1002o`<00_l300;o0`02o`<00_l900;o0P02o`L00ol>00Ko1@02o`T00_l900;o2002o`/0
0_l700;o0`02o`<00_l600;o3`06o`L00_l00`3oo`02o`030?oo00<00_l=00;o3@03o``02Ol700;o
600001@00_l800;o00<0ool00_l>00;o2`02oaL01Ol300;o0P02o`P00_l400;o1`000ol0000300;o
1@02o``00_l400?o2002o`<00_l200?o2002o`H00_lI00;o1002o`<00_l300;o0`02o`<00ol800;o
0P02o`800_l300;o1`000ol0000500;o0P02o`D00_l900;o2@02o`P00_l;00;o1`02o`<00_l300?o
1@03o`L00_l500;o0P02o`H00_l300;o0`02o`800ol700;o0`03o`L00_l300;o1`000ol0000300;o
1@02o`L00_lH00005003o`P00_lB00;o2`02oaL01?l400;o0`02o`H00ol400;o1P02o`D00_l500;o
3002o`D00_l700;o1002o`<00ol700;o1P02oaT00_l400;o0`02o`<00_l300;o1003o`L00_l600;o
0`02o`H00_l600?o0`02o`D00_l700;o2P02o`P00_l;00;o1P02o`@00_l400?o1@02o`L00_l400?o
0`02o`D00_l300;o0`02o`<00_l700;o1002o`L00_l300;o1P02o`D00_l500;o1`02oaP0000E00;o
2003oa8000?o00002002oaP01?l400;o0`03o`@01?l400?o1003o`D00_l500;o3002o`H00_l500;o
1@02o`@00ol600;o1@03oaT00_l400;o0`02o`<00_l300;o1@02o`L00_l600;o0`03o`@00ol600;o
1002o`D00ol500?o2P02o`P00_l;00;o1004o`@00_l500;o1@03o`D00ol400;o1002o`D00_l800;o
0`03o`D00ol400?o1@03o`<00ol400?o1@02o`D00_l700;o600001H00_l800?o2P02o`D00_l800;o
6004o`801_l300[o1@09o`@01?l300Co1P0:o`<02Ol300Go0`05o`802olE00[o00<0ool02_l300[o
100<o`@02Ol400Go0P05o`@02Ol600[o0P08o`L02_l500[o1@0:o`801Ol200Go0P06o`801_l300[o
1@0:o`@02Ol400Co0`04o`<02?lE00005`000ol0000700Oo1@09o`P000?o00005`03o`<01_l500Go
00<0ool01`05o`030?l000<01?l300Co1P0:o`D01Ol500Go0`05o`802OlG00[o00<0ool02_l300[o
100<o`H01Ol00`3o000300Go0P05o`H01Ol800[o0P08o`L02?l700[o1`05o`030?oo00801Ol200Go
0P06o`801_l500Go00<0ool01`05o`030?oo00H01Ol00`3o000300Co0`04o`<02?lE00008`05o`D0
2Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(68\\) NGSHJPKR JTZFSYOJLDZCYWDCTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lF00Ko0`02o`H01_l600;o00<0ool0
0ol600Co0`04o`D01_l600So1P05o`H00_l200Go1P03oa401_l800So1@0:o`@01ol800;o00<0ool0
0ol800So2005o`L01_l700go0P08o`L02_l700Go1`08o`L00_l400;o1@08o`X01Ol700So1@04o`<0
1?l300Go0`05oa00000C00;o2`07o`L02?l;00;o5@06o`800ol400[o100:o`@01?l300Co0`09o`D0
2?l600Go1@03o`801Ol500Co3`09o`L02?l500[o1007o`P02_l600So1P09o`<02Ol600go0P0:o`D0
2_l500Wo1@08o`L00_l400;o1@0:o`H02Ol500So1@04o`<01?l300Go0`05oa00000C00;o2P02o`@0
0_l600?o1003o`X00_lF00;o1004o`<01?l500;o1003o`D00ol400;o1@02o`@00ol400?o1P02o``0
0_l500?o1@02o`D00olA00?o1003o`T00_l900;o1@02o`H00_l;00?o1@03o`P00_l800?o1@03o`80
0ol400?o2002o`H00_l300;o1004o`D00_l500;o1003o`D00ol700;o2@03o`@00ol500;o1004o`@0
0ol500?o1`02o`T00_l500;o1@02o`L00_lA00004`02o`T00_l600;o1@02o`H00_l:00;o5P02o`@0
1?l300;o1`02o`@00_l700;o1002o`D00_l400;o1P02o`H00_l<00;o1@02o`H00_l500;o4P02o`H0
0_l900;o2@03o`@00_l600;o2`02o`L00_l800;o2002o`L00_l200;o1P02o`P00_l600;o0`02o`H0
0_l500?o1002o`@00_l700;o1`02o`T01?l300?o1@02o`H00_l400;o1`02o`L00_l900;o1@02o`D0
0_l700;o4@0001<00_l900;o1P02o`D00_l600;o2P02oaH00_l300Go0P03o`L00_l400;o1`02o`@0
0_l500;o1002o`H00_l600;o3002o`@00_l700;o1002oa<00_l600;o2@02o`X00ol300;o1P02o`80
0_l700;o1`02o`P00_l700;o2@02o`030?oo00H00_l800;o1P02o`<00_l700;o1@03o`<00_l300?o
4002o`T01?l200Co1@02o`L00_l200?o4002o`T00_l500;o1@02o`<00_l200;o4@0001<00_l900;o
1P02o`D00_l600;o2P02oaH00_l300;o00<0ool00P02o`@01ol;00?o1002o`D00_l400;o1P02o`H0
1ol700?o0P03o`L00_l300?o4`02o`H00_l900;o2`02o`<00_l600;o0P02o`l00ol800;o1`02o`T0
0_l00`3oo`0600;o2002o`H00_l300;o1`02o`H00_l300;o0`02oa400_l900;o00@0o`001?l500;o
1`02o`800_lA00;o2@02o`D00_l500;o0P03o`800_lA00004`02o`T00_l600;o1P02o`@00_l;00;o
5P02o`800ol00`3oo`0200;o1007o`H01ol500;o1@02o``00_l600Wo1@07o`P01olL00;o2@02o`/0
0ol:00Ko2P07o`T00ol600;o2@02o`T00_l800;o2`02o`L00_l600?o1`02oa400ol800;o00H0o`00
o`02o`D00_l700;o0P02oa400_l900;o1@02o`D00_l20003o`3o00800_lA00004`02o`T00ol400;o
2007o`/00_lF00;o0P02o`800_l200;o3`07o`L02Ol<00;o1P02o`D00ol400Go2P09oaX00_l900;o
3003o`T01_l800Oo2P04o`H00_l900;o2@02o`P00_l;00;o1`02o`L00ol600;o4004o`P00_l00`3o
o`02o`030?oo00D00_l700;o0P02oa400_l900Wo1@02o`040?oo00;o00<0ool04@0001@00_l800Wo
2006o`/00_lG00;o00<0ool00`02o`800_l>00?o3009o``00_l600;o1P02o`@00_l0103oool900;o
1@03oaT00_l400;o0`02o`<00_l300;o0`02o`T00_l200;o1`03o`h01_l500;o2@02o`T00_l800;o
2`02o`L00_l300;o0`02o`H00_l?00Ko1`02o`030?oo00;o00<0ool01@02o`L00_l200;o3002o`<0
0_l300;o1009o`D00_l00`3oo`020004o`3ooa40000D00;o2002o`030?oo00;o2@02o`@00_l:00;o
5`05o`<00_l200;o2002o`@00_l70003o`0000<00_l500;o3002o`H00_l600;o1002o`800ol800;o
1P02oaT00_l400;o0`02o`<00_l300;o0`03o`P00_l200;o0P02o`<00_l70003o`0000D00_l200;o
1@02o`T00_l900;o2002o`/00_l700;o0`02o`<00ol500?o1`02o`D00_l200;o1P02o`<00_l300;o
1002o`L00_l200?o1`02o`800_l300;o0`02o`@00_l500;o1@02o`030?l0008000Co0?oo4@0001@0
0ol800;o3002o`H00_l900;o5`04o`@00_l300;o1P03o`@00_l600;o1@02o`D00_l<00;o1P02o`H0
0_l400;o0`03o`L00_l600;o6@02o`@00_l300;o0`02o`<00_l400?o1`02o`H00_l300;o1P02o`H0
0ol300;o1@02o`L00_l:00;o2002o`/00_l600;o1002o`@00ol500;o1`02o`@00ol300;o1@02o`<0
0_l300;o1002o`H00_l400;o1`02o`800_l300;o0`02o`@00_l500;o1@04o`<01?lA00005@02o`P0
0ol;00;o1P02o`P00_lH00Co1002o`<00ol400Co1003o`@00ol500;o1@02o``00_l600;o1@03o`@0
0_l400?o1P02o`D00olI00;o1002o`<00_l300;o0`02o`D00_l700;o1P02o`<00ol400?o1P02o`@0
0_l500?o1@03o`X00_l800;o2`02o`@01?l400;o1@02o`D00ol500?o1002o`@00_l500;o2002o`@0
0_l400Co1003o`D00ol200;o0`02o`<00_l400;o1@02o`D01?l400?o4@0001H00_l800?o2P03o`@0
0ol700;o6004o`801_l300[o1@09o`@01?l300Co1P0:o`030?oo00Wo0`05o`<01Ol200_o5@0:o`03
0?oo00[o0`0:o`@03?l400Wo1005o`801Ol400Wo1P0:o`802?l700[o1@0:o`D02_l200Go0P05o`80
1_l200Ko0P0:o`H02_l200co0`04o`<01?l300Co1@04oa00000G0003o`0000L01ol600So20000ol0
000G00?o0`06o`D01Ol00`3oo`0700Go00<0o`000`04o`<01?l600[o00<0ool01ol500Go0`05o`80
2OlG00[o00<0ool02_l300[o100<o`H01Ol00`3o000300Go0P05o`H01Ol800[o0P08o`L02?l700[o
1`05o`030?oo00801Ol200Go0P06o`801_l200So2P05o`030?oo00803?l300Co0`04o`<01?l500Co
400002<01Ol700Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(69\\) NGSHJPKR JTZGSYOJLDZBYWDCTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lF00Ko0`02o`H01_l600;o00<0ool0
0ol600Co0`04o`D01_l600So1P05o`H00_l200Go1P03oa401_l800So1@0:o`P01_l500;o00<0ool0
0ol800So2005o`L01_l700go0P08o`L02_l300[o1P08o`L00_l400;o1@08o`X01Ol700So1@04o`<0
1?l300Go0`05oa00000C00;o2`07o`H01ol=00;o5@06o`800ol400[o100:o`@01?l300Co0`09o`D0
2?l600Go1@03o`801Ol500Co3`09o`L02?l500[o1P0:o`<02_l600So1P09o`<02Ol600go0P0:o`D0
2_l300_o1@08o`L00_l400;o1@0:o`H02Ol500So1@04o`<01?l300Go0`05oa00000C00;o2P02o`@0
0_l;00?o3002oaH00_l400Co0`04o`D00_l400?o1@03o`@00_l500;o1003o`@00ol600;o3002o`D0
0ol500;o1@03oa400ol400?o2@02o`T00_l500;o1@04o`D00_l300?o1@03o`P00_l800?o1@03o`80
0ol400?o2002o`H00_l300;o1004o`D00_l500;o1@02o`D00ol700;o2@03o`@00ol500;o1004o`@0
0ol500?o1`02o`T00_l500;o1@02o`L00_lA00004`02o`T00_l600;o2`03o`/00_lF00;o1004o`<0
0_l700;o1002o`L00_l400;o1@02o`@00_l600;o1P02o``00_l500;o1P02o`D00_lB00;o1P02o`T0
0_l900?o1002o`D00_l700;o0`02o`L00_l800;o2002o`L00_l200;o1P02o`P00_l600;o0`02o`H0
0_l500?o1002o`D00_l600;o1`02o`T01?l300?o1@02o`H00_l400;o1`02o`L00_l900;o1@02o`D0
0_l700;o4@0001<00_l900;o1P02o``00_l;00;o5P02o`<01Ol200?o1`02o`@00_l700;o1002o`D0
0_l400;o1P02o`H00_l<00;o1002o`L00_l400;o4`02o`H00_l900;o2P03o`<00_l400?o1`02o`<0
0_l700;o2002o`L00_l900;o00<0ool01P02o`P00_l600;o0`02o`L00_l500?o0`02o`D00_l600;o
1`02o`T01?l200Co1@02o`L00_l200?o4002o`T00_l500;o1@02o`<00_l200;o4@0001<00_l900;o
1P02o`P01?l00`3oo`0:00;o5P02o`<00_l00`3oo`0200;o1007o`/00ol400;o1@02o`@00_l600;o
1P07o`L00ol200?o1`02o`<00olC00;o1P02o`T00_l;00;o0`02o`@00_l400Oo2P03o`P00_l700;o
2@02o`030?oo00H00_l800;o1P02o`<00_l700;o1P02o`<00_l500;o1P02o`L00_l900;o00@0o`00
1?l500;o1`02o`800_lA00;o2@02o`D00_l500;o0P03o`800_lA00004`02o`T00_l600;o1P09o`X0
0_lF00;o0P03o`030?oo00800_l400Oo1P07o`D00_l500;o3002o`H02Ol500Oo2007oa`00_l900;o
2`03o`P00_l400Oo1@07o`T00ol600;o2@02o`T00_l800;o2`02o`L00_l600?o2@02o`D00ol700?o
2002o`060?l00?l00_l500;o1`02o`800_lA00;o2@02o`D00_l500;o0P000ol0o`0200;o4@0001<0
0_l900?o1002o`L00_l400?o2P02oaH00_l200;o0P02o`800_l?00Oo1`09o``00_l600;o1@03o`@0
1Ol:00Wo6P02o`T00_l<00?o1`02o`h01ol:00Co1P02o`T00_l900;o2002o`/00_l700;o1`03o`P0
2Ol700Co2002o`030?oo00;o00<0ool01@02o`L00_l200;o4@02o`T02Ol500;o00@0ool00_l00`3o
o`0A00005002o`P02Ol600;o1P02o`T00_lG00;o00<0ool00`02o`800_l>00?o3009o``00_l600;o
1P02o`@00_l0103oool900;o1@03oaT00_l400;o0`02o`<00_l300;o0`02o`L00_l=00?o3P06o`D0
0_l900;o2@02o`P00_l;00;o1`02o`<00_l300;o2008o`L01_l700;o00<0ool00_l00`3oo`0500;o
1`02o`800_l<00;o0`02o`<00_l400Wo1@02o`030?oo008000Co0?oo4@0001@00_l800;o00<0ool0
0_l800;o1P02o`T00_lG00Go0`02o`800_l800;o1002o`L000?o00000`02o`D00_l<00;o1P02o`H0
0_l400;o0P03o`P00_l600;o6@02o`@00_l300;o0`02o`<00_l300?o1P02o`P00_l300;o1`000ol0
000500;o0P02o`D00_l900;o2@02o`P00_l;00;o1`02o`<00_l300?o1`02o`@00ol600;o0P02o`H0
0_l300;o0`02o`@00_l700;o0P03o`L00_l200;o0`02o`<00_l400;o1@02o`D00_l00`3o00020004
o`3ooa40000D00?o2002o``00_l600;o2@02oaL01?l400;o0`02o`H00ol400;o1P02o`D00_l500;o
3002o`H00_l600;o1002o`<00ol700;o1P02oaT00_l400;o0`02o`<00_l300;o1003o`H00_l600?o
0`02o`H00_l600?o0`02o`D00_l700;o2P02o`P00_l;00;o1P02o`@00_l400?o1P02o`D00_l500?o
0`02o`D00_l300;o0`02o`@00_l600;o1002o`L00_l200;o0`02o`<00_l400;o1@02o`D01?l300Co
4@0001D00_l800?o2`02o`H000?o00001`02oaP01?l400;o0`03o`@01?l400?o1003o`D00_l500;o
3002o`H00_l500?o1002o`@00ol600;o1@03oaT00_l400;o0`02o`<00_l300;o1@02o`H00ol400Co
0`03o`@00ol600;o1002o`D00ol500?o2P02o`P00_l;00;o1004o`@00_l500;o1P02o`@00ol500;o
1002o`D00_l800;o1002o`@01?l400?o1@03o`800_l300;o0`02o`@00_l500;o1@04o`@00olA0000
5P02o`P00ol;00;o1002o`P00_lH00Co0P06o`<02_l500Wo1004o`<01?l600[o00<0ool02Ol300Go
0`05o`802olE00[o00<0ool02_l300[o1P0:o`@02Ol400Go0P05o`@02Ol600[o0P08o`L02_l500[o
0`0:o`@01Ol200Go0P06o`801_l200[o1P0:o`803?l300Co0`04o`<01?l500Co400001L000?o0000
1`07o`H01ol90003o`0001L00ol300Ko1@05o`030?oo00L01Ol00`3o000300Co0`04o`H02_l00`3o
o`07o`D01Ol300Go0P09oaL02_l00`3oo`0:o`<02_l800Go00<0ool01P05o`030?l000<01Ol200Go
1P05o`P02_l200So1`08o`L02_l300Wo1@05o`801Ol200Ko0P06o`802?l:00Go00<0ool00P0<o`<0
1?l300Co0`04o`D01?l@00008`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(70\\) NGSIJOKR JTZGSYOJLD BYWDBTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lF00Ko0`02o`H01_l600;o00<0ool0
0ol600[o1P06o`X01Ol500Go1P02o`801Ol600?o4@06o`P02?l500[o2006o`D00_l00`3oo`03o`P0
2?l800Go1`06o`L03Ol200So500:o`H02?l700;o1002o`D02?l600[o1P08o`D01?l300Co0`05o`<0
1Ol@00004`02o``00_l<00Ko3002oaD01_l200?o100:o`@02_l400[o1009o`L02Ol300Go1@03o`80
1Ol500Co3`09o`L02?l500[o1P0:o`<02_l600So1P09o`<02Ol600go0P0:oa802ol500So1`02o`@0
0_l500[o100;o`D02?l500Co0`04o`<01Ol300Go400001<00_l=00;o2P03o`800ol;00;o5P02o`@0
1?l300Co1@02o`@00ol500?o1`02o`P00ol400?o1@03o`D00ol400;o1@03o`D00_l500?o4@03o`@0
0ol900;o2@02o`D00_l500Co1@02o`<00ol500?o2002o`P00ol500?o0P03o`@00ol800;o1P02o`<0
0_l400Co4`02o`D00ol700;o2@03o`@00ol500;o1004o`D00_l500?o1`02o`T00_l500;o1@02o`L0
0_lA00004`02o`d00_l:00;o1002o`/00_lF00;o1004o`<00_l700;o1002o`L00_l700;o2002o`H0
0_l500;o1`02o`@00_l500;o1P02o`D00_lB00;o1P02o`T00_l900?o1002o`D00_l700;o0`02o`L0
0_l800;o2002o`L00_l200;o1P02o`P00_l600;o0`02o`H00_lC00;o1P02o`L00_l900Co0`03o`D0
0_l600;o1@02o`H00_l700;o2@02o`D00_l500;o1`02oa40000C00;o3@02o`T00_l600;o2P02oaH0
0_l300Go0P03o`L00_l400;o1`02o`L00_l800;o1P02o`@00_l900;o0`02o`@00_l700;o1002oa<0
0_l600;o2@02o`X00ol300;o1003o`L00_l300;o1`02o`P00_l700;o2@02o`030?oo00H00_l800;o
1P02o`<00_l700;o4P02o`H00_l700;o2@04o`801?l500;o1`02o`@00_l600;o1`02o`T00_l500;o
1@02o`<00_l200;o4@0001<00_l>0003o`0000L00_l600;o2P02oaH00_l300;o00<0ool00P02o`@0
1ol;00?o1`02o`P00_l600;o1002o`T00_l300?o0P03o`L00_l300?o4`02o`H00_l900;o2`02o`<0
0_l400;o1007o`X00ol800;o1`02o`T00_l00`3oo`0600;o2002o`H00_l300;o1`02oa800_l600;o
1`02o`T00_l0103o0004o`D00_l700;o1002o`H00_l700;o2@02o`D00_l500;o0P03o`800_lA0000
4`02o`h00_l800;o1P02o`X00_lF00;o0P03o`030?oo00800_l400Oo1P07o`P00_l@00;o1002o`T0
0_l300Oo2007oa`00_l900;o2`03o`P00_l400Oo1@07o`T00ol600;o2@02o`T00_l800;o2`02o`L0
0_lB00;o1@03o`L00ol800;o00H0o`00o`02o`D00_l700;o1002o`D00ol700;o2@02o`D00_l500;o
0P000ol0o`0200;o4@0001<00_l>00;o2002o`H00_l:00;o5P02o`800_l200;o0P02o`l01ol:00;o
4002o`@00_l900;o0`05o`X02OlJ00;o2@02o``00ol700;o3P07o`X01?l600;o2@02o`T00_l800;o
2`02o`L00_lB00Wo1`04o`P00_l00`3oo`02o`030?oo00D00_l700;o1009o`P00_l900Wo1@02o`04
0?oo00;o00<0ool04@0001@00_l>0003o`0000H00_l600;o2@02oaL00_l00`3oo`0300;o0P02o`h0
0ol?00;o4002o`@00_l900;o0`02o`040?ooo`T00_l500?o6@02o`@00_l300;o0`02o`<00_l300;o
1`02o`d00ol>00Ko1@02o`T00_l900;o2002o`/00_l700;o4P08o`L01_l700;o00<0ool00_l00`3o
o`0500;o1`02o`@02?l400;o0`02o`<00_l400Wo1@02o`030?oo008000Co0?oo4@0001@00_l>00;o
1`02o`H00_l900;o5`05o`<00_l200;o2002o`@00_l70003o`0000H00_l@00;o1002o`T00_l300;o
0P03o`P00_l600;o6@02o`@00_l300;o0`02o`<00_l300?o1P02o`P00_l300;o1`000ol0000500;o
0P02o`D00_l900;o2@02o`P00_l;00;o1`02oa800_l400?o1P02o`800_l600;o0`02o`<00_l400;o
1`02o`@00_l400?o0`02o`<00_l300;o1002o`D00_l500;o00<0o`000P001?l0oolA00005003o`d0
0_l700;o1P02o`T00_lG00Co1002o`<00_l600?o1002o`H00_l800;o4002o`D00_l700;o1002o`<0
0ol700;o1P02oaT00_l400;o0`02o`<00_l300;o1003o`H00_l600?o0`02o`H00_l600?o0`02o`D0
0_l700;o2P02o`P00_l;00;o1P02oa<00_l500;o1@03o`<00_l500;o0`02o`<00_l400;o1P02o`D0
0_l500;o0`02o`<00_l300;o1002o`D00_l500Co0`04oa40000E00;o3P000ol0000600;o1002o`T0
0_lH00Co1002o`<00ol400Co1003o`@00ol800;o4002o`D00ol500?o1002o`@00ol600;o1@03oaT0
0_l400;o0`02o`<00_l300;o1@02o`H00ol400Co0`03o`@00ol600;o1002o`D00ol500?o2P02o`P0
0_l;00;o1004oa<00_l400?o1@02o`@00_l500;o2002o`@00_l400Co1@02o`@00ol300;o0`02o`<0
0_l400;o1@02o`D01?l400?o4@0001H00_l600;o1@02o`L00ol200?o2002oaP01?l200Ko0`0:o`D0
2Ol400[o1`0:o`<02Ol300Go0`05o`802olE00[o00<0ool02_l300[o1P0:o`@02Ol400Go0P05o`@0
2Ol600[o0P08o`L02_lB00[o1005o`801Ol200Ko0P06o`802_l400[o100<o`<01?l300Co0`04o`D0
1?l@00005`000ol0000400Wo2006o`T000?o00005`03o`<01_l500Go00<0ool01`05o`030?l000<0
2_l700[o1@05o`D01Ol300Go0P09oaL02_l00`3oo`0:o`<02_l800Go00<0ool01P05o`030?l000<0
1Ol200Go1P05o`P02_l200So1`08oa@02Ol500Go0P05o`801_l200Ko0P08o`H02Ol500co0`04o`<0
1?l300Co1@04oa00000N00Wo2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(71\\) NFSIJOKR JTZGSYOJLD BYWDBTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2`09o`T00_lF00Ko0`02o`801ol900;o00<0ool0
0ol600[o1P06o`X01Ol500Go1P02o`801Ol600?o4@06o`P02?l500[o2006o`D00_l00`3oo`03o`P0
2?l800Go1`06o`L03Ol200So500:o`H02?l700;o1002o`D02?l600[o1P08o`D01?l300Co0`05o`<0
1Ol@00004`02o``00_l;00Wo2P02oaD01_l200?o0P07o`T02_l400[o1009o`L02Ol300Go1@03o`80
1Ol500Co3`09o`L02?l500[o1P0:o`<02_l600So1P09o`<02Ol600go0P0:oa802ol500So1`02o`@0
0_l500[o100;o`D02?l500Co0`04o`<01Ol300Go400001<00_l=00;o3P02o`d00_lF00;o1004o`@0
0_l<00?o1@03o`L00_l800?o1003o`D00ol500?o1002o`D00ol500;o1@03oa400ol400?o2@02o`T0
0_l500;o1@04o`D00_l300?o1@03o`P00_l800?o1@03o`800ol400?o2002o`H00_l300;o1004oa<0
0_l500?o1`02o`T00ol400?o1@02o`@01?l500;o1@03o`L00_l900;o1@02o`D00_l700;o4@0001<0
0_l=00;o3P02o`d00_lF00;o1004o`@00_l<00;o1`02o`L00_l800;o1P02o`D00_l700;o1002o`D0
0_l600;o1@02oa800_l600;o2@02o`T00ol400;o1@02o`L00_l300;o1`02o`P00_l800;o1`02o`80
0_l600;o2002o`H00_l300;o1P02oa<00_l600;o1`02o`T01?l300?o1@02o`H00_l500;o1P02o`L0
0_l900;o1@02o`D00_l700;o4@0001<00_l=00;o3P02o`d00_lF00;o0`05o`@00_l200;o2002o`L0
0_l700;o2002o`H00_l400;o2@02o`<00_l400;o1`02o`@00_lC00;o1P02o`T00_l:00?o0`02o`@0
0ol700;o0`02o`L00_l800;o1`02o`T00_l00`3oo`0600;o2002o`H00_l300;o1`02oa800_l600;o
1`02o`T01?l200Co1@02o`L00_l400;o1P02o`L00_l900;o1@02o`D00_l300;o0P02oa40000C00;o
3P000ol0000<00;o3@02oaH00_l300;o00<0ool01002o`800_l@00?o1`02o`P00_l600;o1002o`T0
0_l300?o0P03o`L00_l300?o4`02o`H00_l900;o2`02o`<00_l400;o1007o`X00ol800;o1`02o`T0
0_l00`3oo`0600;o2002o`H00_l300;o1`02oa800_l600;o1`02o`T00_l0103o0004o`D00_l700;o
1002o`H00_l700;o2@02o`D00_l500;o0P03o`800_lA00004`02o`h00_l=00;o3@02oaH00_l200?o
00<0ool01006o`/01ol800;o4002o`@00_l900;o0`07o`P01olL00;o2@02o`/00ol800;o1007o`D0
1ol900?o1P02o`T00_l900;o2002o`/00_l700;o4P02o`D00ol700?o2002o`060?l00?l00_l500;o
1`02o`@00_l500?o1`02o`T00_l500;o1@02o`8000?o0?l00P02oa40000C00;o3P02o`d00_l=00;o
5P02o`800_l200;o1006o`T01ol:00;o4002o`@00_l900;o0`05o`X02OlJ00;o2@02o``00ol700;o
3P07o`X01?l600;o2@02o`T00_l800;o2`02o`L00_lB00Wo1`04o`P00_l00`3oo`02o`030?oo00D0
0_l700;o1009o`P00_l900Wo1@02o`040?oo00;o00<0ool04@0001@00_l>0003o`0000/00_l<00;o
5`02o`030?oo00<00_l400;o0P02o`P00ol?00;o4002o`@00_l900;o0`02o`040?ooo`T00_l500?o
6@02o`@00_l300;o0`02o`<00_l300;o1`02o`d00ol>00Ko1@02o`T00_l900;o2002o`/00_l700;o
4P08o`L01_l700;o00<0ool00_l00`3oo`0500;o1`02o`@02?l400;o0`02o`<00_l400Wo1@02o`03
0?oo008000Co0?oo4@0001@00_l>00;o3002o``00_lG00Go0`02o`@00_l200;o0P02o`@00_l70003
o`0000H00_l@00;o1002o`T00_l300;o0P03o`P00_l600;o6@02o`@00_l300;o0`02o`<00_l300?o
1P02o`P00_l300;o1`000ol0000500;o0P02o`D00_l900;o2@02o`P00_l;00;o1`02oa800_l400?o
1P02o`800_l600;o0`02o`<00_l400;o1`02o`@00_l400?o0`02o`<00_l300;o1002o`D00_l500;o
00<0o`000P001?l0oolA00005003o`d00_l<00;o3002oaL01?l400;o1002o`H00_l400;o1P02o`P0
0_l@00;o1@02o`L00_l400;o0`03o`L00_l600;o6@02o`@00_l300;o0`02o`<00_l400?o1P02o`H0
0ol300;o1P02o`H00ol300;o1@02o`L00_l:00;o2002o`/00_l600;o4`02o`D00_l500?o0`02o`D0
0_l300;o0`02o`@00_l600;o1@02o`D00_l300;o0`02o`<00_l400;o1@02o`D01?l300Co4@0001D0
0_l>0003o`0000X00_l;00;o6004o`@00_l400;o1P02o`@00ol400?o2002oa000_l500?o1@03o`@0
0_l400?o1P02o`D00olI00;o1002o`<00_l300;o0`02o`D00_l600?o1004o`<00ol400?o1P02o`@0
0_l500?o1@03o`X00_l800;o2`02o`@01?lC00;o1003o`D00_l400;o1@02o`P00_l400;o1004o`D0
0_l400?o0`02o`<00_l300;o1002o`D00_l500Co1003oa40000F00;o1P02o`D00_l700?o00<0ool0
2P02oaP01?l200Ko00<0ool02_l500Wo100:o`L02_l300Wo0`05o`<01Ol200_o5@0:o`030?oo00[o
0`0:o`H02_l400Wo1005o`801Ol400Wo1P0:o`802?l700[o4P0:o`@01Ol200Go0P06o`801_l200[o
100:o`@03?l300Co0`04o`<01?l500Co400001L000?o00001009o`L01_l:0003o`0001L00ol300Ko
00<0ool02_l700Go00<0o`000`0:o`L02_l500Go1@05o`<01Ol200Wo5`0:o`030?oo00[o0`0:o`P0
1Ol00`3oo`0600Go00<0o`000`05o`801Ol600Go200:o`802?l700So5009o`D01Ol200Go0P06o`80
1_l200So1P09o`D03?l300Co0`04o`<01?l500Co400001h02Ol:00?oo`360000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(72\\) NFSIJOKR JTZHSZOJLD BYWDBTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P0:o`T00_lF00Ko0`02o`801ol900;o00<0ool0
0ol600[o1P06o`X01Ol500Go1P02o`801Ol600?o4@06o`P02?l500[o1@04o`<01?l300;o00<0ool0
0ol700[o1`05o`L01_l700go0P08oa@02_l600So1`02o`@00_l500So1P0:o`H02?l500Co0`04o`<0
1Ol300Go400001<00_l<00;o2P0:o`X00_lE00Ko0P03o`801ol900[o100:o`@02Ol700Wo0`05o`D0
0ol200Go1@04o`l02Ol700So1@0:o`D01?l300Co0`0:o`D02_l500Wo0`09o`H03Ol200[o4P0;o`D0
2?l700;o1002o`D02_l400_o1@08o`D01?l300Co0`05o`<01Ol@00004`02o`d00_l:00;o1@02o`X0
0_lF00;o1004o`@00_l<00?o1@03o`L00_l800?o1003o`D00ol500?o1002o`D00ol500;o1@03oa40
0ol400?o2@02o`T00_l500;o1P02o`D00_l400?o1@03o`D00_l500;o1003o`D00ol200?o1003o`P0
0_l600;o0`02o`@01?lC00;o1@03o`L00_l900?o1003o`D00_l400Co1@02o`D00ol700;o2@02o`D0
0_l500;o1`02oa40000C00;o3@02o`/00ol?00;o5P02o`@01?l400;o3002o`L00_l700;o2002o`H0
0_l500;o1`02o`@00_l500;o1P02o`D00_lB00;o1P02o`T00_l900?o1002o`H00_l500;o1002o`L0
0_l500?o1002o`@00_l700;o0P02o`H00_l800;o1P02o`<00_l600;o4`02o`H00_l700;o2@04o`<0
0ol500;o1P02o`D00_l600;o1`02o`T00_l500;o1@02o`L00_lA00004`02o`d00_l<00?o3P02oaH0
0_l300Go1002o`800_l800;o1`02o`L00_l800;o1P02o`@00_l900;o0`02o`@00_l700;o1002oa<0
0_l600;o2@02o`X00ol300;o1P02o`D00_l400;o1`02o`H00ol300;o0`02o`T00_l00`3oo`0600;o
2002o`H00_l300;o1`02oa800_l600;o1`02o`T01?l200Co1@02o`L00_l400;o1P02o`L00_l900;o
1@02o`D00_l300;o0P02oa40000C00;o3P000ol0000;00?o3@02oaH00_l300;o00<0ool01002o`80
0_l@00?o1`02o`P00_l600;o1002o`T00_l300?o0P03o`L00_l300?o4`02o`H00_l900;o2`02o`<0
0_l600;o1@02o``00ol700;o0`02o`<00_l900;o00<0ool01P02o`P00_l600;o0`02o`L00_lB00;o
1P02o`L00_l900;o00@0o`001?l500;o1`02o`@00_l600;o1`02o`T00_l500;o1@02o`800ol200;o
4@0001<00_l>00;o3@03o``00_lF00;o0P03o`030?oo00@01_l;00Oo2002oa000_l400;o2@02o`<0
1ol800Oo7002o`T00_l;00?o2P02o`D00_l700Oo2003o`L00_l900;o2@02o`P00_l;00;o1`02oa80
0_l500?o1`03o`P00_l01P3o003o00;o1@02o`L00_l400;o1@03o`L00_l900;o1@02o`D00_l20003
o`3o00800_lA00004`02o`h00_l>00?o2`02oaH00_l200;o0P02o`@01_l900Oo2P02oa000_l400;o
2@02o`<01Ol:00Wo6P02o`T00_l<00?o2@09o`D01ol;00?o1P02o`T00_l900;o2002o`/00_l700;o
4P09o`L01?l800;o00<0ool00_l00`3oo`0500;o1`02o`@02Ol800;o2@09o`D00_l0103oo`02o`03
0?oo0140000D00;o3P000ol0000=00;o2P02oaL00_l00`3oo`0300;o1002o`800_l800?o3`02oa00
0_l400;o2@02o`<00_l0103oool900;o1@03oaT00_l400;o0`02o`<00_l300;o0`02o`T02Ol400?o
3002o`<00_l600;o2@02o`T00_l800;o2`02o`L00_lB00So1`06o`L00_l00`3oo`02o`030?oo00D0
0_l700;o1008o`@00_l300;o0`02o`@02Ol500;o00<0ool00P001?l0oolA00005002o`h00_l?00;o
2@02oaL01Ol300;o1002o`800_l200;o1002o`L000?o00001P02oa000_l400;o2@02o`<00_l200?o
2002o`H00_lI00;o1002o`<00_l300;o0`02o`<00ol800;o1@02o`@00_l70003o`0000<00_l300?o
1@02o`T00_l900;o2002o`/00_l700;o4P02o`@00ol600;o0P02o`H00_l300;o0`02o`@00_l700;o
1002o`@00ol300;o0`02o`<00_l400;o1@02o`D00_l00`3o00020004o`3ooa40000D00?o3@02o`l0
0_l900;o5`04o`@00_l400;o1P02o`@00_l600;o2002oa000_l500;o1`02o`@00_l300?o1`02o`H0
0_lI00;o1002o`<00_l300;o0`02o`@00ol700;o1@02o`@00_l600;o1@02o`@00ol500;o1`02o`X0
0_l800;o2`02o`H00_lC00;o1@02o`D00ol300;o1@02o`<00_l300;o1002o`H00_l500;o1@02o`<0
0_l300;o0`02o`@00_l500;o1@04o`<01?lA00005@02o`h000?o00001P02o`D00_l800;o6004o`@0
0_l400;o1P02o`@00ol400?o2002oa000_l500?o1@03o`@00_l400?o1P02o`D00olI00;o1002o`<0
0_l300;o0`02o`D00_l700;o1@02o`@00ol400?o1@02o`D00_l500?o1@03o`X00_l800;o2`02o`@0
1?lC00;o1003o`D00_l400;o1@02o`P00_l400;o1004o`D00_l400?o0`02o`<00_l300;o1002o`D0
0_l500Co1003oa40000F00;o1P02o`D00_l700?o0`03o`L00_lH00Co0P06o`030?oo00[o1@09o`@0
2_l700[o0`09o`<01Ol300Go0P0;oaD02_l00`3oo`0:o`<02_l500Co0`04o`@02Ol500[o1@09o`H0
2_l200So1`0:oa802_l400Go0P05o`801_l200Ko0P0:o`@02_l400co0`04o`<01?l300Co1@04oa00
000G0003o`0000@02Ol800Oo20000ol0000G00?o0`06o`030?oo00[o1`05o`030?l000<02_l700[o
1@05o`D01Ol300Go0P09oaL02_l00`3oo`0:o`<02_l500Co0`04o`H01Ol00`3o000400[o1`05o`P0
2_l200So1`08oa@02Ol500Go0P05o`801_l200Ko0P08o`H02Ol500co0`04o`<01?l300Co1@04oa00
000N00Wo2@05ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(73\\) NFSIJOKR JTZHSZNJLD BYWDBTHM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lF00Ko0`02o`801ol900;o00<0ool0
0ol600[o1P06o`X01Ol500Go1P02o`801Ol600?o4@06o`P02?l500[o1@04o`<01?l300;o00<0ool0
0ol700[o1006o`<00_l400Ko1`0=o`802?lD00[o1P08o`L00_l400;o1@08o`H02_l600So1@04o`<0
1?l300Go0`05oa00000C00;o3002o`X02Ol;00;o5@06o`800ol200Oo2@0:o`@02_l400Wo1`09o`<0
1Ol500?o0P05o`D01?l?00Wo1`08o`D02_l500Co0`04o`<02_l500[o1006o`800ol200Wo1P0=o`80
2_lB00_o1@08o`L00_l400;o1@0:o`@02ol500So1@04o`<01?l300Go0`05oa00000C00;o3@02o`T0
0_l500;o2`02oaH00_l400Co1002o``00ol500?o1`02o`P00ol400?o1@03o`D00ol400;o1@03o`D0
0_l500?o4@03o`@00ol900;o2@02o`D00_l600;o1@02o`@00ol500?o1@02o`D00_l500;o1004o`80
0ol400?o2002o`H00_l300;o1004oa<00_l500?o1`02o`T00ol400?o1@02o`@01?l500;o1@03o`L0
0_l900;o1@02o`D00_l700;o4@0001<00_l=00;o4@02o`X00_lF00;o1004o`@00_l<00;o1`02o`L0
0_l800;o1P02o`D00_l700;o1002o`D00_l600;o1@02oa800_l600;o2@02o`T00ol400;o1P02o`D0
0_l400;o1`02o`D00ol400;o1@02o`@01?l200;o1P02o`P00_l600;o0`02o`H00_lC00;o1P02o`L0
0_l900Co0`03o`D00_l600;o1@02o`H00_l700;o2@02o`D00_l500;o1`02oa40000C00;o3@02oa40
0_l:00;o5P02o`<01Ol400;o0P02o`P00_l700;o1`02o`P00_l600;o1002o`T00_l300;o1002o`L0
0_l400;o4`02o`H00_l900;o2P03o`<00_l600;o1@02o`@00_l700;o1P03o`<00_l500;o0`05o`80
0_l600;o2002o`H00_l300;o1`02oa800_l600;o1`02o`T01?l200Co1@02o`L00_l400;o1P02o`L0
0_l900;o1@02o`D00_l300;o0P02oa40000C00;o3P000ol0000?00;o2P02oaH00_l300;o00<0ool0
1002o`800_l@00?o1`02o`P00_l600;o1002o`T00_l300?o0P03o`L00_l300?o4`02o`H00_l900;o
2`02o`<00_l600;o1@02o``00ol700;o0`02o`D00_l300;o00<0ool00P02o`H00_l800;o1P02o`<0
0_l700;o4P02o`H00_l700;o2@02o`040?l000Co1@02o`L00_l400;o1P02o`L00_l900;o1@02o`D0
0_l200?o0P02oa40000C00;o3P02o`l00_l;00;o5P02o`800ol00`3oo`0400Ko2`07o`P00_l@00;o
1002o`T00_l300Oo2007oa`00_l900;o2`03o`X00_l500;o1`07o`P00ol900;o0P03o`030?oo00X0
0_l800;o2`02o`L00_lB00;o1@03o`L00ol800;o00H0o`00o`02o`D00_l700;o1002o`D00ol700;o
2@02o`D00_l500;o0P000ol0o`0200;o4@0001<00_l>00;o3004o``00_lF00;o0P02o`800_l400Ko
2@07o`X00_l@00;o1002o`T00_l300Go2P09oaX00_l900;o3003o`T02Ol500Oo2`03o`P00_l200;o
0P02o`X00_l800;o2`02o`L00_lB00Wo1`04o`P00_l00`3oo`02o`030?oo00D00_l700;o1009o`P0
0_l900Wo1@02o`040?oo00;o00<0ool04@0001@00_l>0003o`0000X00ol<00;o5`02o`030?oo00<0
0_l400;o0P02o`P00ol?00;o4002o`@00_l900;o0`02o`040?ooo`T00_l500?o6@02o`@00_l300;o
0`02o`<00_l300;o2@09o`@00ol<00;o0`02o`P00_l00`3oo`0300;o2P02o`P00_l;00;o1`02oa80
2?l700Ko1`02o`030?oo00;o00<0ool01@02o`L00_l400So1002o`<00_l300;o1009o`D00_l00`3o
o`020004o`3ooa40000D00;o3P02o`d00_l;00;o5`05o`<00_l400;o0P02o`800_l400;o1`000ol0
000600;o4002o`@00_l900;o0`02o`800ol800;o1P02oaT00_l400;o0`02o`<00_l300;o0`03o`P0
0_l500;o1002o`L000?o00000`02o`<00ol700Go0`02o`X00_l800;o2`02o`L00_lB00;o1003o`H0
0_l200;o1P02o`<00_l300;o1002o`L00_l400;o1003o`<00_l300;o0`02o`@00_l500;o1@02o`03
0?l0008000Co0?oo4@0001@00ol=00;o3P02o`X00_lG00Co1002o`@00_l600;o1002o`H00_l800;o
4002o`D00_l700;o1002o`<00ol700;o1P02oaT00_l400;o0`02o`<00_l300;o1003o`L00_l500;o
1002o`H00_l500;o1003o`H01?l400;o2P02o`P00_l;00;o1P02oa<00_l500;o1@03o`<00_l500;o
0`02o`<00_l400;o1P02o`D00_l500;o0`02o`<00_l300;o1002o`D00_l500Co0`04oa40000E00;o
3P000ol0000<00;o2@02oaP01?l400;o1002o`H00_l400?o1003o`P00_l@00;o1@03o`D00ol400;o
1003o`H00_l500?o6@02o`@00_l300;o0`02o`<00_l500;o1`02o`D00_l400?o1003o`D00_l500;o
1P04o`@00_l:00;o2002o`/00_l400Co4`02o`@00ol500;o1002o`D00_l800;o1002o`@01?l500;o
1003o`<00_l300;o0`02o`@00_l500;o1@04o`@00olA00005P02o`H00_l500;o1`02o`<00ol800;o
6004o`801_l00`3oo`0:o`D02Ol400[o1`0:o`<02Ol300Go0`05o`802olE00[o00<0ool02_l300[o
1@04o`<01?l400Wo1@0:o`@01?l200Ko100:o`802?l700[o4P0:o`@01Ol200Go0P06o`801_l200[o
100:o`@03?l300Co0`04o`<01?l500Co400001L000?o00001009o`L01ol90003o`0001L00ol300Ko
00<0ool02_l700Go00<0o`000`0:o`L02_l500Go1@05o`<01Ol200Wo5`0:o`030?oo00[o0`0:o`D0
1?l300Co1P05o`030?l000@02_l400?o0`06o`@02_l200So1`08oa@02Ol500Go0P05o`801_l200Ko
0P08o`H02Ol500co0`04o`<01?l300Co1@04oa00000N00Wo2@04ool0aP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(74\\) OFTIIOLR JTZHSZMJLD BYWDBTGM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3P06o`T00_lI00Go1@07o`X02?l500[o1@0:o`L0
1Ol500go0P05o`H00olA00Ko2008o`D02_l500Co0`04o`<00_l00`3oo`03o`L02_l300Go0`05o`<0
1_l700go0P08oa@02_l600So1`02o`@00_l500So1P0:o`H02?l800Ko1@05o`<01Ol@00004`02o``0
0_l>00Ko2P02oaH02Ol300Oo2P08o`D02_l500[o1@09o`<03Ol200Go1@04o`l02Ol700So1@0:o`D0
1?l300Co0`0:o`D02_l300Go0`05o`030?oo00Oo1P0=o`802_lB00_o1@08o`L00_l400;o1@0:o`@0
2ol500So1P0:o`<01Ol300Go400001<00_l=00;o3`02o``00_lE00?o1@03o`@00_l@00;o3002o`d0
0_l800?o1@03o`D00_l600;o1002o`D00olA00?o1003o`T00_l900;o1@02o`H00_l500;o1003o`D0
0ol500;o1@02o`@00_l700;o0P03o`@00ol800;o1P02o`<00_l400Co4`02o`D00ol700;o2@03o`@0
0ol500;o1004o`D00_l500?o1`02o`P01?l500;o1002o`L00_lA00004`02o`d00_l?00;o3002oaD0
0_l700;o1002oa000_l<00;o3@02o`P00_l700;o1@02o`H00_l400;o1@02oa800_l600;o2@02o`T0
0ol400;o1P02o`D00_l400;o1`02o`D00ol400;o1002o`L00_l200;o1P02o`P00_l600;o0`02o`H0
0_lC00;o1P02o`L00_l900Co0`03o`D00_l600;o1@02o`H00_l700;o2002o`L00_l400;o1`02oa40
000C00;o3@02o`T02_l:00;o5002o`T00_l300;o0P02o``00_l<00;o3@02o`L00_l900;o1002o`H0
0_l400;o1002oa<00_l600;o2@02o`X00ol300;o1P02o`D00_l400;o1`02o`H00ol300;o1002o`<0
0_l200;o0P02o`H00_l800;o1P02o`<00_l700;o4P02o`H00_l700;o2@04o`801?l500;o1`02o`@0
0_l600;o1`02o`L00ol700;o1002o`<00_l200;o4@0001<00_l>0003o`0000L02_l:00;o5002o`T0
0_l300;o0P02o``00_l<00;o3@02o`L00_l900;o1002o`H00_l400;o0`03oa<00_l600;o2@02o`/0
0_l300;o1P02o`D00_l<00?o1`02o`<00_l400;o0P03o`800_l200;o1P02o`P00_l600;o0`02o`L0
0_lB00;o1P02o`L00_l900;o00@0o`001?l500;o1`02o`@00_l600;o1`02o`L00_l400Oo0`02o`80
0ol200;o4@0001<00_l>00;o2002o`@00_l<00;o5002o`T00_l300Ko3002o``00_l=00;o1`02o`T0
0_l400;o3007oa`00_l900;o2`03o`X00_l500;o1`07o`P00ol800;o0P000ol0o`0200;o2P02o`P0
0_l;00;o1`02oa800_l500?o1`03o`P00_l01P3o003o00;o1@02o`L00_l400;o1@03o`L00_l700;o
1007o`<00_l20003o`3o00800_lA00004`02o`h00_l900;o0`02o``00_lD00;o2@02o`<01_l<00;o
3002o`d00_l700;o2@02o`@00_l<00Wo6P02o`T00_l<00?o2@09o`D01ol;00?o1`02o`040?oo00;o
00<0ool02P02o`P00_l;00;o1`02oa802Ol700Co2002o`030?oo00;o00<0ool01@02o`L00_l400Wo
2002o`L00_l>00;o00@0ool00_l00`3oo`0A00005002o`h000?o000020001?l00002o`/00_lE00;o
2@02o`<00_l200;o1`02o`<00_l300;o1`02o`d00_l700;o2@02o`@00_l<00;o1@03oaT00_l400;o
0`02o`<00_l300;o0`02o`T02Ol400?o3002o`<00_l700;o00<0ool00P001?l0ool:00;o2002o`/0
0_l700;o4P08o`L01_l700;o00<0ool00_l00`3oo`0500;o1`02o`@02?l400;o0`02o`<00_l200;o
3P02o`030?oo008000Co0?oo4@0001@00_l>00;o2@02o`800_l;00;o5@02o`T00_l300;o0P02o`80
0_l300;o0`02o`<00_l700;o3@02o`L00_l900;o1002o``00_l600;o6@02o`@00_l300;o0`02o`<0
0_l300?o2002o`D00_l400;o1`000ol0000300;o0`03o`H00_l00`3o00020004o`3oo`X00_l800;o
2`02o`L00_lB00;o1003o`H00_l200;o1P02o`<00_l300;o1002o`L00_l400;o1003o`<00_l300;o
0`02o`800_l800;o1002o`030?l0008000Co0?oo4@0001@00ol=00;o2P000ol00002o`/00_lF00;o
1`02o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800;o1`02o`D00_l<00;o1P02oaT00_l400;o
0`02o`<00_l300;o1003o`L00_l500;o1002o`H00_l500;o1003o`D01?l300Co2P02o`P00_l;00;o
1P02oa<00_l500;o1@03o`<00_l500;o0`02o`<00_l400;o1P02o`D00_l500;o0`02o`<00_l300;o
0`02o`H00ol400Co0`04oa40000E00;o3P000ol000090004o`3oo`X00_lG00?o1@03o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800?o1@03o`D00_l<00;o1@03oaT00_l400;o0`02o`<00_l300;o
1@02o`L00_l500;o1003o`@00ol500;o1@02o`D01?l400?o2P02o`P00_l;00;o1004oa<00_l400?o
1@02o`@00_l500;o2002o`@00_l400Co1@02o`@00ol300;o0`02o`<00_l300?o1004o`@01?l400?o
4@0001H00_l600;o1@02o`X01?l900;o6@09o`<03?l300co0`0:o`D02_l500Wo0`08o`L02olE00[o
00<0ool02_l300[o1@04o`<01?l400Wo1@0:o`<01?l500Co100:o`802?l700[o4P0:o`@01Ol200Go
0P06o`801_l200[o100:o`@03?l400[o0`04o`D01?l@00005`000ol0000400Wo2`03o`T000?o0000
6P05o`D03?l300co0`0:o`D02_l700Go1@08o`L02OlG00[o00<0ool02_l300[o1@04o`<01?l600Go
00<0o`00100:o`<01?l500Co100:o`802?l700So5009o`D01Ol200Go0P06o`801_l200So1P09o`D0
3?l600Go00<0ool00`04o`D01?l@00007P09o`/00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(75\\) OFTIINLR JTZHSZMJLD BYWDBTGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lI00Go1@07o`X02?l500[o1@0:o`@0
1_l300;o0P0=o`801Ol600?o4@06o`P02?l500[o1@04o`<01?l300;o00<0ool00ol700[o0`05o`<0
1Ol300Ko1`0=o`802?lD00[o1P08o`L00_l400;o1@08o`H02_l600So2006o`D03Ol@00004`02o``0
0_l:00Wo2`02oaH02Ol300Oo2P08o`D02_l500[o1006o`800ol200go0P05o`D01?l?00Wo1`08o`D0
2_l500Co0`04o`<02_l500[o0`05o`<01Ol00`3oo`07o`H03Ol200[o4P0;o`D02?l700;o1002o`D0
2_l400_o1@08o`H02_l300go400001<00_l=00;o2@02o`D00_l;00;o5@03o`D00ol400;o4002o``0
0_l=00;o2@02o`@01?l500;o1P02o`@00_l500?o4@03o`@00ol900;o2@02o`D00_l600;o1@02o`@0
0ol500?o1@02o`D00_l400;o1`02o`800ol400?o2002o`H00_l300;o1004oa<00_l500?o1`02o`T0
0ol400?o1@02o`@01?l500;o1@03o`L00_l800Co1@02o`H00_l600;o400001<00_l=00;o4@02o`X0
0_lE00;o1`02o`@00_l@00;o3002o`d00_l900;o1004o`D00_l600;o1002o`D00_lB00;o1P02o`T0
0_l900?o1002o`H00_l500;o1002o`L00_l500?o1002o`@00_l700;o0P02o`H00_l800;o1P02o`<0
0_l600;o4`02o`H00_l700;o2@04o`<00ol500;o1P02o`D00_l600;o1`02o`P00_l700;o1P02o`H0
0_l@00004`02o`d00_lA00;o2P02oa@00_l900;o0`02o`800_l<00;o3002o`d00_l900;o0`05o`D0
0_l600;o1002o`@00_lC00;o1P02o`T00_l:00?o0`02o`H00_l500;o1002o`L00_l600?o0`02o`@0
0_l300;o0P02o`800_l600;o2002o`H00_l300;o1`02oa800_l600;o1`02o`T01?l200Co1@02o`L0
0_l400;o1P02o`L00_l700?o1`02o`H00_l600;o400001<00_l>0003o`0000l00_l:00;o5002o`T0
0_l300;o0P02o``00_l<00;o3@02o`T00_l300;o00<0ool01@02o`H00_l400;o0`03oa<00_l600;o
2@02o`/00_l300;o1P02o`D00_l<00?o1`02o`<00_l400;o0P03o`800_l200;o1P02o`P00_l600;o
0`02o`L00_lB00;o1P02o`L00_l900;o00@0o`001?l500;o1`02o`@00_l600;o1`02o`L00_l400Oo
1@02o`H00_l@00004`02o`h00_l@00;o2P02oa@00_l900;o0`06o``00_l<00;o3@02o`T00_l200?o
00<0ool01@02o``01olL00;o2@02o`/00ol:00;o1@02o`L01ol800?o2002o`8000?o0?l00P02o`X0
0_l800;o2`02o`L00_lB00;o1@03o`L00ol800;o00H0o`00o`02o`D00_l700;o1002o`D00ol700;o
1`02o`@01ol500;o600001<00_l>00;o2@02o`@00_l;00;o5002o`T00_l300Ko3002o``00_l=00;o
2@02o`800_l200;o1@02o``02OlJ00;o2@02o``00ol900Wo1@07o`/00ol700;o00@0ool00_l00`3o
o`0:00;o2002o`/00_l700;o4P09o`L01?l800;o00<0ool00_l00`3oo`0500;o1`02o`@02Ol800;o
1`02oa000_lH00005002o`h000?o00001`08o`X00_lE00;o2@02o`<00_l200;o1`02o`<00_l300;o
1`02o`d00_l900;o00<0ool00`02o`D00_l<00;o1@03oaT00_l400;o0`02o`<00_l300;o0`02o`T0
2Ol400?o3002o`<00_l700;o00<0ool00P001?l0ool:00;o2002o`/00_l700;o4P08o`L01_l700;o
00<0ool00_l00`3oo`0500;o1`02o`@02?l400;o0`02o`<00_l200;o4002oaP0000D00;o3P02o`P0
1ol;00;o5@02o`T00_l300;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1@02o``0
0_l600;o6@02o`@00_l300;o0`02o`<00_l300?o2002o`D00_l400;o1`000ol0000300;o0`03o`H0
0_l00`3o00020004o`3oo`X00_l800;o2`02o`L00_lB00;o1003o`H00_l200;o1P02o`<00_l300;o
1002o`L00_l400;o1003o`<00_l300;o0`02o`800_l800;o1P02oaP0000D00?o3@02o`P00_l@00;o
5P02o`L00_l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@00_l500;o3002o`H00_lI00;o
1002o`<00_l300;o0`02o`@00ol700;o1@02o`@00_l600;o1@02o`@00ol500Co0`04o`X00_l800;o
2`02o`H00_lC00;o1@02o`D00ol300;o1@02o`<00_l300;o1002o`H00_l500;o1@02o`<00_l300;o
0`02o`<00_l600?o1P02oaP0000E00;o3P000ol0000600;o3`02oaL00ol500?o1002o`H00_l300;o
0`02o`<00_l700;o3@02o`T01?l400;o1@02o``00_l500?o6@02o`@00_l300;o0`02o`<00_l500;o
1`02o`D00_l400?o1003o`D00_l500;o1@04o`@00ol:00;o2002o`/00_l400Co4`02o`@00ol500;o
1002o`D00_l800;o1002o`@01?l500;o1003o`<00_l300;o0`02o`<00ol400Co1P02oaP0000F00;o
1P02o`D00_l700;o3P02oaT02Ol300co0`0<o`<02_l500[o1004o`801_l00`3oo`06o`L02olE00[o
00<0ool02_l300[o1@04o`<01?l400Wo1@0:o`<01?l500Co100:o`802?l700[o4P0:o`@01Ol200Go
0P06o`801_l200[o100:o`@03?l400[o0`08oaD0000G0003o`0000@02Ol700So20000ol0000J00Go
1@0<o`<03?l300[o1@0:o`@00ol300Ko00<0ool01_l700Wo5`0:o`030?oo00[o0`0:o`D01?l300Co
1P05o`030?l000@02_l300Co1@04o`@02_l200So1`08oa@02Ol500Go0P05o`801_l200Ko0P08o`H0
2Ol500co1P05o`030?oo00<02?lE00007P09o`L02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(76\\) OFTIINLR JTZHSZMJLD BZWEBTGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lI00Go1@07o`X02?l500[o1@0:o`@0
1_l300;o0P0=o`801Ol600?o4@06o`P02?l500[o1@04o`<01?l300;o00<0ool00ol700[o0`05o`<0
1Ol300Ko1`0=o`802?lD00[o1@0:o`H00_l400;o100<o`<02_l600So2006o`D03Ol@00004`02o``0
0_l<00Oo2`02oaH02Ol300Oo2P08o`D02_l500[o1006o`800ol200go0P05o`D01?l?00Wo1`08o`D0
2_l500Co0`04o`<02_l500[o0`05o`<01Ol00`3oo`07o`H03Ol200[o4P0;o`@02_l600;o1002o`@0
3?l300_o1@08o`H02_l300go400001<00_l=00;o2P02o`@00_l;00;o5@03o`D00ol400;o4002o``0
0_l=00;o2@02o`@01?l500;o1P02o`@00_l500?o4@03o`@00ol900;o2@02o`D00_l600;o1@02o`@0
0ol500?o1@02o`D00_l400;o1`02o`800ol400?o2002o`H00_l300;o1004oa<00_l500?o1002o`D0
0_l500?o1003o`D00_l600;o1@02o`D00ol700;o2004o`D00_l600;o1P02oa00000C00;o3@02o`T0
0_l600;o2P02oaD00_l700;o1002oa000_l<00;o3@02o`T00_l400Co1@02o`H00_l400;o1@02oa80
0_l600;o2@02o`T00ol400;o1P02o`D00_l400;o1`02o`D00ol400;o1002o`L00_l200;o1P02o`P0
0_l600;o0`02o`H00_lC00;o1P02o`@00ol400;o1@04o`<00ol500;o1P02o`D00_l600;o1`02o`P0
0_l700;o1P02o`H00_l@00004`02o`d00_l900;o1P02o`X00_lD00;o2@02o`<00_l200;o3002o``0
0_l=00;o2@02o`<01Ol500;o1P02o`@00_l400;o4`02o`H00_l900;o2P03o`<00_l600;o1@02o`@0
0_l700;o1P03o`<00_l400;o0`02o`800_l200;o1P02o`P00_l600;o0`02o`L00_lB00;o1P02o`D0
0ol300;o1@04o`801?l500;o0P02o`800_l500;o1P02o`L00_l700?o1`02o`H00_l600;o400001<0
0_l>0003o`0000L00_l600;o2P02oa@00_l900;o0`02o`800_l<00;o3002o`d00_l900;o0`02o`03
0?oo00D00_l600;o1002o`<00olC00;o1P02o`T00_l;00;o0`02o`H00_l500;o3003o`L00_l300;o
1002o`800ol200;o0P02o`H00_l800;o1P02o`<00_l700;o4P02o`H00_l600;o0`02o`D00_l0103o
0004o`D00_l200;o2@02o`H00_l700;o1`02o`@01ol500;o1P02oa00000C00;o3P02o`P00_l600;o
2P02oa@00_l900;o0`06o``00_l<00;o3@02o`T00_l200?o00<0ool01@02o``01olL00;o2@02o`/0
0ol:00;o1@02o`L01ol800?o2002o`8000?o0?l00P02o`X00_l800;o2`02o`L00_lB00;o1@03o`H0
0ol900;o00H0o`00o`02o`D01_l900;o1@03o`L00_l700;o1007o`D00_lH00004`02o`h00_l800?o
1002o`/00_lD00;o2@02o`<01_l<00;o3002o`d00_l900;o0P02o`800_l500;o3009oaX00_l900;o
3003o`T02Ol500Oo2`03o`L00_l0103oo`02o`030?oo00X00_l800;o2`02o`L00_lB00Wo2003o`P0
0_l00`3oo`02o`030?oo00D01_l900Wo2002o`L00_l@00;o600001@00_l>0003o`0000H02Ol:00;o
5@02o`T00_l300;o0P02o`L00_l300;o0`02o`L00_l=00;o2@02o`030?oo00<00_l500;o3002o`D0
0olI00;o1002o`<00_l300;o0`02o`<00_l900Wo1003o``00_l300;o1`02o`030?oo008000Co0?oo
2P02o`P00_l;00;o1`02oa802?l500;o0`02o`P00_l00`3oo`02o`030?oo00D00_l200;o2@08o`@0
0_l300;o0`02o`800_l@00;o600001@00_l>00;o1`02o`030?oo00;o3002oaD00_l900;o0`02o`80
0_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`D00_l<00;o1P02oaT00_l400;o0`02o`<0
0_l300;o0`03o`P00_l500;o1002o`L000?o00000`02o`<00ol600;o00<0o`000P001?l0ool:00;o
2002o`/00_l700;o4P02o`@00ol400;o0`03o`H00_l300;o0`02o`@00_l200;o0P02o`D00_l400?o
0`02o`<00_l300;o0P02o`P00_l600;o600001@00ol=00;o2002oa000_lF00;o1`02o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l900Co1002o`D00_l<00;o1P02oaT00_l400;o0`02o`<00_l300;o
1003o`L00_l500;o1002o`H00_l500;o1003o`D01?l300Co2P02o`P00_l;00;o1P02oa<00_l500;o
1002o`@00ol500;o0`02o`<00_l400;o1P02o`D00_l500;o0`02o`<00_l300;o0`02o`H00ol600;o
600001D00_l>0003o`0000H00ol>00;o5`03o`D00ol400;o1P02o`<00_l300;o0`02o`L00_l=00;o
2@04o`@00_l500;o3002o`D00olI00;o1002o`<00_l300;o0`02o`D00_l700;o1@02o`@00ol400?o
1@02o`D00_l500Co1003o`X00_l800;o2`02o`@01?lC00;o1003o`@00_l500;o1@02o`P00_l400;o
1P02o`D00_l400?o0`02o`<00_l300;o0`03o`@01?l600;o600001H00_l600;o1@02o`P00ol<00;o
6@09o`<03?l300co0`0:o`D02_l400Co0P06o`030?oo00Ko1`0;oaD02_l00`3oo`0:o`<02_l500Co
0`04o`@02Ol500[o0`04o`D01?l400[o0P08o`L02_lB00[o1@0:o`<01_l200Ko00<0ool02_l300[o
100<o`@02_l300So5@0001L000?o00001009o`T01ol70003o`0001X01Ol500co0`0<o`<02_l500[o
1003o`<01_l00`3oo`06o`L02OlG00[o00<0ool02_l300[o1@04o`<01?l600Go00<0o`00100:o`<0
1?l500Co100:o`802?l700So5009o`H02_l300Ko0P06o`030?oo00[o0`09o`D03?l600Go00<0ool0
0`08oaD0000N00Wo2`05ool0``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(77\\) NFTIINLR JTZHSZMJLD BZWEBTGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@02o`h00_lF00Ko0`02o`801ol:00So1@0:o`D0
2_l400Ko0`02o`803Ol200Go1P03oa401_l800So1@0:o`D01?l300Co0`02o`030?oo00?o1`0:o`<0
1Ol300Go0`06o`L03Ol200So500:o`D02_l600;o1002o`@03?l300[o1P08o`P01_l500go400001<0
0_l<00;o3@02o`l00_lE00Ko0P03o`801ol:00So1@0:o`D02_l400Ko0P03o`803Ol200Go1@04o`l0
2Ol700So1@0:o`D01?l300Co0`0:o`D02_l300Go0`05o`030?oo00Oo1P0=o`802_lB00_o100:o`H0
0_l400;o100<o`<02ol500So1P0:o`<03Ol@00004`02o`d00_l=00;o3P02oaH00_l400Co1002oa00
0_l<00;o3@02o`T00_l400Co1@02o`H00_l400;o1@03oa400ol400?o2@02o`T00_l500;o1P02o`D0
0_l400?o1@03o`D00_l500;o1002o`L00_l200?o1003o`P00_l600;o0`02o`@01?lC00;o1@03o`@0
0_l500;o1@03o`@00ol500;o1P02o`D00_l500?o1`02o`P01?l500;o1P02o`H00_l@00004`02o`d0
0_l=00;o3P02oaH00_l400Co1002oa000_l<00;o3@02o`T00_l400Co1@02o`H00_l400;o1@02oa80
0_l600;o2@02o`T00ol400;o1P02o`D00_l400;o1`02o`D00ol400;o1002o`L00_l200;o1P02o`P0
0_l600;o0`02o`H00_lC00;o1P02o`@00ol400;o1@04o`<00ol500;o1P02o`D00_l600;o1`02o`P0
0_l700;o1P02o`H00_l@00004`02o`d00_l=00;o3P02oaH00_l300Go1002o`800_l<00;o3002o`d0
0_l900;o0`05o`D00_l600;o1002o`@00_lC00;o1P02o`T00_l:00?o0`02o`H00_l500;o1002o`L0
0_l600?o0`02o`@00_l300;o0P02o`800_l600;o2002o`H00_l300;o1`02oa800_l600;o1@03o`<0
0_l500Co0P04o`D00_l200;o0P02o`D00_l600;o1`02o`L00ol700;o1P02o`H00_l@00004`02o`h0
00?o000030000ol0000<00;o5P02o`<00_l00`3oo`0400;o0P02o``00_l<00;o3@02o`T00_l300;o
00<0ool01@02o`H00_l400;o0`03oa<00_l600;o2@02o`/00_l300;o1P02o`D00_l<00?o1`02o`<0
0_l400;o0P03o`800_l200;o1P02o`P00_l600;o0`02o`L00_lB00;o1P02o`H00_l300;o1@02o`04
0?l000Co1@02o`800_l900;o1P02o`L00_l700;o1007o`D00_l600;o400001<00_l>00;o3@02o`d0
0_lF00;o0P03o`030?oo00@01_l<00;o3002o`d00_l900;o0P03o`030?oo00D00_l<00Oo7002o`T0
0_l;00?o2P02o`D00_l700Oo2003o`P00_l20003o`3o00800_l:00;o2002o`/00_l700;o4P02o`D0
0ol600?o2@02o`060?l00?l00_l500Ko2@02o`D00ol700;o1`02o`@01ol500;o600001<00_l>00;o
3@02o`d00_lF00;o0P02o`800_l400Ko3002o``00_l=00;o2@02o`800_l200;o1@02o``02OlJ00;o
2@02o``00ol900Wo1@07o`/00ol700;o00@0ool00_l00`3oo`0:00;o2002o`/00_l700;o4P09o`P0
0ol800;o00<0ool00_l00`3oo`0500Ko2@09o`P00_l700;o4002oaP0000D00;o3P000ol0000<0003
o`0000X00_lG00;o00<0ool00`02o`@00_l200;o1`02o`<00_l300;o1`02o`d00_l900;o00<0ool0
0`02o`D00_l<00;o1@03oaT00_l400;o0`02o`<00_l300;o0`02o`T02Ol400?o3002o`<00_l700;o
00<0ool00P001?l0ool:00;o2002o`/00_l700;o4P08o`D00_l300;o2002o`030?oo00;o00<0ool0
1@02o`800_l900So1002o`<00_l300;o0P02oa000_lH00005002o`h00_l=00;o2`02oaL01Ol300;o
1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`D00_l<00;o1P02oaT00_l400;o
0`02o`<00_l300;o0`03o`P00_l500;o1002o`L000?o00000`02o`<00ol600;o00<0o`000P001?l0
ool:00;o2002o`/00_l700;o4P02o`@00ol400;o0`03o`H00_l300;o0`02o`@00_l200;o0P02o`D0
0_l400?o0`02o`<00_l300;o0P02o`P00_l600;o600001@00ol=00;o3@02o`/00_lG00Co1002o`@0
0_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`D00_l<00;o1P02oaT00_l400;o0`02o`<0
0_l300;o1003o`L00_l500;o1002o`H00_l500;o1003o`D01?l300Co2P02o`P00_l;00;o1P02oa<0
0_l500;o1002o`@00ol500;o0`02o`<00_l400;o1P02o`D00_l500;o0`02o`<00_l300;o0`02o`H0
0ol600;o600001D00_l>0003o`0000`000?o00002002oaP01?l400;o1002o`H00_l300;o0`02o`<0
0_l700;o3@02o`T01?l400;o1@02o``00_l500?o6@02o`@00_l300;o0`02o`<00_l500;o1`02o`D0
0_l400?o1003o`D00_l500;o1@04o`@00ol:00;o2002o`/00_l400Co4`02o`@00ol400;o1@02o`D0
0_l800;o1002o`H00_l500;o1003o`<00_l300;o0`02o`<00ol400Co1P02oaP0000F00;o1P02o`D0
0_l600;o1@02o`P00_lH00Co0P06o`030?oo00[o0`0<o`<02_l500[o1004o`801_l00`3oo`06o`L0
2olE00[o00<0ool02_l300[o1@04o`<01?l400Wo1@0:o`<01?l500Co100:o`802?l700[o4P0:o`D0
2_l300Ko0P06o`030?oo00[o0`0:o`@03?l400[o0`08oaD0000G0003o`0000@02Ol600Wo20000ol0
000G00?o0`06o`030?oo00[o0`0<o`<02_l500[o1003o`<01_l00`3oo`06o`L02OlG00[o00<0ool0
2_l300[o1@04o`<01?l600Go00<0o`00100:o`<01?l500Co100:o`802?l700So5009o`H02_l300Ko
0P06o`030?oo00[o0`09o`D03?l600Go00<0ool00`08oaD0000N00Wo1P09ool0a0000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(78\\) NFSIINLR JT ISZMJLD B WEBSGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lF00Ko0`02o`801ol900;o00<0ool0
0ol600[o1@0:o`@01_l300;o0P0=o`801Ol600?o4@06o`P02?lD00[o1002o`030?oo00?o1`0:o`<0
1Ol300Go0`06o`L03Ol200So500:oaD00_l400;o100<o`<02_l500;o00<0ool00ol900Ko1@0=oa00
000C00;o3002o`/02?l;00;o5@06o`800ol200Oo2@0:o`@02_l500[o1006o`800ol200go0P05o`D0
1?l?00Wo1`08oa@02_l400[o1@0:o`<01Ol300Go00<0ool01ol600go0P0:oa802olD00;o1002o`@0
3?l300_o100:o`D02_l300go400001<00_l=00;o2@03o`@00ol:00;o5P02o`@01?l400;o3003o`D0
0ol700;o3@02o`T00_l400Co1@02o`H00_l400;o1@03oa400ol400?o2@02oa/00_l800?o1@03o`D0
0_l500;o1002o`L00_l200?o1003o`P00_l600;o0`02o`@01?lC00;o1@03oa800ol400?o1@02o`H0
0_l500;o1@03o`<00ol500?o0`04o`D00_l600;o1P02oa00000C00;o3@02o`T00_l600;o2P02oaH0
0_l400Co1002o``00_l700;o1`02o`d00_l900;o1004o`D00_l600;o1002o`D00_lB00;o1P02o`T0
0_lK00;o2002o`L00_l500?o1002o`@00_l700;o0P02o`H00_l800;o1P02o`<00_l600;o4`02o`H0
0_lB00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`<00_l700;o1P02o`H00_l@00004`02o`d0
0_l900;o1P02o`X00_lF00;o0`05o`@00_l200;o2002o`L00_l700;o3@02o`T00_l300Go1@02o`H0
0_l400;o1002oa<00_l600;o2@02oa/00_l800;o1`02o`H00ol300;o1002o`<00_l200;o0P02o`H0
0_l800;o1P02o`<00_l700;o4P02o`H00_lB00Co0P04o`D00_l200;o0P02o`D00_l600;o0`02o`L0
0_l200?o1`02o`H00_l600;o400001<00_l>0003o`0000L00_l600;o2P02oaH00_l300;o00<0ool0
1002o`800_l@00?o1`02o`d00_l900;o0`02o`030?oo00D00_l600;o1002o`<00olC00;o1P02o`T0
0_lK00;o4003o`L00_l300;o1002o`800ol200;o0P02o`H00_l800;o1P02o`<00_l700;o4P02o`H0
0_lB00;o00@0o`001?l500;o0P02o`T00_l600;o2`03o`800_l400Oo1@02o`H00_l@00004`02o`h0
0_l900;o1002o`/00_lF00;o0P03o`030?oo00@01_l;00Oo2002o`d00_l900;o0P03o`030?oo00D0
0_l<00Oo7002o`T00_lK00;o2`07o`P00ol800;o0P000ol0o`0200;o2P02o`P00_l;00;o1`02oa80
0_l500?o4P02o`060?l00?l00_l500Ko2@02o`D00ol600Oo0`02o`@01ol500;o600001<00_l>00;o
2P07o`/00_lF00;o0P02o`800_l400Ko2@07o`X00_l=00;o2@02o`800_l200;o1@02o``02OlJ00;o
2@02oa/00_l900Oo2`03o`L00_l0103oo`02o`030?oo00X00_l800;o2`02o`L00_lB00Wo4`02o`03
0?oo00;o00<0ool01@06o`T02Ol500Oo1@02oa000_lH00005002o`h000?o00002006o`/00_lG00;o
00<0ool00`02o`@00_l200;o2003o`l00_l=00;o2@02o`030?oo00<00_l500;o3002o`D00olI00;o
1002o`<00_l300;o5P02o`P00ol<00;o0`02o`L00_l00`3oo`020004o`3oo`X00_l800;o2`02o`L0
0_lB00So5002o`030?oo00;o00<0ool01@02o`800_l900So1@03o`X00_l@00;o600001@00_l>00;o
2002o`@00_l:00;o5`05o`<00_l400;o0P02o`800_l400;o1`000ol0000600;o3@02o`T01Ol300;o
1@02o``00_l600;o6@02o`@00_l300;o0`02oaH00_l800;o1`000ol0000300;o0`03o`H00_l00`3o
00020004o`3oo`X00_l800;o2`02o`L00_lB00;o1003oa800_l300;o0`02o`@00_l200;o0P02o`D0
0_l400?o1002o`L000Co00000_l800;o1P02oaP0000D00?o3@02o`L00_l600;o2@02oaL01?l400;o
1002o`H00_l400;o1P02o`P00_l=00;o2@04o`@00_l500;o3002o`H00_lI00;o1002o`<00_l300;o
5P02o`P00_l600;o1@02o`@00ol500Co0`04o`X00_l800;o2`02o`H00_lC00;o1@02oa800_l300;o
0`02o`@00_l600;o1@02o`D00_l400;o1P02o`@00_l600?o1P02oaP0000E00;o3P000ol0000500;o
1P02o`P00_lH00Co1002o`@00_l600;o1003o`@00ol800;o3@02o`T01?l400;o1@02o``00_l500?o
6@02o`@00_l300;o0`02oaH00_l800?o1003o`D00_l500;o1@04o`@00ol:00;o2002o`/00_l400Co
4`02o`@00olB00;o2002o`@00_l600;o1@02o`@00ol400?o1003o`@00ol400Co1P02oaP0000F00;o
1P02o`D00_l600?o1003o`L00_lH00Co0P06o`030?oo00[o1@09o`@02_l500[o1004o`801_l00`3o
o`06o`L02olE00[o00<0ool02_lB00[o1@09o`D02_l300Co1@04o`@02_l200So1`0:oa802_lB00Ko
0P06o`030?oo00[o0`0:o`H02Ol500[o0`08oaD0000G0003o`0000@02Ol700So20000ol0000G00?o
0`06o`030?oo00[o1`05o`030?l000<02_l500[o1003o`<01_l00`3oo`06o`L02OlG00[o00<0ool0
2_lB00[o1`05o`030?l000@02_l300Co1@04o`@02_l200So1`08oa@02OlC00Ko0P06o`030?oo00[o
0`09o`T01Ol00`3o000600Go00<0ool00`08oaD0000N00Wo2006ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(79\\) NFTIINLR JT ISZMJLD A WEBSGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P05o`h00_lF00Ko0`02o`801ol:00So1@0:o`D0
2_l400Ko0`02o`803Ol200Go1P03oa401_l800So500:o`@00_l00`3oo`03o`L02_l300Go0`05o`<0
1_l700go0P08oa<01_l300Ko4@02o`@00_l400co0`0:o`D00_l00`3oo`03o`T01_l500go400001<0
0_l<00;o2P07o`d00_lE00Ko0P03o`801ol:00So1@0:o`D02_l400Ko0P03o`803Ol200Go1@04o`l0
2Ol700So500:o`@02_l500[o0`05o`<01Ol00`3oo`07o`H03Ol200[o4@06o`<01_lA00;o1002o`@0
3?l300_o100:o`D02_l300go400001<00_l=00;o3P03o``00_lF00;o1004o`@00_l@00;o3002o`d0
0_l900;o1004o`D00_l600;o1002o`D00olA00?o1003o`T00_lK00;o2003o`D00ol500;o1@02o`@0
0_l700;o0P03o`@00ol800;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1@02o`D0
0ol300?o1@03o`<01?l500;o1P02o`H00_l@00004`02o`d00_l?00?o2`02oaH00_l400Co1002oa00
0_l<00;o3@02o`T00_l400Co1@02o`H00_l400;o1@02oa800_l600;o2@02oa/00_l800;o1`02o`D0
0ol400;o1002o`L00_l200;o1P02o`P00_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H0
0_l500;o1P02o`<00_l700;o0`02o`L00_l600;o1P02oa00000C00;o3@02oa000_l;00;o5P02o`<0
1Ol400;o0P02o``00_l<00;o3@02o`T00_l300Go1@02o`H00_l400;o1002oa<00_l600;o2@02oa/0
0_l800;o1`02o`H00ol300;o1002o`<00_l200;o0P02o`H00_l800;o1P02o`<00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o1@02o`H00_l300;o1`02o`800ol700;o1P02o`H00_l@00004`02o`h0
00?o00002P04o`030?oo00X00_lF00;o0`02o`030?oo00@00_l200;o3002o``00_l=00;o2@02o`<0
0_l00`3oo`0500;o1P02o`@00_l300?o4`02o`H00_l900;o6`02oa000ol700;o0`02o`@00_l200?o
0P02o`800_l600;o2002o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o0P02o`T00_l600;o
2`03o`800_l400Oo1@02o`H00_l@00004`02o`h00_l900Wo2P02oaH00_l200?o00<0ool01006o``0
0_l<00;o3@02o`T00_l200?o00<0ool01@02o``01olL00;o2@02oa/00_l;00Oo2003o`P00_l20003
o`3o00800_l:00;o2002o`/00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@03o`H0
1ol300;o1007o`D00_lH00004`02o`h00_l900;o1003o`X00_lF00;o0P02o`800_l400Ko3002o``0
0_l=00;o2@02o`800_l200;o1@02o``02OlJ00;o2@02oa/00_l900Oo2`03o`L00_l0103oo`02o`03
0?oo00X00_l800;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l900Wo1@07o`D0
0_l@00;o600001@00_l>0003o`0000H00_l600;o2@02oaL00_l00`3oo`0300;o1002o`800_l700;o
0`02o`<00_l700;o3@02o`T00_l00`3oo`0300;o1@02o``00_l500?o6@02o`@00_l300;o0`02oaH0
0_l800?o3002o`<00_l700;o00<0ool00P001?l0ool:00;o2002o`/00_l700;o4`02o`<00_lD00;o
00<0ool00_l00`3oo`0500;o0P02o`T02?l500?o2P02oa000_lH00005002o`h00_l700;o1P02o`T0
0_lG00Go0`02o`@00_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o2@05o`<00_l500;o3002o`H0
0_lI00;o1002o`<00_l300;o5P02o`P00_l70003o`0000<00_l300?o1P02o`030?l0008000Co0?oo
2P02o`P00_l;00;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o1003o`@0
0_l70004o`0000;o2002o`H00_lH00005003o`d00_l700;o1P02o`T00_lG00Co1002o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l900Co1002o`D00_l<00;o1P02oaT00_l400;o0`02o`<00_lF00;o
2002o`H00_l500;o1003o`D01?l300Co2P02o`P00_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`D00_l500;o1002o`H00_l400;o1P03o`H00_lH00005@02o`h000?o00001@02o`H0
00?o00001`02oaP01?l400;o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T01?l400;o1@02o``0
0_l500?o6@02o`@00_l300;o0`02oaH00_l800?o1003o`D00_l500;o1@04o`@00ol:00;o2002o`/0
0_l400Co5@05oa@00_l800;o1002o`H00_l500;o1003o`@00ol400?o1003o`@01?l600;o600001H0
0_l600;o1@02o`L00_l400;o2002oaP01?l200Ko00<0ool02_l300co0`0:o`D02_l400Co0P06o`03
0?oo00Ko1`0;oaD02_l00`3oo`0:oa802_l500Wo1@0:o`<01?l500Co100:o`802?l700[o4`07oa@0
1_l200Ko00<0ool02_l300[o1P09o`D02_l300So5@0001L000?o00001009o`L01ol90003o`0001L0
0ol300Ko00<0ool02_l300co0`0:o`D02_l400?o0`06o`030?oo00Ko1`09oaL02_l00`3oo`0:oa80
2_l700Go00<0o`00100:o`<01?l500Co100:o`802?l700So5@07oa@01_l200Ko00<0ool02_l300Wo
2@05o`030?l000H01Ol00`3oo`0300So5@0001h02Ol900Coo`360000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(80\\) MFTIJNLR IT ISZMJKD A WEBSGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00ol700[o0`05o`<0
1Ol300Ko1`05o`H00_l200So4`06o`<01_lA00;o1002o`@03?l300[o1@02o`030?oo00?o2@06o`D0
3Ol@00004`02o`X02?l800Ko3002oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`80
3Ol200Go1@04oa002_l500So500:o`@02_l500[o0`05o`<01Ol00`3oo`07o`H01Ol500?o0P0:oa40
1_l300Ko4@02o`@00_l400co0`0;o`@02_l500[o0`0=oa00000C00;o2@03o`@00ol600?o0P03o`/0
0_lE00;o1`02o`@00_l@00;o3002o`P00ol400?o1P02o`@01?l500;o1P02o`@00_l500?o5P02o``0
0_lK00;o2003o`D00ol500;o1@02o`@00_l700;o0P03o`@00ol700;o1@03o`@00_l400Co4P02o`L0
0_lB00?o1003o`D00_l600;o1@02o`D00ol300?o1@03o`<01?l500;o1P02o`H00_l@00004`02o`T0
0_l600;o1P02o`@00_l;00;o5@02o`L00_l400;o4002o``00_l800;o1P02o`H00_l400Co1@02o`H0
0_l400;o1@02oaL00_l<00;o6`02o`P00_l700;o1@03o`@00_l400;o1`02o`800_l600;o1`02o`D0
0_l500;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`D00_l600;o0`02o`L00_l300;o1`02o`H0
0_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o3002o``0
0_l800;o1P02o`H00_l300Go1@02o`H00_l400;o1002oaP00_l<00;o6`02o`P00_l700;o1P03o`<0
0_l400;o0`02o`800_l200;o1P02o`L00_l400;o1P02o`L00_lA00_o4P04o`801?l500;o0P02o`80
0_l500;o1P02o`<00_l700;o0P03o`L00_l600;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X0
0_lE00;o0P03o`800_l400;o0P02o``00_l<00;o2002o`H00_l600;o0`02o`030?oo00D00_l600;o
1002o`<00olH00;o3002oa/00_l@00?o1`02o`<00_l400;o0P03o`800_l200;o1P02o`L00ol200?o
1P02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900;o1P02o`/00ol200;o1007o`D00_l600;o
400001<00_l:00;o1002o`H00_l600;o2P02oaD00_l20003o`3o00800_l400Ko3002o``00_l@00;o
1P02o`800ol00`3oo`0500;o3007oaT00_l<00;o6`02o`/01ol800?o2002o`8000?o0?l00P02o`X0
0_l700Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500?o1P07o`<00_l400Oo
1@02oaP0000C00;o2`07o`H00_l600;o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002oa00
0_l600;o0P02o`800_l500;o3009oaL00_l<00;o6`02o`T01ol;00?o1`02o`040?oo00;o00<0ool0
2P02o`L01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`T02Ol500Oo1@02oa00
0_lH00005002o`X01_l700;o1P02o`T00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o
0`02o`L00_l@00;o1P02o`030?oo00<00_l500;o3002o`D00olF00;o1`02o`<00_l300;o5P02o`P0
0ol<00;o0`02o`L00_l00`3oo`020004o`3oo`X00_l700;o00@0oooo2002o`L00_lC00;o0`02oa@0
0_l00`3oo`02o`030?oo00D00_l200;o2@08o`D00ol:00;o4002oaP0000D00;o2@02o`@00_l600;o
1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o4002o`H0
1Ol300;o1@02o``00_l600;o5P02o`L00_l300;o0`02oaH00_l800;o1`000ol0000300;o0`03o`H0
0_l00`3o00020004o`3oo`X00_l700;o0P03o`L00_l700;o5002o`040?oooa<00_l300;o0`02o`@0
0_l200;o0P02o`D00_l400?o1002o`L000Co00000_l800;o1P02oaP0000D00?o1`02o`H00_l500;o
1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`D00_l<00;o
1P02oaH00_l700;o0`02o`<00_lF00;o2002o`H00_l500;o1003o`D01?l300Co2P02o`L00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l500;o1@02o`@00_l600;o1002o`H0
0ol600;o600001D00_l700;o1P02o`H00_l400;o2@02oaL01?l400?o1002o`H00_l300;o0`02o`<0
0_l700;o4002o`H01?l400;o1@02o``00_l500?o5P02o`L00_l300;o0`02oaH00_l800?o1003o`D0
0_l500;o1@04o`@00ol:00;o1`02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o1@02o`@0
0ol400?o1003o`@00ol400Co1P02oaP0000F00;o1P03o`@00ol600?o0P03o`P00_lG00Co1@04o`03
0?oo00[o0`0<o`<02_l700[o0P04o`801_l00`3oo`06o`L02olC00[o0`0<oa802_l500Wo1@0:o`<0
1?l500Co100:o`801Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o0`0:o`H02Ol500[o0`08oaD0
000G0003o`0000D02?l800Ko2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l700[o0P03o`<0
1_l00`3oo`06o`L02OlE00[o0`0<oa802_l700Go00<0o`00100:o`<01?l500Co100:o`801Ol300Go
0P08oaD01olD00Ko0P06o`030?oo00[o0`09o`T01Ol00`3o000600Go00<0ool00`08oaD0000P00Ko
2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(81\\) MFTIJNLR IT ISZLJKE A WEBSGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00ol700[o0`0=o`<0
1_l700Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l300[o1@02o`030?oo00?o2@06o`D0
3Ol@00004`02o`X02?l700Wo2P02oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`80
3Ol200Go1@04oa002_l500So500:o`@02_l500[o0`0=o`030?oo00Oo1P05o`D00ol00`3oo`0:oa00
1_l300Ko4@02o`@00_l400co0`0;o`@02_l500[o0`0=oa00000C00;o2@03o`@00ol:00;o3@02oaD0
0_l700;o1002oa000_l<00;o2003o`@00ol600;o1004o`D00_l600;o1002o`D00olF00;o3002oa/0
0_l800?o1@03o`D00_l500;o1P02o`H00_l0103oool400?o1`02o`D00ol400;o1P02oa800_l700;o
4P03o`@00ol500;o1P02o`D00_l500?o0`03o`D00ol300Co1@02o`H00_l600;o400001<00_l900;o
1P02o`X00_l=00;o5@02o`L00_l400;o4002o``00_l800;o1P02o`H00_l400Co1@02o`H00_l400;o
1@02oaL00_l<00;o6`02o`P00_l700;o1@03o`@00_l600;o1P02o`030?oo00H00_l700;o1@02o`D0
0_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`<00_l700;o1P02o`H0
0_l@00004`02o`T00_l600;o2P02o`d00_lE00;o0`02o`800_l400;o0P02o``00_l<00;o2002o`H0
0_l600;o0`05o`D00_l600;o1002o`@00_lH00;o3002oa/00_l800;o1`02o`H00ol300;o1P02o`H0
0_l00`3oo`0600;o1`02o`@00_l600;o0P02o`800_lB00_o4P04o`801?l500;o0P02o`800_l500;o
1P02o`<00_l700;o0P03o`L00_l600;o1P02oa00000C00;o2@02o`H00_l:00;o3@02oaD00_l200?o
0P02o`@00_l200;o3002o``00_l800;o1P02o`H00_l300;o00<0ool01@02o`H00_l400;o0`03oaP0
0_l<00;o6`02oa000ol700;o0`02o`H00_l600;o00<0ool01P02o`L00ol200?o1P02o`800_lG00Wo
4`02o`040?l000Co1@02o`800_l900;o1P02o`/00ol200;o1007o`D00_l600;o400001<00_l:00;o
1002o`/00_l=00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002oa000_l600;o0P03o`030?oo00D0
0_l<00Oo6@02o``00_lK00;o2`07o`P00ol:00;o4@02o`L01ol700Ko5`02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@03o`H01ol300;o1007o`D00_lH00004`02o`/01ol;00;o3@02oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002oa000_l600;o0P02o`800_l500;o3009oaL00_l<00;o6`02o`T0
1ol;00?o2@02oa400_l700Go2@06oaP00_l300;o5002o`030?oo00;o00<0ool01@06o`T02Ol500Oo
1@02oa000_lH00005002o`X01_l<00;o3002oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1`02oa000_l600;o00<0ool00`02o`D00_l<00;o1@03oaH00_l700;o0`02o`<00_lF00;o
2003o``00_l300;o2@02oa400_l700;o00@0oooo2002o`800_lH00;o0`02oa@00_l00`3oo`02o`03
0?oo00D00_l200;o2@08o`D00ol:00;o4002oaP0000D00;o2@02o`@00_l;00;o3002oaH00_l00`3o
00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l@00;o1P05o`<00_l500;o3002o`H0
0_lF00;o1`02o`<00_l300;o5P02o`P00_l70003o`0000<00_l300?o2002oa400_l700;o0P03o`L0
0_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o1003o`@00_l70004
o`0000;o2002o`H00_lH00005003o`L00_l600;o2P02o``00_lF00Co0`04o`@00_l600;o0`02o`<0
0_l300;o1`02oa000_l600Co1002o`D00_l<00;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`H0
0_l500;o1003o`L00_lA00;o1`02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o
1P02o`D00_l500;o1002o`H00_l400;o1P03o`H00_lH00005@02o`L00_l600;o2P02o`/00_lG00Co
1003o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`D00_l<00;o1@03oaH00_l700;o
0`02o`<00_lF00;o2003o`@00ol500;o1@02o`L00_lA00;o1`02o`@00ol500;o1P02oaD01OlD00;o
2002o`@00_l600;o1@02o`@00ol400?o1003o`@00ol400Co1P02oaP0000F00;o1P03o`@00ol600?o
00<0ool02P02oaL01?l500Co00<0ool02_l300co0`0:o`L02_l200Co0P06o`030?oo00Ko1`0;oa<0
2_l300co4P0:o`D02Ol500[o0`08o`T02_l200Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool0
2_l300[o1P09o`D02_l300So5@0001L000?o00001@08o`L01_l:0003o`0001H01?l500Co00<0ool0
2_l300co0`0:o`L02_l200?o0`06o`030?oo00Ko1`09oaD02_l300co4P0:o`L01Ol00`3o000400[o
0`08o`T02_l200Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l300Wo2@05o`030?l000H0
1Ol00`3oo`0300So5@0002001_l;00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(82\\) MFTIJNLR IT ISZLIKE A WEBSGL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00ol700[o0`0=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l300[o1@02o`030?oo00?o2@06o`D0
3Ol@00004`02o`X02?l600[o2P02oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`80
3Ol200Go1@04oa002_l500So500:o`@02_l500[o0`0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l300_o100:o`D02_l300go400001<00_l900?o1003o`H00_l500;o2P02oaD0
0_l700;o1002oa000_l<00;o2003o`@00ol600;o1004o`D00_l600;o1002o`D00olF00;o3002oa/0
0_l800?o1@03o`D00_l500;o1P02o`H00_l600;o2P02o`D00ol400;o1P02oa800_l700;o4P03o`@0
0ol500;o1P02o`D00_l500?o0`03o`D00ol300Co1@02o`H00_l600;o400001<00_l900;o1P02o`L0
0ol?00;o5@02o`L00_l400;o4002o``00_l800;o1P02o`H00_l400Co1@02o`H00_l400;o1@02oaL0
0_l<00;o6`02o`P00_l700;o1@03o`@00_l600;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L0
0_lB00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`<00_l700;o1P02o`H00_l@00004`02o`T0
0_l600;o2003o`h00_lE00;o0`02o`800_l400;o0P02o``00_l<00;o2002o`H00_l600;o0`05o`D0
0_l600;o1002o`@00_lH00;o3002oa/00_l800;o1`02o`H00ol300;o1P02o`H00_l600;o2P02o`@0
0_l600;o0P02o`800_lB00_o4P04o`801?l500;o0P02o`800_l500;o1P02o`<00_l700;o0P03o`L0
0_l600;o1P02oa00000C00;o2@02o`H00_l900?o3@02oaD00_l200?o0P02o`@00_l200;o3002o``0
0_l800;o1P02o`H00_l300;o00<0ool01@02o`H00_l400;o0`03oaP00_l<00;o6`02oa000ol700;o
0`02o`H00_l600;o1P02o`X00ol200?o1P02o`800_lG00Wo4`02o`040?l000Co1@02o`800_l900;o
1P02o`/00ol200;o1007o`D00_l600;o400001<00_l:00;o1002o`/00ol<00;o5@02o`8000?o0?l0
0P02o`@01_l<00;o3002oa000_l600;o0P03o`030?oo00D00_l<00Oo6@02o``00_lK00;o2`07o`P0
0ol:00;o3P02o`X01ol700Ko5`02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@03o`H01ol300;o
1007o`D00_lH00004`02o`/01ol<00?o2`02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002oa00
0_l600;o0P02o`800_l500;o3009oaL00_l<00;o6`02o`T01ol;00?o2@02o`h00_l:00Go2@06oaP0
0_l300;o5002o`030?oo00;o00<0ool01@06o`T02Ol500Oo1@02oa000_lH00005002o`X01_l>00;o
2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02oa000_l600;o00<0ool0
0`02o`D00_l<00;o1@03oaH00_l700;o0`02o`<00_lF00;o2003o``00_l300;o2@02o`h00_l:00;o
00@0oooo2002o`800_lH00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2@08o`D00ol:00;o
4002oaP0000D00;o2@02o`@00_l>00;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<0
0_l300;o0`02o`L00_l@00;o1P05o`<00_l500;o3002o`H00_lF00;o1`02o`<00_l300;o5P02o`P0
0_l70003o`0000<00_l300?o2002o`h00_l:00;o0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l500;o1003o`@00_l70004o`0000;o2002o`H00_lH00005003o`L0
0_l600;o3@02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`D0
0_l<00;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`H00_l500;o1003o`L00_l>00;o2P02o`<0
0ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`D00_l500;o1002o`H00_l400;o
1P03o`H00_lH00005@02o`L00_l600;o1P02o`D00_l800;o5`04o`@00ol400;o1P02o`<00_l300;o
0`02o`L00_l@00;o1P04o`@00_l500;o3002o`D00olF00;o1`02o`<00_l300;o5P02o`P00ol400?o
1@02o`D00_l700;o3P02o`X00_l400?o1@02o`H00_lE00Go5002o`P00_l400;o1P02o`D00_l400?o
1003o`@00ol400?o1004o`H00_lH00005P02o`H00ol400?o1P03o`<00ol700;o5`04o`D01?l00`3o
o`0:o`<03?l300[o1`0:o`801?l200Ko00<0ool01_l700_o4`0:o`<03?lB00[o1@09o`D02_l300So
1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`<02_l600Wo1@0:o`<02?lE0000
5`000ol0000500So2007o`P000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1`0:o`800ol300Ko
00<0ool01_l700Wo5@0:o`<03?lB00[o1`05o`030?l000@02_l300So1`0:o`@01Ol300Go00<0ool0
2_lB00Oo5006o`801_l00`3oo`0:o`<02Ol900Go00<0o`001P05o`030?oo00<02?lE00008006o`X0
1Ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(83\\) MFTIJNLR IT ISZLIJE A WEBSFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00ol700[o0`0=o`80
2_l600Ko1P0<oa001_l300Ko4@02o`@00_l400co0`0:o`D00_l00`3oo`03o`D01ol800go400001<0
0_l:00So1P09o`/00_lD00Go0`05o`030?oo00Go2P08o`D02_l400Wo1P06o`800ol200go0P05o`D0
1?l@00[o1@08oa@02_l400[o1@0:o`<03Ol200[o1009o`D03?l@00Ko0`06oa400_l400;o100<o`<0
2ol400[o0`07o`P03Ol@00004`02o`T00ol400?o1@02o`D00_l;00;o5@02o`L00_l400;o4002o``0
0_l800?o1003o`H00_l400Co1@02o`H00_l400;o1@03oaH00_l<00;o6`02o`P00ol500?o1@02o`D0
0_l600;o1P02o`H00_l800?o1003o`H00_l600;o4P02o`L00_lB00?o1003o`D00_l600;o1@02o`D0
0ol300?o1@03o`@00_l>00;o1P02oa00000C00;o2@02o`H00_l=00;o2P02oaD00_l700;o1002oa00
0_l<00;o2002o`H00_l600;o1004o`D00_l600;o1002o`D00_lG00;o3002oa/00_l800;o1`02o`D0
0ol400;o1P02o`H00_l600;o2002o`H00_l600;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`D0
0_l600;o0`02o`L00_l400;o3P02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lE00;o0`02o`80
0_l400;o0P02o``00_l<00;o2002o`H00_l600;o0`05o`D00_l600;o1002o`@00_lH00;o3002oa/0
0_l800;o1`02o`H00ol300;o1P02o`H00_l600;o2002o`H00_l600;o0P02o`800_lB00_o4P04o`80
1?l500;o0P02o`800_l500;o1P02o`<00_l700;o1002o`800_l:00;o1P02oa00000C00;o2@02o`H0
0_l=00;o2P02oaD00_l200?o0P02o`@00_l200;o3002o``00_l800;o1P02o`H00_l300;o00<0ool0
1@02o`H00_l400;o0`03oaP00_l<00;o6`02oa000ol700;o0`02o`H00_l600;o1P02o`P00_l600;o
1P02o`800_lG00Wo4`02o`040?l000Co1@02o`800_l900;o1P02o`/00ol400;o0P02o`X00_l600;o
400001<00_l:00;o1002o`d00_l;00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002oa000_l600;o
0P03o`030?oo00D00_l<00Oo6@02o``00_lK00;o2`07o`P00ol:00;o3P02oa000_l600Ko5`02o`D0
0_lC00;o00H0o`00o`02o`D01_l900;o1@03o`H01ol500Ko2P02oaP0000C00;o2`07o`X01?l<00;o
5@02o`040?oo00;o00<0ool01006o``00_l<00;o4002o`H00_l200;o0P02o`D00_l<00Wo5`02o``0
0_lK00;o2@07o`/00ol900;o3P02oa000_l600Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko
2@09o`D01ol700Ko2P02oaP0000D00;o2P06o`/00ol<00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l700;o4002o`H00_l00`3oo`0300;o1@02o``00_l500?o5P02o`L00_l300;o
0`02oaH00_l800?o3002o`<00_l900;o3P02oa000_l600;o0P02oaP00_l300;o5002o`030?oo00;o
00<0ool01@02o`800_l900So1@03o``00_l200;o2P02oaP0000D00;o2@02o`@00_l<00;o2`02oaH0
0_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l@00;o1P05o`<00_l500;o
3002o`H00_lF00;o1`02o`<00_l300;o5P02o`P00_l70003o`0000<00_l300?o2002o`h00_l@00;o
1P02o`800_l200;o5@02o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`D00_l400?o1002o`L0
00?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l<00;o2P02oaH01?l300Co1002o`H0
0_l300;o0`02o`<00_l700;o4002o`H01?l400;o1@02o``00_l600;o5P02o`L00_l300;o0`02oaH0
0_l800;o1P02o`D00_l400?o1`02o`h00_l@00;o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o
1002o`H00_l500;o1@02o`@00_l600;o1@02o`H00_l600;o600001D00_l700;o1P02o``00_l900;o
5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l@00;o1P04o`@00_l500;o3002o`D00olF00;o
1`02o`<00_l300;o5P02o`P00ol400?o1@02o`D00_l700;o3P02oa000_l600;o1P02oaD01OlD00;o
2002o`@00_l600;o1@02o`@00ol400?o1003o`D00_l600;o1P02oaP0000F00;o1P03o`@00ol600;o
0`03o`P00_lG00Co1@04o`030?oo00[o0`0<o`<02_l700[o0P04o`801_l00`3oo`06o`L02olC00[o
0`0<oa802_l500Wo1@0:o`<02?l700[o1`0:o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l300[o
1P09o`<03?l300So5@0001L000?o00001@08o`L01ol90003o`0001H01?l500Co00<0ool02_l300co
0`0:o`L02_l200?o0`06o`030?oo00Ko1`09oaD02_l300co4P0:o`L01Ol00`3o000400[o0`08o`L0
2_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`<02Ol900Go00<0o`000P0<o`<02?lE0000
8006o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(84\\) MFTIJNLR IT IS LIJE A WEBSFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co3006o`T00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00olD00go0P0:o`H0
1_l600co4006o`<01_lA00;o1002o`@03?l300[o1@02o`030?oo00?o1@07o`P03Ol@00004`02o`X0
2?l:00Ko2P02oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`803Ol200Go1@04oa00
2_l500So500:o`@02_lB00go0P0:o`@02Ol500co4006o`<01_lA00;o1002o`@03?l300_o100:o`<0
1ol800go400001<00_l900?o1003o`/00_l<00;o5@02o`L00_l400;o4002o``00_l800?o1003o`H0
0_l400Co1@02o`H00_l400;o1@03oaH00_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2003o`@0
0ol600;o1P02oa800_l700;o4P03o`@00ol500;o1P02o`D00_l500?o0`03o`D00ol400;o3P02o`H0
0_l@00004`02o`T00_l600;o2`02o``00_lE00;o1`02o`@00_l@00;o3002o`P00_l600;o1P02o`@0
1?l500;o1P02o`@00_l500;o5`02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l800;o1P02o`H0
0_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`@00_l>00;o1P02oa00
000C00;o2@02o`H00_l500[o2P02oaD00_l300;o0P02o`@00_l200;o3002o``00_l800;o1P02o`H0
0_l300Go1@02o`H00_l400;o1002oaP00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2002o`H0
0_l600;o0P02o`800_lB00_o4P04o`801?l500;o0P02o`800_l500;o1P02o`<00_l700;o1002o`80
0_l:00;o1P02oa00000C00;o2@02o`H00_l500[o2P02oaD00_l200?o0P02o`@00_l200;o3002o``0
0_l800;o1P02o`H00_l300;o00<0ool01@02o`H00_l400;o0`03oaP00_l<00;o6`02oa000olD00;o
1P02o`H00_l800;o1P02o`H00_l200;o5`09oa<00_l0103o0004o`D00_l200;o2@02o`H00_l;00?o
1002o`800_l:00;o1P02oa00000C00;o2P02o`@00_l600;o1002o``00_lE00;o0P000ol0o`0200;o
1006o``00_l<00;o4002o`H00_l200?o00<0ool01@02o``01olI00;o3002oa/00_l;00Oo5@02o`h0
0_l@00;o1P06oaL00_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00ol600Oo1@06o`X00_lH0000
4`02o`/01ol700;o0`02o``00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``00_l@00;o1P02o`80
0_l200;o1@02o``02OlG00;o3002oa/00_l900Oo5`02o`h00_l@00;o1P06oaP00_l300;o5002o`03
0?oo00;o00<0ool01@06o`T02Ol500Oo1`06o`X00_lH00005002o`X01_l90004o`0000;o2`02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02oa000_l600;o00<0ool00`02o`D0
0_l<00;o1@03oaH00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o4002o`H00_l200;o6002o`<0
0_lD00;o00<0ool00_l00`3oo`0500;o0P02o`T02?l500?o3002o`800_l:00;o600001@00_l900;o
1002o`P00_l200;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L0
0_l@00;o1P05o`<00_l500;o3002o`H00_lF00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<0
0_l>00;o4002o`H00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o
1003o`@00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`L00_l600;o20000ol00002o`/0
0_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`D00_l<00;o1P02oaH0
0_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02oa000_l600;o1P02oaD00_l00`3oo`0D00;o
0`02o`<00_l400;o1P02o`D00_l500;o1002o`H00_l500;o1P02o`H00_lH00005@02o`L00_l600;o
2@001?l0ool:00;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l@00;o1P04o`@00_l500;o
3002o`D00olF00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l@00;o1P02o`H00_lE00Go
5002o`P00_l400;o1P02o`D00_l400?o1003o`@00ol500;o1P02o`H00_lH00005P02o`H00ol400?o
2@04o`T00_lG00Co1@04o`030?oo00[o0`0<o`<02_l700[o0P04o`801_l00`3oo`06o`L02olC00[o
0`0<oa802_l500Wo4P08o`L02_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`<02_l600Wo
0`0<o`<02?lE00005`000ol0000500So2`03o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o
1`0:o`800ol300Ko00<0ool01_l700Wo5@0:o`<03?lB00[o1`05o`030?l001402?l700[o1`0:o`03
0?oo00[o4P07oa@01_l200Ko00<0ool02_l300Wo2@05o`030?l000803?l300So5@0002001_l<00?o
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(85\\) MFTIJNLR IT IS LIJE A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200go0P05o`H00ol@00[o1@08oa@02_l400;o00<0ool00olD00go0P0:o`H0
1_l600co4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`X0
2?l600Wo2`02oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`803Ol200Go1@04oa00
2_l500So500:o`@02_lB00go0P0:o`@02Ol500co4006o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`T00ol400?o1@02o`D00_l;00;o5@02o`L00_l400;o4002o``0
0_l800?o1003o`H00_l400Co1@02o`H00_l400;o1@03oaH00_l<00;o6`02o`P00ol500?o5002o`H0
0_l600;o2003o`@00ol600;o1P02oa800_l700;o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D0
0ol400;o3P02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lE00;o1`02o`@00_l@00;o3002o`P0
0_l600;o1P02o`@01?l500;o1P02o`@00_l500;o5`02o``00_lK00;o2002o`L00_lD00;o1P02o`H0
0_l800;o1P02o`H00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@0
0_l>00;o1P02oa00000C00;o2@02o`H00_l=00;o2P02oaD00_l300;o0P02o`@00_l200;o3002o``0
0_l800;o1P02o`H00_l300Go1@02o`H00_l400;o1002oaP00_l<00;o6`02o`P00_l700;o5002o`H0
0_l600;o2002o`H00_l600;o0P02o`800_lB00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L0
0_l400;o0P02o`X00_l600;o400001<00_l900;o1P02o`d00_l:00;o5@02o`800ol200;o1002o`80
0_l<00;o3002o`P00_l600;o1P02o`<00_l00`3oo`0500;o1P02o`@00_l300?o6002o``00_lK00;o
4003oa@00_l600;o1P02o`P00_l600;o1P02o`800_lG00Wo4`02o`040?l000Co1@02o`800_l900Wo
3003o`@00_l200;o2P02o`H00_l@00004`02o`X00_l400;o3P02o`X00_lE00;o0P000ol0o`0200;o
1006o``00_l<00;o4002o`H00_l200?o00<0ool01@02o``01olI00;o3002oa/00_l;00Oo5@02o`h0
0_l@00;o1P06oaL00_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH0000
4`02o`/01ol700;o1002o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``00_l@00;o1P02o`80
0_l200;o1@02o``02OlG00;o3002oa/00_l900Oo5`02o`h00_l@00;o1P06oaP00_l300;o5002o`03
0?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:00Ko2008o`X00_lF00;o
00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l@00;o1P02o`030?oo00<00_l500;o
3002o`D00olF00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02oa000_l600;o0P02oaP00_l300;o
5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T0
0_l400;o1`07o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o
4002o`H01Ol300;o1@02o``00_l600;o5P02o`L00_l300;o0`02oaH00_l800;o1`000ol0000C00;o
3P02oa000_l600;o0P02o`800_lE00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`04
0?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`L00_l600;o1P02oa000_lF00Co
0`04o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`D00_l<00;o1P02oaH00_l700;o
0`02o`<00_lF00;o2002o`H00_lE00;o3P02oa000_l600;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o1`02o`H00_l600;o
3`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o4002o`H01?l400;o1@02o``00_l500?o
5P02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o4002o`H00_l600;o5@05oa@00_l800;o
1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`H00ol400?o1P02o`h00_lG00Co
1@04o`030?oo00[o0`0<o`<02_l700[o0P04o`801_l00`3oo`06o`L02olC00[o0`0<oa802_l500Wo
4P08o`L02_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE0000
5`000ol0000500So1`08o`P000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1`0:o`800ol300Ko
00<0ool01_l700Wo5@0:o`<03?lB00[o1`05o`030?l001402?l700[o1`0:o`030?oo00[o4P07oa@0
1_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002001_l800Soo`340000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(86\\) MFTIJNKR IT IS LIJE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l600Ko1P0<oa001_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D03?l300go400001<0
0_l:00So2007o`/00_lD00Go0`05o`030?oo00Go2P08o`D02_l400Wo1P06o`800ol200Go1@03o`80
1Ol500Co400:o`D02?lD00[o100:oa803Ol200[o1009o`D03?l@00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@03o`@00ol600;o1002o`/00_lE00;o1`02o`@0
0_l@00;o3002o`P00ol400?o1P02o`@01?l400;o1@03o`D00_l500?o5P02o``00_lK00;o2003o`D0
0olD00;o1P02o`H00_l800?o1003o`H00_l600;o4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1@02o`H00_l:00;o5@02o`L0
0_l400;o4002o``00_l800;o1P02o`H00_l400Co1002o`D00_l600;o1@02oaL00_l<00;o6`02o`P0
0_l700;o5002o`H00_l600;o2002o`H00_l600;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaD0
0_l300;o0P02o`@00_l200;o3002o``00_l800;o1P02o`H00_l300Go1002o`@00_l700;o1002oaP0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2002o`H00_l600;o0P02o`800_lB00_o4P04o`80
1?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o2@02o`H0
0_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o2002o`H00_l600;o0`02o`03
0?oo00@00ol200?o1`02o`<00olH00;o3002oa/00_l@00?o5002o`H00_l600;o2002o`H00_l600;o
0P02oaL02OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o
2P02o`@00_l600;o1P02o`X00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o4002o`H00_l200?o
00<0ool01007o`P01olI00;o3002oa/00_l;00Oo5@02o`h00_l@00;o1P06oaL00_l500;o4`02o`06
0?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/01ol600?o1002o`/00_lE00;o
00@0ool00_l00`3oo`0400Ko3002o``00_l@00;o1P02o`800_l200;o1005o`X02OlG00;o3002oa/0
0_l900Oo5`02o`h00_l@00;o1P06oaP00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o
1P07o`L01_l:00;o600001@00_l:00Ko1`09o`X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L0
0_l300;o0`02o`L00_l@00;o1P02o`030?oo00<00_l400;o00@0oooo2@02o`D00olF00;o1`02o`<0
0_l300;o5P02o`P00olL00;o3P02oa000_l600;o0P02oaP00_l300;o5002o`030?oo00;o00<0ool0
1@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T00_l400;o1P02o`030?oo00;o
3002oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l@00;o1P05o`<0
0_l400;o0P03o`P00_l600;o5P02o`L00_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02oa00
0_l600;o0P02o`800_lE00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D0
0_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`L00_l600;o1P02oa000_lF00Co0`04o`@0
0_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`@00_l300?o1`02o`H00_lF00;o1`02o`<0
0_l300;o5P02o`P00_l600;o5@02o`h00_l@00;o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o
1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l600;o1P03o`h0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`@00_l400?o1P02o`D0
0olF00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l@00;o1P02o`H00_lE00Go5002o`P0
0_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o1P03o`@00ol700?o3002oaL0
1?l500Co00<0ool02_l300co0`0:o`L02_l200Co0P06o`030?oo00?o0`05o`802olC00[o0`0<oa80
2_l500Wo4P08o`L02_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<0
2?lE00005`000ol0000500So2@07o`L000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1`0:o`80
0ol300Ko00<0ool00ol300Go0P09oaD02_l300co4P0:o`L01Ol00`3o000A00So1`0:o`L02_l00`3o
o`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000P00Ko3005ool0
``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(87\\) MFTIJNKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`02o`h00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l600Ko1`06o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`X02?l900;o3`02oa@01Ol300Go00<0ool01Ol:00So1@0:o`@02Ol600Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o2@02o`h0
0_lE00;o1`02o`@00_l@00;o3002o`P00ol400?o1P02o`@01?l400;o1@03o`D00_l500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o2@02o`h0
0_lE00;o1`02o`@00_l@00;o3002o`P00_l600;o1P02o`@01?l400;o1@02o`H00_l500;o5`02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o2@02o`h0
0_lE00;o0`02o`800_l400;o0P02o``00_l<00;o2002o`H00_l600;o0`05o`@00_l400;o1`02o`@0
0_lH00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T0
0_l600;o2P000ol0000<00;o5@02o`800ol200;o1002o`800_l<00;o3002o`P00_l600;o1P02o`<0
0_l00`3oo`0400?o0P03o`L00_l300?o6002o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o
1P02o`800_lG00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@0000
4`02o`X00_l400;o2`02o`d00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o4002o`H00_l200?o
00<0ool01007o`P01olI00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`06oaL00_l500;o4`02o`06
0?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/01ol;00;o3@02oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002oa000_l600;o0P02o`800_l400Go2P09oaL00_l<00;o6`02o`T0
1olG00;o3P02o`X01Ol900Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo
1`06o`X00_lH00005002o`X01_l=0003o`0000X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L0
0_l300;o0`02o`L00_l@00;o1P02o`030?oo00<00_l400;o00@0oooo2@02o`D00olF00;o1`02o`<0
0_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o0P02oaP00_l300;o5002o`030?oo00;o
00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T00_l400;o3002o`/0
0_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o4002o`H01Ol300;o
1002o`800ol800;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o
0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l;00;o2`02oaH01?l300Co
1002o`H00_l300;o0`02o`<00_l700;o4002o`H01?l400;o1002o`<00ol700;o1P02oaH00_l700;o
0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<0
0_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l600;o
30000ol0000800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l@00;o1P04o`@00_l400;o
1003o`H00_l500?o5P02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o
1P02oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600?o
1003o`D00_l500;o2002oaL01?l500Co00<0ool02_l300co0`0:o`L02_l200Co0P06o`030?oo00?o
0`05o`802olC00[o0`0<oa802_l500Wo4P08o`L02_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko
00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00001@08o`H02Ol80003o`0001H01?l500Co
00<0ool02_l300co0`0:o`L02_l200?o0`06o`030?oo00?o0`05o`802OlE00[o0`0<oa802_l700Go
00<0o`004@08o`L02_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0002001_l700Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(88\\) MFTIINKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l500[o1006o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`X02?l700So2`02oa@01Ol300Go00<0ool01Ol:00So1@0:o`D02_l400Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o1@03o`@0
0ol:00;o5@02o`L00_l400;o4002o``00_l=00;o2@02o`@01?l400;o1@03o`D00_l500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1@02o`H0
0_l:00;o5@02o`L00_l400;o4002o``00_l=00;o2@02o`@01?l400;o1@02o`H00_l500;o5`02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1@02o`H0
0_l:00;o5@02o`<00_l200;o1002o`800_l<00;o3002o`d00_l900;o0`05o`@00_l400;o1`02o`@0
0_lH00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T0
0_l600;o1@02o`H00_l:00;o5@02o`800ol200;o1002o`800_l<00;o3002o`d00_l900;o0`02o`03
0?oo00@00ol200?o1`02o`<00olH00;o3002oa/00_l@00?o5002o`H00_l600;o2P03o`800ol600;o
0P02oaL02OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o
2P02o`@00_l700;o1002o`/00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o
00<0ool01007o`P01olI00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`06oaL00_l500;o4`02o`06
0?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/01ol800Oo2`02oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002o`d00_l900;o0P02o`800_l400Go2P09oaL00_l<00;o6`02o`T0
1olG00;o3P02o`X01Ol900Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo
1`06o`X00_lH00005002o`X01_l900Ko2`02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1`02o`d00_l900;o00<0ool00`02o`@00_l0103oool900;o1@03oaH00_l700;o0`02o`<0
0_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l200;o6002o`<00_lD00;o00<0ool00_l00`3o
o`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2@02o`@00_l700;o1002o`X0
0_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o
1002o`800ol800;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o
0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l500;o1P02o`T00_lF00Co
0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l300?o1`02o`H00_lF00;o
1`02o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@0
0_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l700;o
1P02o`D00_l600;o2002oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T01?l400;o
1002o`@00ol600;o1@03oaH00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o
1@02o`H00_lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o
1P03o`@00ol500?o1003o`L00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`801_l00`3o
o`03o`<01Ol200_o4`0:o`<03?lB00[o1@09oa802?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko
0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000D02?l700So20000ol0000F00Co
1@04o`030?oo00[o0`0<o`<02_l500[o1003o`<01_l00`3oo`03o`<01Ol200Wo5@0:o`<03?lB00[o
1`05o`030?l001402?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`X0
1Ol00`3o000200co0`08oaD0000P00Ko2@06ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(89\\) MFTIINKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lE00Go0`05o`030?oo00Go2P08o`D0
2_l500[o1006o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`X02?l600Oo3@02oa@01Ol300Go00<0ool01Ol:00So1@0:o`D02_l400Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o2P03o``0
0_lE00;o1`02o`@00_l@00;o3002o`d00_l900;o1004o`@00_l500?o1@02o`D00olF00;o3002oa/0
0_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`H00_lB00;o1`02oa800ol400?o1@02o`H0
0_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l;00?o2`02oaD0
0_l700;o1002oa000_l<00;o3@02o`T00_l400Co1002o`D00_l600;o1@02oaL00_l<00;o6`02o`P0
0_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o``00_l;00;o5@02o`<0
0_l200;o1002o`800_l<00;o3002o`d00_l900;o0`05o`@00_l400;o1`02o`@00_lH00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa801?l200Co1@02o`80
0_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T00_l600;o2004o`03
0?oo00X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`T00_l300;o00<0ool01003o`80
0ol700;o0`03oaP00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l200;o5`09oa<0
0_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l:00;o1002o`L0
2Ol:00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002o`d00_l900;o0P03o`030?oo00@01ol800Oo
6@02o``00_lK00;o2`07oaD00_l>00;o2P07o`L01_lG00;o1@02oa<00_l01P3o003o00;o1@06o`T0
0_l500;o1`07o`D01_l:00;o600001<00_l;00Oo1`02o`@00ol:00;o5@02o`040?oo00;o00<0ool0
1006o``00_l<00;o3@02o`T00_l200;o0P02o`@01Ol:00Wo5`02o``00_lK00;o2@07oaL00_l>00;o
2P05o`T01_lH00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0
000D00;o2P06o`L00_l600;o2@02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o
1`02o`d00_l900;o00<0ool00`02o`@00_l0103oool900;o1@03oaH00_l700;o0`02o`<00_lF00;o
2003oa`00_l>00;o2P02o`040?ooo`P00_l200;o6002o`<00_lD00;o00<0ool00_l00`3oo`0500;o
0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2@02o`@00_l600;o1P02o`T00_lF00;o
00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1002o`80
0ol800;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o0P03o`L0
0_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L0
00?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l500;o1P02o`T00_lF00Co0`04o`@0
0_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l300?o1`02o`H00_lF00;o1`02o`<0
0_l300;o5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o
0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l700;o1P02o`D0
0_l60003o`0000L00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@0
0_l400?o1P02o`D00olF00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D0
0_l600;o5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`H0
0ol400?o1P02o`@00_l800;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@01?l200Ko00<0ool0
0ol300Go0P0;oa<02_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`80
1_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So1`07o`T000?o00005P04o`D0
1?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go0P09oaD02_l300co4P0:o`L0
1Ol00`3o000A00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go
00<0o`000P0<o`<02?lE00008006o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(90\\) METIINKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`T01ol:00Ko3002oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l400Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`h00ol800?o0P03o`/0
0_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`D00_l500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`l00ol700;o1002o`/0
0_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`H00_l500;o5`02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa000_l600;o1P02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1`02o`@0
0_lH00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o``0
1?l00`3oo`0500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`T00_l300;o
00<0ool01003o`800ol700;o0`03oaP00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H0
0_l200;o5`09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<0
0_l:00Wo1@02o`H00_l:00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002o`d00_l900;o0P03o`03
0?oo00@01ol800Oo6@02o``00_lK00;o2`07oaD00_l>00;o2P07o`L01_lG00;o1@02oa<00_l01P3o
003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o600001<00_l:00;o1003o`D00_l600;o2P02oaD0
0_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l900;o0P02o`800_l400Go2P09oaL00_l<00;o
6`02o`T01olG00;o3P02o`X01Ol900Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<0
0_l600Oo1`06o`X00_lH00005002o`P00_l600;o1@02o`H00_l900;o5P02o`030?oo008000Co0?oo
1002o`800_l700;o0`02o`<00_l700;o3@02o`T00_l00`3oo`0300;o1002o`040?ooo`T00_l500?o
5P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`800_lH00;o0`02oa@0
0_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l800;o
1P02o`D00_l600;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L0
0_l=00;o2@05o`<00_l400;o0P03o`P00_l600;o5P02o`L00_l300;o0`02oaH00_l800;o1`000ol0
000C00;o3P02o`X00_l200?o1`02o`800_l200;o5@02o`040?oooa<00_l300;o0`02o`@00_l200;o
0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol700;o1P02o`D0
0_l600;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o3@02o`T01?l400;o1002o`<0
0ol700;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H0
0_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H0
0_lH00005@02o`L00_l60003o`0000D00_l400;o2@02oaL01?l400?o1002o`H00_l300;o0`02o`<0
0_l700;o3@02o`T01?l400;o1002o`@00ol600;o1@03oaH00_l700;o0`02o`<00_lF00;o2003o`@0
0olE00;o3P02o`X00_l400?o1@02o`H00_lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D0
0_l600;o1P02oaP0000F00;o1`02o`@00_l700?o0P03o`P00_lG00Co1@04o`030?oo00[o0`0<o`<0
2_l500[o1004o`801_l00`3oo`03o`<01Ol200_o4`0:o`<03?lB00[o1@09oa802?l700[o1005o`<0
1Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000D0
1ol900Ko2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o1003o`<01_l00`3oo`03o`<0
1Ol200Wo5@0:o`<03?lB00[o1`05o`030?l001402?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko
0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000Q00Co2`04ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(91\\) METIINKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2`09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`T01ol900Wo2P02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l400Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`h00ol<00;o3@02oaD0
0_l700;o1002o`H00_l800;o3002o`d00_l900;o1004o`@00_l500?o1@02o`D00olF00;o3002oa/0
0_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`H00_lB00;o1`02oa800ol400?o1@02o`H0
0_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o3`03o`/00_l=00;o5@02o`L0
0_l400;o1P02o`P00_l<00;o3@02o`T00_l400Co1002o`D00_l600;o1@02oaL00_l<00;o6`02o`P0
0_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l@00;o2`02o`d00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1`02o`@00_lH00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa801?l200Co1@02o`80
0_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o``01?l00`3oo`0:00;o
3@02oaD00_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`L0
0_l300?o6002o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o1P02o`800_lG00Wo4`02o`04
0?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`X02Ol:00;o3@02oaD0
0_l20003o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2007oaT00_l<00;o
6`02o`/01olE00;o3P02o`X01ol700Ko5`02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L0
1ol500Ko2P02oaP0000C00;o2P02o`@00ol:00;o3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o
3002o`d00_l900;o0P02o`800_l400Go2P09oaL00_l<00;o6`02o`T01olG00;o3P02o`X01Ol900Ko
6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`P0
0_l600;o2P02o``00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o
2@02o`030?oo00<00_l400;o00@0oooo2@02o`D00olF00;o1`02o`<00_l300;o5P02o`P00olL00;o
3P02o`X00_l0103oool800;o0P02oaP00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o
0`02o`D00ol<00;o0P02o`X00_lH00005002o`P00_l600;o2P02o``00_lF00;o00<0o`000P001?l0
ool400;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1002o`800ol800;o1P02oaH0
0_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o0P03o`L00_l200;o0P02oaD0
0_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`80
0_l200;o1P02oaP0000D00?o1`02o`H00_l:00;o3002oaH01?l300Co1002o`H00_l300;o0`02o`<0
0_l700;o3@02o`T01?l400;o1002o`<00ol700;o1P02oaH00_l700;o0`02o`<00_lF00;o2002o`H0
0_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o
00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l60003o`0000T00_l;00;o5`04o`@0
0ol400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@00_l400;o1003o`H00_l500?o5P02o`L0
0_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o1P02oaD01OlD00;o2002o`@0
0_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l700;o1002o`L00ol00`3oo`0:00;o
5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@01?l200Ko00<0ool00ol300Go0P0;oa<02_l300co
4P0:o`D02OlB00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol800Wo
0`0<o`<02?lE00005`000ol0000500Oo2006o`X000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o
1@0:o`@00ol300Ko00<0ool00ol300Go0P09oaD02_l300co4P0:o`L01Ol00`3o000A00So1`0:o`@0
1Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE0000
8@04o``00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(92\\) METIINKR IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2P0:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`T01ol800[o2P02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l400Ko0P03o`80
1Ol500?o0P05o`D01?l@00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`h00ol800;o1@02o`X0
0_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`D00_l500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`l00ol800?o3`02oaD0
0_l700;o1002o`H00_l800;o3002o`d00_l900;o1004o`@00_l500;o1P02o`D00_lG00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa801?l300?o1@02o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4002o`T00ol>00;o5@02o`<0
0_l200;o1002o`800_l200;o2002o``00_l=00;o2@02o`<01Ol400;o1002o`L00_l400;o6002o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l200;o0P02oa802olB00Co0P04o`D0
0_l200;o0P02o`@02ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<00_l<00Co00<0ool0
2@03o`d00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`T00_l300;o00<0ool01003o`80
0ol700;o0`03oaP00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l200;o5`09oa<0
0_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l:00Wo2P03o``0
0_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o00<0ool01007o`P01olI00;o
3002oa/00_l;00Oo5@02o`h00_l:00Oo1`06oaL00_l500;o4`02o`060?l00?l00_l500Ko2@02o`D0
0_l700Oo1@06o`X00_lH00004`02o`X00_l400?o2`03o`/00_lE00;o00@0ool00_l00`3oo`0400Ko
3002o``00_l=00;o2@02o`800_l200;o1005o`X02OlG00;o3002oa/00_l900Oo5`02o`h00_l:00Go
2@06oaP00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@0
0_l800;o1P02o``00_l:00;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o
3@02o`T00_l00`3oo`0300;o1002o`040?ooo`T00_l500?o5P02o`L00_l300;o0`02oaH00_l800?o
7002o`h00_l:00;o00@0oooo2002o`800_lH00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o
2P02o`<00_l500?o3002o`800_l:00;o600001@00_l800;o1P02o`d00_l900;o5P02o`030?l00080
00Co0?oo1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`@00_l200?o2002o`H0
0_lF00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o0P02o`80
0_lE00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<0
0_l200;o0P02o`H00_lH00005003o`L00_l600;o3@02o`T00_lF00Co0`04o`@00_l600;o0`02o`<0
0_l300;o1`02o`d00_l900Co1002o`@00_l300?o1`02o`H00_lF00;o1`02o`<00_l300;o5P02o`P0
0_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o
1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l700;o1P000ol0000500;o1@02o`P0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l400?o1P02o`D0
0olF00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l600;o5@05oa@0
0_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`L00_l400;o1`03o`<0
0ol700;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@01?l200Ko00<0ool00ol300Go0P0;oa<0
2_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@0
1ol800Wo0`0<o`<02?lE00005`000ol0000500Oo2@07o`P000?o00005P04o`D01?l00`3oo`0:o`<0
3?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go0P09oaD02_l300co4P0:o`L01Ol00`3o000A00So
1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<0
2?lE00008@04o`/01Ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(93\\) METIINKS IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3005o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o1005o`H00_l00`3oo`0:oa001_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l900Oo2009o`/00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1006o`80
0ol200Go1@03o`<02_lC00[o1@08oa@02_l400[o4P0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`h00ol700;o1@02o`/0
0_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`l00ol>00;o2P02oaD0
0_l700;o1002o`H00_l800;o3002o`d00_l900;o1004o`@00_l500;o1@02o`L00_lF00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa801?l300?o1@02o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4002o`h00_l:00;o5@02o`<0
0_l200;o1002o`800_l200;o2002o``00_l=00;o2@02o`<01Ol400;o1002o`H00_l700;o5P02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l200;o0P02oa802olB00Co0P04o`D0
0_l200;o0P02o`@02ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<00_l<00Co00<0ool0
3@02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`T00_l300;o00<0ool01003o`80
0ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o1P02o`800_lG00Wo4`02o`04
0?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`X02Ol<00;o2`02oaD0
0_l20003o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o
6`02o`/01olE00;o3P02o`X01ol700Ko5`02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L0
1ol500Ko2P02oaP0000C00;o2P02o`@00ol900Co3002oaD00_l0103oo`02o`030?oo00@01_l<00;o
3002o`d00_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T01olG00;o3P02o`X01Ol900Ko
6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`P0
0_l600;o2@03o``00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o
2@02o`030?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o
2P02o`040?ooo`P00_l200;o6002o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o
1@03o``00_l200;o2P02oaP0000D00;o2002o`H00_l;00;o2`02oaH00_l00`3o00020004o`3oo`@0
0_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o2@05o`<00_l400;o0P03o`L00_l70003o`0001D0
0_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o0P03o`L00_l200;o0P02oaD0
0_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`80
0_l200;o1P02oaP0000D00?o1`02o`H00_l<00;o2P02oaH01?l300Co1002o`H00_l300;o0`02o`<0
0_l700;o3@02o`T01?l400;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H0
0_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o
00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l60003o`0000/00_l900;o5`04o`@0
0ol400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L0
0_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o1P02oaD01OlD00;o2002o`@0
0_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l700;o1002o`L00_l300?o2002oaL0
1?l500Co00<0ool02_l300co0`0:o`D02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa80
2_l500Wo4P08o`L02_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<0
3?l300So5@0001L000?o00001@07o`P01ol90003o`0001H01?l500Co00<0ool02_l300co0`0:o`D0
2_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L0
2_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So
5@0002401?l;00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(94\\) METHINKS IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->4.98333,
  AnimationCycleOffset->-0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3P06o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o00<0ool02_l@00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool0
1Ol500co0`0=oa00000C00;o2@07o``01_l:00;o5005o`<01Ol00`3oo`0:o`D02?l500Co0`04o`@0
2_l400Ko0P03o`801Ol500?o0`0:oa<02_l500So500:o`@02_lB00go0P0:o`@01Ol500?o00<0ool0
2_l@00Ko0`06oa400_l400;o100<o`801_l300Ko00<0ool02?l300co0`0=oa00000C00;o3P03o`d0
0_l<00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`H00_lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o3`03o``0
0_l<00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4002o`H0
2_l:00;o5@02o`<00_l200;o1002o`800_l200;o2002o`T00_l500;o2@02o`T00_l300Go1002o`@0
0_l600;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`@00_l600;o0P02o`80
0_lB00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o3004o`030?oo00D02_l:00;o5@02o`800ol200;o1002o`800_l<00;o2@02o`D00_l900;o
2@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o3002oa/00_l@00?o5002o`H00_l600;o2P03o`80
0ol600;o0P02oaL02OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00
000C00;o2P09o`D00_l400;o3002oaD00_l20003o`3o00800_l400Ko3002o`T00_l500;o2@02o`T0
0_l200?o00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`06oaL00_l500;o
4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`X00_l400?o1P02o`<0
0_l<00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo
6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T01_lH00;o0`02oa@00_l00`3oo`02o`030?oo00D0
1_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2002o`H00_l70004o`0000;o2`02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103o
ool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`800_lH00;o
0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@0
0_l800;o1P02o`L00_l200;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o0P02o`800_lE00;o00@0oooo4`02o`<0
0_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH0000
5003o`L00_l600;o20000ol00002o`/00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D0
0_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD0
0_l>00;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3o
o`0600;o1P02o`D00_l600;o1P02oaP0000E00;o1`02o`H000?o000020001?l0ool:00;o5`04o`@0
0ol400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o1003oaL0
0_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o1@02o`H00_lE00Go5002o`P0
0_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o1`02o`@00_l:00Co2@02oaL0
1?l500Co00<0ool02_l300co0`04o`<01?l400[o1004o`801_l00`3oo`03o`<01Ol400Wo4`0:o`<0
3?lB00[o1@09oa802?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P0
2Ol300co0`08oaD0000G0003o`0000D01ol<00?o2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<0
1?l300Co100:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`L01Ol00`3o
000A00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`00
0P0<o`<02?lE00008@04o`d00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "See also the QuickTime movie ",
  StyleBox["Weasel-50-1-0.1.movie",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  " in the directory \[RightGuillemet]Movies\[LeftGuillemet]. The first \
parameter indicates the population size (50), the second and third parameters \
denote mutation radius (1) and mutation rate (0.1), respectively."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Experiment 2:\n\[Dash] 50 individuals, mutation radius: 5, mutation rate: \
0.1"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Iterated selection and mutation", "Subsubsection"],

Cell["We define an objective sentence.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(weaselSentence = encodeSentence["\<METHINKS IT IS LIKE A WEASEL.\>"]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 73, 
      75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We start an evolution experiment with a population size of ",
  StyleBox["m=50",
    FontSlant->"Italic"],
  ", that is, we will have 30 individual sentences per generation. Mutations \
are applied with a probability of ",
  StyleBox["\[Mu]=0.1",
    FontSlant->"Italic"],
  ", the mutation radius is set to ",
  StyleBox["\[Rho]=5",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveSentences[weaselSentence, 50, 5, .1]\)], "Input"],

Cell["\<\
0: Min.: 2002
ZNJJHULOXVIFAYTIKEKWMMULNWCI
1: Min.: 1817
ZNJJHULOXVIKAYTIKEKWMMULNWCI
2: Min.: 1622
ZNJJHULOXVIKAYTIKEKWIRULNWCI
3: Min.: 1449
ZNJJHULOXQIKATWIKEKWIRULNWCI
4: Min.: 1306
ZNOJHULRXQIKCTWIKEKWIRULMWCI
5: Min.: 1177
ZNOJHVLRXQIPCTWIKEKWIRULMWCL
6: Min.: 1074
ZNOJHTLRXQMPCTWIKEKWIRULMWDL
7: Min.: 938
ZIOJHTLRXLMPCT IKEKWIRULMWDL
8: Min.: 848
ZIOJHTLRXLMPCT IFEKWIRULHWDL
9: Min.: 759
ZIOJHTLRXLMPCTWIFEKWIWUHHWDL
10: Min.: 652
UHOJHTLRXLMPCTWIFEKWIWTHHWDL
11: Min.: 562
UHOJHTLRXLMUCTWNFEKWIWTHHWDL
12: Min.: 500
PHOJHQLRXLMUCTWRFEKWIYTHHWDL
13: Min.: 428
PHOJLRLRXLMUCTWRFIKWDYTHHWDL
14: Min.: 358
PHOJLRLR LQUCTWRFIKWAYTHHUDL
15: Min.: 307
PHOJLNLR LQUHTWRFIKWAYTHHUDL
16: Min.: 260
PHOJLNLR LQYHTWRFLKXAYUHHUDL
17: Min.: 230
PHOJLNLQ LQYHTWRFLKXAYUHEUDL
18: Min.: 203
PHOJLNLQ LQYHTWOFLKXAYUHEUDL
19: Min.: 185
MHPJLNLQ LQYHTWOFLKXA ZHEUEL
20: Min.: 142
MHPJLNLQ LSYHTWOFLFXA ZHEUEL
21: Min.: 114
MHPJLNLQ HSYHTZOILFXA ZHEUEN
22: Min.: 105
MHPJLNLQ HSYHT MIJFXA ZHEUEN
23: Min.: 98
MHSJLNLQ HSYHT MIJFXA  HEUFN
24: Min.: 70
MHSJLNLQ JSYHT MIJCXA WHBUFN
25: Min.: 61
MHSJLLLQ JS HT MIJC A WHBUFN
26: Min.: 58
MHSJLOLQ JS HT MIJC A WHBUFN
27: Min.: 58
MHSJLOLQ JS HT MIJC A WHBUFN
28: Min.: 54
MGSJLOLQ JSZHT MIJC A WHBUFN
29: Min.: 51
MGSJLOLR JSZHT MIJC A WHBUFN
30: Min.: 47
MGSJLOLR JSZIT MIJC A WHBRFN
31: Min.: 39
MGSJLOLR JSZIT MIJC A WFBRFN
32: Min.: 30
MGSJIOLR JUZIT MIJG A WFBRFN
33: Min.: 30
MGSJIOLR JUZIT MIJG A WFBRFN
34: Min.: 29
MGSJIOLR JU IT MIJG A WFBRFN
35: Min.: 28
MGSJIOLR JU IT MIJG A WFARFN
36: Min.: 24
MESJIOLR JU IT MIJG A WFARFN
37: Min.: 22
METJIOLS JU IT MIJG A WFARFN
38: Min.: 18
METIIOLS JU IT MIJG A WFASFN
39: Min.: 14
METIIOLS JU IT MIJG A WFASFL
40: Min.: 11
METIIOLS JU IT MILD A WFASFL
41: Min.: 11
METIIOLS JU IT MILD A WFASFL
42: Min.: 10
METIIOKS JU IT MILD A WFASFL
43: Min.: 9
METIIOKS JU IT MILD A WEASFL
44: Min.: 9
METIIOKS JU IT MILD A WEASFL
45: Min.: 8
METIIOKS JU IT MIKD A WEASFL
46: Min.: 8
METIIOKS JU IT MIKD A WEASFL
47: Min.: 8
METIIOKS JU IT MIKD A WEASFL
48: Min.: 8
METIIOKS JU IT MIKD A WEASFL
49: Min.: 7
METIIOKS JU IT LIKD A WEASFL
50: Min.: 7
METIIOKS JU IS LILD A WEASFL
51: Min.: 6
METIINKS JU IS LILD A WEASFL
52: Min.: 5
METIINKS JU IS LILD A WEASEL
53: Min.: 4
METIINKS JT IS LILD A WEASEL
54: Min.: 4
METIINKS JT IS LILD A WEASEL
55: Min.: 3
METIINKS IT IS LILD A WEASEL
56: Min.: 3
METIINKS IT IS LILD A WEASEL
57: Min.: 3
METIINKS IT IS LILD A WEASEL
58: Min.: 3
METIINKS IT IS LILD A WEASEL
59: Min.: 3
METIINKS IT IS LILD A WEASEL
60: Min.: 3
METIINKS IT IS LILD A WEASEL
61: Min.: 3
METIINKS IT IS LILD A WEASEL
62: Min.: 2
METHINKS IT IS LILD A WEASEL
63: Min.: 1
METHINKS IT IS LIKD A WEASEL
64: Min.: 1
METHINKS IT IS LIKD A WEASEL
65: Min.: 1
METHINKS IT IS LIKD A WEASEL
66: Min.: 1
METHINKS IT IS LIKD A WEASEL
67: Min.: 1
METHINKS IT IS LIKD A WEASEL
68: Min.: 1
METHINKS IT IS LIKD A WEASEL
69: Min.: 1
METHINKS IT IS LIKD A WEASEL
70: Min.: 1
METHINKS IT IS LIKD A WEASEL
71: Min.: 1
METHINKS IT IS LIKD A WEASEL
72: Min.: 1
METHINKS IT IS LIKD A WEASEL
73: Min.: 1
METHINKS IT IS LIKD A WEASEL
74: Min.: 1
METHINKS IT IS LIKD A WEASEL
75: Min.: 1
METHINKS IT IS LIKD A WEASEL
76: Min.: 1
METHINKS IT IS LIKD A WEASEL
77: Min.: 1
METHINKS IT IS LIKD A WEASEL
78: Min.: 1
METHINKS IT IS LIKD A WEASEL
79: Min.: 1
METHINKS IT IS LIKD A WEASEL
80: Min.: 1
METHINKS IT IS LIKD A WEASEL
81: Min.: 1
METHINKS IT IS LIKD A WEASEL
82: Min.: 0
METHINKS IT IS LIKE A WEASEL\
\>", "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitness plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0121951 0.0116144 0.0147151 0.000294008 [
[(20)] .24448 .01472 0 2 Msboxa
[(40)] .47677 .01472 0 2 Msboxa
[(60)] .70906 .01472 0 2 Msboxa
[(80)] .94135 .01472 0 2 Msboxa
[(500)] -0.0003 .16172 1 0 Msboxa
[(1000)] -0.0003 .30872 1 0 Msboxa
[(1500)] -0.0003 .45573 1 0 Msboxa
[(2000)] -0.0003 .60273 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.24448 .01472 m
.24448 .02097 L
s
P
[(20)] .24448 .01472 0 2 Mshowa
p
.002 w
.47677 .01472 m
.47677 .02097 L
s
P
[(40)] .47677 .01472 0 2 Mshowa
p
.002 w
.70906 .01472 m
.70906 .02097 L
s
P
[(60)] .70906 .01472 0 2 Mshowa
p
.002 w
.94135 .01472 m
.94135 .02097 L
s
P
[(80)] .94135 .01472 0 2 Mshowa
p
.001 w
.05865 .01472 m
.05865 .01847 L
s
P
p
.001 w
.10511 .01472 m
.10511 .01847 L
s
P
p
.001 w
.15157 .01472 m
.15157 .01847 L
s
P
p
.001 w
.19803 .01472 m
.19803 .01847 L
s
P
p
.001 w
.29094 .01472 m
.29094 .01847 L
s
P
p
.001 w
.3374 .01472 m
.3374 .01847 L
s
P
p
.001 w
.38386 .01472 m
.38386 .01847 L
s
P
p
.001 w
.43031 .01472 m
.43031 .01847 L
s
P
p
.001 w
.52323 .01472 m
.52323 .01847 L
s
P
p
.001 w
.56969 .01472 m
.56969 .01847 L
s
P
p
.001 w
.61614 .01472 m
.61614 .01847 L
s
P
p
.001 w
.6626 .01472 m
.6626 .01847 L
s
P
p
.001 w
.75552 .01472 m
.75552 .01847 L
s
P
p
.001 w
.80197 .01472 m
.80197 .01847 L
s
P
p
.001 w
.84843 .01472 m
.84843 .01847 L
s
P
p
.001 w
.89489 .01472 m
.89489 .01847 L
s
P
p
.001 w
.9878 .01472 m
.9878 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.0122 .16172 m
.01845 .16172 L
s
P
[(500)] -0.0003 .16172 1 0 Mshowa
p
.002 w
.0122 .30872 m
.01845 .30872 L
s
P
[(1000)] -0.0003 .30872 1 0 Mshowa
p
.002 w
.0122 .45573 m
.01845 .45573 L
s
P
[(1500)] -0.0003 .45573 1 0 Mshowa
p
.002 w
.0122 .60273 m
.01845 .60273 L
s
P
[(2000)] -0.0003 .60273 1 0 Mshowa
p
.001 w
.0122 .04412 m
.01595 .04412 L
s
P
p
.001 w
.0122 .07352 m
.01595 .07352 L
s
P
p
.001 w
.0122 .10292 m
.01595 .10292 L
s
P
p
.001 w
.0122 .13232 m
.01595 .13232 L
s
P
p
.001 w
.0122 .19112 m
.01595 .19112 L
s
P
p
.001 w
.0122 .22052 m
.01595 .22052 L
s
P
p
.001 w
.0122 .24992 m
.01595 .24992 L
s
P
p
.001 w
.0122 .27932 m
.01595 .27932 L
s
P
p
.001 w
.0122 .33812 m
.01595 .33812 L
s
P
p
.001 w
.0122 .36752 m
.01595 .36752 L
s
P
p
.001 w
.0122 .39693 m
.01595 .39693 L
s
P
p
.001 w
.0122 .42633 m
.01595 .42633 L
s
P
p
.001 w
.0122 .48513 m
.01595 .48513 L
s
P
p
.001 w
.0122 .51453 m
.01595 .51453 L
s
P
p
.001 w
.0122 .54393 m
.01595 .54393 L
s
P
p
.001 w
.0122 .57333 m
.01595 .57333 L
s
P
p
.002 w
.0122 0 m
.0122 .61803 L
s
P
P
.004 w
.02381 .60332 m
.03542 .54893 L
.04704 .4916 L
.05865 .44073 L
.07027 .39869 L
.08188 .36076 L
.0935 .33048 L
.10511 .29049 L
.11672 .26403 L
.12834 .23787 L
.13995 .20641 L
.15157 .17995 L
.16318 .16172 L
.1748 .14055 L
.18641 .11997 L
.19803 .10498 L
.20964 .09116 L
.22125 .08234 L
.23287 .0744 L
.24448 .06911 L
.2561 .05646 L
.26771 .04823 L
.27933 .04559 L
.29094 .04353 L
.30256 .0353 L
.31417 .03265 L
.32578 .03177 L
.3374 .03177 L
.34901 .03059 L
.36063 .02971 L
.37224 .02853 L
.38386 .02618 L
.39547 .02354 L
.40708 .02354 L
.4187 .02324 L
.43031 .02295 L
.44193 .02177 L
.45354 .02118 L
.46516 .02001 L
.47677 .01883 L
.48839 .01795 L
.5 .01795 L
.51161 .01766 L
.52323 .01736 L
.53484 .01736 L
.54646 .01707 L
.55807 .01707 L
.56969 .01707 L
.5813 .01707 L
.59292 .01677 L
Mistroke
.60453 .01677 L
.61614 .01648 L
.62776 .01619 L
.63937 .01589 L
.65099 .01589 L
.6626 .0156 L
.67422 .0156 L
.68583 .0156 L
.69744 .0156 L
.70906 .0156 L
.72067 .0156 L
.73229 .0156 L
.7439 .0153 L
.75552 .01501 L
.76713 .01501 L
.77875 .01501 L
.79036 .01501 L
.80197 .01501 L
.81359 .01501 L
.8252 .01501 L
.83682 .01501 L
.84843 .01501 L
.86005 .01501 L
.87166 .01501 L
.88328 .01501 L
.89489 .01501 L
.9065 .01501 L
.91812 .01501 L
.92973 .01501 L
.94135 .01501 L
.95296 .01501 L
.96458 .01501 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06P000?l06P000?l06P000?l06P000?l0
6P0005401?l300;o<`03o`<00_ld00;o1002oc<00_l400;o3@00058000?o00000P001?l00?lc0005
o`000?l00P000ol0000`0004o`00o`8000Co003o<@001?l00?l20004o`00o``0001C0005o`000?l0
0P000ol0000_00Co0P001?l00?lb0004o`00o`8000Co003o<@001?l00?l20004o`00o``0001D0004
o`00o`8000?o0000;`000ol0o`030004o`00oc800ol30004o`00oc800_l30004o`00o``0001A0004
o`00o`8000Co003o<@000ol0o`030004o`00oc8000?o00000`001?l00?la0004o`00o`8000Co003o
300005800_l400;o<`02o`@00_ld00?o0`02oc<00_l400;o3@000?l06P000?l06P0001/000?o0000
n`0001/000?o0000n`0001/000?o0000n`0001/000?o0000n`0001P0ool1o`40000K0003o`0000T0
00?o000020000ol000090003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00090003o`0000805ol70003o`0000T000?o00002@000ol000090003o`0000T000?o00002@000ol0
00080003o`0000T000?o00002@000ol000090003o`000080000K0003o`0005h03on>00006`000ol0
001H00KoW@0001/000?o0000B@0?oj<0000K0003o`0004H00onb00006`000ol000150003o`000;<0
000K00;oA002okH0000K0003o`0003h01Onh00006`000ol0000m0003o`000;/0000K0003o`0003`0
00?o0000_00001/000?o0000>`000ol0002m00006`000ol0000j0003o`000;h0000K0003o`0003T0
00?o0000_`0001/000?o0000=`02ol80000K00;o=@03ol@0000K0003o`0003<000?o0000a@0001/0
00?o0000<@02olP0000K0003o`00030000?o0000b00001/000?o0000;`000ol0003900006`000ol0
000_0003o`000<T0000K0003o`0002h000?o0000bP0001/00_l^0003o`000</0000K0003o`0002`0
00?o0000c00001/000?o0000;0000ol0003<00006`000ol0000[0003o`000<d0000K0003o`0002X0
00?o0000cP0001/000?o0000:@000ol0003?00006`000ol0000Y0003o`000<l0000K0003o`0002P0
00?o0000d00001/00_lX0003o`000=40000K0003o`0002L000?o0000d@0001/000?o00009P000ol0
003B00006`000ol0000V0003o`000=80000K0003o`0002D000?o0000d`0000L00ol400;o1002o`D0
00?o000090000ol0003D00002P001?l00?l20004o`00o`8000?o00000P000ol0000T0003o`000=@0
000:0004o`00o`8000Co003o0P000ol0000200;o90000ol0003E00001`03o`<000Co003o0P001?l0
0?l40003o`0002<000?o0000e@0000L000?o00000`001?l00?l20004o`00o`@000?o00008P000ol0
003F00001`04o`<00_l400;o1@000ol0000Q0003o`000=L0000K0003o`00024000?o0000e`0001/0
00?o000080000ol0003H00006`000ol0000P0003o`000=P0000K0003o`0001l000?o0000f@0001/0
0_lP0003o`000=T0000K0003o`0001h000?o0000fP0001/000?o00007P000ol0003J00006`000ol0
000N0003o`000=X0000K0003o`0001d000?o0000f`0001/000?o00007@000ol0003K00006`000ol0
000L0003o`000=`0000K00;o7@000ol0003L00006`000ol0000L0003o`000=`0000K0003o`0001/0
00?o0000g@0001/000?o00006`000ol0003M00006`000ol0000K0003o`000=d0000K0003o`0001X0
00?o0000gP0001/000?o00006P000ol0003N00006`000ol0000I0003o`000=l0000K00;o6P000ol0
003O00006`000ol0000H0003o`000>00000K0003o`0001P000?o0000h00001/000?o000060000ol0
003P00006`000ol0000G0003o`000>40000K0003o`0001L000?o0000h@0001/000?o00005P000ol0
003R00006`02oaL000?o0000hP0001/000?o00005@000ol0003S00006`000ol0000E0003o`000><0
000K0003o`0001@000?o0000i00001/000?o000050000ol0003T00006`000ol0000D0003o`000>@0
0000103oool400;o1002o`@00_l50003o`0001<000?o0000i@00008000?o00000P001?l00?l20004
o`00o`8000Co003o10000ol0000C0003o`000>D000020003o`00008000Co003o0P001?l00?l20004
o`00o`@00_lD0003o`000>D000020003o`00008000Co003o0P001?l00?l20004o`00o`@000?o0000
4P000ol0003V00000P000ol000020004o`00o`8000Co003o0P001?l00?l40003o`00018000?o0000
iP0000030?oo00D00_l400;o1002o`D000?o00004P000ol0003V00006`000ol0000B0003o`000>H0
000K0003o`00014000?o0000i`0001/000?o00004@000ol0003W00006`000ol0000A0003o`000>L0
000K00;o4P000ol0003W00006`000ol0000@0003o`000>P0000K0003o`00010000?o0000j00001/0
00?o000040000ol0003X00006`000ol0000?0003o`000>T0000K0003o`0000l000?o0000j@0001/0
00?o00003`000ol0003Y00006`02oa0000?o0000j@0001/000?o00003P000ol0003Z00006`000ol0
000>0003o`000>X0000K0003o`0000h000?o0000jP0001/000?o00003@000ol0003[00006`000ol0
000=0003o`000>/0000K0003o`0000d000?o0000j`0001/000?o000030000ol0003/00006`02o`d0
00?o0000k00001/000?o000030000ol0003/00006`000ol0000<0003o`000>`0000K0003o`0000/0
00?o0000k@0001/000?o00002`000ol0003]00006`000ol0000;0003o`000>d0000K0003o`0000X0
00?o0000kP0001/00_l;0003o`000>h0000K0003o`0000X000?o0000kP0001/000?o00002P000ol0
003^00006`000ol000090003o`000>l0000K0003o`0000T000?o0000k`0001/000?o00002@000ol0
003_000000@0oooo0`03o`@00_l400;o1@000ol000090003o`000>l000020003o`0000D000Co003o
0P001?l00?l20003o`00008000?o000020000ol0003`00000P000ol000050004o`00o`8000Co003o
0P000ol0000200;o2@000ol0003`00000P000ol0000200?o0`001?l00?l20004o`00o`@000?o0000
20000ol0003`00000P000ol000020003o`0000<000Co003o0P001?l00?l40003o`0000P000?o0000
l00000030?oo00@01?l300;o1002o`D000?o00001`000ol0003a00006`000ol000070003o`000?40
000K0003o`0000L000?o0000l@0001/000?o00001`000ol0003a00006`02o`P000?o0000l@0001/0
00?o00001P000ol0003b00006`000ol000060003o`000?80000K0003o`0000H000?o0000lP0001/0
00?o00001P000ol0003b00006`000ol000050003o`000?<0000K0003o`0000D000?o0000l`0001/0
00?o00001@000ol0003c00006`02o`H000?o0000l`0001/000?o00001@000ol0003c00006`000ol0
00040003o`000?@0000K0003o`0000@000?o0000m00001/000?o000010000ol0003d00006`000ol0
00040003o`000?@0000K0003o`0000@000?o0000m00001/00_l40003o`000?D0000K0003o`0000<0
00?o0000m@0001/000?o00000`000ol0003e00006`000ol000030003o`000?D0000K0003o`000080
00?o0000mP0001/000?o00000P000ol0003f00006`000ol000020003o`000?H0000K0003o`000080
00?o0000mP0001/00_l30003o`000?H0000K0005o`000?l0n@0001/000Go0000o`3i00006`001Ol0
003o0?T0000K0005o`000?l0n@0000030?oo00;o0`02o`@00_l400;o1@001Ol0003o0?T000020003
o`00008000Co003o0P001?l00?l20004o`00o`@000Co003onP0000<000Go0000o`020004o`00o`80
00Co003o0P000ol0000200;o00<0o`00n@0000@000Co003o0P001?l00?l20004o`00o`8000?o0000
0P000ol0003k000000D0o`00o`020004o`00o`8000Co003o0P001?l00?l40003o`000?/0000200;o
1002o`@00_l400;o1@000ol0003k00006`000ol0003k0000o`0J0000o`0J0000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-9.15871, -217.274, 0.336769, 
  13.3036}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] {{50, 83}, {0, 5}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51515 0.030303 0 0.123607 [
[(55)] .15152 0 0 2 Msboxa
[(60)] .30303 0 0 2 Msboxa
[(65)] .45455 0 0 2 Msboxa
[(70)] .60606 0 0 2 Msboxa
[(75)] .75758 0 0 2 Msboxa
[(80)] .90909 0 0 2 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(1)] -0.0125 .12361 1 0 Msboxa
[(2)] -0.0125 .24721 1 0 Msboxa
[(3)] -0.0125 .37082 1 0 Msboxa
[(4)] -0.0125 .49443 1 0 Msboxa
[(5)] -0.0125 .61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.15152 0 m
.15152 .00625 L
s
P
[(55)] .15152 0 0 2 Mshowa
p
.002 w
.30303 0 m
.30303 .00625 L
s
P
[(60)] .30303 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(65)] .45455 0 0 2 Mshowa
p
.002 w
.60606 0 m
.60606 .00625 L
s
P
[(70)] .60606 0 0 2 Mshowa
p
.002 w
.75758 0 m
.75758 .00625 L
s
P
[(75)] .75758 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(80)] .90909 0 0 2 Mshowa
p
.001 w
.0303 0 m
.0303 .00375 L
s
P
p
.001 w
.06061 0 m
.06061 .00375 L
s
P
p
.001 w
.09091 0 m
.09091 .00375 L
s
P
p
.001 w
.12121 0 m
.12121 .00375 L
s
P
p
.001 w
.18182 0 m
.18182 .00375 L
s
P
p
.001 w
.21212 0 m
.21212 .00375 L
s
P
p
.001 w
.24242 0 m
.24242 .00375 L
s
P
p
.001 w
.27273 0 m
.27273 .00375 L
s
P
p
.001 w
.33333 0 m
.33333 .00375 L
s
P
p
.001 w
.36364 0 m
.36364 .00375 L
s
P
p
.001 w
.39394 0 m
.39394 .00375 L
s
P
p
.001 w
.42424 0 m
.42424 .00375 L
s
P
p
.001 w
.48485 0 m
.48485 .00375 L
s
P
p
.001 w
.51515 0 m
.51515 .00375 L
s
P
p
.001 w
.54545 0 m
.54545 .00375 L
s
P
p
.001 w
.57576 0 m
.57576 .00375 L
s
P
p
.001 w
.63636 0 m
.63636 .00375 L
s
P
p
.001 w
.66667 0 m
.66667 .00375 L
s
P
p
.001 w
.69697 0 m
.69697 .00375 L
s
P
p
.001 w
.72727 0 m
.72727 .00375 L
s
P
p
.001 w
.78788 0 m
.78788 .00375 L
s
P
p
.001 w
.81818 0 m
.81818 .00375 L
s
P
p
.001 w
.84848 0 m
.84848 .00375 L
s
P
p
.001 w
.87879 0 m
.87879 .00375 L
s
P
p
.001 w
.93939 0 m
.93939 .00375 L
s
P
p
.001 w
.9697 0 m
.9697 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(1)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(2)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(3)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(4)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(5)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.09091 .61803 m
.09091 .61803 L
s
.09091 .61803 m
.12121 .49443 L
.15152 .49443 L
.18182 .37082 L
.21212 .37082 L
.24242 .37082 L
.27273 .37082 L
.30303 .37082 L
.33333 .37082 L
.36364 .37082 L
.39394 .24721 L
.42424 .12361 L
.45455 .12361 L
.48485 .12361 L
.51515 .12361 L
.54545 .12361 L
.57576 .12361 L
.60606 .12361 L
.63636 .12361 L
.66667 .12361 L
.69697 .12361 L
.72727 .12361 L
.75758 .12361 L
.78788 .12361 L
.81818 .12361 L
.84848 .12361 L
.87879 .12361 L
.90909 .12361 L
.93939 .12361 L
.9697 .12361 L
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06`000?l06`000?l06`0003D00ol300?o
7P02o`@00_lM00;o0`03oah000?o00000`02oad000?o00000P03oah00_l400;o800003P000?o0000
0`000ol0000J0004o`00o`8000Co003o6`001?l00?l50003o`0001/000?o00000P001?l00?lL0003
o`0000D000?o00006P001?l00?l20004o`00oal0000h0003o`0000<000?o00006P001?l00?l20004
o`00oa/000Co003o1@000ol0000L0005o`000?l00P000ol0000K0003o`0000@000?o00006P001?l0
0?l20004o`00oal0000e00?o0`03oad00ol30004o`00oa/00ol300?o7`001Ol0003o008000?o0000
6`001?l00003oah00_l30004o`00oal0000e0003o`0000<000?o00007@000ol000030004o`00oa/0
00?o00000`000ol0000P0004o`00o`8000?o000070001?l00?lO0004o`00o`8000Co003o7`0003D0
1?l200Co7@03o`<00_lM00?o0P04oa`01?l300;o7004o`801?lM00;o1002ob00003o01/0003o01/0
003o01/0003o01/0000>00;oo`0;00003@001?l00?oo00X0000=0004o`00o`@0n?l=00003@001?l0
0?l40003o`0000@000?o00001@000ol000040003o`0000D000?o000010000ol000050003o`0000@0
00?o00001@000ol000040003o`0000D000?o000010000ol000050003o`0000@000?o00001@000ol0
00040003o`0000D000?o000010000ol000050003o`0000@000?o00001@000ol000040003o`0000D0
00?o000010000ol000050003o`0000@000?o00001@000ol000040003o`0000D000?o000010000ol0
00050003o`0000@000?o00001@000ol000040003o`0000/0000=0004o`00o`@000?o00008P000ol0
000S0003o`00028000?o00008`000ol0000R0003o`0002<000?o00004`000ol0000;00003P02o`D0
00?o0000l`000ol0000<00005@000ol0003c0003o`0000`0000E0003o`000?<000?o0000300001D0
00?o0000l`000ol0000<00005@02oo@000?o0000300001D000?o0000lP000ol0000=00005@000ol0
003b0003o`0000d0000E0003o`000?8000?o00003@0001D000?o0000lP000ol0000=00005@000ol0
003a0003o`0000h0000E00;olP000ol0000>00005@000ol0003a0003o`0000h0000E0003o`000?40
00?o00003P0001D000?o0000l0000ol0000?00005@000ol0003`0003o`0000l0000E0003o`000?00
00?o00003`0001D00_oa0003o`0000l0000E0003o`000?0000?o00003`0001D000?o0000k`000ol0
000@00005@000ol0003_0003o`000100000E0003o`000>l000?o0000400001D000?o0000k`000ol0
000@00005@02onl000?o00004@0001D000?o0000kP000ol0000A00005@000ol0003^0003o`000140
000E0003o`000>h000?o00004@0000d00ol50003o`000>h000?o00004@0000h000?o000010000ol0
003]0003o`000180000>0003o`0000@00_mW08So500000h000?o000010000ol0001V0003o`0009T0
000>0003o`0000@000?o0000IP000ol0002I00003@02o`H000?o0000I@000ol0002J00005@000ol0
001U0003o`0009X0000E0003o`0006D000?o0000VP0001D00_mV0003o`0009X0000E0003o`0006@0
00?o0000V`0001D000?o0000I0000ol0002K00005@000ol0001T0003o`0009/0000E0003o`0006@0
00?o0000V`0001D000?o0000H`000ol0002L00005@02of@000?o0000W00001D000?o0000H`000ol0
002L00005@000ol0001S0003o`0009`0000E0003o`00068000?o0000W@0001D000?o0000HP000ol0
002M00005@000ol0001R0003o`0009d0000E00;oHP000ol0002N00005@000ol0001Q0003o`0009h0
000E0003o`00064000?o0000WP0001D000?o0000H@000ol0002N00005@000ol0001P0003o`0009l0
000E0003o`00060000?o0000W`0001D000?o0000H0000ol0002O00005@02of4000?o0000W`0001D0
00?o0000G`000ol0002P00005@000ol0001O0003o`000:00000E0003o`0005l000?o0000X00000d0
1?l40003o`0005l000?o0000X00000h000?o000010000ol0001N0003o`000:40000?0003o`0000<0
0_mO0003o`000:40000@0003o`00008000?o0000GP000ol0002Q00003@001?l00?l40003o`0005h0
00?o0000X@0000h00_l50003o`0005d000?o0000XP0001D000?o0000G@000ol0002R00005@000ol0
001M0003o`000:80000E00;oGP000ol0002R00005@000ol0001L0003o`000:<0000E0003o`0005`0
00?o0000X`0001D000?o0000G0000ol0002S00005@000ol0001L0003o`000:<0000E0003o`0005`0
00?o0000X`0001D00_mL0003o`000:@0000E0003o`0005/000?o0000Y00001D000?o0000F`000ol0
002T00005@000ol0001K0003o`000:@0000E0003o`0005X000?o0000Y@0001D000?o0000FP000ol0
002U00005@02oe/000?o0000Y@0001D000?o0000FP000ol0002U00005@000ol0001I0003o`000:H0
000E0003o`0005T000?o0000YP0001D000?o0000F@000ol0002V00005@000ol0001I0003o`000:H0
000E00;oFP000ol0002V00005@000ol0001H0003o`000:L0000E0003o`0005P000?o0000Y`0001D0
00?o0000F0000ol0002W00003@03o`D000?o0000F0000ol0002W000040000ol000020003o`0005L0
00?o0000Z000010000?o00000P02ob/0;_nZ00003P02o`D000?o0000:P000ol0003E000040000ol0
00020003o`0002X000?o0000e@0000d00ol50003o`0002T000?o0000eP0001D000?o0000:@000ol0
003F00005@000ol0000Y0003o`000=H0000E00;o:P000ol0003F00005@000ol0000X0003o`000=L0
000E0003o`0002P000?o0000e`0001D000?o0000:0000ol0003G00005@000ol0000X0003o`000=L0
000E0003o`0002L000?o0000f00001D000?o00009`000ol0003H00005@02obP000?o0000f00001D0
00?o00009`000ol0003H00005@000ol0000V0003o`000=T0000E0003o`0002H000?o0000f@0001D0
00?o00009P000ol0003I00005@000ol0000U0003o`000=X0000E00;o9P000ol0003J00005@000ol0
000U0003o`000=X0000E0003o`0002D000?o0000fP0001D000?o000090000ol0003K00005@000ol0
000T0003o`000=/0000E0003o`0002@000?o0000f`0001D00_lU0003o`000=/0000E0003o`0002<0
00?o0000g00001D000?o00008`000ol0003L00005@000ol0000S0003o`000=`0000>00?o10000ol0
000S0003o`000=`0000?0003o`0000<000?o00008P000ol0003M00003@04o`@00_lL00Sog`0000d0
00?o0?l01@000ol0000K0003o`000>@0000=0003o`3o00D000?o00006`000ol0003T00003P02o`D0
00?o00006P000ol0003U00005@000ol0000J0003o`000>D0000E0003o`0001X000?o0000i@0001D0
0_lK0003o`000>D0000E0003o`0001T000?o0000iP0001D000?o00006@000ol0003V00005@000ol0
000I0003o`000>H0000E0003o`0001P000?o0000i`0001D000?o000060000ol0003W00005@02oaT0
00?o0000i`0001D000?o000060000ol0003W00005@000ol0000G0003o`000>P0000E0003o`0001L0
00?o0000j00001D000?o00005`000ol0003X00005@000ol0000G0003o`000>P0000E00;o5`000ol0
003Y00005@000ol0000F0003o`000>T0000E0003o`0001H000?o0000j@0001D000?o00005P000ol0
003Y00005@000ol0000E0003o`000>X0000E0003o`0001D000?o0000jP0001D00_lF0003o`000>X0
000E0003o`0001@000?o0000j`0001D000?o000050000ol0003[00005@000ol0000D0003o`000>/0
000=00?o1@000ol0000D0003o`000>/0000@0003o`00008000?o00004`000ol0003/000040000ol0
000200;o50000ol0003/00003@03ool02`0000d000?o0000o`0;00003@04ool02P000?l06`000?l0
6`000001\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {47.1814, -0.490222, 0.133302, 
  0.0326798}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sentences overview", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[interpretSentence/@bestSentences]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("ZNJJHULOXVIFAYTIKEKWMMULNWCI"\)},
          {\("ZNJJHULOXVIKAYTIKEKWMMULNWC      I"\)},
          {\("ZNJJHULOXVIKAYTIKEKWIRULNWCI"\)},
          {\("ZNJJHULOXQIKATWIKEKWIRULNWCI"\)},
          {\("ZNOJHULRXQIKCTWIKEKWIRULMWCI"\)},
          {\("ZNOJHVLRXQIPCTWIKEKWIRULMWCL"\)},
          {\("ZNOJHTLRXQMPCTWIKEKWIRULMWDL"\)},
          {\("ZIOJHTLRXLMPCT IKEKWIRULMWDL"\)},
          {\("ZIOJHTLRXLMPCT IFEKWIRULHWDL"\)},
          {\("ZIOJHTLRXLMPCTWIFEKWIWUHHWDL"\)},
          {\("UHOJHTLRXLMPCTWIFEKWIWTHHWDL"\)},
          {\("UHOJHTLRXLMUCTWNFEKWIWTHHWDL"\)},
          {\("PHOJHQLRXLMUCTWRFEKWIYTHHWDL"\)},
          {\("PHOJLRLRXLMUCTWRFIKWDYTHHWDL"\)},
          {\("PHOJLRLR LQUCTWRFIKWAYTHHUDL"\)},
          {\("PHOJLNLR LQUHTWRFIKWAYTHHUDL"\)},
          {\("PHOJLNLR LQYHTWRFLKXAYUHHUDL"\)},
          {\("PHOJLNLQ LQYHTWRFLKXAYUHEUDL"\)},
          {\("PHOJLNLQ LQYHTWOFLKXAYUHEUDL"\)},
          {\("MHPJLNLQ LQYHTWOFLKXA ZHEUEL"\)},
          {\("MHPJLNLQ LSYHTWOFLFXA ZHEUEL"\)},
          {\("MHPJLNLQ HSYHTZOILFXA ZHEUEN"\)},
          {\("MHPJLNLQ HSYHT MIJFXA ZHEUEN"\)},
          {\("MHSJLNLQ HSYHT MIJFXA  HEUFN"\)},
          {\("MHSJLNLQ JSYHT MIJCXA WHBUFN"\)},
          {\("MHSJLLLQ JS HT MIJC A WHBUFN"\)},
          {\("MHSJLOLQ JS HT MIJC A WHBUFN"\)},
          {\("MHSJLOLQ JS HT MIJC A WHBUFN"\)},
          {\("MGSJLOLQ JSZHT MIJC A WHBUFN"\)},
          {\("MGSJLOLR JSZHT MIJC A WHBUFN"\)},
          {\("MGSJLOLR JSZIT MIJC A WHBRFN"\)},
          {\("MGSJLOLR JSZIT MIJC A WFBRFN"\)},
          {\("MGSJIOLR JUZIT MIJG A WFBRFN"\)},
          {\("MGSJIOLR JUZIT MIJG A WFBRFN"\)},
          {\("MGSJIOLR JU IT MIJG A WFBRFN"\)},
          {\("MGSJIOLR JU IT MIJG A WFARFN"\)},
          {\("MESJIOLR JU IT MIJG A WFARFN"\)},
          {\("METJIOLS JU IT MIJG A WFARFN"\)},
          {\("METIIOLS JU IT MIJG A WFASFN"\)},
          {\("METIIOLS JU IT MIJG A WFASFL"\)},
          {\("METIIOLS JU IT MILD A WFASFL"\)},
          {\("METIIOLS JU IT MILD A WFASFL"\)},
          {\("METIIOKS JU IT MILD A WFASFL"\)},
          {\("METIIOKS JU IT MILD A WEASFL"\)},
          {\("METIIOKS JU IT MILD A WEASFL"\)},
          {\("METIIOKS JU IT MIKD A WEASFL"\)},
          {\("METIIOKS JU IT MIKD A WEASFL"\)},
          {\("METIIOKS JU IT MIKD A WEASFL"\)},
          {\("METIIOKS JU IT MIKD A WEASFL"\)},
          {\("METIIOKS JU IT LIKD A WEASFL"\)},
          {\("METIIOKS JU IS LILD A WEASFL"\)},
          {\("METIINKS JU IS LILD A WEASFL"\)},
          {\("METIINKS JU IS LILD A WEASEL"\)},
          {\("METIINKS JT IS LILD A WEASEL"\)},
          {\("METIINKS JT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METIINKS IT IS LILD A WEASEL"\)},
          {\("METHINKS IT IS LILD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKD A WEASEL"\)},
          {\("METHINKS IT IS LIKE A WEASEL"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"ZNJJHULOXVIFAYTIKEKWMMULNWCI", "ZNJJHULOXVIKAYTIKEKWMMULNWC      I", 
        "ZNJJHULOXVIKAYTIKEKWIRULNWCI", "ZNJJHULOXQIKATWIKEKWIRULNWCI", 
        "ZNOJHULRXQIKCTWIKEKWIRULMWCI", "ZNOJHVLRXQIPCTWIKEKWIRULMWCL", 
        "ZNOJHTLRXQMPCTWIKEKWIRULMWDL", "ZIOJHTLRXLMPCT IKEKWIRULMWDL", 
        "ZIOJHTLRXLMPCT IFEKWIRULHWDL", "ZIOJHTLRXLMPCTWIFEKWIWUHHWDL", 
        "UHOJHTLRXLMPCTWIFEKWIWTHHWDL", "UHOJHTLRXLMUCTWNFEKWIWTHHWDL", 
        "PHOJHQLRXLMUCTWRFEKWIYTHHWDL", "PHOJLRLRXLMUCTWRFIKWDYTHHWDL", 
        "PHOJLRLR LQUCTWRFIKWAYTHHUDL", "PHOJLNLR LQUHTWRFIKWAYTHHUDL", 
        "PHOJLNLR LQYHTWRFLKXAYUHHUDL", "PHOJLNLQ LQYHTWRFLKXAYUHEUDL", 
        "PHOJLNLQ LQYHTWOFLKXAYUHEUDL", "MHPJLNLQ LQYHTWOFLKXA ZHEUEL", 
        "MHPJLNLQ LSYHTWOFLFXA ZHEUEL", "MHPJLNLQ HSYHTZOILFXA ZHEUEN", 
        "MHPJLNLQ HSYHT MIJFXA ZHEUEN", "MHSJLNLQ HSYHT MIJFXA  HEUFN", 
        "MHSJLNLQ JSYHT MIJCXA WHBUFN", "MHSJLLLQ JS HT MIJC A WHBUFN", 
        "MHSJLOLQ JS HT MIJC A WHBUFN", "MHSJLOLQ JS HT MIJC A WHBUFN", 
        "MGSJLOLQ JSZHT MIJC A WHBUFN", "MGSJLOLR JSZHT MIJC A WHBUFN", 
        "MGSJLOLR JSZIT MIJC A WHBRFN", "MGSJLOLR JSZIT MIJC A WFBRFN", 
        "MGSJIOLR JUZIT MIJG A WFBRFN", "MGSJIOLR JUZIT MIJG A WFBRFN", 
        "MGSJIOLR JU IT MIJG A WFBRFN", "MGSJIOLR JU IT MIJG A WFARFN", 
        "MESJIOLR JU IT MIJG A WFARFN", "METJIOLS JU IT MIJG A WFARFN", 
        "METIIOLS JU IT MIJG A WFASFN", "METIIOLS JU IT MIJG A WFASFL", 
        "METIIOLS JU IT MILD A WFASFL", "METIIOLS JU IT MILD A WFASFL", 
        "METIIOKS JU IT MILD A WFASFL", "METIIOKS JU IT MILD A WEASFL", 
        "METIIOKS JU IT MILD A WEASFL", "METIIOKS JU IT MIKD A WEASFL", 
        "METIIOKS JU IT MIKD A WEASFL", "METIIOKS JU IT MIKD A WEASFL", 
        "METIIOKS JU IT MIKD A WEASFL", "METIIOKS JU IT LIKD A WEASFL", 
        "METIIOKS JU IS LILD A WEASFL", "METIINKS JU IS LILD A WEASFL", 
        "METIINKS JU IS LILD A WEASEL", "METIINKS JT IS LILD A WEASEL", 
        "METIINKS JT IS LILD A WEASEL", "METIINKS IT IS LILD A WEASEL", 
        "METIINKS IT IS LILD A WEASEL", "METIINKS IT IS LILD A WEASEL", 
        "METIINKS IT IS LILD A WEASEL", "METIINKS IT IS LILD A WEASEL", 
        "METIINKS IT IS LILD A WEASEL", "METIINKS IT IS LILD A WEASEL", 
        "METHINKS IT IS LILD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKD A WEASEL", "METHINKS IT IS LIKD A WEASEL", 
        "METHINKS IT IS LIKE A WEASEL"}]]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation ...", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MapIndexed[
      Show[Graphics[
            Text["\<(\>"<>ToString[First[#2]]<>"\<) \>"<>
                interpretSentence[#1], {0, 0}], 
            DefaultFont \[Rule] {"\<Courier\>", 24}], 
          AspectRatio \[Rule] .1]&, bestSentences]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(1\\) ZNJJHULOXVIFAYTIKEKWMMULNWCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  AnimationCycleOffset->0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l900Wo2P02oaH02_l400Ko0`02o`@01_l900Ko1`04o`<0
1?l800Co1@0=o`D01Ol600Go0P05o`L00_l900[o0`07o`H01_l300Ko0`08o`H02?l600[o0`05o`H0
0_l00`3oo`0:o`<01Ol600;o0`02o`@00_l500Go0`05o`030?oo00?o0`05o`H01?l600go0P06o`<0
0_l500;o1002o`P01Ol600[o6P0001X00_l:00Wo2`02oaD02_l400Ko0P03o`802Ol600Wo1P04o`<0
1?l600So0`0=o`<02Ol400Go0P05o`H01?l800[o0`07o`H01_l300Ko0`08o`H02?l600[o0`05o`D0
0ol00`3oo`0:o`<01Ol500?o0`02o`@00_l500Go0`05o`030?oo00?o0`05o`@02?l400go0P06o`80
0ol500;o1002o`H02Ol400[o6P0001X00_l>00;o3P02oaH00_l500;o1@02o`@01?l200?o1003o`D0
0ol400?o1P02o`D00_l700;o1002o`H00_l600;o0P03o`D00ol400?o1003o`L01?l<00;o2@02o`/0
0_l700;o2002o``00_l=00;o2@02o`D00ol400;o1P02o`D00_l500?o0`03o`@00ol500;o1`02o`<0
0_l700;o1@02o`@00_l700;o1P02o`<00_l400Co1003o`@00ol400?o1@03o`L00_lN00006P02o`h0
0_l>00;o5P03o`@00_l500;o1004o`800_l600;o1@02o`H00_l600;o1@02o`H00_l600;o1@02o`H0
0_l200;o1`02o`D00ol200?o2004o``00_l900;o2`02o`L00_l800;o3002o`d00_l900;o1@02o`D0
0_l600;o1@02o`D00_l400Co0`03o`D00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o0`02o`@0
1?l400Co0`03o`@00_l700;o1`02oah0000J00;o3P02o`h00_lG00?o0`02o`D00_l300Go0P02o`H0
0_l500;o1P02o`H00_l500;o1P02o`H00_l500;o1P02o`030?oo00T00_l500;o0P02o`P00_l200;o
2`02o`T00_l200;o1`0;o`P00_l<00;o3@02o`T00_l400;o1P02o`800_l200;o1@02o`@00_l500Co
0P04o`D00_l300;o0P02o`<00_l300;o0P02o`@00_l600;o1P02o`H00_l300;o0`05o`@01?l200Co
0`03oa000_lN00006P02o`h00_l>00;o6002o`<00_l500;o0`02o`030?oo00800_l600;o1@02o`H0
0_l600;o1@02o`H00_l600;o1@02o`H00_l00`3oo`0900;o1P04o`T00_l200;o2`02o`T00_l200;o
2009o`T00_l<00;o3@02o`T00ol200?o1P02o`800_l900?o0P03o`D00_l0103o0004o`D00_l200?o
0P02o`<00_l200?o0P02o`@00_l600;o1P02o`H00_l300;o0`02o`030?oo00@00_l0103o0004o`<0
0_lA00;o7P0001X00_l>00;o3P02oaP00ol900;o0P03o`030?oo00X00_l=00;o1P02o`D00_l600;o
1P02o`D00_l900;o2@02o`H01?l800?o0P03o`X00_l900Ko2002o`D00_l900?o2`02o`d00_l900Oo
1`06o`T01ol600;o00H0o`00o`02o`D00_l20003o`3o00800_l300;o0P000ol0o`0200;o1002o`H0
0_l600;o2`02o`800ol00`3oo`0400;o00H0o`00o`02o`<00_lA00;o7P0001X00_l>00;o3P02oaT0
0ol800;o0P02o`800_l:00;o3@02o`H02Ol600;o1P02o`D00_l900;o2@02o`H00ol900;o1002o`X0
0_l900Ko2@02o`<00_l900Co2`02o`d00_l900Go2@06o`T01Ol800;o00<0ool00_l00`3oo`0500;o
00@0ool00_l00`3oo`0300;o00@0ool00_l00`3oo`0400;o1P02o`H00_l;00;o0P02o`800_l400;o
00<0ool00_l00`3oo`0300;o4@02oah0000K00;o3@02o`d00_lF00;o0`02o`P00_l00`3oo`0300;o
2P02o`d00_l600Wo1P02o`H00_l500;o2@02o`T00_l600Co2002o`@00_l:00;o2@02o`800_l900;o
0`02o`P01_l500;o0`02o`<00_l800;o2@02o`040?ooo`P00_l200;o2@02o`040?ooo`L00_l00`3o
o`02o`030?oo00D00_l00`3oo`020004o`3oo`<00_l00`3oo`020004o`3oo`@00_l600;o1P02o`/0
0_l00`3oo`0300;o1002o`030?oo00;o00<0ool00`02oa400_lN00006`02o`d00_l=00;o5P02o`<0
0ol700Go0`02o`X00_l=00;o1P02o`D00_l600;o1P02o`D00_l900;o2@02o`D01_l600;o1P02o`T0
0_l900;o0P02o`800_l600;o00@0oooo2002o`800_l500;o0`02o`<00_l800;o2@02o`800ol700;o
0P02o`800_l500;o0P03o`D00_l300;o0`02o`@00_l00`3o00020004o`3oo`<00_l00`3o00020004
o`3oo`@00_l600;o1P02o`/01Ol300;o0`02o`<00_l300;o0P03o`L00_l700;o7P0001/00ol<00;o
3@02oaH00_l400?o1P04o`@00_l:00;o3@02o`H00_l500;o1P02o`H00_l500;o2P02o`L00_l500?o
0P03o`D00_l600;o2@02o`T00_l600;o1P02o`030?oo00P00ol300;o1002o`<00_l300;o2002o`T0
0_l300?o1P02o`H00_l500;o0`03o`@00_l300;o0`02o`@01?l300Co0`04o`<01?l400;o1P02o`H0
0_l;00Co1002o`<00_l300;o0`02o`<00_l700;o1`02oah0000L00;o3002o``00_lG00;o1@02o`H0
1?l400;o2P02o`d00_l600;o1@02o`H00_l600;o1@02o`X00ol500?o1@02o`@00_l400?o1P03o`P0
0_l900;o1P02o`H01Ol800;o1002o`@00_l300;o0`02o`P00_l900;o1003o`D00_l600;o1@02o`@0
0ol300;o2002o`@01?l400?o0`04o`@00ol400;o1P02o`H00_l;00Co1002o`<00_l800;o0`03o`D0
0ol700;o7P0001d00_l700?o00<0ool02`02oaP02_l400Co0P06o`@02_l500[o0P04o`<01?l400Co
1004o`030?oo00Ko2009o`@01Ol200Go00<0ool01?l200Ko0`0:o`<03?l300Oo1`05o`801Ol200co
100:o`<01Ol300Go00<0ool02_l300Go0`0;o`801_l200Co1@04o`030?oo00;o1@04o`801?l400Co
0P08o`L01?l200Ko00<0ool01?l200Ko0`0:o`<02_lJ00007P000ol0000500Ko2`000ol0000G00[o
1003o`<01_l400[o1@0:o`801?l300Co1004o`@01?l00`3oo`06o`X01Ol600Go0P05o`030?oo00Co
0P06o`<02_l300co0`07o`L01Ol200Go0P0<o`@02_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko
0P04o`D01?l00`3oo`02o`D01?l200Co1004o`802?l700?o0`06o`030?oo00Co0P06o`D01Ol00`3o
o`0300[o6P0002T00ooo0<h0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(2\\) ZNJJHULOXVIKAYTIKEKWMMULNWCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l800[o2P02oaH02_l400Ko0`02o`@01_l900Ko1`04o`<0
1?l800Co1@0=o`D01Ol600Go0P05o`L00_l900[o0`05o`H02?l300Ko0`08o`H02?l600[o0`05o`H0
0_l00`3oo`0:o`<01Ol600;o0`02o`@00_l500Go0`05o`030?oo00?o0`05o`H01?l600go0P06o`<0
0_l500;o1002o`P01Ol600[o6P0001X00_l900[o2`02oaD02_l400Ko0P03o`802Ol600Wo1P04o`<0
1?l600So0`0=o`<02Ol400Go0P05o`H01?l800[o0`05o`D02Ol300Ko0`08o`H02?l600[o0`05o`D0
0ol00`3oo`0:o`<01Ol500?o0`02o`@00_l500Go0`05o`030?oo00?o0`05o`@02?l400go0P06o`80
0ol500;o1002o`H02Ol400[o6P0001X00_l:00;o1@02o`/00_lF00;o1@02o`D00_l400Co0P03o`@0
0ol500?o1003o`H00_l500;o1`02o`@00_l600;o1P02o`800ol500?o1003o`@00ol700Co3002o`T0
0_l500?o0`02o`L00_l800;o3002o`d00_l900;o1@03o`@00_l600;o1@02o`D00ol300?o1003o`D0
0_l700;o0`02o`L00_l500;o1002o`L00_l600;o0`02o`@01?l400?o1003o`@00ol500?o1`02oah0
000J00;o2`03oa000_lF00?o1002o`D00_l400Co0P02o`H00_l500;o1P02o`H00_l500;o1P02o`H0
0_l500;o1P02o`800_l700;o1@03o`800ol800Co3002o`T00_l500;o1002o`L00_l800;o3002o`d0
0_l900;o1@02o`D00_l600;o1@02o`D00_l400Co0`03o`D00_l700;o0`02o`L00_l400;o1P02o`H0
0_l600;o0`02o`@01?l400Co0`03o`@00_l700;o1`02oah0000J00;o3003o`l00_lG00?o0`02o`D0
0_l300Go0P02o`H00_l500;o1P02o`H00_l500;o1P02o`H00_l500;o1P02o`030?oo00T00_l500;o
0P02o`P00_l200;o2`02o`T00_l400;o1@0;o`P00_l<00;o3@02o`T00_l400;o1P02o`800_l200;o
1@02o`@00_l500Co0P04o`D00_l300;o0P02o`<00_l300;o0P02o`@00_l600;o1P02o`H00_l300;o
0`05o`@01?l200Co0`03oa000_lN00006P02o`d00ol>00;o6002o`<00_l500;o0`02o`030?oo0080
0_l600;o1@02o`H00_l600;o1@02o`H00_l600;o1@02o`H00_l00`3oo`0900;o1P04o`T00_l200;o
2`02o`T00ol200?o1P09o`T00_l<00;o3@02o`T00ol200?o1P02o`800_l900?o0P03o`D00_l0103o
0004o`D00_l200?o0P02o`<00_l200?o0P02o`@00_l600;o1P02o`H00_l300;o0`02o`030?oo00@0
0_l0103o0004o`<00_lA00;o7P0001X00_l>00?o3@02oaP00ol900;o0P03o`030?oo00X00_l=00;o
1P02o`D00_l600;o1P02o`D00_l900;o2@02o`H01?l800?o0P03o`X00_l900Oo1`02o`D00_l900?o
2`02o`d00_l900Oo1`06o`T01ol600;o00H0o`00o`02o`D00_l20003o`3o00800_l300;o0P000ol0
o`0200;o1002o`H00_l600;o2`02o`800ol00`3oo`0400;o00H0o`00o`02o`<00_lA00;o7P0001X0
0_l?00?o3002oaT00ol800;o0P02o`800_l:00;o3@02o`H02Ol600;o1P02o`D00_l900;o2@02o`H0
0ol900;o1002o`X00_l900Go2P02o`<00_l900Co2`02o`d00_l900Go2@06o`T01Ol800;o00<0ool0
0_l00`3oo`0500;o00@0ool00_l00`3oo`0300;o00@0ool00_l00`3oo`0400;o1P02o`H00_l;00;o
0P02o`800_l400;o00<0ool00_l00`3oo`0300;o4@02oah0000K00;o3`02o`/00_lF00;o0`02o`P0
0_l00`3oo`0300;o2P02o`d00_l600Wo1P02o`H00_l500;o2@02o`T00_l600Co2002o`@00_l:00;o
2@02o`040?ooo`T00_l300;o2006o`D00_l300;o0`02o`P00_l900;o00@0oooo2002o`800_l900;o
00@0oooo1`02o`030?oo00;o00<0ool01@02o`030?oo008000Co0?oo0`02o`030?oo008000Co0?oo
1002o`H00_l600;o2`02o`030?oo00<00_l400;o00<0ool00_l00`3oo`0300;o4@02oah0000K00;o
4002o`X00_lF00;o0`03o`L01Ol300;o2P02o`d00_l600;o1@02o`H00_l600;o1@02o`T00_l900;o
1@06o`H00_l600;o2@02o`T00_l200?o2@02o`040?ooo`P00_l200;o1@02o`<00_l300;o2002o`T0
0_l200?o1`02o`800_l200;o1@02o`800ol500;o0`02o`<00_l400;o00<0o`000P001?l0ool300;o
00<0o`000P001?l0ool400;o1P02o`H00_l;00Go0`02o`<00_l300;o0`02o`800ol700;o1`02oah0
000K00?o3`02o`X00_lF00;o1003o`H01?l400;o2P02o`d00_l600;o1@02o`H00_l600;o1@02o`X0
0_l700;o1@03o`800ol500;o1P02o`T00_l900;o0`03o`P00_l00`3oo`0800?o0`02o`@00_l300;o
0`02o`P00_l900;o0`03o`H00_l600;o1@02o`<00ol400;o0`02o`<00_l400Co0`04o`<01?l300Co
1002o`H00_l600;o2`04o`@00_l300;o0`02o`<00_l300;o1`02o`L00_lN00007002o`P00_l500;o
2@02oaL00_l500;o1P04o`@00_l:00;o3@02o`H00_l500;o1P02o`H00_l500;o2P03o`D00ol500;o
1002o`@00ol600?o2002o`T00_l400?o1`05o`P00_l400;o1002o`<00_l300;o2002o`T00_l400?o
1@02o`H00_l500;o1003o`<00_l800;o1004o`@00ol300Co1003o`@00_l600;o1P02o`/01?l400;o
0`02o`P00_l300?o1@03o`L00_lN00007@02o`L00ol300?o2002oaP02_l400Co0P06o`@02_l500[o
0P04o`<01?l400Co1004o`030?oo00Ko2009o`@01Ol200Go00<0ool01?l200Ko0`0:o`<01Ol300Go
0P07o`L01Ol200Go0P0<o`@02_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko0P04o`D01?l00`3o
o`02o`D01?l200Co1004o`802?l700Co0P06o`030?oo00Co0P06o`<02_l300[o6P0001h000?o0000
1P07o`T000?o00005`0:o`@00ol300Ko100:o`D02_l200Co0`04o`@01?l400Co00<0ool01_l:00Go
1P05o`801Ol00`3oo`04o`801_l300[o0`05o`<01Ol200Oo1`05o`801Ol200co100:o`<01Ol300Go
00<0ool02_l300Go0`0;o`801_l200Co1@04o`030?oo00;o1@04o`801?l400Co0P08o`L00ol300Ko
00<0ool01?l200Ko1@05o`030?oo00<02_lJ0000:005ool0c@000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(3\\) ZNJJHULOXVIKAYTIKEKWIRULNWCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l:00Go3@02oaH02_l400Ko0`02o`@01_l900Ko1`04o`<0
1?l800Co1@0=o`D01Ol600Go0P05o`L00_l900[o0`05o`H02?l300Ko0`08o`H02?l600[o0`05o`H0
0_l00`3oo`0:o`<01Ol600;o0`02o`@00_l600[o0`05o`H00ol500Co1P0=o`801_l300;o1@02o`@0
0_l800Go1P0:oaX0000J00;o2@09o``00_lE00[o1006o`800ol200Wo1P09o`H01?l300Co1P08o`<0
3Ol300Wo1005o`801Ol600Co200:o`<01Ol500Wo0`06o`<02?l600So1P0:o`<01Ol500?o00<0ool0
2_l300Go1@03o`<00_l400;o1P0:o`<01Ol500Co0`08o`@03Ol200Ko0P03o`D00_l400;o1P09o`@0
2_lJ00006P02o`T00_l500;o3002oaH00_l500;o1@02o`@01?l200?o1003o`D00ol400?o1P02o`D0
0_l700;o1002o`H00_l600;o0P03o`D00ol400?o1003o`L01?l<00;o2@02o`D00ol300;o1`02o`P0
0_l<00;o3@02o`T00_l500?o1002o`H00_l500;o1@03o`<00ol400?o2@02o`T00_l500?o1@02o`@0
0_l700;o1P02o`<00_l400Co1003o`@00ol400?o1@03o`L00_lN00006P02oa400_l;00;o5P03o`@0
0_l500;o1004o`800_l600;o1@02o`H00_l600;o1@02o`H00_l600;o1@02o`H00_l200;o1`02o`D0
0ol200?o2004o``00_l900;o1@02o`@00_l700;o2002o``00_l=00;o2@02o`D00_l500;o1P02o`D0
0_l500;o1004o`<00ol900;o2@02o`D00_l500;o1P02o`H00_l600;o0`02o`@01?l400Co0`03o`@0
0_l700;o1`02oah0000J00;o4@02o`/00_lG00?o0`02o`D00_l300Go0P02o`H00_l500;o1P02o`H0
0_l500;o1P02o`H00_l500;o1P02o`030?oo00T00_l500;o0P02o`P00_l200;o2`02o`T00_l400;o
1@0;o`P00_l<00;o3@02o`T00_l400;o1P02o`800_l200;o1@02o`@00_l500Co0P04o`T00_l900;o
1002o`H00_l600;o1P02o`H00_l300;o0`05o`@01?l200Co0`03oa000_lN00006P02oa400_l;00;o
6002o`<00_l500;o0`02o`030?oo00800_l600;o1@02o`H00_l600;o1@02o`H00_l600;o1@02o`H0
0_l00`3oo`0900;o1P04o`T00_l200;o2`02o`T00ol200?o1P09o`T00_l<00;o3@02o`T00ol200?o
1P02o`800_l900?o0P03o`D00_l0103o0004o`T00_l900;o0`03o`H00_l600;o1P02o`H00_l300;o
0`02o`030?oo00@00_l0103o0004o`<00_lA00;o7P0001X00_l@00;o3002oaP00ol900;o0P03o`03
0?oo00X00_l=00;o1P02o`D00_l600;o1P02o`D00_l900;o2@02o`H01?l800?o0P03o`X00_l900Oo
1`02o`D00_l900?o2`02o`d00_l900Oo1`06o`T01ol600;o00H0o`00o`02o`T00_l900Oo1`02o`H0
0_l600;o2`02o`800ol00`3oo`0400;o00H0o`00o`02o`<00_lA00;o7P0001X00_l=00Co3@02oaT0
0ol800;o0P02o`800_l:00;o3@02o`H02Ol600;o1P02o`D00_l900;o2@02o`H00ol900;o1002o`X0
0_l900Go2P02o`<00_l900Co2`02o`d00_l900Go2@06o`T01Ol800;o00<0ool00_l00`3oo`0900;o
2@09o`D00_l600;o1P02o`/00_l200;o0P02o`@00_l00`3oo`02o`030?oo00<00_lA00;o7P0001/0
0_l<00?o3@02oaH00_l300;o2002o`030?oo00<00_l:00;o3@02o`H02Ol600;o1P02o`D00_l900;o
2@02o`H01?l800;o1002o`X00_l900;o00@0oooo2@02o`<00_l800Ko1@02o`<00_l300;o2002o`T0
0_l0103oool800;o0P02o`T00_l0103oool700;o00<0ool00_l00`3oo`0900;o2@02o`D00ol400;o
1P02o`H00_l;00;o00<0ool00`02o`@00_l00`3oo`02o`030?oo00<00_lA00;o7P0001/00_l>00;o
3002oaH00_l300?o1`05o`<00_l:00;o3@02o`H00_l500;o1P02o`H00_l500;o2@02o`T00_l500Ko
1P02o`H00_l900;o2@02o`800ol900;o00@0oooo2002o`800_l500;o0`02o`<00_l800;o2@02o`80
0ol700;o0P02o`800_l500;o0P03o`D00_l300;o0`02o`P00_l900;o1P02o`@00_l600;o1P02o`/0
1Ol300;o0`02o`<00_l300;o0P03o`L00_l700;o7P0001/00ol>00;o2`02oaH00_l400?o1P04o`@0
0_l:00;o3@02o`H00_l500;o1P02o`H00_l500;o2P02o`L00_l500?o0P03o`D00_l600;o2@02o`T0
0_l300?o2002o`030?oo00P00ol300;o1002o`<00_l300;o2002o`T00_l300?o1P02o`H00_l500;o
0`03o`@00_l300;o0`02o`P00_l900;o1P02o`@00_l600;o1P02o`/01?l400;o0`02o`<00_l300;o
0`02o`L00_l700;o7P0001`00_l>00;o2P02oaL00_l500;o1P04o`@00_l:00;o3@02o`H00_l500;o
1P02o`H00_l500;o2P03o`D00ol500;o1002o`@00ol600?o2002o`T00_l400?o1`05o`P00_l400;o
1002o`<00_l300;o2002o`T00_l400?o1@02o`H00_l500;o1003o`<00_l800;o2002o`T00_l500?o
1002o`H00_l600;o2`04o`@00_l300;o2002o`<00ol500?o1`02oah0000M00;o1`02o`<00ol900;o
600:o`@01?l200Ko100:o`D02_l200Co0`04o`@01?l400Co00<0ool01_l800Wo1005o`801Ol00`3o
o`04o`801_l300[o0`05o`<01Ol200Oo1`05o`801Ol200co100:o`<01Ol300Go00<0ool02_l300Go
0`0;o`801_l300[o0`0;o`@01?l400Co0P08o`L01?l200Ko00<0ool01?l200Ko0`0:o`<02_lJ0000
7P000ol0000500Oo2P000ol0000G00[o1003o`<01_l400[o1@0:o`801?l300Co1004o`@01?l00`3o
o`06o`X01Ol600Go0P05o`030?oo00Co0P06o`<02_l300Go0`05o`801ol700Go0P05o`803?l400[o
0`05o`<01Ol00`3oo`0:o`<01Ol300_o0P06o`<02_l300Wo1P04o`@01?l200So1`03o`<01_l00`3o
o`04o`801_l500Go00<0ool00`0:oaX0000X00Coo`3>0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(4\\) ZNJJHULOXQIKATWIKEKWIRULNWCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oi/00_l400?oo`0M00007002oaX00_nJ00[o
o`0L00006`02oa`00_nJ00Go0P02ool0700001/00_lL00;oVP000ol0003o0280000K00;o3006o`X0
0_lF00[o1006o`<00_l400Ko2@06o`L01?l300Co2004o`D03Ol500Go1P05o`801Ol600Go1`0:o`<0
1Ol600So0`06o`<02?l600;o1002o`H02_l300Go1P02o`030?oo00[o0`05o`H00_l300;o1002o`H0
2_l300Go1P03o`D01?l600go0P06o`<00_l500;o1002o`P01Ol600[o6P0001X00_l=00Ko2`02oaD0
2_l400Ko0P03o`802Ol600Wo1P04o`<01?l600So0`0=o`<02Ol400Go0P05o`@02Ol500[o0`05o`D0
2Ol300Ko0`08o`H00_l400;o1P0:o`<01Ol500?o00<0ool02_l300Go1@03o`<00_l400;o1P0:o`<0
1Ol500Co0`08o`@03Ol200Ko0P03o`D00_l400;o1P09o`@02_lJ00006P02o`l00_l=00;o5P02o`D0
0_l500;o1004o`800ol400?o1@03o`@00ol600;o1@02o`L00_l400;o1P02o`H00_l200?o1@03o`@0
0ol400?o1003o`D00ol800;o2@02o`D00ol300;o1`02o`P00_l800?o1003o`T00_l900;o1@03o`@0
0_l600;o1@02o`D00ol300?o1003o`T00_l900;o1@03o`D00_l400;o1`02o`H00_l300;o1004o`@0
0ol400?o1003o`D00ol700;o7P0001X00_l?00;o3@02oaH00ol400;o1@02o`@01?l200;o1P02o`D0
0_l600;o1P02o`D00_l600;o1P02o`D00_l600;o0P02o`L00_l500?o0P03o`D00_l700;o2002o`T0
0_l500;o1002o`L00_l800;o2004o`<00ol900;o2@02o`D00_l500;o1P02o`D00_l500;o1004o`<0
0ol900;o2@02o`D00_l500;o1P02o`H00_l600;o0`02o`@01?l400Co0`03o`@00_l700;o1`02oah0
000J00;o2@0:o`/00_lG00?o0`02o`D00_l300Go0P02o`H00_l500;o1P02o`H00_l500;o1P02o`H0
0_l500;o1P02o`030?oo00T00_l500;o0P02o`D00_l900;o1`02o`T00_l400;o1@0;o`P00_l800Co
0P04o`T00_l900;o1002o`H00_l200;o0P02o`D00_l400;o1@04o`801?l900;o2@02o`@00_l600;o
1P02o`H00_l600;o0`02o`<01Ol400Co0P04o`<00ol@00;o7P0001X00_l900[o2`02oaP00_l300;o
1@02o`<00_l00`3oo`0200;o1P02o`D00_l600;o1P02o`D00_l600;o1P02o`D00_l600;o00<0ool0
2@02o`H01?l600;o2@02o`L00_l900?o0P03o`H02Ol900;o2002o`040?l000Co2@02o`T00ol200?o
1P02o`800_l900?o0P03o`D00_l0103o0004o`T00_l900;o0`03o`H00_l600;o1P02o`H00_l300;o
0`02o`030?oo00@00_l0103o0004o`<00_lA00;o7P0001X00_l900;o1002o`d00_lH00?o2@02o`80
0ol00`3oo`0:00;o3@02o`H00_l500;o1P02o`H00_l500;o2@02o`T00_l600Co1P02o`T00_l700;o
2@07o`L00_l500;o2@02o`P00_l01P3o003o00;o2@02o`T01ol700Ko2@07o`H00_l01P3o003o00;o
2@02o`T01ol700;o1P02o`H00_l;00;o0P03o`030?oo00@00_l01P3o003o00;o0`02oa400_lN0000
6P02o`X00_l300;o3@02oaT00ol800;o0P02o`800_l:00;o3@02o`H02Ol600;o1P02o`D00_l900;o
2@02o`H00ol700;o2@02o`L00_l900Go2P02o`<00_l:00;o2002o`030?oo00;o00<0ool02@02o`T0
1Ol900Ko2@05o`P00_l00`3oo`02o`030?oo00T00_l900Wo1@02o`H00_l600;o2`02o`800_l200;o
1002o`030?oo00;o00<0ool00`02oa400_lN00006`02o`X000Co00000_l<00;o5P02o`<00_l800;o
00<0ool00`02o`X00_l=00;o1P09o`H00_l600;o1@02o`T00_l900;o1P04o`H00_l900;o1`02o`T0
0_l0103oool900;o0`02o`D00_l300;o0`02o`<00_l00`3oo`02o`030?oo00T00_l900;o00@0oooo
2002o`800_l900;o00@0oooo1`02o`030?oo00;o00<0ool02@02o`T00_l500?o1002o`H00_l600;o
2`02o`030?oo00<00_l400;o00<0ool00_l00`3oo`0300;o4@02oah0000K00;o2P02o`800_l<00;o
5P02o`<00ol700Go0`02o`X00_l=00;o1P02o`D00_l600;o1P02o`D00_l900;o2@02o`D01_l500?o
2002o`L00_l900;o0P03o`T00_l0103oool500;o0`02o`<00_l200;o0`02o`<00_l800;o2@02o`80
0ol700;o0P02o`800_l500;o0P03o`D00_l300;o0`02o`P00_l900;o1P02o`@00_l600;o1P02o`/0
1Ol300;o0`02o`<00_l300;o0P03o`L00_l700;o7P0001/00ol:0003o`0000;o3002oaH00_l400?o
1P04o`@00_l:00;o3@02o`H00_l500;o1P02o`H00_l500;o2P02o`L00_l500?o0P03o`D00_l700;o
2002o`T00_l300?o2002o`030?oo00H00_l300;o0`02o`800_l300;o0`02o`P00_l900;o0`03o`H0
0_l600;o1@02o`<00ol400;o0`02o`<00_l800;o2@02o`H00_l400;o1P02o`H00_l;00Co1002o`<0
0_l300;o0`02o`<00_l700;o1`02oah0000L00;o2`001?l0ool;00;o5`02o`D00_l600Co1002o`X0
0_l=00;o1P02o`D00_l600;o1P02o`D00_l:00?o1@03o`D00_l400;o1P02o`D00_l900;o2@02o`@0
0ol700Go1P02o`<00_l300;o0P02o`P00_l800;o2@02o`@00ol500;o1P02o`D00_l400?o0`02o`P0
0_l800;o2@02o`D00ol400;o1P02o`H00_l;00Co1002o`<00_l800;o0`03o`D00ol700;o7P0001d0
0_l:00Co2P02oaP02_l400Co0P06o`@02_l500[o0P04o`<01?l400Co1004o`030?oo00Ko2009o`@0
1Ol200Go1009o`D02_l300Go0`05o`801ol700co00<0ool01?l200Ko0`0:o`<01Ol300Go00<0ool0
2_l300Go0`0;o`801_l300[o0`0;o`@01?l400Co0P08o`L01?l200Ko00<0ool01?l200Ko0`0:o`<0
2_lJ00007P000ol0000900?o2P000ol0000G00[o1003o`<01_l400[o1@0:o`801?l300Co1004o`@0
1?l00`3oo`06o`X01Ol600Go0P05o`H01Ol700[o0`05o`<01Ol200Oo1`0<o`030?oo00Co0P06o`<0
2_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko0`0:o`<02Ol600Co1004o`802?l700?o0`06o`03
0?oo00Co0P06o`D01Ol00`3oo`0300[o6P0002X00ooo0<d0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(5\\) ZNOJHULRXQIKCTWIKEKWIRULMWCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oi/00_l400?oo`0M00007002oaX00_nJ00[o
o`0L00006`02oa`00_nJ00Go0P02ool0700001/00_lL00;oVP000ol0003o0280000K00;o2P05o`d0
0_lF00[o1006o`<00_l600Go2006o`L01?l300Co2004o`D03Ol00`3oo`03o`H00ol00`3oo`03o`80
1Ol600Go1`0:o`<01Ol600;o1@05o`P02?l600;o1002o`H02_l300Go1P02o`030?oo00[o0`05o`H0
0_l300;o1002o`H02_l300Go1P03o`D01?l600go00<0ool00ol300Go1002o`@00_l800Go1P0:oaX0
000J00;o2@09o``00_lE00[o1006o`800ol400Wo1009o`H01?l300Co1P08o`<03Ol00`3oo`03o`D0
1?l00`3oo`03o`801Ol400Wo1@0:o`<01Ol500?o0`09o`H02?l600;o1002o`H02_l300Go1@03o`03
0?oo00[o0`05o`D00ol300;o1002o`H02_l300Go1@04o`<02?l400go00<0ool00ol300Go1002o`@0
0_l600Wo100:oaX0000J00;o2@02o`D00_l<00;o5P02o`D00_l500;o1004o`<00ol500?o0`03o`@0
0ol600;o1@02o`L00_l400;o1P02o`H00_l300;o1@03o`@00ol400?o1003o`D00ol800;o2@02o`D0
0ol300?o1@03o`P00_l800?o1003o`T00_l900;o1@03o`@00_l600;o1@02o`D00ol300?o1003o`T0
0_l900;o1@03o`D00_l400;o1`02o`H00_l200;o1`02o`@00ol400?o1003o`D00ol700;o7P0001X0
0_lA00;o2`02oaH00ol400;o1@02o`@01?l300;o1`02o`<00_l600;o1P02o`D00_l600;o1P02o`D0
0_l600;o0`02o`D00_l600?o0P03o`D00_l700;o2002o`T00_l500;o1002o`L00_l800;o2004o`<0
0ol900;o2@02o`D00_l500;o1P02o`D00_l500;o1004o`<00ol900;o2@02o`D00_l500;o1P02o`H0
0_l600;o0P02o`L00_l400Co0`03o`@00_l700;o1`02oah0000J00;o4@02o`/00_lG00?o0`02o`D0
0_l300Go0P02o`T00_l200;o1P02o`H00_l500;o1P02o`H00_l500;o1P02o`<00_l400;o2002o`80
0_l500;o2@02o`L00_l900;o1002o`@00olA00;o2004o`801?l900;o2@02o`@00_l600;o0P02o`80
0_l500;o1002o`D01?l200Co2@02o`T00_l400;o1P02o`H00_l600;o1P02o`800_l300;o0P02o`@0
1?l200Co0`03oa000_lN00006P02oa400_l;00;o6002o`<00_l500;o0`02o`030?oo00800_l900;o
0P02o`H00_l600;o1@02o`H00_l600;o1@02o`H00_l300;o0`03o`T01?l600;o2@02o`L00_l900?o
0P03o`@00_lB00;o2002o`040?l000Co2@02o`T00ol200?o1P02o`800_l900?o0P03o`D00_l0103o
0004o`T00_l900;o0`03o`H00_l600;o1P02o`H00_l200;o0P03o`800_l400;o00@0o`001?l300;o
4@02oah0000J00;o4@02o`/00_lH00?o2@02o`800ol00`3oo`0200;o2@02o`X00_l600;o1@02o`H0
0_l600;o1@02o`/01ol:00Co1P02o`T00_l700;o2@07o`D00_lB00;o2002o`060?l00?l00_l900;o
2@07o`L01_l900Oo1P02o`060?l00?l00_l900;o2@07o`L00_l600;o1P02o`X00_l20003o`3o0080
0_l400;o00H0o`00o`02o`<00_lA00;o7P0001X00_l:00;o1002o``00_lI00?o2002o`800_l200;o
0P02o`T00_l:00;o1P09o`H00_l600;o1@02o`/02Ol800?o1`02o`T00_l700;o2@05o`L00_lB00;o
2002o`030?oo00;o00<0ool02@02o`T01Ol900Ko2@05o`P00_l00`3oo`02o`030?oo00T00_l900Wo
1@02o`H00_l600;o2P02o`040?oo00;o00<0ool01002o`030?oo00;o00<0ool00`02oa400_lN0000
6`02o`T02?l;00;o5P02o`<00_l800;o00<0ool00`02o`800_l900;o2P02o`H02Ol600;o1P02o`D0
0_l;00;o1@03o`L01?l600;o2@02o`L00_l900;o00@0oooo1P02o`d00_l300;o0`02o`<00_l00`3o
o`02o`030?oo00T00_l900;o00@0oooo2002o`800_l900;o00@0oooo1`02o`030?oo00;o00<0ool0
2@02o`T00_l500?o1002o`H00_l600;o2P02o`030?oo008000Co0?oo1002o`030?oo00;o00<0ool0
0`02oa400_lN00006`02o`T01ol<00;o5P02o`<00ol700Go0`02o`800_l900;o2P02o`H00_l500;o
1P02o`H00_l500;o2`02o`H00_l600Ko1@03o`P00_l700;o2@02o`800ol500?o1`02o`<00_l300;o
0`02o`800_l300;o0`02o`P00_l900;o0P03o`L00_l200;o0P02o`D00_l200?o1@02o`<00_l300;o
2002o`T00_l600;o1002o`H00_l600;o2P02o`030?l0008000Co0?oo0`02o`<00_l300;o0P03o`L0
0_l700;o7P0001/00ol800;o4@02oaH00_l400?o1P04o`@00_l300;o1`02o`/00_l600;o1@02o`H0
0_l600;o1@02o`/00_l600;o1@03o`800ol500;o1`02o`P00_l900;o0`03o`D00_l700;o0`02o`<0
0_l300;o0P02o`<00_l300;o2002o`T00_l300?o1P02o`H00_l500;o0`03o`@00_l300;o0`02o`P0
0_l900;o1P02o`@00_l600;o1P02o`X01?l300Co0`02o`<00_l300;o0`02o`L00_l700;o7P0001`0
0_l800;o4002oaL00_l500;o1P04o`@00_l300?o1@03o`/00_l600;o1@02o`H00_l600;o1@02o`/0
0_l500?o1@02o`@00_l600;o1@02o`T00_l900;o1003o`@00ol500?o0`02o`<00_l300;o0P02o`P0
0_l800;o2@02o`@00ol500;o1P02o`D00_l400?o0`02o`P00_l800;o2@02o`D00ol400;o1P02o`H0
0_l:00Co1003o`<00_l800;o0`03o`D00ol700;o7P0001d00_l700;o3`02oaP02_l400Co0P06o`<0
2Ol700[o0P04o`<01?l400Co1004o`030?oo00Ko1P0;o`@01Ol200Go1009o`D02_l300Go0`05o`<0
2_l300co00<0ool01?l200Ko0`0:o`<01Ol300Go00<0ool02_l300Go0`0;o`801_l300[o0`0;o`@0
1?l400Co0P08o`H01?l500Co00<0ool01?l200Ko0`0:o`<02_lJ00007P000ol0000500So2@000ol0
000G00[o1003o`<01_l500Go2@0:o`801?l300Co1004o`@01?l00`3oo`06o`H02Ol600Go0P05o`H0
1Ol700[o0`05o`<01Ol500Go00<0ool00`0<o`030?oo00Co0P06o`<02_l300Go0`05o`030?oo00[o
0`05o`<02ol200Ko0`0:o`<02Ol600Co1004o`802?l600Co1@04o`030?oo00Co0P06o`D01Ol00`3o
o`0300[o6P0002H02?oo0<`0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(6\\) ZNOJHVLRXQIPCTWIKEKWIRULMWCL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oi/00_l400?oo`0M00007002oaX00_nJ00[o
o`0L00006`02oa`00_nJ00Go0P02ool0700001/00_lL00;oVP000ol0003o0280000K00;o2`04o`d0
0_lF00[o1006o`<00_l600Go2006o`L01?l300Co2002o`L03Ol00`3oo`03o`H00ol00`3oo`03o`80
1Ol600Go1`0:o`<02?l:00Go2008o`H00_l400;o1P0:o`<01Ol600;o00<0ool02_l300Go1P02o`<0
0_l400;o1P0:o`<01Ol600?o1@04o`H03Ol00`3oo`03o`<01Ol400;o1002o`P01Ol500go600001X0
0_l;00Oo3002oaD02_l400Ko0P03o`@02Ol400Wo1P04o`<01?l700Co1P0=o`030?oo00?o1@04o`03
0?oo00?o0P05o`@02Ol500[o0`08o`P02Ol600So1P02o`@00_l600[o0`05o`D00ol00`3oo`0:o`<0
1Ol500?o0`02o`@00_l600[o0`05o`D01?l300So100=o`030?oo00?o0`05o`@00_l400;o1P09o`<0
3OlH00006P02o`X00_l400;o3002oaH00_l500;o1@02o`@01?l300?o1@03o`<00ol400?o1P02o`D0
0_l800Co2@02o`H00_l300;o1@03o`@00ol400?o1003o`D00ol800;o2@02o`/00ol500?o2002o`P0
0ol400?o2@02o`T00_l500?o1002o`H00_l500;o1@03o`<00ol400?o2@02o`T00_l500?o1@02o`@0
0_l700;o1P02o`800_l700;o1003o`@00ol400?o1@03o`D00_l600;o600001X00_l900;o1P02o`/0
0_lF00?o1002o`D00_l400Co0`02o`L00_l300;o1P02o`H00_l500;o2004o`T00_l600;o0`02o`D0
0_l600?o0P03o`D00_l700;o2002o`T00_l;00;o1`02o`P00_l800Co0`03o`T00_l900;o1@02o`D0
0_l600;o1@02o`D00_l400Co0`03o`T00_l900;o1@02o`D00_l600;o1P02o`H00_l200;o1`02o`@0
1?l300?o1002o`L00_l500;o1P02oaP0000J00;o2@02o`H00_l;00;o5`03o`<00_l500;o0`05o`80
0_l900;o0P02o`H00_l600;o1@02o`L00_l200;o2002o`H00_l300;o1002o`P00_l200;o1@02o`T0
0_l700;o2@02o`X00olA00;o2004o`801?l900;o2@02o`@00_l600;o0P02o`800_l500;o1002o`D0
1?l200Co2@02o`T00_l400;o1P02o`H00_l600;o1P02o`800_l300;o0P02o`@01?l200Co0`03o`h0
0_l600;o600001X00_l900;o1P02o`/00_lH00;o0`02o`D00_l300;o00<0ool00P02o`T00_l200;o
1P02o`H00_l500;o1`02o`800_l800;o1P02o`<00_l300?o2@04o`H00_l900;o1`02o`T01ol500;o
4P02o`P00_l0103o0004o`T00_l900?o0P03o`H00_l200;o2@03o`800ol500;o00@0o`001?l900;o
2@02o`<00ol600;o1P02o`H00_l600;o0P02o`800ol200;o1002o`040?l000Co0`02o`l00_l600;o
600001X00_l900;o1P02o`/00_lH00?o2@02o`800ol00`3oo`0200;o2@02o`X00_l600;o1@02o`H0
0ol200?o1`02o`/01ol:00Co1P02o`T00_l700;o2@09o`<00_lB00;o2002o`060?l00?l00_l900;o
2@07o`L01_l900Oo1P02o`060?l00?l00_l900;o2@07o`L00_l600;o1P02o`X00_l20003o`3o0080
0_l400;o00H0o`00o`02o`<00_l?00;o800001X00_l900?o1002o``00_lI00?o2002o`800_l200;o
0P02o`T00_l:00;o1P09o`H00_l400;o1`02o`/02Ol800?o1`02o`T00_l700;o2@02o`D00ol200;o
4P02o`P00_l00`3oo`02o`030?oo00T00_l900Go2@06o`T01Ol800;o00<0ool00_l00`3oo`0900;o
2@09o`D00_l600;o1P02o`X00_l0103oo`02o`030?oo00@00_l00`3oo`02o`030?oo00<00_l?00;o
800001/00_l800Wo2`02oaH00_l300;o2002o`030?oo00<00_l200;o2@02o`X00_l600Wo1P02o`@0
0_l700;o2`02o`D00ol700Co1P02o`T00_l700;o2@02o`H00_l200;o3@02o`<00_l300;o0`02o`03
0?oo00;o00<0ool02@02o`T00_l0103oool800;o0P02o`T00_l0103oool700;o00<0ool00_l00`3o
o`0900;o2@02o`D00ol400;o1P02o`H00_l:00;o00<0ool00P001?l0ool400;o00<0ool00_l00`3o
o`0300;o3`02ob00000K00;o2002o`030?oo00;o3@02oaH00_l300?o1`05o`<00_l200;o2@02o`X0
0_l600;o1@02o`D00_l600;o1P02o`/00_l600;o1P06o`D00ol800;o1`02o`T00_l600;o0P03o`L0
0_l300;o0`02o`<00_l200;o0`02o`<00_l800;o2@02o`800ol700;o0P02o`800_l500;o0P03o`D0
0_l300;o0`02o`P00_l900;o1P02o`@00_l600;o1P02o`X00_l00`3o00020004o`3oo`<00_l300;o
0`02o`800ol700;o1@02ob00000K00?o2002oa400_lF00;o1003o`H01?l400;o0`02o`L00_l;00;o
1P02o`D00_l500;o1P02o`H00_l;00;o1P02o`D00ol200?o1@02o`L00_l800;o2@02o`H00_l300;o
1`02o`<00_l300;o0`02o`800_l300;o0`02o`P00_l900;o0`03o`H00_l600;o1@02o`<00ol400;o
0`02o`<00_l800;o2@02o`H00_l400;o1P02o`H00_l:00Co0`04o`<00_l300;o0`02o`<00_l700;o
1@02ob00000L00;o2003o`l00_lG00;o1@02o`H01?l400;o0`03o`D00ol;00;o1P02o`D00_l400?o
1P03o`D00_l;00;o1@03o`D00_l400;o1P02o`D00_l900;o2@02o`D00ol300?o1@03o`<00_l300;o
0`02o`800_l800;o2002o`T00_l400?o1@02o`H00_l500;o1003o`<00_l800;o2002o`T00_l500?o
1002o`H00_l600;o2P04o`@00ol300;o2002o`<00ol500?o1@02ob00000M00;o2003o`d00_lH00[o
1004o`801_l300Wo1`0:o`801?l300Co0P06o`801_l00`3oo`06o`H02ol400Go0P05o`@02Ol500[o
0`0;o`D02_l300co00<0ool01?l200Ko0`0:o`<01Ol300Go00<0ool02_l300Go0`0;o`801_l300[o
0`0;o`@01?l400Co0P08o`H01?l500Co00<0ool01?l200Ko0`0:o`802?lM00007P000ol0000700Oo
20000ol0000G00[o1003o`<01_l500Go2@0:o`801?l300Co0P06o`801_l00`3oo`06o`H02Ol600Go
0P05o`H01Ol700[o0`09o`T01Ol00`3oo`0300co00<0ool01?l200Ko0`0:o`<01Ol300Go00<0ool0
2_l300Go0`0;o`801_l300[o0`09o`H01?l400Co0P08o`H01?l500Co00<0ool01?l200Ko1@05o`03
0?oo00802?lM0000:P05ool0b`000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(7\\) ZNOJHTLRXQMPCTWIKEKWIRULMWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oi/00_l400?oo`0M00007002oaX00_nJ00[o
o`0L00006`02oa`00_nJ00Go0P02ool0700001/00_lL00;oVP000ol0003o0280000K00;o2`02o`l0
0_lF00[o1006o`<00_l600Go2006o`L01?l300Co1@08o`@03Ol00`3oo`03o`H00ol00`3oo`03o`80
1Ol600Go1P05o`<01Ol00`3oo`06o`X01Ol800So1P02o`@00_l600[o0`05o`H00_l00`3oo`0:o`<0
1Ol600;o0`02o`@00_l600[o0`05o`H00ol500Co1P0=o`030?oo00?o0`05o`@00_l400;o1@08o`D0
3OlH00006P02o``00_l@00;o5@0:o`@01_l200?o1009o`@02Ol600Co0`04o`D02?l400go00<0ool0
0ol500Co00<0ool00ol200Go1009o`@01Ol300Go00<0ool01_l800Wo1P08o`H00_l400;o1P0:o`<0
1Ol500?o00<0ool02_l300Go1@03o`<00_l400;o1P0:o`<01Ol500Co0`08o`@03Ol00`3oo`03o`<0
1Ol400;o1002o`D02_l300go600001X00_l=00;o3`02oaH00_l500;o1@02o`@01?l300?o1@03o`<0
0ol400?o1P02o`D00_l900;o2P02o`H00_l300;o1@03o`@00ol400?o1003o`D00ol400;o1`02o`@0
0_l;00?o1@03o`P00_l800?o1003o`T00_l900;o1@03o`@00_l600;o1@02o`D00ol300?o1003o`T0
0_l900;o1@03o`D00_l400;o1`02o`H00_l200;o1`02o`@00ol400?o1@02o`@01?l500;o1P02oaP0
000J00;o3@02o`l00_lF00?o1002o`D00_l400Co0`02o`L00_l300;o1P02o`H00_l500;o2@02o`X0
0_l600;o0`02o`D00_l600?o0P03o`D00_l700;o1002o`L00_l400;o2`02o`L00_l800;o2004o`<0
0ol900;o2@02o`D00_l500;o1P02o`D00_l500;o1004o`<00ol900;o2@02o`D00_l500;o1P02o`H0
0_l600;o0P02o`L00_l400Co0`03o`D00_l600;o1@02o`H00_lH00006P02o`d00_l?00;o5`03o`<0
0_l500;o0`05o`800_l900;o0P02o`H00_l600;o1@02o`T00_l:00;o1P02o`<00_l400;o2002o`80
0_l500;o2@02o`<00_l300;o0P02o`@00_l:00?o4@02o`P01?l200Co2@02o`T00_l400;o1P02o`80
0_l200;o1@02o`@00_l500Co0P04o`T00_l900;o1002o`H00_l600;o1P02o`H00_l200;o0`02o`80
0_l400Co0P04o`D00_l700;o1002o`H00_lH00006P02o`h000?o00003@02oaP00_l300;o1@02o`<0
0_l00`3oo`0200;o2@02o`800_l600;o1P02o`D00_l900;o2P02o`H00_l300;o0`03o`T01?l600;o
2@02o`<00_l200?o0P02o`@01ol500;o4P02o`P00_l0103o0004o`T00_l900?o0P03o`H00_l200;o
2@03o`800ol500;o00@0o`001?l900;o2@02o`<00ol600;o1P02o`H00_l600;o0P02o`800ol200;o
1002o`040?l000Co1@02o`L00_l400;o1P02oaP0000J00;o3P02o`h00_lH00?o2@02o`800ol00`3o
o`0200;o2@02o`X00_l600;o1@02o`T00_l:00;o2`07o`X01?l600;o2@02o`<00_l20003o`3o0080
0_l400Wo0`02oa800_l800;o00H0o`00o`02o`T00_l900Oo1`06o`T01ol600;o00H0o`00o`02o`T0
0_l900Oo1`02o`H00_l600;o2P02o`8000?o0?l00P02o`@00_l01P3o003o00;o1@02o`L00_l400;o
800001X00_l>00;o3P02oaT00ol800;o0P02o`800_l200;o2@02o`X00_l600Wo2@02o`X00_l;00Wo
2003o`L00_l900;o0`02o`040?oo00;o00<0ool01002o`D00ol200;o4P02o`P00_l00`3oo`02o`03
0?oo00T00_l900Go2@06o`T01Ol800;o00<0ool00_l00`3oo`0900;o2@09o`D00_l600;o1P02o`X0
0_l0103oo`02o`030?oo00@00_l00`3oo`02o`030?oo00D00_l700;o1002ob00000K00;o3P000ol0
000;00;o5P02o`<00_l800;o00<0ool00`02o`800_l900;o2P02o`H02Ol400;o0`02o`<00_l500;o
2`02o`D00ol700Co1P02o`T00_l300;o00<0ool00P001?l0ool400;o1P02o`800_l=00;o0`02o`<0
0_l300;o00<0ool00_l00`3oo`0900;o2@02o`040?ooo`P00_l200;o2@02o`040?ooo`L00_l00`3o
o`02o`030?oo00T00_l900;o1@03o`@00_l600;o1P02o`X00_l00`3oo`020004o`3oo`@00_l00`3o
o`02o`030?oo00D00_l700;o1002ob00000K00;o3P02o``00_lF00;o0`03o`L01Ol300;o0P02o`T0
0_l:00;o1P02o`D00_l400;o0`02o`<00_l500;o2`02o`H00_l600Ko1@03o`P00_l300;o00<0o`00
0P001?l0ool400;o1P02o`800ol700;o0`02o`<00_l300;o0P02o`<00_l300;o2002o`T00_l200?o
1`02o`800_l200;o1@02o`800ol500;o0`02o`<00_l800;o2@02o`H00_l400;o1P02o`H00_l:00;o
00<0o`000P001?l0ool300;o0`02o`<00_l400;o1`02o`@00_lP00006`03o`d00_l<00;o5P02o`@0
0ol600Co1002o`<00_l700;o2`02o`H00_l500;o1002o`<00_l300;o1@02o`/00_l600;o1@03o`80
0ol500;o1`02o`@01?l300Co1002o`H00_l300;o1`02o`<00_l300;o0`02o`800_l300;o0`02o`P0
0_l900;o0`03o`H00_l600;o1@02o`<00ol400;o0`02o`<00_l800;o2@02o`H00_l400;o1P02o`H0
0_l:00Co0`04o`<00_l300;o0`02o`@00_l600;o1@02ob00000L00;o3P000ol0000900;o5`02o`D0
0_l600Co1002o`<00ol500?o2`02o`H00_l500;o1002o`<00_l300;o1@02o`/00_l500?o1@02o`@0
0_l600;o1@02o`D01?l400?o1002o`D00ol300?o1@03o`<00_l300;o0`02o`800_l800;o2002o`T0
0_l400?o1@02o`H00_l500;o1003o`<00_l800;o2002o`T00_l500?o1002o`H00_l600;o2P04o`@0
0ol300;o2002o`@00_l400Co1@02ob00000M00;o1P02o`D00_l900;o600:o`@01?l200Ko0`09o`L0
2_l200Co0`04o`<03?l200So1P0;o`@01Ol200Go1009o`@01?l500Co00<0ool02Ol500[o0`0<o`03
0?oo00Co0P06o`<02_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko0`0:o`<02ol400Co1004o`80
2?l600Co1@04o`030?oo00Co0P06o`802_l300So7@0001h000?o00001009o`T000?o00005`0:o`@0
0ol300Ko1@05o`T02_l200Co0`04o`<03?l200So1P09o`H01Ol200Go1P05o`H01?l500Co00<0ool0
1ol900Go00<0ool00`0<o`030?oo00Co0P06o`<02_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko
0`0:o`<02Ol600Co1004o`802?l600Co1@04o`030?oo00Co0P06o`802?l500So7@0002D02Ooo0<`0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(8\\) ZIOJHTLRXLMPCT IKEKWIRULMWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l;00Co3@02oaH02_l400[o1`05o`P01_l700Co0`04o`D0
2?l400go00<0ool00ol600?o00<0ool00ol200Go0P0=o`801Ol300Go00<0ool01_l:00Go2008oa@0
2_l300Go1P02o`030?oo00[o0`05o`H00_l300;o1002o`H02_l300Go1P03o`D01?l600go00<0ool0
0ol300Go1002o`@00_l500So1@0=oaP0000J00;o2P08o``00_lE00[o100:o`D02Ol400Wo1P04o`<0
1?l500So100=o`030?oo00?o1@04o`030?oo00?o0P05o`803Ol200Go0`05o`030?oo00Ko2009o`H0
2?lD00[o0`05o`D00ol00`3oo`0:o`<01Ol500?o0`02o`@00_l600[o0`05o`D01?l300So100=o`03
0?oo00?o0`05o`@00_l400;o1@0:o`<03OlH00006P02o`T00ol400?o2`02oaH00_l500;o2002o`P0
0ol500?o0`03o`@00ol600;o1@02o`T00_l:00;o1P02o`<00_l500?o1003o`@00ol600;o1P02o`<0
0_l700;o1002o`/00ol500?o2002oa/00_l900;o1@03o`@00_l600;o1@02o`D00ol300?o1003o`T0
0_l900;o1@03o`D00_l400;o1`02o`H00_l200;o1`02o`@00ol400?o1@02o`@01?l500;o1P02oaP0
000J00;o2@02o`H00_l;00;o5P03o`@00_l800;o2002o`L00_l300;o1P02o`H00_l500;o2@02o`X0
0_l600;o0`02o`D00_l600?o0P03o`L00_l600;o0`02o`L00_l400;o2`02o`L00_l800;o6`02o`T0
0_l500;o1@02o`H00_l500;o1@02o`@01?l300?o2@02o`T00_l500;o1@02o`H00_l600;o1P02o`80
0_l700;o1004o`<00ol500;o1P02o`D00_l600;o600001X00_l900;o1P02o`/00_lG00?o0`02o`P0
0_l700;o2@02o`800_l600;o1P02o`D00_l900;o2P02o`H00_l300;o1002o`P00_l200;o2002o`H0
0_l300;o0`02o`800_l400;o2P03oa400_lK00;o2@02o`@00_l600;o0P02o`800_l500;o1002o`D0
1?l200Co2@02o`T00_l400;o1P02o`H00_l600;o1P02o`800_l300;o0P02o`@01?l200Co1@02o`L0
0_l400;o1P02oaP0000J00;o2@02o`H00_l;00;o6002o`<00_l800;o1`02o`T00_l200;o1P02o`H0
0_l500;o2@02o`X00_l600;o0`02o`<00ol900Co2@02o`H00_l300;o0P03o`800_l400Oo1@02oa80
0_lK00;o2@03o`800ol600;o0P02o`T00ol200?o1@02o`040?l000Co2@02o`T00_l300?o1P02o`H0
0_l600;o1P02o`800_l200?o0P02o`@00_l0103o0004o`D00_l700;o1002o`H00_lH00006P02o`X0
0_l400;o3002oaP00ol<00;o1`02o`T00_l:00;o1P02o`D00_l900;o2P02o`/01ol:00Co2@02o`/0
0_l20003o`3o00800_l400Wo0`02oa800_lK00;o2@07o`L01_l900Oo1P02o`060?l00?l00_l900;o
2@07o`L00_l600;o1P02o`X00_l20003o`3o00800_l400;o00H0o`00o`02o`D00_l700;o1002ob00
000J00;o2`07o``00_lI00?o2`02o`L00_l900;o2P02o`H02Ol900;o2P02o`/02Ol800?o2P02o`/0
0_l0103oo`02o`030?oo00@00_l500?o0P02oa800_lK00;o2@05o`T01_l900Go2002o`030?oo00;o
00<0ool02@02o`T02Ol500;o1P02o`H00_l:00;o00@0ool00_l00`3oo`0400;o00<0ool00_l00`3o
o`0500;o1`02o`@00_lP00006`02o`X01_l<00;o5P02o`<00_l;00;o1`02o`T00_l:00;o1P09o`@0
0_l300;o0`02o`D00_l;00;o1@03o`L01?l900;o2`02o`030?oo008000Co0?oo1002o`H00_l200;o
3@02o`<00_l300;o5P02o`T00_l0103oool800;o0P02o`T00_l0103oool700;o00<0ool00_l00`3o
o`0900;o2@02o`D00ol400;o1P02o`H00_l:00;o00<0ool00P001?l0ool400;o00<0ool00_l00`3o
o`0500;o1`02o`@00_lP00006`02o`T00_l400;o2`02oaH00_l300?o2P02o`L00_l900;o2P02o`H0
0_l500;o1002o`<00_l300;o1@02o`/00_l600;o1P06o`P00_l;00;o00<0o`000P001?l0ool400;o
1P02o`800ol700;o0`02o`<00_l300;o5P02o`T00_l200?o1`02o`800_l200;o1@02o`800ol500;o
0`02o`<00_l800;o2@02o`H00_l400;o1P02o`H00_l:00;o00<0o`000P001?l0ool300;o0`02o`<0
0_l400;o1`02o`@00_lP00006`03o`L00_l600;o2P02oaH00_l400?o2@02o`P00_l700;o2`02o`H0
0_l500;o1002o`<00_l300;o1@02o`/00_l600;o1@03o`800ol700;o2`04o`<01?l400;o1P02o`<0
0_l700;o0`02o`<00_l300;o5P02o`T00_l300?o1P02o`H00_l500;o0`03o`@00_l300;o0`02o`P0
0_l900;o1P02o`@00_l600;o1P02o`X01?l300Co0`02o`<00_l300;o1002o`H00_l500;o800001`0
0_l700;o1P02o`T00_lG00;o1@02o`T00_l800?o1@03o`/00_l600;o1@02o`@00_l300;o0`02o`D0
0_l;00;o1@03o`D00_l400;o1`02o`/01?l400?o1002o`D00ol300?o1@03o`<00_l300;o0`02oaH0
0_l900;o1003o`D00_l600;o1@02o`@00ol300;o2002o`P00_l900;o1@03o`@00_l600;o1P02o`X0
1?l400?o0`02o`P00_l400;o1004o`D00_lP00007@02o`H00ol400?o2002oaP02_l400[o1@09o`L0
2_l200Co0`04o`<03?l200So1P0;o`@01Ol200Go0P08o`L01?l500Co00<0ool02Ol500[o0`0<oa80
2_l300Go0`05o`030?oo00[o0`05o`<02ol200Ko0`0:o`<02ol400Co1004o`802?l600Co1@04o`03
0?oo00Co0P06o`802_l300So7@0001h000?o00001@08o`T000?o00005`0:o`@02_l700Go2@0:o`80
1?l300Co0`0<o`802?l600Wo1P05o`801Ol200So1`04o`D01?l00`3oo`07o`T01Ol00`3oo`0300co
4P0:o`<01Ol300Go00<0ool02_l300Go0`0;o`801_l300[o0`09o`H01?l400Co0P08o`H01?l500Co
00<0ool01?l200Ko0P08o`D02?lM00009`06ool0c@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(9\\) ZIOJHTLRXLMPCT IFEKWIRULHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l800Go3`02oaH02_l400[o1`05o`P01_l700Co0`04o`D0
2?l400go00<0ool00ol600?o00<0ool00ol200Go0P0=o`801Ol300Go00<0ool01_l:00Go2008oa@0
2_l300Oo1`0<o`<01Ol600;o0`02o`@00_l600[o0`05o`H00ol500Co1P0=o`801?l300Co1@02o`@0
0_l500So1@0=oaP0000J00;o2@07o`h00_lE00[o100:o`D02Ol400Wo1P04o`<01?l500So100=o`03
0?oo00?o1@04o`030?oo00?o0P05o`803Ol200Go0`05o`030?oo00Ko2009o`H02?lD00[o0`07o`L0
3?l300Go1@03o`<00_l400;o1P0:o`<01Ol500Co0`08o`@03Ol200Co0`04o`D00_l400;o1@0:o`<0
3OlH00006P02o`h00ol=00;o5P02o`D00_l800;o2003o`D00ol300?o1003o`H00_l500;o2@02o`X0
0_l600;o0`02o`D00ol400?o1003o`H00_l600;o0`02o`L00_l400;o2`03o`D00ol800;o6`02o`T0
0_l<00;o1P02o`D00_l500?o0`03o`@00ol900;o2@02o`D00ol500;o1002o`L00_l600;o0`02o`D0
0_l500?o1003o`D00_l400Co1@02o`H00_lH00006P02o`l00ol<00;o5P03o`@00_l800;o2002o`L0
0_l300;o1P02o`H00_l500;o2@02o`X00_l600;o0`02o`D00_l600?o0P03o`L00_l600;o0`02o`L0
0_l400;o2`02o`L00_l800;o6`02o`T00_l<00;o1P02o`D00_l500;o1004o`<00ol900;o2@02o`D0
0_l500;o1P02o`H00_l600;o0`02o`D00_l500Co0`03o`D00_l600;o1@02o`H00_lH00006P02oa00
0_l<00;o5`03o`<00_l800;o1`02o`T00_l200;o1P02o`H00_l500;o2@02o`X00_l600;o0`02o`@0
0_l800;o0P02o`P00_l600;o0`02o`<00_l200;o1002o`X00olA00;o6`02o`T00_l200;o2002o`80
0_l200;o1@02o`@00_l500Co0P04o`T00_l900;o1002o`H00_l600;o1P02o`H00_l300;o1@02o`D0
1?l200Co1@02o`L00_l400;o1P02oaP0000J00;o3004o`030?oo00/00_lH00;o0`02o`P00_l700;o
2@02o`800_l600;o1P02o`D00_l900;o2P02o`H00_l300;o0`03o`T01?l900;o1P02o`<00_l200?o
0P02o`@01ol500;o4P02oa/00_l900;o0P02o`P00_l200;o2@03o`800ol500;o00@0o`001?l900;o
2@02o`<00ol600;o1P02o`H00_l600;o0`02o`D00_l500;o00@0o`001?l500;o1`02o`@00_l600;o
600001X00_l:00Wo2`02oaP00ol<00;o1`02o`T00_l:00;o1P02o`D00_l900;o2P02o`/01ol:00Co
2@02o`/00_l20003o`3o00800_l400Wo0`02oa800_lK00;o2@06o`P01_l900Oo1P02o`060?l00?l0
0_l900;o2@07o`L00_l600;o1P02o`/00_l500;o1@02o`060?l00?l00_l500;o1`02o`@00_lP0000
6P02o`X00_l400?o2`02oaT00ol;00;o1`02o`T00_l:00;o1P09o`T00_l:00;o2`09o`P00ol:00;o
2`02o`040?oo00;o00<0ool01002o`D00ol200;o4P02oa/00_l900Ko2006o`T01Ol800;o00<0ool0
0_l00`3oo`0900;o2@09o`D00_l600;o1P02o`/02Ol500;o00<0ool00_l00`3oo`0500;o1`02o`@0
0_lP00006`02o`P00_l600;o2P02oaH00_l300;o2`02o`L00_l900;o2P02o`H02Ol400;o0`02o`<0
0_l500;o2`02o`D00ol700Co2@02o`/00_l00`3oo`020004o`3oo`@00_l600;o0P02o`d00_l300;o
0`02oaH00_l900;o0P02o`P00_l200;o2@02o`040?ooo`L00_l00`3oo`02o`030?oo00T00_l900;o
1@03o`@00_l600;o1P02o`/02Ol500;o00<0ool00_l00`3oo`0500;o1`02o`@00_lP00006`02o`P0
0_l600;o2P02oaH00_l300?o2P02o`L00_l900;o2P02o`H00_l500;o1002o`<00_l300;o1@02o`/0
0_l600;o1P06o`P00_l;00;o00<0o`000P001?l0ool400;o1P02o`800ol700;o0`02o`<00_l300;o
5P02o`T00_l200;o0P02o`@00_l200;o0P02o`D00_l200?o1@02o`<00_l300;o2002o`T00_l600;o
1002o`H00_l600;o2`02o`D00_l400;o0`02o`<00_l400;o1`02o`@00_lP00006`03o`L00_l600;o
2P02oaH00_l400?o2@02o`P00_l700;o2`02o`H00_l500;o1002o`<00_l300;o1@02o`/00_l600;o
1@03o`800ol700;o2`04o`<01?l400;o1P02o`<00_l700;o0`02o`<00_l300;o5P02o`T00_l600;o
1002o`H00_l500;o0`03o`@00_l300;o0`02o`P00_l900;o1P02o`@00_l600;o1P02o`/00_l500;o
1002o`<00_l300;o1002o`H00_l500;o800001`00_l700;o1P000ol0000800;o5`02o`D00_l900;o
2003o`D00ol;00;o1P02o`D00_l400;o0`02o`<00_l500;o2`02o`D00ol500;o1002o`L00_l;00Co
1003o`@00_l500?o0`03o`D00ol300;o0`02o`<00_lF00;o2@02o`H00_l400;o1P02o`D00_l400?o
0`02o`P00_l800;o2@02o`D00ol400;o1P02o`H00_l;00;o1@02o`@00_l800;o1002o`@01?l500;o
800001d00_l700;o1002o`T00_lH00[o100:o`D02Ol700[o0P04o`<01?l300co0P08o`H02ol400Go
0P05o`802?l700Co1@04o`030?oo00Wo1@0:o`<03?lB00[o0`0<o`803?l300Go0`0;o`801_l300[o
0`0;o`@01?l400Co0P08o`L01?l300Co0P06o`801_l200[o0`08oad0000N0003o`0000D01ol:0003
o`0001L02_l400[o1`05o`T02_l200Co0`04o`<03?l200So1P09o`H01Ol200Go0P08o`L01?l500Co
00<0ool01ol900Go00<0ool00`0<oa802_l300co0P0<o`<01Ol300_o0P06o`<02_l300Wo1P04o`@0
1?l200So1`04o`<01?l200Ko0P06o`802?l500So7@0002P01?oo0<h0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(10\\) ZIOJHTLRXLMPCTWIFEKWIWUHHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l900Wo2004o``00_lF00[o100:o`P01Ol700Ko2004o`<0
1?l400So100=o`801Ol600So0P05o`<03Ol00`3oo`03o`<01Ol00`3oo`06o`/01Ol700So1`02o`@0
0_l500[o0`07o`P03?l200Go1P02o`@00_l400;o1@0:o`D00_l400;o2P04o`H01?l300Co1004o`<0
1?l400;o1002o`D02?l600go400001<00_l:00Wo1`06o``00_lE00[o100:o`H02Ol300Wo1`04o`<0
1?l400So100=o`801Ol500Wo0P05o`<03Ol00`3oo`03o`<01Ol00`3oo`06o`T02Ol500So1`02o`@0
0_l500[o0`07o`P03?l200Go1@03o`@00_l400;o1@0:o`D00_l400;o2008o`@01?l300Co1004o`<0
1?l400;o1002o`D02_l400go400001<00_l>00;o2@03o`800ol;00;o5P02o`D00_l800;o2@03o`D0
0ol200?o1003o`L00_l500;o2002o`X00_l600;o1002o`D00ol300?o1003o`L00_l600;o0P02o`L0
0_l400;o3003o`D00ol700;o2@03o`@00ol800;o2@02o`d00_l600;o1002o`D00ol400?o1003o`P0
0_l800?o1003o`L00_l400;o1@02o`D00_l600;o1@02o`@00ol400?o1@02o`@01?l600;o1P02oa00
000C00;o3P02o`T00_l400;o2`02oaH00ol400;o2002o`T00_l700;o0P02o`H00_l700;o1@02o`P0
0_l:00;o1P02o`@00_l500;o1@03o`800ol800;o1P02o`800_l700;o1002o``00_l700;o1`02o`T0
1?l300?o2002o`T00_l=00;o1P02o`@00_l500;o1@04o`<00ol800;o2004o`<00ol600;o1P02o`@0
0_l500;o1P02o`D00_l400Co0`03o`D00_l600;o1P02o`H00_l@00004`02o`h00_l800;o1P02o`X0
0_lG00?o0`02o`P00_l800;o2@02o`030?oo00H00_l700;o1@02o`P00_l:00;o1P02o`@00_l400;o
1`02o`800_l900;o1P02o`800_l300;o0P02o`@00_l;00?o4002o`T01?l200Co2002o`T00_l200;o
2@02o`800_l200;o1002o`@00_l600Co0P04o`P00_l800Co0P04o`H00_l600;o1002o`D00_l600;o
1@02o`@01?l200Co1@02o`L00_l500;o1P02oa00000C00;o3P02o`P00_l600;o2P02oaP00_l300;o
2002o`P00_l900;o00<0ool01P02o`L00_l500;o2002o`X00_l600;o1002o`<00ol800Co2P02o`H0
0_l200;o0P03o`800_l400Oo1P02oa400_l900;o00@0o`001?l800;o2@02o`800_l900;o0P02o`P0
0ol200?o1P02o`040?l000Co2002o`P00_l0103o0004o`H00_l600;o1002o`D00_l600;o1@02o`@0
0_l0103o0004o`D00_l700;o1@02o`H00_l@00004`02o`h00_l800;o1P02o`X00_lH00?o3002o`P0
0_l900;o2@02o`L00_l500;o2002o`X00_l<00Oo2@04o`X00_l:00;o0P000ol0o`0200;o1009o`@0
0_lA00;o2@02o`060?l00?l00_l800;o2@06o`T01_l800Oo1`02o`060?l00?l00_l800;o2002o`06
0?l00?l00_l600;o1P02o`@00_l500;o1P02o`D00_l400;o00H0o`00o`02o`D00_l700;o1@02oaP0
000C00;o3P02o`P00_l600;o2P02oaT00ol;00;o2002o`T00_l900;o1`09o`P00_l:00;o3009o`L0
0ol;00;o2P02o`040?oo00;o00<0ool01002o`D00ol300;o4@02o`T00_l00`3oo`02o`030?oo00P0
0_l900Ko2@06o`P01Ol900;o00<0ool00_l00`3oo`0800;o2002o`030?oo00;o00<0ool01P02o`H0
0_l400Wo1P09o`@00_l00`3oo`02o`030?oo00D00_l700;o1@02oaP0000D00;o3@02o`P00_l600;o
2@02oaH00_l300;o2`02o`P00_l900;o2@02o`L02Ol300;o0`02o`<00_l500;o3002o`D00ol600Co
2P02o`X00_l00`3oo`020004o`3oo`@00_l600;o0`02o``00_l300;o0`02o`@00_l00`3oo`02o`03
0?oo00P00_l900;o0P02o`T00_l200;o2002o`040?ooo`P00_l00`3oo`02o`030?oo00P00_l800;o
00<0ool00_l00`3oo`0600;o1P02o`@02Ol600Wo1002o`030?oo00;o00<0ool01@02o`L00_l500;o
600001@00_l=00;o2002o`H00_l900;o5P02o`<00ol:00;o2002o`T00_l900;o1`02o`D00_l300;o
0`02o`<00_l500;o3002o`H00_l500Ko2@02o`X00_l00`3o00020004o`3oo`@00_l600;o0`03o`L0
0_l200;o0`02o`<00_l300;o0`02o`<00_l700;o2@02o`800_l200;o1@02o`800_l200;o1002o`80
0ol600;o0`02o`<00_l700;o1`02o`<00_l300;o1@02o`H00_l400;o1@02o`H00_l500;o0`02o`<0
0_l300;o1002o`L00_l500;o600001@00ol<00;o2002o`H00_l900;o5P02o`@00ol900;o2@02o`L0
0_l:00;o1`02o`D00_l300;o0`02o`<00_l500;o3002o`H00_l400?o0P03o`P00_l:00Co0`04o`@0
0_l600;o1002o`L00_l200;o0`02o`<00_l300;o0`02o`<00_l700;o2@02o`H00_l500;o1P02o`@0
0_l300?o1@02o`<00_l300;o1`02o`L00_l300;o0`02o`D00_l600;o1002o`D00_l600;o1@02o`<0
0_l300;o0`02o`@00_l600;o1P02oaP0000E00;o3002o`T00_l400;o2@02oaL00_l500;o2@02o`T0
0ol500?o2P02o`L00_l500;o0`02o`<00_l300;o1@02o``00_l500?o1002o`@00_l800;o2P04o`@0
0ol400;o1@03o`@00ol500?o0P02o`<00_l300;o0`02o`P00_l700;o2@02o`H00_l500;o1P02o`@0
0_l400?o1002o`P00_l700;o1`02o`P00_l500;o1P02o`@00_l500;o1P02o`D00_l300;o2002o`@0
0_l400Co1P02oaP0000F00;o1`03o`030?oo00T00ol200?o2002oaP02_l400[o1P09o`H02_l300Co
0`04o`803?l200So1`0;o`<01Ol200Go0`08o`H01?l500Co00<0ool02Ol600[o0P0<o`801_l200Ko
0P0:o`<03?l300co0P05o`<01Ol00`3oo`04o`801_l200[o0P06o`801_l300Co1004o`801?l300Co
1004o`<01?l00`3oo`04o`801_l200[o1008oaD0000G0003o`0000D01_l:00Ko2@000ol0000G00[o
100:o`P01Ol800[o0`04o`<01?l200co0P08o`L02Ol500Go0P05o`<02?l600Co1@04o`030?oo00Oo
2P05o`030?oo00803?l200Ko0P06o`802_l300co0`0<o`801Ol300Go00<0ool01?l200Ko0P0:o`80
1_l200Ko0`04o`@01?l200Co0`04o`@01?l300Co00<0ool01?l200Ko0P08o`H02?lE00008P03o`/0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(11\\) UHOJHTLRXLMPCTWIFEKWIWTHHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l900Wo1P09o`T00_lJ00Co1P04o`<01?l700Go1`06o`P0
1?l300Co1008o`@03Ol200Go1P08o`801Ol300go00<0ool00ol300Go00<0ool01_l;00Go1`08o`L0
0_l400;o1@0:o`<01ol800co0P05o`H00_l400;o1002o`D02_l500;o1002o`L02?l500Co0`04o`@0
1?l300Co1002o`@00_l500So1P0=oa00000C00;o2P09o`H02Ol:00;o5`08o`@01?l300Co1@09o`<0
2Ol700Co0`04o`@02?l400go0P05o`D02Ol200Go0`0=o`030?oo00?o0`05o`030?oo00Ko2@09o`D0
2?l700;o1002o`D02_l300Oo200<o`801Ol500?o1002o`@00_l500[o1@02o`@00_l700So1@04o`<0
1?l400Co0`04o`@00_l400;o1@0:o`@03Ol@00004`02o`h00_l=00;o3@02oaL00_l400;o1@02o`D0
0_l500?o1@03o`800ol400?o1`02o`D00_l800;o2P02o`H00_l400;o1@03o`<00ol400?o1`02o`H0
0_l200;o1`02o`@00_l<00?o1@03o`L00_l900?o1003o`P00_l900;o3@02o`H00_l400;o1@03o`@0
0ol400?o2002o`P00ol400?o2@02o`T00_l500;o1P02o`D00_l400?o1003o`D00_l400Co1P02o`H0
0_l@00004`02o`h00_l=00;o3@02oaH00_l600;o1002o`D00_l500;o1`02o`800_l600;o1`02o`D0
0_l800;o2P02o`H00_l400;o1@02o`D00ol200?o2002o`H00_l200;o1`02o`@00_l<00;o1`02o`L0
0_l900Co0`03o`P00_l900;o3@02o`H00_l400;o1@02o`D01?l300?o2002o`P01?l300?o2@02o`T0
0_l500;o1P02o`D00_l400Co0`03o`D00_l600;o1P02o`H00_l@00004`02o`h00_l=00;o3@02oaH0
0_l600;o1002o`D00_l400;o2@02o`030?oo00H00_l700;o1@02o`P00_l:00;o1P02o`@00_l400;o
1`02o`800_l900;o1P02o`800_l300;o0P02o`@00_l;00?o4002o`T01?l200Co2002o`T00_l200;o
2@02o`800_l200;o1002o`@00_l600Co0P04o`P00_l800Co0P04o`T00_l900;o1@02o`H00_l500;o
1004o`801?l500;o1`02o`D00_l600;o400001<00_l>00;o3@02o`d00_lF00;o1P02o`@00_l500;o
1002o`T00_l00`3oo`0600;o1`02o`D00_l800;o2P02o`H00_l400;o0`03o`P01?l:00;o1P02o`80
0_l200?o0P02o`@01ol600;o4@02o`T00_l0103o0004o`P00_l900;o0P02o`T00_l200;o2003o`80
0ol600;o00@0o`001?l800;o2002o`040?l000Co2@02o`T00_l500;o1P02o`D00_l400;o00@0o`00
1?l500;o1`02o`D00_l600;o400001<00_l>00;o3@02o`d00_lF00;o1P02o`@00_l500;o1002o`T0
0_l900;o1`02o`D00_l800;o2P02o``01ol900Co2P02o`X00_l20003o`3o00800_l400Wo1002oa40
0_l900;o00H0o`00o`02o`P00_l900Ko2@06o`P01ol700;o00H0o`00o`02o`P00_l800;o00H0o`00
o`02o`T00_l900;o1@02o`H00_l500;o1002o`060?l00?l00_l500;o1`02o`D00_lH00004`02o`h0
0_l=00;o3@02oaH00_l600;o1009o`@00_l900;o2@02o`L02Ol800;o2P02o``02Ol700?o2`02o`X0
0_l0103oo`02o`030?oo00@00_l500?o0`02oa400_l900;o00<0ool00_l00`3oo`0800;o2@06o`T0
1_l800Go2@02o`030?oo00;o00<0ool02002o`P00_l00`3oo`02o`030?oo00T00_l900Wo1P09o`@0
0_l00`3oo`02o`030?oo00D00_l700;o1@02oaP0000D00;o3@02o`d00_l<00;o5`02o`H00_l400Wo
1002o`T00_l900;o1`09o`<00_l300;o0`02o`D00_l<00;o1@03o`H01?l:00;o2P02o`030?oo0080
00Co0?oo1002o`H00_l300;o3002o`<00_l300;o1002o`030?oo00;o00<0ool02002o`T00_l200;o
2@02o`800_l800;o00@0oooo2002o`030?oo00;o00<0ool02002o`P00_l00`3oo`02o`030?oo00@0
0_l300;o0`02o`@02Ol600Wo1002o`030?oo00;o00<0ool01@02o`L00_l500;o600001@00_l=00;o
3@02o``00_lG00;o1P02o`@00_l500;o1002o`T00_l900;o1`02o`D00_l300;o0`02o`<00_l500;o
3002o`H00_l500Ko2@02o`X00_l00`3o00020004o`3oo`@00_l600;o0`03o`L00_l200;o0`02o`<0
0_l300;o0`02o`<00_l700;o2@02o`800_l200;o1@02o`800_l200;o1002o`800ol600;o0`02o`<0
0_l700;o1`02o`<00_l300;o0`02o`<00_l300;o1002o`D00_l600;o1@02o`<00_l300;o0`02o`@0
0_l700;o1@02oaP0000D00?o3002o`d00_l<00;o5`02o`H00_l400;o1@02o`D00_l700;o2P02o`L0
0_l500;o0`02o`<00_l300;o1@02o``00_l600;o1003o`800ol800;o2P04o`<01?l400;o1P02o`@0
0_l700;o0P02o`<00_l300;o0`02o`<00_l300;o1`02o`T00_l600;o1@02o`H00_l400;o0`03o`D0
0_l300;o0`02o`L00_l700;o0`02o`<00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o0`02o`<0
0_l300;o1002o`H00_l600;o600001D00_l<00;o3@02o`/00_lH00;o1P02o`@00_l500;o1@03o`D0
0ol:00;o1`02o`D00_l300;o0`02o`<00_l500;o3002o`D00ol400;o1002o`P00_l:00Co1003o`@0
0_l500?o1003o`D00ol200;o0`02o`<00_l300;o2002o`L00_l900;o1P02o`D00_l600;o1002o`@0
0ol400;o2002o`L00_l700;o2002o`<00_l300;o0`02o`@00_l500;o1P02o`D00_l300;o2002o`@0
0_l400Co1P02oaP0000F00;o1`03o`030?oo00T00ol00`3oo`0:00;o6004o`@01?l200Co0`04o`D0
2Ol600[o0`04o`<01?l200co0P08o`L02ol300Go0P05o`<02?l600Co1@04o`030?oo00Wo1P0:o`80
3?l200Ko0P06o`802_l300co0`0<o`801Ol300Go00<0ool01?l200Ko0P0:o`801_l200Ko0P0<o`<0
1?l300Co1004o`<01?l00`3oo`04o`801_l200[o1008oaD0000G0003o`0000D01_l900Ko2P000ol0
000G00Co1004o`801?l300Co1`05o`P02_l300Co0`04o`803?l200So1`09o`D01Ol200Go0`08o`H0
1?l500Co00<0ool01ol:00Go00<0ool00P0<o`801_l200Ko0P0:o`<03?l300co0P05o`<01Ol00`3o
o`04o`801_l200[o0P06o`801_l200co0`04o`<01?l400Co0`04o`030?oo00Co0P06o`802?l600So
5@0002800ol<00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(12\\) UHOJHTLRXLMUCTWNFEKWIWTHHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l900Wo1@0:o`T00_lJ00Co1P04o`<01?l700Go1`06o`P0
1?l300Co1008o`@03Ol200Go1P08o`801Ol300go00<0ool00ol300Go1P04o`X01Ol700So1`02o`@0
0_l500Ko0`02o`801ol800co0P05o`H00_l400;o1002o`D02_l500;o1002o`L02?l500Co0`04o`@0
1?l300Co1002o`@00_l500So1P0=oa00000C00;o2P09o`D02_l:00;o5`08o`@01?l300Co1@09o`<0
2Ol700Co0`04o`@02?l400go0P05o`D02Ol200Go0`0=o`030?oo00?o0`05o`@02?l600Wo1@08o`L0
0_l400;o1@06o`800ol200Oo200<o`801Ol500?o1002o`@00_l500[o1@02o`@00_l700So1@04o`<0
1?l400Co0`04o`@00_l400;o1@0:o`@03Ol@00004`02o`h00_l900;o1@02o`X00_lG00;o1002o`D0
0_l500;o1@03o`D00ol200?o1003o`L00_l500;o2002o`X00_l600;o1002o`D00ol300?o1003o`L0
0_l600;o0P02o`L00_l500;o1002o`D00ol500?o1`02o`T00ol400?o1@02o`@01?l400;o3@02o`H0
0_l400;o1@03o`@00ol400?o2002o`P00ol400?o2@02o`T00_l500;o1P02o`D00_l400?o1003o`D0
0_l400Co1P02o`H00_l@00004`02o`h00_l:00?o3`02oaH00_l600;o1002o`D00_l500;o1`02o`80
0_l600;o1`02o`D00_l800;o2P02o`H00_l400;o1@02o`D00ol200?o2002o`H00_l200;o1`02o`@0
0_l600;o1002o`L00_l700;o2@04o`<00ol500;o1004o`@00_l=00;o1P02o`@00_l500;o1@04o`<0
0ol800;o2004o`<00ol900;o2@02o`D00_l600;o1@02o`@01?l300?o1@02o`H00_l600;o1P02oa00
000C00;o3P02o`/00ol>00;o5P02o`H00_l400;o1@02o`@00_l900;o00<0ool01P02o`L00_l500;o
2002o`X00_l600;o1002o`@00_l700;o0P02o`T00_l600;o0P02o`<00_l200;o1002o`H00_l300?o
4002o`T01?l200Co1@02o`<01Ol400;o0P02o`T00_l200;o0P02o`@00_l400;o1P04o`801?l800;o
2004o`801?l900;o2@02o`D00_l600;o1@02o`@01?l200Co1@02o`L00_l500;o1P02oa00000C00;o
3P02o``00ol=00;o5P02o`H00_l400;o1@02o`@00_l900;o00<0ool01P02o`L00_l500;o2002o`X0
0_l600;o1002o`<00ol800Co2P02o`H00_l200;o0P03o`800_l400;o1P02o`<00_lA00;o2@02o`04
0?l000Co1@02o`<00_l00`3oo`0400;o0P02o`T00_l200;o2003o`800ol600;o00@0o`001?l800;o
2002o`040?l000Co2@02o`T00_l500;o1P02o`D00_l400;o00@0o`001?l500;o1`02o`D00_l600;o
400001<00_l>00;o3@03o``00_lF00;o1P02o`@00_l500;o1002o`T00_l900;o1`02o`D00_l800;o
2P02o``01ol900Co2P02o`X00_l20003o`3o00800_l400;o1P02o`<00_lA00;o2@02o`060?l00?l0
0_l500;o0P03o`030?oo00@01_l900Ko2007o`L00_l01P3o003o00;o2002o`P00_l01P3o003o00;o
2@02o`T00_l500;o1P02o`D00_l400;o00H0o`00o`02o`D00_l700;o1@02oaP0000C00;o3P02o`h0
0ol;00;o5P02o`H00_l400Wo1002o`T00_l900;o1`09o`P00_l:00;o3009o`L00ol;00;o2P02o`04
0?oo00;o00<0ool01002o`H00_l300;o4@02o`T00_l00`3oo`02o`030?oo00D00_l200;o0P02o`@0
1_l900Ko2005o`T00_l00`3oo`02o`030?oo00P00_l800;o00<0ool00_l00`3oo`0900;o2@09o`H0
2Ol400;o00<0ool00_l00`3oo`0500;o1`02o`D00_lH00005002o`d00_l?00;o2P02oaL00_l600;o
1009o`@00_l900;o2@02o`L02Ol300;o0`02o`<00_l500;o3002o`D00ol600Co2P02o`X00_l00`3o
o`020004o`3oo`@00_l600;o0`02o``00_l300;o0`02o`@00_l00`3oo`02o`030?oo00D00_l00`3o
o`0300;o1002o`800_l900;o0P02o`P00_l0103oool800;o00<0ool00_l00`3oo`0800;o2002o`03
0?oo00;o00<0ool01002o`<00_l300;o1009o`H02Ol400;o00<0ool00_l00`3oo`0500;o1`02o`D0
0_lH00005002o`d00_l@00;o2@02oaL00_l600;o1002o`D00_l400;o2@02o`T00_l700;o1@02o`<0
0_l300;o0`02o`D00_l<00;o1P02o`D01_l900;o2P02o`030?l0008000Co0?oo1002o`H00_l300?o
1`02o`800_l300;o0`02o`<00_l300;o0`02o`@01Ol300;o1002o`800_l200;o1@02o`800_l200;o
1002o`800ol600;o0`02o`<00_l700;o1`02o`<00_l300;o0`02o`<00_l300;o1002o`D00_l600;o
1@02o`<00_l300;o0`02o`@00_l700;o1@02oaP0000D00?o3002oa000_l900;o5`02o`H00_l400;o
1@02o`D00_l700;o2P02o`L00_l500;o0`02o`<00_l300;o1@02o``00_l600;o1003o`800ol800;o
2P04o`<01?l400;o1P02o`@00_l700;o0P02o`<00_l300;o0`02o`<00_l300;o1004o`@00_l400;o
1P02o`D00_l600;o1002o`<00ol500;o0`02o`<00_l700;o1`02o`<00_l300;o0`02o`<00_l300;o
1002o`D00_l600;o1@02o`<00_l300;o0`02o`@00_l600;o1P02oaP0000E00;o3002o`T00_l500;o
2002oaP00_l600;o1002o`D00_l500?o1@03o`X00_l700;o1@02o`<00_l300;o0`02o`D00_l<00;o
1@03o`@00_l400;o2002o`X01?l400?o1002o`H00_l400?o1@03o`800_l300;o0`02o`<00_l800;o
1004o`@00_l400;o1P02o`D00_l600;o1002o`@00ol400;o2002o`L00_l700;o2002o`<00_l300;o
0`02o`@00_l500;o1P02o`D00_l300;o2002o`@00_l400Co1P02oaP0000F00;o1`03o`030?oo00T0
0ol300?o1`02oaP01?l400Co0P04o`<01?l500Wo1P0:o`<01?l300Co0P0<o`802?l700_o0`05o`80
1Ol300So1P04o`D01?l200Co1004o`@02_l200co0P06o`801_l200Co0P06o`030?oo00[o0`0<o`80
1Ol300Go00<0ool01?l200Ko0P0:o`801_l200Ko0P0<o`<01?l300Co1004o`<01?l00`3oo`04o`80
1_l200[o1008oaD0000G0003o`0000D01_l:00Oo20000ol0000G00Co1004o`801?l300Co1`05o`P0
2_l300Co0`04o`803?l200So1`09o`D01Ol200Go0`08o`H01?l500Co0P04o`@01?l600Go00<0ool0
0P0<o`801_l200Ko0P03o`<01_l00`3oo`0:o`<03?l200Go0`05o`030?oo00Co0P06o`802_l200Ko
0P06o`803?l300Co0`04o`@01?l300Co00<0ool01?l200Ko0P08o`H02?lE00008P03o`/01Ooo0<D0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(13\\) PHOJHQLRXLMUCTWRFEKWIYTHHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2@09o`L0
1Ol<00;o5@08o`L01?l300Co1`05o`L01_l800Co0`04o`H01Ol500go0P05o`H02?l200Go0`0=o`03
0?oo00?o0`05o`H01?l:00Go1`08o`L00_l400;o1005o`H02_l800co0P05o`H00_l400;o1002o`D0
2_l500So1`08o`D01?l300Co1004o`<01?l400;o1002o`D02?l600go400001<00_l:00Wo1@09o`/0
0_lD00So1`04o`<01?l500Wo0`09o`L01?l300Co1009o`<03Ol200Go1@09o`801Ol300go00<0ool0
0ol300Go1008o`H02Ol500So1`02o`@00_l400Go1@0;o`P03?l200Go1@03o`@00_l400;o1@0:o`D0
2?l700So1@04o`<01?l400Co0`04o`@00_l400;o1@0:o`@03Ol@00004`02o`h00_l800;o1@02o`/0
0_lF00;o3002o`D00_l500?o1@03o`800ol400?o1`02o`D00_l400?o1@03o`D00_l600;o1002o`D0
0ol300?o1003o`L00_l600;o0P02o`L00_l500;o1002o`D00ol500?o1`02o`T00ol400?o1@02o`D0
0ol400;o3@02o`H00_l400;o1@03o`@00ol400?o2002o``00_l=00;o2@02o`D00_l600;o1@02o`@0
0ol400?o1@02o`@01?l600;o1P02oa00000C00;o3P02oa000_l:00;o5P02o``00_l500;o1@02o`L0
0_l200;o1P02o`L00_l500;o1002o`L00_l500;o1P02o`@00_l500;o1@03o`800ol800;o1P02o`80
0_l700;o1002o`H00_l400;o1`02o`L00_l900Co0`03o`D00_l500;o1@02o`d00_l600;o1002o`D0
0_l500Co0`03o`P00_l<00;o3@02o`T00_l500;o1P02o`D00_l400Co0`03o`D00_l600;o1P02o`H0
0_l@00004`02o`h00_l@00;o2P02oaH00_l<00;o1@02o`@00_l900;o00<0ool01P02o`L00_l500;o
0`02o`T00_l400;o1P02o`@00_l400;o1`02o`800_l900;o1P02o`800_l300;o0P02o`@00_l600;o
0`03oa000_l900Co0P04o`D00_l400;o1P02o`800_l900;o0P02o`800_l400;o1002o`H01?l200Co
2002o``00_l=00;o2@02o`D00_l600;o1@02o`@01?l200Co1@02o`L00_l500;o1P02oa00000C00;o
3P02oa000_l:00;o5P07o`L00_l500;o1002o`T00_l00`3oo`0600;o1`02o`D00_l300;o2@02o`@0
0_l600;o1002o`<00ol800Co2P02o`H00_l200;o0P03o`800_l400;o1P02o`<00_lA00;o2@02o`04
0?l000Co1@02o`<00ol600;o0P02o`T00_l200;o2003o`800ol600;o00@0o`001?l800;o3002o`d0
0_l900;o1@02o`H00_l500;o1002o`040?l000Co1@02o`L00_l500;o1P02oa00000C00;o3P02o`l0
0_l;00;o5P09o`D00_l500;o1002o`T00_l900;o1`02o`D00_l300;o2@02o`@00_l<00Oo2@04o`X0
0_l:00;o0P000ol0o`0200;o1002o`H00_l300;o4@02o`T00_l01P3o003o00;o1@07o`L01_l900Ko
2007o`L00_l01P3o003o00;o2002o``00ol<00;o2@02o`D00_l600;o1@02o`@00_l01P3o003o00;o
1@02o`L00_l500;o600001<00_l>00;o3004o``00_lF00;o1@03o`@02Ol400;o2@02o`T00_l700Wo
0`02o`T00_l400;o3009o`L00ol;00;o2P02o`040?oo00;o00<0ool01002o`H00_l300;o4@02o`T0
0_l00`3oo`02o`030?oo00D02Ol500Ko2@06o`P01Ol900;o00<0ool00_l00`3oo`0800;o2`04o``0
0_l900Wo1P09o`@00_l00`3oo`02o`030?oo00D00_l700;o1@02oaP0000D00;o3@02o``00ol<00;o
5`02o`H00_l400Wo1002o`T00_l900;o1`09o`<00_l900;o1002o``00_l500?o1P04o`X00_l:00;o
00<0ool00P001?l0ool400;o1P02o`<00_l<00;o0`02o`<00_l400;o00<0ool00_l00`3oo`0500;o
1@03o`@00_l200;o2@02o`800_l800;o00@0oooo2002o`030?oo00;o00<0ool02002o`X01_l600;o
0`02o`<00_l400Wo1P09o`@00_l00`3oo`02o`030?oo00D00_l700;o1@02oaP0000D00;o3@02o`h0
0_l;00;o5`02o`H00_l400;o1@02o`@00_l900;o2@02o`L00_l500;o0`03o`P00_l400;o3002o`H0
0_l500Ko2@02o`X00_l00`3o00020004o`3oo`@00_l600;o0`03o`L00_l200;o0`02o`<00_l300;o
0`02o`<00_l400;o1P02o`@00_l200;o0P02o`D00_l200;o0P02o`@00_l200?o1P02o`<00_l300;o
1`02o`X00_l200;o1P02o`<00_l300;o1002o`D00_l600;o1@02o`<00_l300;o0`02o`@00_l700;o
1@02oaP0000D00?o3002o`l00_l:00;o5`02o`H00_l400;o1@02o`D00_l700;o2P02o`L00_l500;o
1002o`L00_l500;o3002o`H00_l400?o0P03o`P00_l:00Co0`04o`@00_l600;o1002o`L00_l200;o
0`02o`<00_l300;o0`02o`<00_l400;o1P02o`@00_l600;o1@02o`H00_l400;o0`03o`D00_l300;o
0`02o`L00_l900?o0`02o`D00_l300;o0`02o`@00_l500;o1P02o`D00_l300;o0`02o`<00_l400;o
1P02o`H00_lH00005@02o``00_l?00;o2@02oaP00_l500?o1002o`D00_l500?o1@03o`X00_l700;o
1@02o`D00_l500;o1P02o``00_l500?o1002o`@00_l800;o2P04o`@00ol400;o1P02o`@00ol500?o
0P02o`<00_l300;o0`02o`P00_l400;o1@03o`@00_l600;o1@02o`H00_l400;o1003o`@00_l800;o
1`02o`T00_l400;o1@02o`<00_l300;o1002o`D00_l600;o1@02o`<00_l800;o1002o`@01?l600;o
600001H00_l700?o00<0ool02@02o`<00ol800;o5`0;o`@01?l300Co1@09o`H02_l300Co0`04o`@0
2Ol300So1`0;o`<01Ol200Go0`08o`H01?l500Co0P04o`@01?l400[o0P0<o`801_l200Ko00<0ool0
2Ol300co0`0<o`801Ol300Go00<0ool01?l200Ko0P0:o`<01Ol200Go0`0<o`<01?l300Co1004o`<0
1?l00`3oo`04o`801_l200[o1008oaD0000G0003o`0000D01_l900Oo2@000ol0000F00Wo1P04o`<0
1?l700Go200:o`<01?l300Co1P05o`D02?l700Wo1@05o`801Ol300So1P04o`D01?l200Co1004o`H0
1Ol00`3oo`0200co0P06o`801_l00`3oo`07o`D03?l300co0P05o`<01Ol00`3oo`04o`801_l200[o
0`05o`801Ol300co0`04o`<01?l400Co0`04o`030?oo00Co0P06o`802?l600So5@0002800ol;00Co
o`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(14\\) PHOJLRLRXLMUCTWRFIKWDYTHHWDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l900Wo2@06o`T00_lE00So1`04o`<01?l700Go1`06o`L0
3Ol00`3oo`03o`H04?l200Go1P08o`801Ol300go00<0ool00ol300Go1P04o`X01Ol700So1`02o`@0
0_l400Go1P0:o`T02_l300Go1P02o`@00_l400;o1@08o`L02?l700So1@04o`<01?l400Co0`04o`@0
0_l400;o1@08o`H03Ol@00004`02o`X02Ol900Ko2P02oa@02?l700Co0`04o`D02Ol300Wo1P0=o`03
0?oo00?o1@0Ao`801Ol500Wo0P05o`<03Ol00`3oo`03o`<01Ol400So1P09o`D02?l700;o1002o`@0
1Ol500_o2@0:o`<01Ol500?o1002o`@00_l500[o1@08o`L02?l500Co0`04o`@01?l300Co1002o`@0
0_l500[o100=oa00000C00;o3P02o`h00_l<00;o5P02o``00_l500;o1@03o`D00ol200?o1003o`P0
0_l600;o0`02o`D00ol500;o1P02o`@00_l500?o0`03o`@00ol700;o1P02o`800_l700;o1@02o`@0
0_l500?o1@03o`L00_l900?o1003o`D00_l500?o1002oa000_l900;o1@03o`@00ol400?o1@02o`@0
1?l700;o3@02o`T00_l500;o1P02o`D00_l400?o1003o`D00_l400Co1P02o`H00_l@00004`02o`h0
0_l>00;o3002oaH00_l<00;o1@02o`D00_l700;o0P02o`H00_l800;o1P02o`<00_l500;o1P02o`H0
0_l400;o1@02o`D00ol200?o2002o`H00_l200;o1`02o`@00_l600;o1002o`L00_l700;o2@04o`<0
0ol500;o1@02o`D00_l@00;o2@02o`D00_l500Co0`03o`D00_l600;o1`02o`d00_l900;o1@02o`H0
0_l500;o1004o`<00ol500;o1P02o`H00_l600;o400001<00_l>00;o200:o`X00_lF00;o3002o`D0
0_l400;o2@02o`030?oo00H00_l800;o1P02o`<00_l400;o1`02o`H00_l400;o1002o`L00_l200;o
2@02o`H00_l200;o0`02o`800_l400;o1P02o`<00ol@00;o2@04o`801?l500;o1002o`H00_l200;o
3002o`T00_l400;o1P04o`801?l500;o1`02o`H00_l=00;o2@02o`D00_l600;o1@02o`@01?l200Co
1@02o`L00_l500;o1P02oa00000C00;o3P02o`P02_l:00;o5P07o`L00_l500;o1002o`T00_l00`3o
o`0600;o2002o`H00_l300;o0`03o`L00_l600;o1002o`<00ol800Co2P02o`H00_l200;o0P03o`80
0_l400;o1P02o`<00_lA00;o2@02o`040?l000Co1@02o`<00ol600;o0P02o``00_l900?o0P03o`H0
0_l0103o0004o`D00_l700;o1P02o`d00_l900;o1@02o`H00_l500;o1002o`040?l000Co1@02o`L0
0_l500;o1P02oa00000C00;o3P02o`P00_l400;o3002oaH02Ol500;o1@02o`@00_l900;o2@02o`P0
0_l;00Oo2002o``01ol900Co2P02o`X00_l20003o`3o00800_l400;o1P02o`<00_lA00;o2@02o`06
0?l00?l00_l500Oo1`06o``00_l900Oo1`02o`060?l00?l00_l500;o1`02o`H00ol<00;o2@02o`D0
0_l600;o1@02o`@00_l01P3o003o00;o1@02o`L00_l500;o600001<00_l>00;o2@02o`<00_l<00;o
5P02o`D00ol400Wo1002o`T00_l900;o2002o`/02Ol600;o3009o`L00ol;00;o2P02o`040?oo00;o
00<0ool01002o`H00_l300;o4@02o`T00_l00`3oo`02o`030?oo00D02Ol500Ko3002o`T01Ol900;o
00<0ool00_l00`3oo`0500;o1`02o`D01?l<00;o2@09o`H02Ol400;o00<0ool00_l00`3oo`0500;o
1`02o`D00_lH00005002o`d00_l:0004o`0000;o2`02oaL00_l600;o1009o`@00_l900;o2@02o`P0
0_l;00;o1@03o`D00_l<00;o1@03o`H01?l:00;o2P02o`030?oo008000Co0?oo1002o`H00_l300;o
3002o`<00_l300;o1002o`030?oo00;o00<0ool01@02o`D00ol400;o0P02o``00_l900;o00@0oooo
2002o`030?oo00;o00<0ool01@02o`L00_l400Ko1P02o`<00_l300;o1009o`H02Ol400;o00<0ool0
0_l00`3oo`0500;o1`02o`D00_lH00005002o`d00_l:00;o0P02o`/00_lG00;o1P02o`@00_l500;o
1002o`T00_l900;o2002o`/00_l600;o1@02o``00_l600;o1@06o`T00_l:00;o00<0o`000P001?l0
ool400;o1P02o`<00ol700;o0P02o`<00_l300;o0`02o`<00_l300;o1002o`H00_l400;o0P02o`80
0_l800;o2@02o`800ol600;o0`02o`<00_l400;o1`02o`@00_l200;o1P02o`<00_l300;o1002o`D0
0_l600;o1@02o`<00_l300;o0`02o`@00_l700;o1@02oaP0000D00?o3002o`/000?o00000_l;00;o
5`02o`H00_l400;o1@02o`D00_l700;o2P02o`P00_l;00;o1P02o`D00_l<00;o1P02o`@00ol200?o
2002o`X01?l300Co1002o`H00_l400;o1`02o`800_l300;o0`02o`<00_l300;o0`02o`@00_l600;o
1002o`H00_l800;o2@02o`<00ol500;o0`02o`<00_l400;o1P02o`@00ol300;o1@02o`<00_l300;o
1002o`D00_l600;o1@02o`<00_l300;o0`02o`@00_l600;o1P02oaP0000E00;o3002o``000Co0?oo
2P02oaP00_l500?o1002o`D00_l500?o1@03o`X00_l800;o2`02o`D00ol500;o3002o`D00ol400;o
1002o`P00_l:00Co1003o`@00_l600;o1003o`D00ol200;o0`02o`<00_l300;o2002o`@00_l500?o
1002o`H00_l800;o2@02o`@00ol400;o2002o`@00_l400Co1002o`@00_l500;o0`02o`<00_l400;o
1@02o`H00_l500;o0`02o`P00_l400;o1004o`H00_lH00005P02o`L00ol00`3oo`0<00Co2@02oaL0
2ol400Co0`04o`D02Ol600[o0P08o`H02ol300So1`0;o`<01Ol200Go0`08o`H01?l500Co0P04o`@0
1?l400[o0P0<o`801_l200Ko00<0ool02Ol300co100:o`<01Ol300Go00<0ool01?l200Ko0P0:o`<0
1Ol200Go0`0<o`<01?l300Co1004o`<01?l00`3oo`04o`801_l200[o1008oaD0000G0003o`0000D0
1_l=00?o2@000ol0000F00Wo1P04o`<01?l700Go200:o`802?l600Wo1@08o`L02Ol500Go0P05o`<0
2?l600Co1@04o`801?l400Co1P05o`030?oo00803?l200Ko0P06o`030?oo00Oo1@0<o`@02_l300Go
0`05o`030?oo00Co0P06o`802?l500Go0P05o`<03?l300Co0`04o`@01?l300Co00<0ool01?l200Ko
0P08o`H02?lE00008P03o`d00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(15\\) PHOJLRLR LQUCTWRFIKWAYTHHUDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2@09o`L0
1Ol<00;o5@08o`L01?l300Co1`05o`L01_l700go00<0ool00ol6013o0P05o`H00ol?00go1@05o`X0
1?l:00Go1`08o`L00_l400;o1005o`H02_l900[o0`05o`H00_l400;o1002o`<01_l300Ko0P08o`L0
2?l500Co0`04o`@01?l300Co1`04o`H02?l600go400001<00_l:00Wo1@09o`/00_lD00So1`04o`<0
1?l500Wo0`09o`H03Ol00`3oo`03o`D04Ol200Go1@04o`l03Ol300Wo1P08o`H02Ol500So1`02o`@0
0_l400Go1@0;o`T02_l300Go1@03o`@00_l400;o0`06o`<01_l200So1`08o`D01?l300Co1004o`<0
1?l500So100:o`@03Ol@00004`02o`h00_l800;o1@02o`/00_lF00;o3002o`D00_l500?o1@03o`80
0ol400?o2002o`H00_l300;o1@03o`D00_l600;o1002o`D00olD00;o1P02o`800ol500?o1@02o`@0
0_l500?o1@03o`L00_l900?o1003o`D00_l500?o1002oa000_l900;o1@03o`@00ol400?o1002o`L0
0_l700;o3@02o`T00_l500;o1P02o`D00_l600;o1002o`D00_l400Co1P02o`H00_l@00004`02o`h0
0_l@00;o2P02oaH00_l<00;o1@02o`D00_l700;o0P02o`H00_l800;o1P02o`<00_l500;o1P02o`H0
0_l400;o1@02oaD00_l600;o0P02o`L00_l400;o1P02o`@00_l700;o1`02o`T01?l300?o1@02o`D0
0_l500;o4002o`T00_l500;o1@04o`<00ol400;o1`02o`L00_l=00;o2@02o`D00_l600;o1@02o`D0
0_l600;o1002o`H00_l600;o1P02oa00000C00;o3P02oa000_l:00;o5P02o``00_l500;o1002o`T0
0_l00`3oo`0600;o2002o`H00_l300;o1002o`L00_l600;o1002o`@00_lF00;o1P02o`030?oo00T0
0_l300;o1P02o`<00ol@00;o2@04o`801?l500;o1002o`H00_l200;o3002o`T00_l400;o1P04o`80
1?l400_o1`02o`d00_l900;o1@02o`H00_l500;o1@02o`H00_l400;o1`02o`D00_l600;o400001<0
0_l>00;o4002o`X00_lF00Oo1`02o`D00_l400;o2@02o`030?oo00H00_l800;o1P02o`<00_l300?o
1`02o`H00_l400;o0`03oaH00_l600;o00<0ool02@02o`<00_l600;o0`02oa400_l900;o00@0o`00
1?l500;o0`03o`H00_l200;o3002o`T00ol200?o1P02o`040?l000Co1@09o`P00_l=00;o2@02o`D0
0_l600;o1@02o`D00_l600;o1002o`L00_l500;o1P02oa00000C00;o3P02oa000_l:00;o5P09o`D0
0_l500;o1002o`T00_l900;o2002o`/01ol800;o3007oaL00_l900;o2@02o`<00_l600;o0`02oa40
0_l900;o00H0o`00o`02o`D01ol700Ko3002o`T01ol700;o00H0o`00o`02o`D00_l500;o2003o``0
0_l900;o1@02o`H00_l500;o1@02o`H00_l400;o1`02o`D00_lH00004`02o`h00_l900;o1002o`/0
0_lF00;o1@03o`@02Ol400;o2@02o`T00_l800;o2`09o`H00_l<00Wo5@02o`T00_l900;o0`02o`H0
0_l300;o4@02o`T00_l00`3oo`02o`030?oo00D02Ol500Ko3002o`T01Ol900;o00<0ool00_l00`3o
o`0600;o0`02o`P01?l<00;o2@09o`H02Ol500;o1P02o`@00_l700;o1@02oaP0000D00;o3@02o`T0
2?l:00;o5`02o`H00_l400Wo1002o`T00_l900;o2002o`/00_l500?o1@02o``00_l500?o5002o`T0
0_l900;o0`02o`H00_l300;o3002o`<00_l300;o1002o`030?oo00;o00<0ool01@02o`D00ol400;o
0P02o``00_l900;o00@0oooo2002o`030?oo00;o00<0ool01P02o`<00_l700Ko1P02o`<00_l300;o
1009o`H02Ol500;o1P02o`@00_l700;o1@02oaP0000D00;o3@02o`T01ol;00;o5`02o`H00_l400;o
1@02o`@00_l900;o2@02o`P00_l;00;o1P02o`D00_l<00;o1P02oa@00_l900?o2002o`<00_l600;o
0`03o`L00_l200;o0`02o`<00_l300;o0`02o`<00_l400;o1P02o`@00_l200;o0P02o`P00_l900;o
0P03o`H00_l300;o0`02o`H00_l0103oool700;o0P02o`H00_l300;o0`02o`@00_l500;o1P02o`D0
0_l500;o1P02o`@00_l700;o1@02oaP0000D00?o3002o`T00_l@00;o5`02o`H00_l400;o1@02o`D0
0_l700;o2P02o`P00_l;00;o1P02o`D00_l<00;o1P02oa@00_l:00;o1`02o`@00_l600;o1002o`L0
0_l200;o0`02o`<00_l300;o0`02o`<00_l400;o1P02o`@00_l600;o2002o`T00_l300?o1@02o`<0
0_l300;o1P02o`030?oo00L00ol300;o1@02o`<00_l300;o1002o`D00_l600;o1@02o`D00_l600;o
1002o`H00_l600;o600001D00_l<00;o2@02o`l00_lH00;o1@03o`@00_l500;o1@03o`D00ol:00;o
2002o`/00_l500?o1@02o``00_l500?o5002o`/00_l500;o1@02o`H00_l400?o1@03o`800_l300;o
0`02o`<00_l800;o1002o`D00ol400;o1P02o`P00_l900;o1003o`@00_l800;o1P05o`L00_l400;o
1@02o`<00_l300;o1002o`D00_l600;o1@02o`D00_l600;o1002o`@01?l600;o600001H00_l700?o
00<0ool02@02o`h00_lG00_o1004o`<01?l500Wo1P0:o`802?l600_o0`08o`L02olB00So2009o`@0
1?l400Co100:o`803?l200Ko0P06o`030?oo00Wo0`0<o`@02_l300Go0`05o`030?oo00Co0P06o`80
1ol600Go0P05o`<03?l300Co0`04o`@01?l300Co0`04o`@01?l200[o1008oaD0000G0003o`0000D0
1_l900So20000ol0000F00Wo1P04o`<01?l700Go200:o`802?l600Wo1@08o`L02OlD00So2P05o`H0
1?l400Co1P05o`030?oo00803?l200Ko0P06o`030?oo00Oo1@0<o`@02_l300Go0`05o`030?oo00Co
0P06o`801ol600Go0P05o`<03?l300Co0`04o`@01?l300Co0`04o`@01?l200So1P08oaD0000R00?o
2@08ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(16\\) PHOJLNLR LQUHTWRFIKWAYTHHUDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2@09o`P0
1?l<00;o5@08o`L01?l300Co1`05o`L01_l700go0P06o`<00_l200go0P05o`H00ol?00go1@05o`X0
1?l700Co0`04o`@02?l700;o1002o`@01Ol600[o2@0:o`<01Ol600;o1002o`@00_l300Ko0`06o`80
2?l700So1@04o`<01?l400Co0`04o`L01?l600So1P0=oa00000C00;o2P09o`L01ol;00;o5008o`L0
1?l300Co1@09o`<02Ol600go0P06o`800ol200go0P05o`D01?l?00go0`09o`H02?l500Co0`04o`@0
2?l700;o1002o`@01Ol500_o2@0:o`<01Ol500?o1002o`@00_l300Ko0`06o`802?l700So1@04o`<0
1?l400Co0`04o`D02?l400[o100=oa00000C00;o3P02o`T00_l400;o2`02oaH00_l<00;o1@02o`D0
0ol500?o0P03o`@00ol800;o1P02o`<00_l400Co1@02o`H00_l400;o1@03oa@00_l600;o0P03o`D0
0ol500;o1002o`H00_l500;o2002o`T00ol400?o1@02o`D00ol400;o4002o`T00_l500?o1003o`@0
0ol400;o1`02o`L00_l=00;o2@02o`D00_l600;o1@02o`H00_l400;o1@02o`@01?l600;o1P02oa00
000C00;o3P02o`P00_l600;o2P02oaH00_l<00;o1@02o`D00_l700;o0P02o`H00_l800;o1P02o`<0
0_l400Co1@02o`H00_l400;o1@02oaD00_l600;o0P02o`L00_l400;o1P02o`D00_l500;o2002o`T0
1?l300?o1@02o`D00_l500;o4002o`T00_l500;o1@04o`<00ol400;o1`02o`L00_l=00;o2@02o`D0
0_l600;o1@02o`D00_l600;o1002o`H00_l600;o1P02oa00000C00;o3P02o`P00_l600;o2P02oaH0
0_l<00;o1@02o`@00_l900;o00<0ool01P02o`P00_l600;o0`02o`<01Ol500;o1P02o`@00_l400;o
5P02o`H00_l00`3oo`0900;o0`02o`H00_l500;o1@02o`P00_l900Co0P04o`D00_l400;o1P02o`80
0_l<00;o2@02o`@00_l600Co0P04o`@02ol700;o3@02o`T00_l500;o1P02o`D00_l500;o1P02o`@0
0_l700;o1@02o`H00_l@00004`02o`h00_l800;o1P02o`X00_lF00Oo1`02o`D00_l400;o2@02o`03
0?oo00H00_l800;o1P02o`<00_l300;o00<0ool01@02o`H00_l400;o0`03oaH00_l600;o00<0ool0
2@02o`<00_l600;o1@02o`D00_l800;o2@02o`040?l000Co1@02o`<00ol600;o0P02o``00_l900?o
0P03o`H00_l0103o0004o`D02Ol800;o3@02o`T00_l500;o1P02o`D00_l500;o1P02o`@00_l700;o
1@02o`H00_l@00004`02o`h00_l800;o1P02o`X00_lF00Wo1@02o`D00_l400;o2@02o`T00_l800;o
2`02o`800ol00`3oo`0500;o3007oaL00_l900;o2@02o`<00_l600;o1@02o`D00_l800;o2@02o`06
0?l00?l00_l500Oo1`06o``00_l900Oo1`02o`060?l00?l00_l500;o1@02o`P00ol<00;o2@02o`D0
0_l600;o1@02o`D00_l600;o1002o`L00_l500;o600001<00_l>00;o2003o`@00_l;00;o5P02o`D0
0ol400Wo1002o`T00_l900;o2002o`/00_l200;o0P02o`D00_l<00Wo5@02o`T00_l900;o0`02o`H0
0_l500Wo2002o`T00_l00`3oo`02o`030?oo00D02Ol500Ko3002o`T01Ol900;o00<0ool00_l00`3o
o`0600;o0`02o`P01?l<00;o2@09o`H02Ol500;o1P02o`@00_l700;o1@02oaP0000D00;o3@02o`P0
2Ol:00;o5`02o`H00_l400Wo1002o`T00_l900;o2002o`/00_l00`3oo`0300;o1@02o``00_l500?o
5002o`T00_l900;o0`02o`H00_l500Wo0`02o`<00_l300;o1002o`030?oo00;o00<0ool01@02o`D0
0ol400;o0P02o``00_l900;o00@0oooo2002o`030?oo00;o00<0ool01P02o`<00_l700Ko1P02o`<0
0_l300;o1009o`H02Ol500;o1P02o`@00_l700;o1@02oaP0000D00;o3@02o`P00_l00`3oo`02o``0
0_lG00;o1P02o`@00_l500;o1002o`T00_l900;o2002o`/01Ol300;o1@02o``00_l600;o5002o`T0
0ol800;o0`02o`H00_l500;o1@02o`<00_l300;o0`02o`<00_l300;o0`02o`@00_l600;o1002o`80
0_l200;o2002o`T00_l200?o1P02o`<00_l300;o1P02o`040?ooo`L00_l200;o1P02o`<00_l300;o
1002o`D00_l600;o1@02o`D00_l600;o1002o`L00_l500;o600001@00ol<00;o2@02oa000_lG00;o
1P02o`@00_l500;o1@02o`L00_l:00;o2002o`/01?l400;o1@02o``00_l600;o5002o`X00_l700;o
1002o`H00_l500;o1@02o`<00_l300;o0`02o`<00_l300;o0`02o`@00_l600;o1002o`H00_l800;o
2@02o`<00ol500;o0`02o`<00_l600;o00<0ool01`03o`<00_l500;o0`02o`<00_l400;o1@02o`H0
0_l500;o1@02o`H00_l400;o1P02o`H00_lH00005@02o``00_l900?o3P02oaP00_l500?o1002o`D0
0_l500?o1@03o`X00_l800;o2`04o`@00_l500;o3002o`D00olD00;o2`02o`D00_l500;o1P02o`D0
0_l500;o0`02o`<00_l300;o0`02o`P00_l400;o1@03o`@00_l600;o2002o`T00_l400?o1002o`P0
0_l600Go1`02o`@00_l500;o0`02o`<00_l400;o1@02o`H00_l500;o1@02o`H00_l400;o1004o`H0
0_lH00005P02o`L00ol00`3oo`0:00?o3002oaL02ol400Co0`04o`D02Ol600[o0P08o`L01?l200Ko
00<0ool01_l700_o4P08o`P02Ol400Co1004o`<01?l300Co0P0<o`801_l200Ko00<0ool02Ol300co
100:o`<01Ol300Go00<0ool01?l200Ko0P07o`H01Ol200Go0`0<o`<01?l300Co1004o`<01?l300Co
1004o`802_l400So5@0001L000?o00001@06o`/01ol70003o`0001H02Ol600Co0`04o`L01Ol800[o
0P08o`L00ol300Ko00<0ool01_l700Wo5008o`X01Ol600Co1004o`<01?l300Co0P0<o`801_l200Ko
00<0ool01ol500co100:o`<01Ol300Go00<0ool01?l200Ko0P07o`H01Ol200Go0`0<o`<01?l300Co
1004o`<01?l300Co1004o`802?l600So5@0002800ol=00Goo`330000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(17\\) PHOJLNLR LQYHTWRFLKXAYUHHUDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2@09o`P0
0_l>00;o5@08o`L01?l300Co1`05o`L01_l700go0P06o`<00_l200go0P05o`H00ol?00go1@05o`L0
2?l600Co0`04o`@02?l700;o1002o`@01Ol600[o200=o`030?oo00?o1P02o`801Ol200Go00<0ool0
1?l300Ko0P08o`X01?l600Co0`04o`@01?l300Co1`04o`H02?l600go400001<00_l:00Wo2002o`l0
0_lD00So1`04o`<01?l500Wo0`09o`H03Ol200Ko0P03o`803Ol200Go1@04o`l03Ol300Wo1@08o`H0
1?l300Co1008o`L00_l400;o1005o`D02ol800go00<0ool00ol500?o0P05o`801Ol00`3oo`04o`<0
1_l200So2008o`@01?l300Co1004o`<01?l500So100:o`@03Ol@00004`02o`h00_l<00;o3P02oaH0
0_l<00;o1@02o`D00ol500?o0P03o`@00ol800;o1P02o`<00_l400Co1@02o`H00_l400;o1@03oa@0
0_l600;o0P03o`D00ol700;o2P02o`D00_l800;o2@03o`@00ol500;o1@03o`@00_l>00;o1P02o`<0
0_l500?o1003o`@00ol400;o1`02o`L00_l;00;o1002o`D00_l500;o1P02o`D00_l600;o1002o`D0
0_l400Co1P02o`H00_l@00004`02o`h00_l<00;o3P02oaH00_l<00;o1@02o`D00_l700;o0P02o`H0
0_l800;o1P02o`<00_l400Co1@02o`H00_l400;o1@02oaD00_l600;o0P02o`L00_l700;o2P02o`D0
0_l800;o2@04o`<00ol500;o1@02o`D00_l>00;o1P02o`<00_l500;o1P03o`800ol500;o1`02o`L0
0_l:00;o1P02o`@00_l500;o1P02o`D00_l500;o1P02o`@00_l600;o1P02o`H00_l@00004`02o`h0
0_l<00;o3P02oaH00_l<00;o1@02o`@00_l900;o00<0ool01P02o`P00_l600;o0`02o`<01Ol500;o
1P02o`@00_l400;o5P02o`H00_l00`3oo`0900;o1P02o`X00_l500;o2002o`T01?l200Co1@02o`@0
0_l600;o0P02o`X00_l600;o0`02o`@00_l800;o0P02o`H02ol700;o2P02o`H00_l400;o1@02o`H0
0_l500;o1@02o`H00_l400;o1`02o`D00_l600;o400001<00_l>00;o3@000ol0000<00;o5P07o`L0
0_l500;o1002o`T00_l00`3oo`0600;o2002o`H00_l300;o0`02o`030?oo00D00_l600;o1002o`<0
0olF00;o1P02o`030?oo00T00_l600;o2P02o`D00_l800;o2@02o`040?l000Co1@02o`<00ol600;o
0P02o`X00_l600;o0`03o`800ol900Co2009o`P00_l:00;o1P02o`@00_l500;o1P02o`D00_l500;o
1P02o`@00_l700;o1@02o`H00_l@00004`02o`h00_l=00;o3@02oaH02Ol500;o1@02o`@00_l900;o
2@02o`P00_l;00;o0P03o`030?oo00D00_l<00Oo5`02o`T00_l900;o1P03o`T00_l500;o2002o`T0
0_l01P3o003o00;o1@07o`L01_l:00;o2`07o`X01?l800;o1@02o`P00ol900;o1P02o`@00_l500;o
1P02o`D00_l500;o1P02o`@00_l700;o1@02oaP0000C00;o3P02o`d00_l=00;o5P02o`D00ol400Wo
1002o`T00_l900;o2002o`/00_l200;o0P02o`D00_l<00Wo5@02o`T00_l900;o1@04o`T02Ol800;o
2@02o`030?oo00;o00<0ool01@09o`D01_l:00;o2`05o``00ol:00;o0`02o`P01?l900;o1P02o`@0
2Ol600Wo1@02o`H00_l400;o1`02o`D00_lH00005002o`d00_l>0003o`0000X00_lG00;o1P02o`@0
2Ol400;o2@02o`T00_l800;o2`02o`030?oo00<00_l500;o3002o`D00olD00;o2@02o`T00_l400Ko
2009o`<00_l300;o0`02o`@00_l00`3oo`02o`030?oo00D00_l500?o1002o`800_l:00;o2`02o`04
0?ooo`/01?l900;o0`02o`L01_l800;o1P02o`@02Ol600Wo1@02o`H00_l400;o1`02o`D00_lH0000
5002o`d00_l>00;o2`02oaL00_l600;o1002o`D00_l400;o2@02o`T00_l800;o2`05o`<00_l500;o
3002o`H00_lD00;o2@03o`P00_l400;o0P02o`P00_l500;o0`02o`<00_l300;o0`02o`<00_l300;o
1002o`H00_l400;o0P02o`800_l600;o2`02o`800ol900Ko2@02o`040?ooo`L00_l200;o2002o`H0
0_l400;o1@02o`H00_l500;o1@02o`H00_l400;o1`02o`D00_lH00005003o``00_l>00;o2`02oaL0
0_l600;o1002o`D00_l500;o1`02o`X00_l800;o2`04o`@00_l500;o3002o`H00_lD00;o2P02o`L0
0_l400?o0`02o`L00_l500;o0`02o`<00_l300;o0`02o`<00_l300;o1002o`H00_l400;o1P02o`H0
0_l;00;o0`03o`L00ol200?o2002o`030?oo00L00ol300;o1`02o`H00_l400;o1@02o`H00_l500;o
1@02o`H00_l400;o1P02o`H00_lH00005@02o``00_l?0003o`0000P00_lH00;o1@03o`@00_l500;o
1@03o`D00ol:00;o2002o`/01?l400;o1@02o``00_l500?o5002o`/00_l500;o1@02o`@00_l700;o
1@02o`<00_l300;o0`02o`<00_l800;o1002o`D00ol400;o1P02o`H00_l;00;o1003o`H00_l400;o
2005o`L00_l400;o1`02o`H00_l400;o1@02o`H00_l500;o1@02o`H00_l400;o1004o`H00_lH0000
5P02o`L00ol00`3oo`0800;o1@02o`P00_lG00_o1004o`<01?l500Wo1P0:o`802?l700Co0P06o`03
0?oo00Ko1`0;oa802?l800Wo0`05o`801Ol400Co0`04o`803?l200Ko0P06o`030?oo00Wo0`0<o`<0
2?l600Go0`05o`801Ol200Go0`07o`H01Ol200Go1004o`@01?l200Co0`04o`@01?l300Co0`04o`@0
1?l200[o1008oaD0000G0003o`0000D01_l800Wo20000ol0000F00Wo1P04o`<01?l700Go200:o`80
2?l700?o0`06o`030?oo00Ko1`09oa@02?l:00Go1@05o`801Ol400Co0`04o`803?l200Ko0P06o`03
0?oo00Oo1@0<o`<02?l600Go0`05o`801Ol200Go0`07o`H01Ol200Go1004o`@01?l200Co0`04o`@0
1?l300Co0`04o`@01?l200So1P08oaD0000R00?o2009ool0a0000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(18\\) PHOJLNLQ LQYHTWRFLKXAYUHEUDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`T02Ol800Co3002oaD02?l700Co0`04o`L01Ol700Ko1`0=o`80
1_l300;o0P0=o`H01OlD00go1@05o`L02?l600Co0`04o`@02?l700;o1002o`@01Ol600[o200=o`03
0?oo00?o1P02o`801Ol200Go00<0ool01?l300Ko0P08o`X01?l600Co0`04o`<03?l700Co1P08o`H0
3Ol@00004`02o`X02Ol600So2`02oa@02?l700Co0`04o`D02Ol300Wo1P0=o`801_l200?o0P0=o`@0
2OlB00go0`09o`D02?l600Co0`04o`@02?l700;o1002o`@01Ol500_o200=o`030?oo00?o1@03o`80
1Ol200Go00<0ool01?l300Ko0P08o`P02?l400Co0`04o`<03?l500So100:o`@03Ol@00004`02o`h0
0_l800?o1003o`X00_lF00;o3002o`D00_l500?o1@03o`800ol400?o2002o`H00_l300;o1004o`D0
0_l600;o0`03o`D00olD00;o1P02o`800ol500?o1`02o`X00_l500;o2002o`T00ol400?o1@02o`D0
0ol400;o3P02o`H00_l300;o1@03o`@00ol400?o1002o`L00_l700;o2`02o`@00_l500;o1@02o`H0
0_l600;o1@02o`@00_l500;o1004o`H00_l600;o400001<00_l>00;o2002o`H00_l:00;o5P02o``0
0_l500;o1@02o`L00_l200;o1P02o`P00_l600;o0`02o`@01?l500;o1P02o`<00_l700;o5002o`H0
0_l200;o1`02o`L00_l:00;o1@02o`P00_l900Co0`03o`D00_l500;o1@02o`h00_l600;o0`02o`D0
0_l600?o0P03o`D00_l700;o1`02o`X00_l600;o1002o`D00_l600;o1P02o`@00_l600;o1002o`H0
0_l600;o1P02oa00000C00;o3P02o`P00_l600;o2P02oaH00_l<00;o1@02o`@00_l900;o00<0ool0
1P02o`P00_l600;o0`02o`<01Ol500;o1P02o`800_l900;o4`02o`H00_l00`3oo`0900;o1P02o`X0
0_l500;o2002o`T01?l200Co1@02o`@00_l600;o0P02o`X00_l600;o0`02o`@00_l800;o0P02o`H0
2ol700;o2P02o`H00_l400;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`L00_l500;o1P02oa00
000C00;o3P02o`P00_l600;o2P02oaH01ol700;o1@02o`@00_l900;o00<0ool01P02o`P00_l600;o
0`02o`<00_l00`3oo`0500;o1P02o`800_l900;o4`02o`H00_l00`3oo`0900;o1P02o`X00_l500;o
2002o`T00_l0103o0004o`D00_l300?o1P02o`800_l:00;o1P02o`<00ol200?o2@04o`P02Ol800;o
2P02o`H00_l400;o1@02o`H00_l200;o2002o`H00_l400;o1`02o`D00_l600;o400001<00_l>00;o
2@02o`@00_l;00;o5P09o`D00_l500;o1002o`T00_l900;o2002o`/00_l200?o00<0ool01@02o`X0
0_l900;o4`02o`T00_l900;o1P03o`T00_l500;o2002o`T00_l01P3o003o00;o1@07o`L01_l:00;o
2`07o`X01?l800;o1@02o`P00ol900;o1P02o`@00_l500;o1P06o`P00_l600;o1002o`L00_l500;o
600001<00_l>00;o2P07o`/00_lF00;o1@03o`@02Ol400;o2@02o`T00_l800;o2`02o`800_l200;o
1@02o`X00_l900;o4`02o`T00_l900;o1@04o`T02Ol800;o2@02o`030?oo00;o00<0ool01@09o`D0
1_l:00;o2`05o``00ol:00;o0`02o`P01?l900;o1P02o`@02Ol600Ko2002o`H00_l400;o1`02o`D0
0_lH00005002o`d00_l:00Ko2`02oaL00_l600;o1009o`@00_l900;o2@02o`P00_l;00;o00<0ool0
0`02o`D00_l:00;o2@02oa<00_l900;o2@02o`@01_l800Wo0`02o`<00_l300;o1002o`030?oo00;o
00<0ool01@02o`D00ol400;o0P02o`X00_l;00;o00@0oooo2`04o`T00_l300;o1`06o`P00_l600;o
1009o`H00_l200;o2002o`H00_l400;o1`02o`D00_lH00005002o`d00_l900;o1002o`X00_lG00;o
1P02o`@00_l500;o1002o`T00_l900;o2002o`/01Ol300;o1@02o`X00ol800;o4`02o`T00ol800;o
1002o`800_l800;o1@02o`<00_l300;o0`02o`<00_l300;o0`02o`@00_l600;o1002o`800_l200;o
1P02o`/00_l200?o2@06o`T00_l0103oool700;o0P02o`P00_l600;o1002o`D00_l600;o0P02o`80
0_l400;o1P02o`@00_l700;o1@02oaP0000D00?o3002o`P00_l600;o2@02oaL00_l600;o1002o`D0
0_l500;o1`02o`X00_l800;o2`04o`@00_l500;o2`02o`L00_lD00;o2P02o`L00_l400?o0`02o`L0
0_l500;o0`02o`<00_l300;o0`02o`<00_l300;o1002o`H00_l400;o1P02o`H00_l;00;o0`03o`L0
0ol200?o2002o`030?oo00L00ol300;o1`02o`H00_l400;o1@02o`H00_l600;o1002o`H00_l400;o
1P02o`H00_lH00005@02o``00_l800;o1P02o`P00_lH00;o1@03o`@00_l500;o1@03o`D00ol:00;o
2002o`/01?l400;o1@02o``00_l500;o5@02o`/00_l500;o1@02o`@00_l700;o1@02o`<00_l300;o
0`02o`<00_l800;o1002o`D00ol400;o1P02o`H00_l;00;o1003o`H00_l400;o2005o`L00_l400;o
1`02o`H00_l400;o1@02o`H00_l600;o1002o`H00_l400;o1004o`H00_lH00005P02o`L00ol00`3o
o`0800?o1003o`L00_lG00_o1004o`<01?l500Wo1P0:o`802?l700Co0P06o`030?oo00Ko2@09oa80
2?l800Wo0`05o`801Ol400Co0`04o`803?l200Ko0P06o`030?oo00Wo0`0<o`<02?l600Go0`05o`80
1Ol200Go0`07o`H01Ol200Go1004o`@01?l200Co0`04o`<03?l300Co1004o`802_l400So5@0001L0
00?o00001@06o`T02?l80003o`0001H02Ol600Co0`04o`L01Ol800[o0P08o`L00ol300Ko00<0ool0
1_l;00Go5008o`X01Ol500Go0P05o`@01?l300Co0P0<o`801_l200Ko00<0ool01ol500co0`08o`H0
1Ol300Go0P05o`801Ol300Oo1P05o`801Ol400Co1004o`801?l300Co0`0<o`<01?l400Co0P08o`H0
2?lE00008P03o`X01_oo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(19\\) PHOJLNLQ LQYHTWOFLKXAYUHEUDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`T02Ol500Go3P02oaD02?l700Co0`04o`L01Ol700Ko1`0=o`80
1_l300;o0P0=o`H01OlD00go1@05o`L02?l600Co0`04o`@02?l700;o1002o`P01Ol500Oo200=o`03
0?oo00?o1P02o`801Ol200Go00<0ool01?l300Ko0P08o`X01?l600Co0`04o`<03?l700Co1P08o`H0
3Ol@00004`02o`X02Ol500Oo3@02oa@02?l700Co0`04o`D02Ol300Wo1P0=o`801_l200?o0P0=o`@0
2OlB00go0`09o`D02?l600Co0`04o`@02?l700;o1002o`H02Ol300Oo200=o`030?oo00?o1@03o`80
1Ol200Go00<0ool01?l300Ko0P08o`P02?l400Co0`04o`<03?l500So100:o`@03Ol@00004`02o`h0
0_l=00?o3002oaH00_l<00;o1@02o`D00ol500?o0P03o`@00ol800;o1P02o`<00_l400Co1@02o`H0
0_l300?o1@03oa@00_l600;o0P03o`D00ol700;o2P02o`D00_l800;o2@03o`@00ol400?o1@03o`@0
0_l>00;o1P02o`<00_l500?o1003o`@00ol400;o1`02o`L00_l;00;o1002o`D00_l500;o1P02o`H0
0_l500;o1002o`D00_l400Co1P02o`H00_l@00004`02o`h00_l>00?o2`02oaH00_l<00;o1@02o`D0
0_l700;o0P02o`H00_l800;o1P02o`<00_l400Co1@02o`H00_l300;o1`02oa@00_l600;o0P02o`L0
0_l700;o2P02o`D00_l800;o2@04o`<00ol400;o1`02o`@00_l>00;o1P02o`<00_l500;o1P03o`80
0ol500;o1`02o`L00_l:00;o1P02o`@00_l500;o1P02o`H00_l400;o1P02o`@00_l600;o1P02o`H0
0_l@00004`02o`h00_l?00;o2`02oaH00_l<00;o1@02o`@00_l900;o00<0ool01P02o`P00_l600;o
0`02o`<01Ol500;o1P02o`800_l900;o4`02o`H00_l00`3oo`0900;o1P02o`X00_l500;o2002o`T0
1?l200Co0`02o`T00_l300;o0P02o`X00_l600;o0`02o`@00_l800;o0P02o`H02ol700;o2P02o`H0
0_l400;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`L00_l500;o1P02oa00000C00;o3P02o`/0
1?l00`3oo`0:00;o5P07o`L00_l500;o1002o`T00_l00`3oo`0600;o2002o`H00_l300;o0`02o`03
0?oo00D00_l600;o0P02o`T00_lC00;o1P02o`030?oo00T00_l600;o2P02o`D00_l800;o2@02o`04
0?l000Co0`02o`T00_l300;o0P02o`X00_l600;o0`03o`800ol900Co2009o`P00_l:00;o1P02o`@0
0_l500;o1P02o`800_l800;o1P02o`@00_l700;o1@02o`H00_l@00004`02o`h00_l900Wo2P02oaH0
2Ol500;o1@02o`@00_l900;o2@02o`P00_l;00;o0P03o`030?oo00D00_l:00;o2@02oa<00_l900;o
2@02o`H00ol900;o1@02o`P00_l900;o00H0o`00o`02o`<00_l900;o0`06o`X00_l;00Oo2P04o`P0
0_l500;o2003o`T00_l600;o1002o`D00_l600Ko2002o`H00_l400;o1`02o`D00_lH00004`02o`h0
0_l900;o1003o`X00_lF00;o1@03o`@02Ol400;o2@02o`T00_l800;o2`02o`800_l200;o1@02o`X0
0_l900;o4`02o`T00_l900;o1@04o`T02Ol800;o2@02o`030?oo00;o00<0ool00`02o`T00_l300Ko
2P02o`/01Ol<00?o2P02o`<00_l800Co2@02o`H00_l400Wo1P06o`P00_l600;o1002o`L00_l500;o
600001@00_l=00;o2002o`H00_l900;o5`02o`H00_l400Wo1002o`T00_l900;o2002o`/00_l00`3o
o`0300;o1@02o`X00_l900;o4`02o`T00_l900;o1006o`P02Ol300;o0`02o`<00_l400;o00<0ool0
0_l00`3oo`0300;o2@02o`<00_l200;o2P02o`/00_l0103oool;00Co2@02o`<00_l700Ko2002o`H0
0_l400Wo1P02o`800_l800;o1P02o`@00_l700;o1@02oaP0000D00;o3@02o`P00_l600;o2@02oaL0
0_l600;o1002o`D00_l400;o2@02o`T00_l800;o2`05o`<00_l500;o2P03o`P00_lC00;o2@03o`P0
0_l400;o0P02o`P00_l500;o0`02o`<00_l300;o0`02o`<00_l300;o0P02o`T00_l300;o0P02o`80
0_l600;o2`02o`800ol900Ko2@02o`040?ooo`L00_l200;o2002o`H00_l400;o1@02o`H00_l200;o
0P02o`@00_l600;o1002o`L00_l500;o600001@00ol<00;o2002o`H00_l900;o5`02o`H00_l400;o
1@02o`D00_l700;o2P02o`P00_l;00Co1002o`D00_l;00;o1`02oa@00_l:00;o1`02o`@00ol300;o
1`02o`D00_l300;o0`02o`<00_l300;o0`02o`<00_l300;o1`02o`@00_l600;o1P02o`/00_l300?o
1`03o`800ol800;o00<0ool01`03o`<00_l700;o1P02o`@00_l500;o1P02o`H00_l400;o1P02o`@0
0_l600;o1P02oaP0000E00;o3002o`P00_l60003o`0000L00_lH00;o1@03o`@00_l500;o1@03o`D0
0ol:00;o2002o`/01?l400;o1@02o``00_l500;o5@02o`/00_l500;o1@02o`@00_l700;o1@02o`<0
0_l300;o0`02o`<00_l800;o0`03o`D00ol400;o1P02o`H00_l;00;o1003o`H00_l400;o2005o`L0
0_l400;o1`02o`H00_l400;o1@02o`H00_l600;o1002o`H00_l400;o1004o`H00_lH00005P02o`L0
0ol00`3oo`0900;o1002o`P00_lG00_o1004o`<01?l500Wo1P0:o`802?l700Co0P06o`030?oo00Ko
2@09oa802?l800Wo0`05o`801Ol400Co0`04o`803?l200Ko0P06o`<02Ol300co0`08o`H01Ol300Go
0P05o`801Ol300Oo1P05o`801Ol400Co1004o`801?l300Co0`0<o`<01?l400Co0P0:o`@02?lE0000
5`000ol0000500Ko2@07o`T000?o00005P09o`H01?l300Co1`05o`P02_l200So1`03o`<01_l00`3o
o`06o`/01OlD00So2P05o`D01Ol200Go1004o`<01?l200co0P06o`801_l500Go1@0<o`<02?l600Go
0`05o`801Ol200Go0`07o`H01Ol200Go1004o`@01?l200Co0`04o`<03?l300Co1004o`802?l600So
5@0002800ol;00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(20\\) MHPJLNLQ LQYHTWOFLKXA ZHEUEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?o8P02o`@00ooo00L0000E00;o
:002ogh02_lQ00[oo`0600005002obX00_mn00Go0P02ob801Ol200;oo`0600005002obX00_mn0003
o`0002P000?o0000o`0<00005002o`P02_l800Co3002oaD01Ol300Go0P04o`<01?l300So2006o`L0
3Ol200Ko0`02o`803Ol600Go500=o`D01Ol700So1P04o`<01?l400So1`02o`@00_l800Go1@07o`P0
3Ol00`3oo`03o`H00_l200Go0P05o`030?oo00Co0`06oa002_l400Co0`04o`<03?l700Co1@0<o`<0
3Ol@00004`02o`T02_l700Ko3002oa@01Ol300Go0P04o`<01?l300So1P09o`H03Ol200Ko0P03o`80
3Ol400Wo4P0=o`<02Ol500So1P04o`<01?l400So1`02o`@00_l600Wo0`07o`P03Ol00`3oo`03o`D0
0ol200Go0P05o`030?oo00Co0`06oa002_l400Co0`04o`<03?l500So0`0<o`<03Ol@00004`02o`X0
0_l500;o1P03o`800ol;00;o5@02o`L00_l400;o1@02o`H00_l:00?o1003o`P00_l600;o0`02o`@0
1?l500;o1P02o`<00ol500?o5002o`H00_l200?o1@03o`L00_l:00;o1@02o`P00_l900?o1003o`@0
0ol500?o1002o`h00_l600;o0`02o`D00ol400?o1003o`@00_l700;o4`02o`D00_l500;o1@02o`H0
0_l600;o1@02o`@00_l500;o1P02o`H00_l600;o400001<00_l;00?o2`02o`@00_l;00;o5@02o`L0
0_l400;o1@02o`H00_l:00;o1P02o`P00_l600;o0`02o`@01?l500;o1P02o`<00_l700;o5002o`H0
0_l200;o1`02o`L00_l:00;o1@02o`P00_l900Co0`03o`@00_l700;o1002o`h00_l600;o0`02o`D0
0_l600?o0P03o`D00_l700;o4`03o`@00_l500;o1@02o`H00_l600;o1002o`H00_l400;o1P02o`H0
0_l600;o400001<00_l<00?o2@02o`H00_l:00;o5@02o`<00_l200;o1002o`D00_l600;o2P02o`H0
0_l800;o1P02o`<00_l300Go1@02o`H00_l200;o2@02oa<00_l600;o00<0ool02@02o`H00_l:00;o
1@02o`P00_l900Co0P04o`<00_l900;o0`02o`800_l:00;o1P02o`<00_l400;o2002o`800_l600_o
5003o`<00_l500;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`800_l200;o1P02o`H00_l@0000
4`02o`d00ol800;o1P02o`X00_lE00;o0P03o`800_l400;o1@02o`H01ol500;o1P02o`P00_l600;o
0`02o`<00_l00`3oo`0500;o1P02o`800_l900;o4`02o`H00_l00`3oo`0900;o1P02o`X00_l500;o
2002o`T00_l0103o0004o`<00_l900;o0`02o`800_l:00;o1P02o`<00ol200?o2@04o`P02OlF00;o
0`02o`D00_l500;o1P02o`800_l800;o1P02o`@00_l200;o2P02o`H00_l@00004`02o`h00ol700;o
1P02o`X00_lE00;o0P000ol0o`0200;o1002o`D00_l600Wo2`02o`P00_l;00;o0P03o`030?oo00D0
0_l:00;o2@02oa<00_l900;o2@02o`H00ol900;o1@02o`P00_l900;o00H0o`00o`02o`<00_l900;o
0`06o`X00_l;00Oo2P04o`P00_l500;o5P03o`T00_l500;o1P06o`P00_l600;o1006o`X00_lH0000
4`02o`l00ol600;o1P02o`X00_lE00;o00@0ool00_l00`3oo`0400Wo1P02o`D00ol:00;o2002o`/0
0_l200;o0P02o`D00_l:00;o2@02oa<00_l900;o2@02o`D01?l900Wo2002o`T00_l00`3oo`02o`03
0?oo00<00_l900;o0`06o`X00_l;00Go3003o`X00_l300;o6003o`P02Ol600Ko2002o`H00_l400Ko
2P02oaP0000D00;o3`02o`H00_l600;o2@02oaH00_l00`3oo`020004o`3oo`@02Ol600;o1P02o`X0
0_l800;o2`02o`030?oo00<00_l500;o2P02o`T00_lC00;o2@02o`T00_l400Ko2009o`<00_l300;o
0`02o`@00_l00`3oo`02o`030?oo00<00_l900;o0`02o`800_l:00;o2`02o`040?ooo`/01?l900;o
0`02oa@00_l300;o2009o`H00_l200;o2002o`H00_l400;o0P02o`X00_lH00005002oa000_l500;o
1P02o`T00_lF00;o00<0o`000P001?l0ool400;o1@02o`H00_l600;o2P02o`P00_l;00Go0`02o`D0
0_l:00?o2002oa<00_l900?o2002o`@00_l200;o2002o`D00_l300;o0`02o`<00_l300;o0`02o`<0
0_l200;o2@02o`<00_l200;o0P02o`H00_l;00;o0P03o`T01_l900;o00@0oooo5002o`<00ol700;o
1@02o`H00_l200;o0P02o`@00_l600;o1002o`800_l200;o1P02oaP0000D00?o3`02o`D00_l600;o
2@02oaH01?l300Co1002o`D00_l600;o1P02o`X00_l800;o2`04o`@00_l500;o2`02o`L00_lD00;o
2P02o`L00_l400?o0`02o`L00_l500;o0`02o`<00_l300;o0`02o`<00_l300;o0`02o`L00_l400;o
1P02o`H00_l;00;o0`03o`L00ol200?o2002o`030?oo01D00_l400?o1P02o`D00_l600;o1P02o`@0
0_l600;o1002o`H00_l600;o600001D00_l800;o1@02o`H00_l400;o2@02oaL01?l400?o1002o`D0
0_l600;o1@03o`X00_l800;o2`04o`@00_l500;o3002o`D00_lE00;o2`02o`D00_l500;o1002o`L0
0_l500;o0`02o`<00_l300;o0`02o`P00_l300?o1@03o`@00_l600;o1P02o`/00_l400?o1P02o`@0
0_l800Go5@02o`D00_l600;o1@02o`H00_l600;o1002o`H00_l400;o1P02o`H00_lH00005P02o`L0
0ol300?o1P03o`800ol800;o5`04o`D01?l200Co0`04o`<02ol600[o0P08o`L01?l200Ko00<0ool0
1_l900Wo4P08o`P02Ol300Go0P05o`@01?l300Co0P0<o`801_l200Ko0`09o`<03?l300So1P05o`<0
1Ol200Go0P05o`<01olF00[o1004o`<01?l300co0`04o`@01?l00`3oo`0:o`<02?lE00005`000ol0
000600Oo2006o`T000?o00005P04o`D01?l200Co0`04o`<02Ol800[o0P08o`L00ol300Ko00<0ool0
1_l;00Go5008o`X01Ol500Go0P05o`@01?l300Co0P0<o`801_l200Ko1@05o`D03?l300So1P05o`<0
1Ol200Go0P05o`<01olF00[o1004o`<01?l300co0`04o`@01?l00`3oo`0:o`<02?lE00008@05o`X0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(21\\) MHPJLNLQ LSYHTWOFLFXA ZHEUEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`H0
2Ol900;o5@05o`<01Ol200Co0`04o`<02?l800Ko1`0=o`801_l300;o0P0=o`H01OlD00go0P02o`03
0?oo00?o1`08o`H01?l300Co1008o`L00_l400;o2005o`D01ol800go00<0ool01Ol800Go0P05o`03
0?oo00Co0`06oa002_l400Co0`04o`<03?l700Co1@0<o`<03Ol@00004`02o`T02_l600Wo2P02oa@0
1Ol300Go0P04o`<01?l300So1P09o`H03Ol200Ko0P03o`803Ol400Wo4P0=o`802_l500So1P04o`<0
1?l400So1`02o`@00_l600Wo0`07o`P03Ol00`3oo`05o`P01Ol200Go00<0ool01?l300Ko400:o`@0
1?l300Co0`0<o`D02?l300co0`0=oa00000C00;o2P02o`D00_l:00;o3@02oaD00_l700;o1002o`D0
0_l600;o2P03o`@00ol800;o1P02o`<00_l400Co1@02o`H00_l300?o1@03oa@00_l600;o0P03o`D0
0ol700;o2P02o`D00_l800;o2@03o`@00ol400?o1@03o`@00_l>00;o1P02o`<00_l<00?o1003o`@0
0_l700;o4`02o`D00_l500;o1@02o`H00_l600;o1@02o`@00_l500;o1P02o`H00_l600;o400001<0
0_l;00?o3`02o`d00_lE00;o1`02o`@00_l500;o1P02o`X00_l600;o2002o`H00_l300;o1004o`D0
0_l600;o0`02o`L00_lD00;o1P02o`800_l700;o1`02o`X00_l500;o2002o`T01?l300?o1002o`L0
0_l400;o3P02o`H00_l300;o3@03o`800ol500;o1`02oa<00ol400;o1@02o`D00_l600;o1P02o`@0
0_l600;o1002o`H00_l600;o1P02oa00000C00;o3003o`h00_l=00;o5@02o`<00_l200;o1002o`D0
0_l600;o2P02o`H00_l800;o1P02o`<00_l300Go1@02o`H00_l200;o2@02oa<00_l600;o0P02o`L0
0_l700;o2P02o`D00_l800;o2@04o`801?l300;o2@02o`<00_l200;o2P02o`H00_l300;o0P02o`X0
0_l200;o1P0;oa@00ol300;o1@02o`D00_l600;o0P02o`800_l400;o1P02o`@00_l200;o0P02o`H0
0_l600;o400001<00_l=00?o3@02o`d00_lE00;o0P03o`800_l400;o1@02o`H01ol500;o1P02o`P0
0_l600;o0`02o`<00_l00`3oo`0500;o1P02o`800_l900;o4`02o`H00_l:00?o1`02o`X00_l500;o
2002o`T00_l0103o0004o`<00_l900;o0`02o`800_l:00;o1P02o`<00_l200;o2`04o`P02OlF00;o
0`02o`D00_l500;o1P02o`800_l800;o1P02o`@00_l200;o2P02o`H00_l@00004`02o`h00ol<00;o
3@02oaD00_l20003o`3o00800_l400;o1@02o`H02Ol;00;o2002o`/00_l200?o00<0ool01@02o`X0
0_l900;o4`02o`d01ol800?o2@02o`D00_l800;o2@02o`060?l00?l00_l300;o2@02o`<01_l:00;o
2`06o`/01?l800;o1@02oaH00ol900;o1@02o`H01_l800;o1P02o`@01_l:00;o600001<00_l?00?o
2`02o`d00_lE00;o00@0ool00_l00`3oo`0400Wo1P02o`D00ol:00;o2002o`/00_l200;o0P02o`D0
0_l:00;o2@02oa<00_l;00Oo2@04o`T02Ol800;o2@02o`030?oo00;o00<0ool00`02o`T00_l300Ko
2P02o`/01_l;00?o2P02o`<00_lH00?o2009o`H01_l800;o1P02o`@01_l:00;o600001@00_l?00;o
2`02o``00_lF00;o00<0ool00P001?l0ool400Wo1P02o`H00_l:00;o2002o`/00_l00`3oo`0300;o
1@02o`X00_l900;o4`02o`X00ol=00Ko2009o`<00_l300;o0`02o`@00_l00`3oo`02o`030?oo00<0
0_l900;o0`02o`800_l:00;o2`02o`800_l;00Co2@02o`<00_lD00;o0`02o`P02Ol600;o0P02o`P0
0_l600;o1002o`800_l:00;o600001@00_l@00;o2P02o``00_lF00;o00<0o`000P001?l0ool400;o
1@02o`H00_l600;o2P02o`P00_l;00Go0`02o`D00_l:00?o2002oa<00_l:00;o1`000ol0000400;o
0P02o`P00_l500;o0`02o`<00_l300;o0`02o`<00_l300;o0P02o`T00_l300;o0P02o`800_l600;o
2`02o`800_l200;o1P06o`T00_l0103ooolD00;o0`03o`L00_l500;o1P02o`800_l200;o1002o`H0
0_l400;o0P02o`800_l600;o600001@00ol?00;o2P02o``00_lF00Co0`04o`@00_l500;o1P02o`H0
0_l:00;o2002o`/01?l400;o1@02o`/00_l700;o5002o`X00_l600;o1@03o`<00_l700;o1@02o`<0
0_l300;o0`02o`<00_l300;o0`02o`<00_l700;o1002o`H00_l600;o2`02o`H00_l500?o0P03o`P0
0_l00`3oo`0E00;o1003o`H00_l500;o1P02o`H00_l400;o1P02o`@00_l600;o1P02oaP0000E00;o
2002o`D00_l:00;o2`02oaL01?l400?o1002o`D00_l600;o1@03o`X00_l800;o2`04o`@00_l500;o
3002o`D00_lE00;o2P03o`@00ol500;o1002o`L00_l500;o0`02o`<00_l300;o0`02o`P00_l300?o
1@03o`@00_l600;o1P02o`/00_l600;o1@02o`@00_l800Go5@02o`D00_l600;o1@02o`H00_l600;o
1002o`H00_l400;o1P02o`H00_lH00005P02o`L00ol300?o1P03o`030?oo00X00_lG00Co1@04o`80
1?l300Co0`0;o`H02_l200So1`04o`801_l00`3oo`06o`T02OlB00So2009o`<01Ol200Go1004o`<0
1?l200co0P06o`801_l300Wo0`0<o`<02?l600co0`05o`801Ol300Oo5P0:o`@01?l300Co0`0<o`<0
1?l400Co00<0ool02_l300So5@0001L000?o00001P07o`L01_l:0003o`0001H01?l500Co0P04o`<0
1?l300Wo200:o`802?l700?o0`06o`030?oo00Ko2`05oa@02?l:00Go00<0o`000P05o`801Ol400Co
0`04o`803?l200Ko0P06o`D01Ol500co0`08o`H03?l300Go0P05o`<01olF00[o1004o`<01?l300co
0`04o`@01?l00`3oo`0:o`<02?lE00008@05o`/00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(22\\) MHPJLNLQ HSYHTZOILFXA ZHEUEN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`D0
2_l900;o5@05o`<01Ol200Co0`04o`<02?l800Ko1`0=o`801_l300;o0P0=o`H01OlE00Co0`04o`<0
0_l00`3oo`03o`L02?l600Co0`04o`@02?l600[o1`05o`H02_l400go00<0ool01Ol800Go0P05o`03
0?oo00Co0`06oa002_l400Co0`04o`<03?l700Co1@0<o`@01_l300;o4@0001<00_l900[o1@0:o`X0
0_lD00Go0`05o`801?l300Co0`08o`H02Ol600go0P06o`800ol200go1009oa<01?l300Co0`0:o`D0
2?l600Co0`04o`@02?l600[o1@09o`@02_l400go00<0ool01Ol800Go0P05o`030?oo00Co0`06oa00
2_l400Co0`04o`<03?l500So0`0<o`@01_l200?o4@0001<00_l:00;o1@02o`H00_l500;o2P02oaD0
0_l700;o1002o`D00_l600;o2P03o`@00ol800;o1P02o`<00_l400Co1@02o`H00_l300?o1@03oa<0
0_l500;o1003o`D00ol700;o2P02o`D00_l800;o2P02o`D00_l400?o1@03o`L00_l;00;o1P02o`<0
0_l<00?o1003o`@00_l700;o4`02o`D00_l500;o1@02o`H00_l600;o1@02o`@00_l500;o1P02o`D0
0_l400Co4@0001<00_l;00?o3003o`l00_lE00;o1`02o`@00_l500;o1P02o`X00_l600;o2002o`H0
0_l300;o1004o`D00_l600;o0`02o`L00_lC00;o1@02o`@00_l700;o1`02o`X00_l500;o2002o`X0
0ol400;o1002o`L00_l700;o2`02o`H00_l300;o3@03o`800ol500;o1`02oa<00ol400;o1@02o`D0
0_l600;o1P02o`@00_l600;o1002o`H00_l500;o1004oa40000C00;o3003o``00ol>00;o5@02o`<0
0_l200;o1002o`D00_l600;o2P02o`H00_l800;o1P02o`<00_l300Go1@02o`H00_l200;o2@02oa80
0_l500;o1002o`L00_l700;o2P02o`D00_l800;o2`03o`<00_l300;o2@02o`H00_l;00;o1P02o`<0
0_l200;o2P02o`800_l600_o5003o`<00_l500;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`80
0_l200;o1@02o`<01OlA00004`02o`d00ol<00?o3@02oaD00_l200?o0P02o`@00_l500;o1P07o`D0
0_l600;o2002o`H00_l300;o0`02o`030?oo00D00_l600;o0P02o`T00_lB00;o1@02o``00ol700;o
2P02o`D00_l800;o3002o`<00_l300;o2@02o`H00_l;00;o1P02o`<00_l200;o2`04o`P02OlF00;o
0`02o`D00_l500;o1P02o`800_l800;o1P02o`@00_l200;o2@02o`<00_l00`3oo`0A00004`02o`h0
0ol<00?o3002oaD00_l20003o`3o00800_l400;o1@02o`H02Ol;00;o2002o`/00_l200?o00<0ool0
1@02o`X00_l900;o4P02o`D00_l700Oo2003o`T00_l500;o2002o``00ol700;o2@02o`H00_l;00;o
2`06o`/01?l800;o1@02oaH00ol900;o1@02o`H01_l800;o1P02o`@01_l900;o0P03o`030?oo0140
000C00;o3`03o``00ol;00;o5@02o`040?oo00;o00<0ool01009o`H00_l500?o2P02o`P00_l;00;o
0P02o`800_l500;o2P02o`T00_lB00Wo1@07o`T01?l900Wo2002o`d00ol600;o2@02o`H00_l;00;o
2`06o`/00ol:00;o0`02oaP00ol800Wo1P06o`P00_l600;o1006o`T00_l200;o0P02oa40000D00;o
3`02o`d00_l:00;o5P02o`030?oo008000Co0?oo1009o`H00_l600;o2P02o`P00_l;00;o00<0ool0
0`02o`D00_l:00;o2@02oa802Ol400?o3@06o`P02Ol300;o0`02o`<00_l400;o0`02o`H00_l900;o
1P02o`/00_l;00;o0P02o`/01?l900;o0`02oa@00_l300;o2009o`H00_l200;o2002o`H00_l400;o
0P02o`T00_l00`3oo`0300;o4@0001@00_l@00;o3@02o`T00_lF00;o00<0o`000P001?l0ool400;o
1@02o`H00_l600;o2P02o`P00_l;00Go0`02o`D00_l:00?o2002oa800_l500;o1002o`L000?o0000
1002o`800_l800;o1@02o`<00_l300;o0`02o`@00_l300?o1@02o`T00_l600;o2`02o`/00_l200;o
0P02o`H01_l900;o00@0oooo5002o`<00ol700;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`80
0_l200;o1@05o`<00_lA00005003o`l00_l=00;o2@02oaH01?l300Co1002o`D00_l600;o1P02o`X0
0_l800;o2`04o`@00_l500;o2`02o`L00_lC00;o1@02o`@00_l600;o1@03o`<00_l700;o1@02o`<0
0_l300;o0`02o`@00_l400?o1@02o`L00_l700;o2`02o`/00_l600;o1@03o`800ol800;o00<0ool0
5@02o`@00ol600;o1@02o`H00_l600;o1002o`H00_l400;o1P02o`D01?l400;o4@0001D00_l800;o
1@02o`H00_l500;o2002oaL01?l400?o1002o`D00_l600;o1@03o`X00_l800;o2`04o`@00_l500;o
3002o`D00_lD00;o1@02o`@00ol400?o1@02o`@00_l700;o1@02o`<00_l300;o0`02o`@00_l500;o
1@03o`D00ol700;o2`02o`/00_l600;o1@02o`@00_l800Go5@02o`D00_l600;o1@02o`H00_l600;o
1002o`H00_l400;o1P02o`D01?l400;o4@0001H00_l700?o0`03o`H00ol300?o1`02oaL01?l500Co
0P04o`<01?l300_o1P0:o`802?l700Co0P06o`030?oo00Ko2@09oa<01?l300Co1009o`<01Ol200Go
1004o`<01?l200co100:o`D02Ol400[o1008o`H03?l300Go0P05o`<01olF00[o1004o`<01?l300co
0`04o`@01?l00`3oo`0:o`@01?l200Ko400001L000?o00001P07o`P01ol80003o`0001H01?l500Co
0P04o`<01?l300Wo200:o`802?l700?o0`06o`030?oo00Ko2`05oaD01?l300Co1P05o`030?l00080
1Ol200Go1004o`<01?l200co100:o`L01Ol600[o1008o`H03?l300Go0P05o`<01olF00[o1004o`<0
1?l300co0`04o`@01?l00`3oo`0:o`@00ol300Ko400002401Ol:00Goo`350000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(23\\) MHPJLNLQ HSYHT MIJFXA ZHEUEN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`L0
1Ol<00;o5@05o`<01Ol200Co0`04o`<02?l800Ko1`0=o`801_l300;o0P0=o`H01OlE00Co0`04o`<0
0_l00`3oo`03o`L02?l600Co0`04o`@02?lC00Go0`05o`802_l600Ko1P07o`P01Ol200Go00<0ool0
1?l300Ko400:o`@01?l300Co0`0<o`L01?l500co1006o`<00_lA00004`02o`T02_l500Wo2`02oa@0
1Ol300Go0P04o`<01?l300So1P09o`H03Ol200Ko0P03o`803Ol400Wo4`04o`<01?l300[o1@08o`H0
1?l300Co1008oa<01Ol300Go0P0:o`@02Ol500Oo2005o`801Ol00`3oo`04o`<01_l@00[o1004o`<0
1?l300co1@08o`<03?l400Ko0P03oa40000C00;o2P02o`D00_l500;o1@02o`/00_lE00;o1`02o`@0
0_l500;o1P02o`X00ol400?o2002o`H00_l300;o1004o`D00_l600;o0`03o`D00olC00;o1@02o`@0
0ol500?o1`02o`X00_l500;o2002oaL00_l700;o1`02o`P00ol400?o1P02o``00ol400?o1002o`L0
0_lC00;o1@02o`D00_l500;o1P02o`H00_l500;o1002o`D00_l600;o1@02o`@01?lA00004`02o`/0
0olB00;o2P02oaD00_l700;o1002o`D00_l600;o2P02o`H00_l800;o1P02o`<00_l400Co1@02o`H0
0_l300;o1`02oa<00_l500;o1002o`L00_l700;o2P02o`D00_l800;o5`02o`L00_l700;o2002o`H0
0_l600;o3@03o`800ol500;o1`02oa<00ol400;o1@02o`D00_l600;o1P02o`@00_l600;o1002o`H0
0_l500;o1004oa40000C00;o3003oa400_l:00;o5@02o`<00_l200;o1002o`D00_l600;o2P02o`H0
0_l800;o1P02o`<00_l300Go1@02o`H00_l200;o2@02oa800_l500;o1002o`L00_l700;o2P02o`D0
0_l800;o5`02o`<00_l200;o1`02o`P00_l600;o1P02o`800_l:00;o0P02o`H02olD00?o0`02o`D0
0_l500;o1P02o`800_l200;o1002o`H00_l400;o0P02o`800_l500;o0`05oa40000C00;o3@03oa00
0_l:00;o5@02o`800ol200;o1002o`D00_l600Oo1@02o`H00_l800;o1P02o`<00_l300;o00<0ool0
1@02o`H00_l200;o2@02oa800_l500;o3003o`L00_l:00;o1@02o`P00_lG00;o0P03o`800_l700;o
2002o`H00_l600;o0P02o`/01?l800Wo5P02o`<00_l500;o1@02o`H00_l200;o2002o`H00_l400;o
0P02o`T00_l300;o00<0ool04@0001<00_l>00?o3P02o`/00_lE00;o0P000ol0o`0200;o1002o`D0
0_l600Wo2`02o`P00_l;00;o0P03o`030?oo00D00_l:00;o2@02oa800_l500;o1`07o`P00ol900;o
1@02o`P00_lG00;o0P000ol0o`0200;o1`02oa000_l600Ko2`04o`P00_l500;o5P03o`T00_l500;o
1P06o`P00_l600;o1006o`T00_l200?o00<0ool04@0001<00_l?00?o2P04o``00_lE00;o00@0ool0
0_l00`3oo`0400Wo1P02o`D00ol:00;o2002o`/00_l200;o0P02o`D00_l:00;o2@02oa802Ol500Oo
2@04o`T02Ol800;o5`02o`040?oo00;o00<0ool01`02oa000_l600Ko2`03o`X00_l300;o6003o`P0
2Ol600Ko2002o`H00_l400Ko2@02o`800_l200;o4@0001@00_l?00;o2P03o``00_lF00;o00<0ool0
0P001?l0ool400Wo1P02o`H00_l:00;o2002o`/00_l00`3oo`0300;o1@02o`X00_l900;o4P09o`@0
0ol=00Ko2009o`<00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1P02o`800_l;00Co
2@02o`<00_lD00;o0`02o`P02Ol600;o0P02o`P00_l600;o1002o`800_l900;o00<0ool00`02oa40
000D00;o4002o`/00_l;00;o5P02o`030?l0008000Co0?oo1002o`D00_l600;o1P02o`X00_l800;o
2`05o`<00_l500;o2P03o`P00_lB00;o1@02o`@00_l70003o`0000@00_l200;o2002o`D00_l300;o
0`02o`<00_lB00;o00<0o`000P001?l0ool700;o4002o`H00_l200;o0P02o`H01_l900;o00@0oooo
5002o`<00ol700;o1@02o`H00_l200;o0P02o`@00_l600;o1002o`800_l200;o1@05o`<00_lA0000
5003o`l00_l<00;o2P02oaH01?l300Co1002o`D00_l600;o1P02o`X00_l800;o2`04o`@00_l500;o
2`02o`L00_lC00;o1@02o`@00_l600;o1@03o`<00_l700;o1@02o`<00_l300;o0`02oa801?l300Co
1`02oa000_l600;o1P02o`D00ol200?o2002o`030?oo01D00_l400?o1P02o`D00_l600;o1P02o`@0
0_l600;o1002o`H00_l500Co1002oa40000E00;o2002o`D00_l<00;o2@02oaL01?l400?o1002o`D0
0_l600;o1@03o`X00_l800;o2`04o`@00_l500;o3002o`D00_lD00;o1@02o`@00ol400?o1@02o`@0
0_l700;o1@02o`<00_l300;o0`02oa801?l400?o1`02oa000_l600;o1P02o`D00_l400;o2005oaD0
0_l500;o1P02o`D00_l600;o1P02o`@00_l600;o1002o`H00_l500Co1002oa40000F00;o1`03o`<0
0ol600;o0`03o`P00_lG00Co1@04o`801?l300Co0`0;o`H02_l200So1`04o`801_l00`3oo`06o`T0
2OlC00Co0`04o`@02Ol300Go0P05o`@01?l300Co0P0<oa401?l500Co0P0:o`L02_l00`3oo`0:o`<0
1Ol200Go0`07oaH02_l400Co0`04o`<03?l300Co1004o`030?oo00[o1004o`801_l@00005`000ol0
000600Oo1`07o`T000?o00005P04o`D01?l200Co0`04o`<02Ol800[o0P08o`L00ol300Ko00<0ool0
1_l;00Go5@04o`<01?l600Go00<0o`000P05o`801Ol400Co0`04o`803?lA00Co1@04o`802_l700[o
00<0ool02_l300Go0P05o`<01olF00[o1004o`<01?l300co0`04o`@01?l00`3oo`0:o`@00ol300Ko
400002401Ol:00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(24\\) MHSJLNLQ HSYHT MIJFXA  HEUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`T0
1_l900;o5@05o`<01Ol200Co0`04o`@00_l00`3oo`03o`L01_l700go0P06o`<00_l200go1P05oaD0
1?l300Co0`02o`030?oo00?o1`08o`H01?l300Co1008oa<01Ol300Go0P0:o`H01_l600Oo2005o`80
1Ol00`3oo`04o`<01_lN00Co0`04o`<03?l700Co1@07o`T01_l300;o4@0001<00_l900[o2@06o`X0
0_lD00Go0`05o`801?l300Co100:o`<02Ol600go0P06o`800ol200go1009oa<01?l300Co0`0:o`D0
2?l600Co0`04o`@02?lC00Go0`05o`802_l400Wo1@07o`P01Ol200Go00<0ool01?l300Ko7P04o`<0
1?l300co1@08o`<01ol900Ko0P03oa40000C00;o2P02o`D00_l;00;o3002oaD00_l700;o1002o`D0
0_l500?o1@03o`800ol400?o2002o`H00_l300;o1004o`D00_l600;o0`03o`D00olC00;o1@02o`@0
0ol500?o1`02o`X00_l500;o2002oaL00_l700;o1`02o`P00ol400?o1P02o``00ol400?o1002o`L0
0_lQ00;o1@02o`H00_l600;o1@02o`@00_l500;o3@02o`@01?lA00004`02o`/00ol@00;o3002oaD0
0_l700;o1002o`D00_l500;o1`02o`800_l600;o2002o`H00_l300;o1004o`D00_l600;o0`02o`L0
0_lC00;o1@02o`@00_l700;o1`02o`X00_l500;o2002oaL00_l700;o1`02o`P00_l600;o1P02o`d0
0ol200?o1@02o`L00_lQ00;o1@02o`H00_l600;o1002o`H00_l400;o3@02o`@01?lA00004`02o``0
0ol900[o2P02oaD00_l300;o0P02o`@00_l500;o1@02o`L00_l200;o1P02o`P00_l600;o0`02o`<0
1Ol500;o1P02o`800_l900;o4P02o`D00_l400;o1`02o`L00_l:00;o1@02o`P00_lG00;o0`02o`80
0_l700;o2002o`H00_l600;o0P02o`X00_l200;o1P0;ob400_l500;o1P02o`800_l200;o1002o`H0
0_l400;o0P02o`T00_l300Go4@0001<00_l=00?o200:o`X00_lE00;o0P03o`800_l400;o1@02o`d0
0ol200;o1P02o`P00_l600;o0`02o`<00_l00`3oo`0500;o1P02o`800_l900;o4P02o`D00_l<00?o
1`02o`X00_l500;o2002oaL00_l200?o0P02o`L00_l800;o1P02o`H00_l200;o2`04o`P02OlR00;o
1@02o`H00_l200;o2002o`H00_l400;o0P02o`T00_l300;o00<0ool04@0001<00_l>00?o1`02o`@0
0_l<00;o5@02o`8000?o0?l00P02o`@00_l500;o2007o`/00_l800;o2`02o`800ol00`3oo`0500;o
2P02o`T00_lB00;o1@02o`L01ol800?o2@02o`D00_l800;o5`02o`8000?o0?l00P02o`L00_l@00;o
1P06o`/01?l800;o1@02ob800_l500;o1P06o`P00_l600;o1006o`T00_l200?o00<0ool04@0001<0
0_l?00?o1`02o`<00_l<00;o5@02o`040?oo00;o00<0ool01009o`H01ol=00;o2002o`/00_l200;o
0P02o`D00_l:00;o2@02oa802Ol500Oo2@04o`T02Ol800;o5`02o`040?oo00;o00<0ool01`02oa00
0_l600Ko2`03o`X00_l300;o8`09o`H01_l800;o1P02o`@01_l900;o0P02o`800_lA00005002o`l0
0_l80004o`0000;o2`02oaH00_l00`3oo`020004o`3oo`@02Ol500?o4P02o`P00_l;00;o00<0ool0
0`02o`D00_l:00;o2@02oa802Ol400?o3@06o`P02Ol300;o0`02o`<00_lB00;o00<0ool00P001?l0
ool700;o4002o`H00_l200;o2`04o`T00_l300;o8`09o`H00_l200;o2002o`H00_l400;o0P02o`T0
0_l00`3oo`0300;o4@0001@00_l@00;o1`02o`800_l;00;o5P02o`030?l0008000Co0?oo1002o`D0
0_l500;o1`000ol0000900;o2002o`/01Ol300;o1@02o`X00ol800;o4P02o`D00_l400;o1`000ol0
000400;o0P02o`P00_l500;o0`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02oa000_l600;o
0P02o`800_l600Ko2@02o`040?ooob<00_l500;o1P02o`800_l200;o1002o`H00_l400;o0P02o`80
0_l500Go0`02oa40000D00?o3`02o`P000?o00000_l;00;o5P04o`<01?l400;o1@02o`D00_l600;o
2`02o`P00_l;00Co1002o`D00_l;00;o1`02oa<00_l500;o1002o`H00_l500?o0`02o`L00_l500;o
0`02o`<00_l300;o4P04o`<01?l700;o4002o`H00_l600;o1@03o`800ol800;o00<0ool09002o`D0
0_l600;o1P02o`@00_l600;o1002o`H00_l500Co1002oa40000E00;o2002o`D00_l90004o`3oo`X0
0_lG00Co1003o`@00_l500;o1@03o`@00ol;00;o2002o`/01?l400;o1@02o``00_l500;o5002o`D0
0_l400?o1003o`D00_l400;o1`02o`D00_l300;o0`02o`<00_lB00Co1003o`L00_l@00;o1P02o`H0
0_l500;o1002o`P01OlT00;o1@02o`H00_l600;o1002o`H00_l400;o1P02o`D01?l400;o4@0001H0
0_l700?o0`03o`T01?l900;o5`04o`D01?l200Co0`04o`D02Ol600[o0P08o`L01?l200Ko00<0ool0
1_l900Wo4`04o`<01?l400Wo0`05o`801Ol400Co0`04o`803?lA00Co1@04o`802_l700[o00<0ool0
2_l300Go0P05o`<01olT00Co0`04o`<03?l300Co1004o`030?oo00[o1004o`801_l@00005`000ol0
000600Oo2`03o`T000?o00005P04o`D01?l200Co0`04o`L01Ol00`3o000500[o0P08o`L00ol300Ko
00<0ool01_l;00Go5@04o`<01?l600Go00<0o`000P05o`801Ol400Co0`04o`803?lA00Co1@04o`80
2_l700[o00<0ool02_l300Go0P05o`<01olT00Co0`04o`<03?l300Co1004o`030?oo00[o1003o`<0
1_l@00008@05o``00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(25\\) MHSJLNLQ JSYHT MIJCXA WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`L0
1Ol<00;o5@05o`<01Ol200Co0`04o`@00_l00`3oo`03o`L01_l700go0P06o`<00_l200go1P05oaH0
1_l700;o00<0ool00ol700So1P04o`<01?l400So4`05o`<01Ol200[o1P06o`X01Ol600Go0P05o`03
0?oo00Co0`06oa400_l400;o1@04o`<01?l300[o2@04o`D01ol900Ko0`02oa40000C00;o2@0:o`D0
2Ol;00;o5005o`<01Ol200Co0`04o`@02_l300Wo1P0=o`801_l200?o0P0=o`@02OlB00Wo1P0:o`D0
2?l600Co0`04o`@02?lC00Go0`05o`802_l400Wo1`09o`@01Ol200Go00<0ool01?l300Ko4@02o`@0
0_l500Co0`04o`<02ol600So0`07o`T01_l200?o4@0001<00_l:00;o1@02o`D00_l500;o2`02oaD0
0_l700;o1002o`D00_l500?o1@03o`800ol400?o2002o`H00_l300;o1004o`D00_l600;o0`03o`D0
0olA00?o1003o`D00ol500?o1`02o`X00_l500;o2002oaL00_l700;o1`02o`P00ol400?o1@03o`D0
0ol400?o1003o`@00_l700;o4P03o`@00ol500;o1@02o`H00_l500?o1@02o`@00_l500;o3@02o`@0
1?lA00004`02o`/00olB00;o2P02oaD00_l700;o1002o`D00_l500;o1`02o`800_l600;o2002o`H0
0_l300;o1004o`D00_l600;o0`02o`L00_lA00;o1P02o`D00_l700;o1`02o`X00_l500;o2002oaL0
0_l700;o1`02o`P00_l600;o1@02o`L00_l500?o0P03o`D00_l700;o4P04o`<00ol500;o1@02o`H0
0_l600;o1002o`H00_l400;o3@02o`@01?lA00004`02o``00olA00;o2P02oaD00_l300;o0P02o`@0
0_l500;o1@02o`L00_l200;o1P02o`P00_l600;o0`02o`<01Ol500;o1P02o`800_l900;o4002o`H0
0_l500;o1`02o`L00_l:00;o1@02o`P00_lG00;o0`02o`800_l700;o2002o`H00_l400?o3`02o`80
0_l600_o4P04o`801?l500;o1@02o`H00_l600;o1002o`H00_l400;o0P02o`T00_l300Go4@0001<0
0_l=00?o4002o`X00_lE00;o0P03o`800_l400;o1@02o`d00ol200;o1P02o`P00_l600;o0`02o`<0
0_l00`3oo`0500;o1P02o`800_l900;o4002o`H00_l=00?o1`02o`X00_l500;o2002oaL00_l200?o
0P02o`L00_l800;o1P02o`@00_lA00Co2009oa<00_l0103o0004o`D00_l500;o1P02o`H00_l400;o
1P02o`@00_l200;o2@02o`<00_l00`3oo`0A00004`02o`h00ol?00;o2P02oaD00_l20003o`3o0080
0_l400;o1@02o`P01ol;00;o2002o`/00_l200?o00<0ool01@02o`X00_l900;o6002o`P01ol800?o
2@02o`D00_l800;o5`02o`8000?o0?l00P02o`L00_l@00;o1002oa401?l800;o1@02oa<00_l01P3o
003o00;o1@02o`D00_l600;o1@03o`@00_l600;o1006o`T00_l200?o00<0ool04@0001<00_l?00?o
1`02o`@00_l;00;o5@02o`040?oo00;o00<0ool01009o`H01ol=00;o2002o`/00_l200;o0P02o`D0
0_l:00;o2@02oaP00_l600Oo2@04o`T02Ol800;o5`02o`040?oo00;o00<0ool01`02oa000_l400;o
4@03o`X00_l300;o5002o`030?oo00;o00<0ool01@09o`H02Ol500;o1P02o`@01_l900;o0P02o`80
0_lA00005002o`l00_l700So2P02oaH00_l00`3oo`020004o`3oo`@02Ol500?o4P02o`P00_l;00;o
00<0ool00`02o`D00_l:00;o2@02oaP00_l500?o3@06o`P02Ol300;o0`02o`<00_lB00;o00<0ool0
0P001?l0ool700;o4002o`@00_lA00Co2@02o`<00_lD00;o00<0ool00_l00`3oo`0500Wo1P08o`H0
0_l600;o1002o`800_l900;o00<0ool00`02oa40000D00;o4002o`H01ol;00;o5P02o`030?l00080
00Co0?oo1002o`D00_l500;o1`000ol0000900;o2002o`/01Ol300;o1@02o`X00ol800;o6002o`D0
0_l70003o`0000@00_l200;o2002o`D00_l300;o0`02o`<00_lB00;o00<0o`000P001?l0ool700;o
4002o`@00ol700;o1P06o`T00_l0103ooolC00;o0`02o`<00_l400;o1@02o`H00_l400?o1@02o`H0
0_l400;o0P02o`800_l500Go0`02oa40000D00?o3`02o`H00_l@00;o5P04o`<01?l400;o1@02o`D0
0_l600;o2`02o`P00_l;00Co1002o`D00_l;00;o1`02oaT00_l500;o1P02o`D00ol300;o1`02o`D0
0_l300;o0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`L00_l500?o0P03o`P00_l00`3oo`0D00;o
0`02o`<00_l400;o1@02o`H00_l500;o1@02o`H00_l400;o1P02o`D01?l400;o4@0001D00_l800;o
1@02o`H00_l?00;o5`04o`@00ol400;o1@02o`D00ol400?o2`02o`P00_l;00Co1002o`D00_l<00;o
1@02oaX00_l500?o1003o`D00_l400;o1`02o`D00_l300;o0`02o`<00_lB00Co1003o`L00_l@00;o
1@03o`D00ol500;o1002o`P01OlD00;o2002o`@00_l500;o1P02o`@00ol500;o1P02o`@00_l600;o
1@04o`@00_lA00005P02o`L00ol300?o1P02o`h00_lG00Co1@04o`801?l300Co1@09o`H02_l200So
1`04o`801_l00`3oo`06o`T02OlE00[o0`09o`<01Ol200Go1004o`<01?l200co4@04o`D01?l200[o
1`0:o`<02_l300Go0P05o`<01olD00Ko0P06o`801?l300Co0`0:o`D01?l400Co00<0ool02_l400Co
0P06oa00000G0003o`0000H01ol700So20000ol0000F00Co1@04o`801?l300Co1`05o`030?l000D0
2_l200So1`03o`<01_l00`3oo`06o`/01OlG00[o1@05o`030?l000801Ol200Go1004o`<01?l200co
4@04o`D01?l200[o1`0:o`D01Ol00`3oo`0300Go0P05o`<01olD00Ko0P06o`801?l300Co0`09o`H0
1?l400Co00<0ool02_l400?o0`06oa00000Q00Go2008ool0a0000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(26\\) MHSJLLLQ JS HT MIJC A WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`P0
1?l<00;o5@05o`<01Ol200Co0`04o`@00_l00`3oo`03o`L01_l700go00<0ool02ol00`3oo`0;o`H0
1OlF00Ko1`02o`030?oo00?o5@04o`<01?l400So4`05o`<01Ol200[o1P06o`X01OlC00Ko0`06oa40
0_l400;o1@04o`<01?l300[o2@04o`D01ol900Ko0`02oa40000C00;o2@0:o`L01ol;00;o5005o`<0
1Ol200Co0`04o`@02_l300Wo1P0=o`030?oo00_o00<0ool02ol400Wo4P09o`H02_lC00Co0`04o`@0
2?lC00Go0`05o`802_l400Wo1`09oa401_l300Ko4@02o`@00_l500Co0`04o`<02ol600So0`07o`T0
1_l200?o4@0001<00_l:00;o1@02o`H00_l400;o2`02oaD00_l700;o1002o`D00_l500?o1@03o`80
0ol400?o2002o`H00_l400;o1P02o`@00_l600;o0`03o`D00olA00?o1003o`D00ol500?o4`02o`D0
0_l800;o5`02o`L00_l700;o2003o`@00ol500?o1@03oa800_l700;o4P03o`@00ol500;o1@02o`H0
0_l500?o1@02o`@00_l500;o3@02o`@01?lA00004`02o`/00ol:00;o1P02o`X00_lE00;o1`02o`@0
0_l500;o1@02o`L00_l200;o1P02o`P00_l600;o1002o`H00_l400;o1P02o`<00_l700;o4@02o`H0
0_l500;o1`02oa<00_l500;o2002oaL00_l700;o1`02o`P00_l600;o1@02o`L00_lB00;o1`02oa80
1?l300?o1@02o`D00_l600;o1P02o`@00_l600;o1002o`d00_l400Co4@0001<00_l<00?o2@02o`H0
0_l:00;o5@02o`<00_l200;o1002o`D00_l500;o1`02o`800_l600;o2002o`H00_l400;o1P02o`@0
0_l600;o0P02o`T00_l@00;o1P02o`D00_l700;o4`02o`D00_l800;o5`02o`<00_l200;o1`02o`P0
0_l600;o1003oa/02olB00Co0P04o`D00_l500;o1P02o`H00_l400;o1P02o`@00_l200;o2@02o`<0
1OlA00004`02o`d00ol800;o1P02o`X00_lE00;o0P03o`800_l400;o1@02o`d00ol200;o1P02o`P0
0_l600;o1002o`H00_l400;o1P02o`800_l900;o4002o`H00_l=00?o4`02o`D00_l800;o5`02o`80
0ol200;o1`02o`P00_l600;o1002oad02OlC00;o00@0o`001?l500;o1@02o`H00_l600;o1002o`H0
0_l400;o0P02o`T00_l300;o00<0ool04@0001<00_l>00?o1`02o`H00_l:00;o5@02o`8000?o0?l0
0P02o`@00_l500;o2007o`/00_l800;o3002o``00_l:00;o2@02oaP00_l800Oo5002o`D00_l800;o
5`02o`8000?o0?l00P02o`L00_l@00;o1002oad00_l500;o4`02o`060?l00?l00_l500;o1@02o`H0
0_l500?o1002o`H00_l400Ko2@02o`800ol00`3oo`0A00004`02o`l00ol600?o1002o`/00_lE00;o
00@0ool00_l00`3oo`0400Wo1P07o`d00_l800;o3002o``00_l:00;o2@02oaP00_l600Oo5P09o`P0
0_lG00;o00@0ool00_l00`3oo`0700;o4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`030?oo00D0
2Ol600Wo1@02o`H00_l400Ko2@02o`800_l200;o4@0001@00_l?00;o1P09o`X00_lF00;o00<0ool0
0P001?l0ool400Wo1@03oa800_l800;o3002o``00_l:00;o2@02oaP00_l500?o6`09o`<00_l300;o
0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1002oah00_l300;o5002o`030?oo00;o00<0ool0
1@09o`H02?l600;o1P02o`@00_l200;o2@02o`030?oo00<00_lA00005002oa000_l500;o00<0ool0
0_l<00;o5P02o`030?l0008000Co0?oo1002o`D00_l500;o1`000ol0000900;o2002o``00_l<00;o
2P03o`P00_lH00;o1@02o`L000?o00004P02o`D00_l300;o0`02o`<00_lB00;o00<0o`000P001?l0
ool700;o4002o`@00ol700;o5@02o`040?oooa<00_l300;o0`02o`@00_l500;o1P02o`@00ol500;o
1P02o`@00_l200;o0P02o`D01Ol300;o4@0001@00ol?00;o1P02oa000_lF00Co0`04o`@00_l500;o
1@02o`H00_l;00;o2002o``00_l<00;o2`02o`L00_lI00;o1@02o`H00_lD00;o1@02o`<00_l300;o
0`02oa801?l300Co1`02oa000_l500;o1`02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1@02o`H0
0_l500;o1@02o`H00_l400;o1P02o`D01?l400;o4@0001D00_l800;o1@02o`H00ol>00;o5`04o`@0
0ol400;o1@02o`D00ol400?o2`02o`P00_l<00;o3002o``00_l500;o6P02o`D00ol400?o5002o`D0
0_l300;o0`02o`<00_lB00Co1003o`L00_l@00;o1@03o`D00olE00Go5002o`P00_l400;o1@02o`H0
0_l400?o1@02o`H00_l400;o1P02o`D01?l400;o4@0001H00_l700?o0`03o`L00ol<00;o5`04o`D0
1?l200Co0`04o`D02Ol600[o0P08o`H02?l600So2@09oaD02_l300Wo4`04o`<01?l200co4@04o`D0
1?l200[o1`0:o`<02_lB00Oo5006o`801_l200Co0`04o`<02_l500Co1004o`030?oo00[o1004o`80
1_l@00005`000ol0000600Oo2@07o`L000?o00005P04o`D01?l200Co0`04o`L01Ol00`3o000500[o
0P08o`H02?l600So2`05oaL02_l500Go00<0o`004P04o`<01?l200co4@04o`D01?l200[o1`0:o`D0
1Ol00`3oo`0B00Oo5006o`801_l200Co0`04o`<02Ol600Co1004o`030?oo00[o1003o`<01_l@0000
8@05o``01Ooo0<<0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(27\\) MHSJLOLQ JS HT MIJC A WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`P0
0_l>00;o5@05o`<01Ol200Co0`04o`@00_l00`3oo`03o`L01_l700go1@05o`D03Ol600Go5P06o`L0
0_l00`3oo`03oaD01?l300Co1008oa<01Ol300Go0P0:o`H01_l:00Go4`06o`<01_lA00;o1002o`D0
1?l300Co0`0:o`T01?l500Oo2@06o`<00_lA00004`02o`T02_l800;o3`02oa@01Ol300Go0P04o`<0
1?l400[o0`09o`H03Ol300Wo0`0=o`@02OlB00Wo1P0:oa<01?l300Co1008oa<01Ol300Go0P0:o`@0
2Ol700Wo4@06o`<01_lA00;o1002o`D01?l300Co0`0;o`H02?l300Oo2@06o`800olA00004`02o`X0
0_l500;o2@02o`h00_lE00;o1`02o`@00_l500;o1@03o`D00ol200?o1003o`P00_l600;o0P03o`D0
0ol500;o1P02o`<00ol500?o4@03o`@00ol500?o1@03oa<00_l500;o2002oaL00_l700;o1`02o`P0
0ol400?o1@03o`D00olB00;o1`02oa800ol400?o1@02o`D00_l600;o1@03o`D00_l400;o1@02o`d0
0_l400Co4@0001<00_l;00?o3P02o`h00_lE00;o1`02o`@00_l500;o1@02o`L00_l200;o1P02o`P0
0_l600;o0P02o`L00_l500;o1P02o`<00_l700;o4@02o`H00_l500;o1`02oa<00_l500;o2002oaL0
0_l700;o1`02o`P00_l600;o1@02o`L00_lB00;o1`02oa801?l300?o1@02o`D00_l600;o1P02o`@0
0_l600;o1002o`d00_l400Co4@0001<00_l<00?o3@02o`h00_lE00;o0`02o`800_l400;o1@02o`D0
0_l700;o0P02o`H00_l800;o1P02o`030?oo00T00_l400;o1P02o`800_l900;o4002o`H00_l500;o
1`02oa<00_l500;o2002oaL00_l300;o0P02o`L00_l800;o1P02o`@00olK00_o4P04o`801?l500;o
1@02o`H00_l600;o1002o`H00_l400;o0P02o`T00_l300Go4@0001<00_l=00?o3@000ol0000<00;o
5@02o`800ol200;o1002o`D00_l=00?o0P02o`H00_l800;o1P02o`030?oo00T00_l400;o1P02o`80
0_l900;o4002o`H00_l=00?o4`02o`D00_l800;o5`02o`800ol200;o1`02o`P00_l600;o1002oad0
2OlC00;o00@0o`001?l500;o1@02o`H00_l600;o1002o`H00_l400;o0P02o`T00_l300;o00<0ool0
4@0001<00_l>00?o3002o`d00_lE00;o0P000ol0o`0200;o1002o`D00_l800Oo2`02o`P00_l900;o
2@02o`@00_l:00;o2@02oaP00_l800Oo5002o`D00_l800;o5`02o`8000?o0?l00P02o`L00_l@00;o
1002oad00_l500;o4`02o`060?l00?l00_l500;o1@02o`H00_l500?o1002o`H00_l400Ko2@02o`80
0ol00`3oo`0A00004`02o`l00ol;00;o3@02oaD00_l0103oo`02o`030?oo00@02Ol600Oo3@02o`P0
0_l900;o2@02o`@00_l:00;o2@02oaP00_l600Oo5P09o`P00_lG00;o00@0ool00_l00`3oo`0700;o
4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`030?oo00D02Ol600Wo1@02o`H00_l400Ko2@02o`80
0_l200;o4@0001@00_l?00;o30000ol0000:00;o5P02o`030?oo008000Co0?oo1009o`D00olB00;o
2002o`T00_l900;o1002o`X00_l900;o6002o`D00olK00Wo0`02o`<00_l300;o4P02o`030?oo0080
00Co0?oo1`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3oo`0500Wo1P08o`H00_l600;o
1002o`800_l900;o00<0ool00`02oa40000D00;o4002o`/00_l;00;o5P02o`030?l0008000Co0?oo
1002o`D00_l500;o1`000ol0000900;o2002o`T00_l900;o1002o`X00ol800;o6002o`D00_l70003
o`0001800_l500;o0`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02oa000_l400?o1`02oaD0
0_l0103ooolC00;o0`02o`<00_l400;o1@02o`H00_l400?o1@02o`H00_l400;o0P02o`800_l500Go
0`02oa40000D00?o3`02o`/00_l;00;o5P04o`<01?l400;o1@02o`D00_l600;o2`02o`P00_l:00;o
1`02o`D00_l;00;o1`02oaT00_l500;o1P02oa@00_l500;o0`02o`<00_l300;o4P04o`<01?l700;o
4002o`D00_l700;o5@02o`030?oo01@00_l300;o0`02o`@00_l500;o1P02o`D00_l500;o1P02o`@0
0_l600;o1@04o`@00_lA00005@02o`P00_l500;o30000ol0000800;o5`04o`@00ol400;o1@02o`D0
0ol400?o2`02o`P00_l:00?o1@03o`D00_l<00;o1@02oaX00_l500?o1003oa@00_l500;o0`02o`<0
0_l300;o4P04o`@00ol700;o4002o`D00ol500?o5@05oa@00_l800;o1002o`D00_l600;o1003o`D0
0_l600;o1002o`H00_l500Co1002oa40000F00;o1`03o`<00ol500;o1@02o`P00_lG00Co1@04o`80
1?l300Co1@09o`H02_l200So2009o`<02?l900Wo5@0:o`<02OlC00Co0`04o`803?lA00Co1@04o`80
2_l700[o0`0:oa801olD00Ko0P06o`801?l300Co0`0:o`D01?l400Co00<0ool02_l400Co0P06oa00
000G0003o`0000H01ol600Wo20000ol0000F00Co1@04o`801?l300Co1`05o`030?l000D02_l200So
2P05o`D02?l;00Go5`0:o`D01Ol00`3o000B00Co0`04o`803?lA00Co1@04o`802_l700[o1@05o`03
0?oo01801olD00Ko0P06o`801?l300Co0`09o`H01?l400Co00<0ool02_l400?o0`06oa00000Q00Go
1`09ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(28\\) MHSJLOLQ JS HT MIJC A WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`P0
1?l<00;o5@05o`<01Ol200Co0`04o`@00_l00`3oo`03o`L01_l700go1@05o`D03Ol600Go5P06o`L0
0_l00`3oo`03oaD01?l300Co1008oa<01Ol300Go0P0:o`H01_l:00Go4`06o`<01_lA00;o1002o`D0
1?l300Co0`0:o`T01?l500Oo2@06o`<00_lA00004`02o`T02_l600So2`02oa@01Ol300Go0P04o`<0
1?l400[o0`09o`H03Ol300Wo0`0=o`@02OlB00Wo1P0:oa<01?l300Co1008oa<01Ol300Go0P0:o`@0
2Ol700Wo4@06o`<01_lA00;o1002o`D01?l300Co0`0;o`H02?l300Oo2@06o`800olA00004`02o`X0
0_l500;o1@03o`@00ol:00;o5@02o`L00_l400;o1@02o`D00ol500?o0P03o`@00ol800;o1P02o`80
0ol500?o1@02o`H00_l300?o1@03oa400ol400?o1@03o`D00olC00;o1@02o`P00_lG00;o1`02o`L0
0_l800?o1003o`D00ol500?o4P02o`L00_lB00?o1003o`D00_l500;o1P02o`D00ol500;o1002o`D0
0_l=00;o1004oa40000C00;o2`03o`X00_l600;o2P02oaD00_l700;o1002o`D00_l500;o1`02o`80
0_l600;o2002o`H00_l200;o1`02o`D00_l600;o0`02o`L00_lA00;o1P02o`D00_l700;o4`02o`D0
0_l800;o5`02o`L00_l700;o2002o`H00_l500;o1`02oa800_l700;o4P04o`<00ol500;o1@02o`H0
0_l600;o1002o`H00_l400;o3@02o`@01?lA00004`02o``00ol900;o1P02o`X00_lE00;o0`02o`80
0_l400;o1@02o`D00_l700;o0P02o`H00_l800;o1P02o`030?oo00T00_l400;o1P02o`800_l900;o
4002o`H00_l500;o1`02oa<00_l500;o2002oaL00_l300;o0P02o`L00_l800;o1P02o`@00olK00_o
4P04o`801?l500;o1@02o`H00_l600;o1002o`H00_l400;o0P02o`T00_l300Go4@0001<00_l=00?o
2002o`H00_l:00;o5@02o`800ol200;o1002o`D00_l=00?o0P02o`H00_l800;o1P02o`030?oo00T0
0_l400;o1P02o`800_l900;o4002o`H00_l=00?o4`02o`D00_l800;o5`02o`800ol200;o1`02o`P0
0_l600;o1002oad02OlC00;o00@0o`001?l500;o1@02o`H00_l600;o1002o`H00_l400;o0P02o`T0
0_l300;o00<0ool04@0001<00_l>00?o2002o`@00_l;00;o5@02o`8000?o0?l00P02o`@00_l500;o
2007o`/00_l800;o2@02o`T00_l400;o2P02o`T00_lH00;o2007oa@00_l500;o2002oaL00_l20003
o`3o00800_l700;o4002o`@00_lM00;o1@02oa<00_l01P3o003o00;o1@02o`D00_l600;o1@03o`@0
0_l600;o1006o`T00_l200?o00<0ool04@0001<00_l?00?o2007o`/00_lE00;o00@0ool00_l00`3o
o`0400Wo1P07o`d00_l800;o2@02o`T00_l400;o2P02o`T00_lH00;o1P07oaH02Ol800;o5`02o`04
0?oo00;o00<0ool01`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3oo`0500Wo1P09o`D0
0_l600;o1006o`T00_l200;o0P02oa40000D00;o3`02o`P01_l;00;o5P02o`030?oo008000Co0?oo
1009o`D00olB00;o2002o`T00_l900;o1002o`X00_l900;o6002o`D00olK00Wo0`02o`<00_l300;o
4P02o`030?oo008000Co0?oo1`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3oo`0500Wo
1P08o`H00_l600;o1002o`800_l900;o00<0ool00`02oa40000D00;o4002o`H00_l400;o2P02oaH0
0_l00`3o00020004o`3oo`@00_l500;o1@02o`L000?o00002@02o`P00_l900;o2@02o`@00_l:00?o
2002oaP00_l500;o1`000ol0000B00;o1@02o`<00_l300;o0`02oa800_l00`3o00020004o`3oo`L0
0_l@00;o1003o`L00_lE00;o00@0oooo4`02o`<00_l300;o1002o`D00_l600;o1003o`D00_l600;o
1002o`800_l200;o1@05o`<00_lA00005003o`l00_l500;o1P02o`T00_lF00Co0`04o`@00_l500;o
1@02o`H00_l;00;o2002o`X00_l700;o1@02o`/00_l700;o6@02o`D00_l600;o5002o`D00_l300;o
0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`L00_lE00;o00<0ool05002o`<00_l300;o1002o`D0
0_l600;o1@02o`D00_l600;o1002o`H00_l500Co1002oa40000E00;o2002o`D00_l500;o1P02o`P0
0_lG00Co1003o`@00_l500;o1@03o`@00ol;00;o2002o`X00ol500?o1@02o``00_l500;o6P02o`D0
0ol400?o5002o`D00_l300;o0`02o`<00_lB00Co1003o`L00_l@00;o1@03o`D00olE00Go5002o`P0
0_l400;o1@02o`H00_l400?o1@02o`H00_l400;o1P02o`D01?l400;o4@0001H00_l700?o0`03o`D0
0ol400?o1`02oaL01?l500Co0P04o`<01?l500Wo1P0:o`802?l800Wo0`08o`T02OlE00[o0`09oa<0
1?l300Co0P0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko0P04o`<01?l300[o1@04o`@0
1?l00`3oo`0:o`@01?l200Ko400001L000?o00001P07o`L02?l80003o`0001H01?l500Co0P04o`<0
1?l700Go00<0o`001@0:o`802?l:00Go1@08o`/01OlG00[o1@05o`030?l001801?l300Co0P0<oa40
1?l500Co0P0:o`L02_l500Go00<0ool04P07oa@01_l200Ko0P04o`<01?l300Wo1P04o`@01?l00`3o
o`0:o`@00ol300Ko400002401Ol900Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(29\\) MGSJLOLQ JSZHT MIJC A WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o200:o`D0
1Ol>00;o5@05o`<01Ol500Ko1P02o`030?oo00?o1`06o`L03Ol500Go1@0=o`H01OlF00Ko1`02o`03
0?oo00?o1P0:o`D01?l300Co1008oa<01Ol300Go0P0:o`H01_l:00Go4`06o`<01_lA00;o1002o`D0
1?l300Co0`0:o`T01?l500Oo2@06o`<00_lA00004`02o`T02_l500Oo3@02oa@01Ol300Go0`0:o`@0
2_l300Wo1P0=o`<02Ol300go1009oa802Ol600[o100:o`D01?l300Co1008oa<01Ol300Go0P0:o`@0
2Ol700Wo4@06o`<01_lA00;o1002o`D01?l300Co0`0;o`H02?l300Oo2@06o`800olA00004`02o`X0
0_l500;o2P03o``00_lE00;o1`02o`<01?l500;o1003o`D00ol200?o1003o`P00_l600;o0P03o`D0
0ol500;o1P02o`<00ol500?o4@03o`@00ol500?o1@03o`@00_l500;o1P02o`D00_l800;o5`02o`L0
0_l700;o2003o`@00ol500?o1@03oa800_l700;o4P03o`@00ol500;o1@02o`H00_l500?o1@02o`@0
0_l500;o3@02o`@01?lA00004`02o`/00ol@00?o2`02oaD00_l700;o0`02o`L00_l400;o1`02o`80
0_l600;o2002o`H00_l200;o1`02o`D00_l600;o0`02o`L00_lA00;o1P02o`D00_l700;o1003o`@0
0_l600;o1@02o`P00_lG00;o1`02o`L00_l800;o1P02o`D00_l700;o4P02o`L00_lB00Co0`03o`D0
0_l500;o1P02o`H00_l400;o1P02o`@00_l=00;o1004oa40000C00;o3003oa000_l;00;o5@02o`<0
0_l200;o0P03o`L00_l400;o1`02o`800_l600;o2002o`H00_l00`3oo`0900;o1002o`H00_l200;o
2@02oa000_l600;o1@02o`L00_l500?o0`02o`H00_l500;o2002oaL00_l300;o0P02o`L00_l800;o
1P02o`@00olK00_o4P04o`801?l500;o1@02o`H00_l600;o1002o`H00_l400;o0P02o`T00_l300Go
4@0001<00_l=00?o2`04o`030?oo00X00_lE00;o0P03o`800_l200;o1007o`/00ol200;o1P02o`P0
0_l600;o00<0ool02@02o`@00_l600;o0P02o`T00_l@00;o1P02o`d00ol600;o0`02o`H00_l500;o
2002oaL00_l200?o0P02o`L00_l800;o1P02o`@00_lM00Wo4`02o`040?l000Co1@02o`D00_l600;o
1P02o`@00_l600;o1002o`800_l900;o0`02o`030?oo0140000C00;o3P03o`P02Ol:00;o5@02o`80
00?o0?l00P02o`800_l400Oo1P07o`/00_l800;o2@02o`T00_l400;o2P02o`T00_lH00;o2007o`L0
0ol:00;o1@02o`P00_lG00;o0P000ol0o`0200;o1`02oa000_l400;o7@02o`D00_lC00;o00H0o`00
o`02o`D00_l500;o1P02o`D00ol400;o1P02o`@01_l900;o0P03o`030?oo0140000C00;o3`03o`L0
0_l400?o2P02oaD00_l0103oo`02o`030?oo00800_l?00Oo3@02o`P00_l900;o2@02o`@00_l:00;o
2@02oaP00_l600Oo2P03o`T02Ol800;o5`02o`040?oo00;o00<0ool01`02oa000_l400;o7P02o`<0
0_lD00;o00<0ool00_l00`3oo`0500Wo1P09o`D00_l600;o1006o`T00_l200;o0P02oa40000D00;o
3`02o`H00_l600;o2@02oaH00_l00`3oo`020004o`3oo`800_l>00?o4P02o`P00_l900;o2@02o`@0
0_l:00;o2@02oaP00_l500?o2`02o`<00_l900Wo0`02o`<00_l300;o4P02o`030?oo008000Co0?oo
1`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3oo`0500Wo1P08o`H00_l600;o1002o`80
0_l900;o00<0ool00`02oa40000D00;o4002o`D00_l600;o2@02oaH00_l00`3o00020004o`3oo`80
0_l800;o1002o`L000?o00002@02o`P00_l900;o2@02o`@00_l:00?o2002oaP00_l500;o1`000ol0
000200;o0`03o`P00_l500;o0`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02oa000_l400?o
1`02oaD00_l0103ooolC00;o0`02o`<00_l400;o1@02o`H00_l400?o1@02o`H00_l400;o0P02o`80
0_l500Go0`02oa40000D00?o3`02o`D00_l600;o2@02oaH01?l300Co0`02o`H00ol400;o1P02o`/0
0_l800;o2P02o`L00_l500;o2`02o`L00_lI00;o1@02o`H00_l400;o1003o`L00_l500;o0`02o`<0
0_l300;o4P04o`<01?l700;o4002o`D00_l700;o5@02o`030?oo01@00_l300;o0`02o`@00_l500;o
1P02o`D00_l500;o1P02o`@00_l600;o1@04o`@00_lA00005@02o`P00_l500;o1@02o`H000?o0000
1`02oaL01?l400?o0`03o`@01?l400?o1003o`/00_l800;o2P03o`D00ol500;o3002o`D00_lJ00;o
1@03o`@00ol400;o1@02o`L00_l500;o0`02o`<00_l300;o4P04o`@00ol700;o4002o`D00ol500?o
5@05oa@00_l800;o1002o`D00_l600;o1003o`D00_l600;o1002o`H00_l500Co1002oa40000F00;o
1`03o`<00ol600;o1002o`P00_lG00Co1@04o`<02_l500Wo1P0:o`802?l800Wo0`08o`T02OlE00[o
0`09o`@02_l500Co0`04o`803?lA00Co1@04o`802_l700[o0`0:oa801olD00Ko0P06o`801?l300Co
0`0:o`D01?l400Co00<0ool02_l400Co0P06oa00000G0003o`0000H01ol700Oo2@000ol0000F00Co
1@04o`D01Ol00`3oo`0700Go00<0o`001@0:o`802?l:00Go1@08o`/01OlG00[o1@05o`030?l000<0
2_l500Co0`04o`803?lA00Co1@04o`802_l700[o1@05o`030?oo01801olD00Ko0P06o`801?l300Co
0`09o`H01?l400Co00<0ool02_l400?o0`06oa00000Q00Go2P04ool0aP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(30\\) MGSJLOLR JSZHT MIJC A WHBUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko1`0=o`D01Ol500go0P05o`H00olA00Ko1`02o`030?oo00?o1P0:o`D01?l300Co1008oa<0
1Ol300Go0P0:o`H01_l:00Go4`06o`<01_lA00;o1002o`D01?l300Co0`0:o`T01?l500Oo2@06o`<0
0_lA00004`02o`T02Ol800Ko3002oa@01Ol300Go0`0:o`@02_l300Wo1P0=o`<02Ol300go0P05o`D0
1?l?00Wo1P0:o`@02_l500Co0`04o`@02?lC00Go0`05o`802_l400Wo1`09oa401_l300Ko4@02o`@0
0_l500Co0`04o`<02ol600So0`07o`T01_l200?o4@0001<00_l900;o1@02o`L00ol200?o2`02oaD0
0_l700;o0`04o`D00_l400?o1@03o`800ol400?o2002o`H00_l200?o1@03o`D00_l600;o1002o`D0
0olA00?o1003o`D00ol500?o1002o`D00_l600;o1@02o`P00_lG00;o1`02o`L00_l800?o1003o`D0
0ol500?o4P02o`L00_lB00?o1003o`D00_l500;o1P02o`D00ol500;o1002o`D00_l=00;o1004oa40
000C00;o4@02o`H00_l400;o2`02oaD00_l700;o0`02o`L00_l400;o1`02o`800_l600;o2002o`H0
0_l200;o1`02o`D00_l600;o1002o`D00_lB00;o1P02o`D00_l700;o1003o`@00_l600;o1@02o`P0
0_lG00;o1`02o`L00_l800;o1P02o`D00_l700;o4P02o`L00_lB00Co0`03o`D00_l500;o1P02o`H0
0_l400;o1P02o`@00_l=00;o1004oa40000C00;o4@02o`D00_l600;o2P02oaD00_l300;o0P02o`80
0ol700;o1002o`L00_l200;o1P02o`P00_l600;o00<0ool02@02o`@00_l600;o1002o`@00_lC00;o
1P02o`D00_l700;o1@03o`<00_l600;o1@02o`P00_lG00;o0`02o`800_l700;o2002o`H00_l400?o
6`0;oa801?l200Co1@02o`D00_l600;o1P02o`@00_l600;o1002o`800_l900;o0`05oa40000C00;o
4@02o`D00_l600;o2P02oaD00_l200?o0P02o`800_l400Oo2`03o`800_l600;o2002o`H00_l00`3o
o`0900;o1002o`H00_l400;o0`03oa<00_l600;o3@03o`H00_l300;o1P02o`D00_l800;o5`02o`80
0ol200;o1`02o`P00_l600;o1002oad02OlC00;o00@0o`001?l500;o1@02o`H00_l600;o1002o`H0
0_l400;o0P02o`T00_l300;o00<0ool04@0001<00_l@00;o1P02o`H00_l:00;o5@02o`8000?o0?l0
0P02o`800_l400Oo1P07o`/00_l800;o2@02o`T00_l400;o3007oa`00_l800Oo1`03o`X00_l500;o
2002oaL00_l20003o`3o00800_l700;o4002o`@00_lM00;o1@02oa<00_l01P3o003o00;o1@02o`D0
0_l600;o1@03o`@00_l600;o1006o`T00_l200?o00<0ool04@0001<00_l=00Co1`02o`H00_l:00;o
5@02o`040?oo00;o00<0ool00P02o`l01ol=00;o2002o`T00_l900;o1002o``02OlJ00;o1P07o`X0
0ol900Wo2002oaL00_l0103oo`02o`030?oo00L00_l@00;o1002oah00_l300;o5002o`030?oo00;o
00<0ool01@09o`H02Ol500;o1P02o`@01_l900;o0P02o`800_lA00005002o``00ol800;o1P02o`T0
0_lF00;o00<0ool00P001?l0ool200;o3P03oa800_l800;o2@02o`T00_l400;o3002o`D00olI00;o
1@03o`/00_l300;o2@09o`<00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1002oah0
0_l300;o5002o`030?oo00;o00<0ool01@09o`H02?l600;o1P02o`@00_l200;o2@02o`030?oo00<0
0_lA00005002o`h00_l700;o1P02o`T00_lF00;o00<0o`000P001?l0ool200;o2002o`@00_l70003
o`0000T00_l800;o2@02o`T00_l400;o3002o`H00_lI00;o1@02o`L000?o00000P02o`<00ol800;o
1@02o`<00_l300;o0`02oa800_l00`3o00020004o`3oo`L00_l@00;o1003o`L00_lE00;o00@0oooo
4`02o`<00_l300;o1002o`D00_l600;o1003o`D00_l600;o1002o`800_l200;o1@05o`<00_lA0000
5003o`h00_l600;o1P02o`T00_lF00Co0`04o`<00_l600?o1002o`H00_l;00;o2002o`X00_l700;o
1@02o``00_l600;o6@02o`D00_l600;o1002o`@00ol700;o1@02o`<00_l300;o0`02oa801?l300Co
1`02oa000_l500;o1`02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1@02o`H00_l500;o1@02o`H0
0_l400;o1P02o`D01?l400;o4@0001D00_l>00;o1`02o`@00_l900;o5`04o`@00ol300?o1004o`@0
0ol400?o2`02o`P00_l:00?o1@03o`D00_l<00;o1@03oaT00_l500?o1003o`@00_l500;o1`02o`D0
0_l300;o0`02o`<00_lB00Co1003o`L00_l@00;o1@03o`D00olE00Go5002o`P00_l400;o1@02o`H0
0_l400?o1@02o`H00_l400;o1P02o`D01?l400;o4@0001H00_l700;o0`03o`L00ol200?o2002oaL0
1?l500Co0`0:o`D02Ol600[o0P08o`P02Ol300So1`0;oaD02_l300Wo100:o`D01?l300Co0P0<oa40
1?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko0P04o`<01?l300[o1@04o`@01?l00`3oo`0:o`@0
1?l200Ko400001L000?o00001@07o`T01_l90003o`0001H01?l500Co1@05o`030?oo00L01Ol00`3o
000500[o0P08o`X01Ol500So1`09oaL02_l500Go00<0o`000`0:o`D01?l300Co0P0<oa401?l500Co
0P0:o`L02_l500Go00<0ool04P07oa@01_l200Ko0P04o`<01?l300Wo1P04o`@01?l00`3oo`0:o`@0
0ol300Ko400002401?l;00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(31\\) MGSJLOLR JSZIT MIJC A WHBRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2@09o`T00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko1`0=o`D01Ol500go0P05o`H00olA00Ko1`02o`030?oo00?o1P0:o`D02_l500So4`05o`<0
1Ol200[o1P06o`X01OlC00Ko0`06oa400_l400;o1@04o`<01?l300[o1005o`H02_l900Ko0`02oa40
000C00;o2@09o`L02Ol:00;o5005o`<01Ol300[o100:o`<02Ol600go0`09o`<03Ol200Go1@04o`l0
2Ol600[o100:o`D02_l500So4`05o`<01Ol200[o1009o`L02OlA00Ko0`06oa400_l400;o1@04o`<0
1?l300_o0`05o`D02ol900Ko0P03oa40000C00;o2@02o`D00_l;00;o3@02oaD00_l700;o0`04o`D0
0_l400?o1@03o`800ol400?o2002o`H00_l200?o1@03o`D00_l600;o1002o`D00olA00?o1003o`D0
0ol500?o1002o`D00_l900;o3002oaL00_l700;o1`02o`P00ol400?o1@03o`D00olB00;o1`02oa80
0ol400?o1@02o`D00_l600;o1@03o`@00_l500?o1002o`d00_l400Co4@0001<00_lA00;o2P02o`d0
0_lE00;o1`02o`<00_l700;o1002o`L00_l200;o1P02o`P00_l600;o0P02o`L00_l500;o1P02o`@0
0_l500;o4P02o`H00_l500;o1`02o`@00ol400;o2@02o``00_lG00;o1`02o`L00_l800;o1P02o`D0
0_l700;o4P02o`L00_lB00Co0`03o`D00_l500;o1P02o`H00_l400;o1@02o`D00_l=00;o1004oa40
000C00;o4@02o`X00_l=00;o5@02o`<00_l200;o0P03o`L00_l400;o1`02o`800_l600;o2002o`H0
0_l00`3oo`0900;o1002o`H00_l400;o1002oa<00_l600;o1@02o`L00_l500?o0`02o`T00_l<00;o
5`02o`<00_l200;o1`02o`P00_l600;o1003oa/02olB00Co0P04o`D00_l500;o1P02o`H00_l400;o
1002o`H00_l200;o2@02o`<01OlA00004`02oa400_l:00;o3@02oaD00_l200?o0P02o`800_l400Oo
2`03o`800_l600;o2002o`H00_l00`3oo`0900;o1002o`H00_l400;o0`03oa<00_l600;o3@03o`H0
0_l300;o2@02o``00_lG00;o0P03o`800_l700;o2002o`H00_l400;o7@09oa<00_l0103o0004o`D0
0_l500;o1P02o`H00_l400;o0`03o`H00_l200;o2@02o`<00_l00`3oo`0A00004`02oa000_l;00;o
3@02oaD00_l20003o`3o00800_l200;o1007o`H01ol;00;o2002o`T00_l900;o1002o``01olL00;o
2007o`L00ol=00;o3002oaL00_l20003o`3o00800_l700;o4002o`@00_lM00;o1@02oa<00_l01P3o
003o00;o1@02o`D00_l600;o1@03o`@01ol700Ko2@02o`800ol00`3oo`0A00004`02o`d01?l<00;o
3@02oaD00_l0103oo`02o`030?oo00800_l?00Oo3@02o`P00_l900;o2@02o`@00_l<00Wo6P02o`H0
1ol:00?o3002o``00_lG00;o00@0ool00_l00`3oo`0700;o4002o`@00_lN00;o0`02oa@00_l00`3o
o`02o`030?oo00D02Ol600Wo1@09o`D01_l900;o0P02o`800_lA00005002o``00ol=00;o3002oaH0
0_l00`3oo`020004o`3oo`800_l>00?o4P02o`P00_l900;o2@02o`@00_l<00;o1@03oaT00_l500?o
2`02o`<00_l<00;o1`02o`<00_l300;o4P02o`030?oo008000Co0?oo1`02oa000_l400;o7P02o`<0
0_lD00;o00<0ool00_l00`3oo`0500Wo1P08o`H00_l500?o1002o`800_l900;o00<0ool00`02oa40
000D00;o3P02o``00_l<00;o5P02o`030?l0008000Co0?oo0P02o`P00_l400;o1`000ol0000900;o
2002o`T00_l900;o1002o``00_l600;o6@02o`D00_l70003o`0000800_l300?o2`02o`L00_l300;o
0`02oa800_l00`3o00020004o`3oo`L00_l@00;o1003o`L00_lE00;o00@0oooo4`02o`<00_l300;o
1002o`D00_l600;o1003o`D00_l600;o1002o`800_l200;o1@05o`<00_lA00005003o`h00_l;00;o
3002oaH01?l300Co0`02o`H00ol400;o1P02o`/00_l800;o2P02o`L00_l500;o3002o`H00_lI00;o
1@02o`H00_l400;o1003o`X00_l700;o0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`L00_lE00;o
00<0ool05002o`<00_l300;o1002o`D00_l600;o1@02o`D00_l600;o1002o`H00_l500Co1002oa40
000E00;o3P02o`/00_l;00;o5`04o`@00ol300?o1004o`@00ol400?o2`02o`P00_l:00?o1@03o`D0
0_l<00;o1@03oaT00_l500?o1003o`@00_l500;o2P02o`L00_l300;o0`02oa801?l400?o1`02oa00
0_l500?o1@03oaD01OlD00;o2002o`@00_l500;o1P02o`@00ol500;o1@03o`@00_l600;o1@04o`@0
0_lA00005P02o`L00_l300?o1`03o`030?oo00X00_lG00Co1@04o`<02_l500Wo1P0:o`802?l800Wo
0`08o`L02olE00[o0`09o`@02_l500[o0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko
0P04o`<01?l300[o100;o`<03?l400Co0P06oa00000G0003o`0000D01ol800Ko2P000ol0000F00Co
1@04o`D01Ol00`3oo`0700Go00<0o`001@0:o`802?l:00Go1@08o`L02OlG00[o1@05o`030?l000<0
2_l500[o0`0<oa401?l500Co0P0:o`L02_l500Go00<0ool04P07oa@01_l200Ko0P04o`<01?l300Wo
1@09o`D03?l400?o0`06oa00000Q00Co3003ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(32\\) MGSJLOLR JSZIT MIJC A WFBRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go200:o`T00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko1`0=o`D01Ol500go0P05o`H00olA00Ko1`02o`030?oo00?o1P0:o`D02_l500So4`05o`<0
1Ol200[o1P06o`X01OlC00Ko0`06oa400_l400;o1007o`P02_l400Go1P0:o`T01_l300;o4@0001<0
0_l900Wo1P0:o`X00_lD00Go0`05o`<02_l400[o0`09o`H03Ol300Wo0`0=o`801Ol500Co3`09o`H0
2_l400[o1@0:o`D02?lC00Go0`05o`802_l400Wo1`09oa401_l300Ko4@02o`@00_l400Oo200;o`<0
1Ol500_o2@06o`800olA00004`02o`T00_l500;o1`02o`D00_l:00;o5@02o`L00_l300Co1@02o`@0
0ol500?o0P03o`@00ol800;o1P02o`800ol500?o1@02o`H00_l400;o1@03oa400ol400?o1@03o`D0
0ol400;o1@02o`T00_l<00;o5`02o`L00_l700;o2003o`@00ol500?o1@03oa800_l700;o4P03o`@0
0ol500;o3@02o`D00ol400;o1@03o`@00_l=00;o1004oa40000C00;o4@02o`L00ol?00;o5@02o`L0
0_l300;o1`02o`@00_l700;o0P02o`H00_l800;o1P02o`800_l700;o1@02o`H00_l400;o1@02oa80
0_l600;o1@02o`L00_l400?o1002o`T00_l<00;o5`02o`L00_l700;o2002o`H00_l500;o1`02oa80
0_l700;o4P04o`<00ol500;o3@02o`H00_l400;o1@02o`D00_l=00;o1004oa40000C00;o4@02o`P0
0ol>00;o5@02o`<00_l200;o0P03o`L00_l400;o1`02o`800_l600;o2002o`H00_l00`3oo`0900;o
1002o`H00_l400;o1002oa<00_l600;o1@02o`L00_l500?o0`02o`T00_l<00;o5`02o`<00_l200;o
1`02o`P00_l600;o1003oa/02olB00Co0P04o`D00_l200;o2@02o`H00_l400;o1002o`H00_l200;o
2@02o`<01OlA00004`02oa400_l900?o3@02oaD00_l200?o0P02o`800_l400Oo2`03o`800_l600;o
2002o`H00_l00`3oo`0900;o1002o`H00_l400;o0`03oa<00_l600;o3@03o`H00_l300;o2@02o``0
0_lG00;o0P03o`800_l700;o2002o`H00_l400;o7@09oa<00_l0103o0004o`D00_l200;o2@02o`H0
0_l400;o0`03o`H00_l200;o2@02o`<00_l00`3oo`0A00004`02oa000_l;00?o3002oaD00_l20003
o`3o00800_l200;o1007o`H01ol;00;o2002o`T00_l900;o1002o``01olL00;o2007o`L00ol=00;o
3002oaL00_l20003o`3o00800_l700;o4002o`@00_lM00;o1@02oa<00_l01P3o003o00;o1@06o`T0
0_l500?o1007o`L01_l900;o0P03o`030?oo0140000C00;o3@04o`d00ol;00;o5@02o`040?oo00;o
00<0ool00P02o`l01ol=00;o2002o`T00_l900;o1002o``02OlJ00;o1P07o`X00ol<00;o3002oaL0
0_l0103oo`02o`030?oo00L00_l@00;o1002oah00_l300;o5002o`030?oo00;o00<0ool01@06o`T0
2Ol500Wo1@06o`T00_l200;o0P02oa40000D00;o3003o`l00_l:00;o5P02o`030?oo008000Co0?oo
0P02o`h00olB00;o2002o`T00_l900;o1002o``00_l500?o6@02o`D00ol;00;o0`02o``00_l700;o
0`02o`<00_lB00;o00<0ool00P001?l0ool700;o4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`03
0?oo00D00_l200;o2@08o`H00_l500?o1002o`800_l900;o00<0ool00`02oa40000D00;o3P02o`l0
0_l900;o5P02o`030?l0008000Co0?oo0P02o`P00_l400;o1`000ol0000900;o2002o`T00_l900;o
1002o``00_l600;o6@02o`D00_l70003o`0000800_l300?o2`02o`L00_l300;o0`02oa800_l00`3o
00020004o`3oo`L00_l@00;o1003o`L00_lE00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1@02o`@00ol500;o1P02o`@00_l200;o0P02o`D01Ol300;o4@0001@00ol>00;o3P02o`T00_lF00Co
0`04o`<00_l600?o1002o`H00_l;00;o2002o`X00_l700;o1@02o``00_l600;o6@02o`D00_l600;o
1002o`@00ol:00;o1`02o`<00_l300;o4P04o`<01?l700;o4002o`D00_l700;o5@02o`030?oo01@0
0_l300;o0`02o`@00_l600;o1@02o`D00_l500;o1P02o`@00_l600;o1@04o`@00_lA00005@02o`h0
0_l700;o1@02o`P00_lG00Co1003o`<00ol400Co1003o`@00ol;00;o2002o`X00ol500?o1@02o``0
0_l500?o6@02o`D00ol400?o1002o`D00_l:00;o1`02o`<00_l300;o4P04o`@00ol700;o4002o`D0
0ol500?o5@05oa@00_l800;o1002o`H00_l500;o1003o`D00_l500?o1002o`H00_l500Co1002oa40
000F00;o1`02o`<00ol700?o0`03o`L00_lG00Co1@04o`<02_l500Wo1P0:o`802?l800Wo0`08o`L0
2olE00[o0`09o`@02_l500[o0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko00<0ool0
2_l300[o100;o`<03?l400Co0P06oa00000G0003o`0000D01ol900Oo20000ol0000F00Co1@04o`D0
1Ol00`3oo`0700Go00<0o`001@0:o`802?l:00Go1@08o`L02OlG00[o1@05o`030?l000<02_l500[o
0`0<oa401?l500Co0P0:o`L02_l500Go00<0ool04P07oa@01_l200Ko00<0ool02_l300Wo1@09o`D0
3?l400?o0`06oa00000Q00Co2`05ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(33\\) MGSJIOLR JUZIT MIJG A WFBRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko200:o`L01Ol500go0P05o`H00olA00Ko2`04o`H02_l500[o1@08oa<01Ol300Go0P0:o`H0
1_l:00Ko4P06o`<01_lA00;o1002o`@01ol800[o1005o`H02_l900Ko0`02oa40000C00;o2@09o`H0
2Ol;00;o5005o`<01Ol300[o100:o`<02Ol700[o1@09o`<03Ol200Go1@04o`l02Ol800So100:o`D0
2_l500So4`05o`<01Ol200[o1009o`L02_l@00Ko0`06oa400_l400;o1007o`P02ol300Go1@0;o`T0
1_l200?o4@0001<00_l900;o1@02o`H00_l500;o2`02oaD00_l700;o0`04o`D00_l400?o1@03o`80
0ol400?o2P02o`P00ol500?o1@02o`H00_l400;o1@03oa400ol400?o1`02o`@00_l500;o1@02o`T0
0_l<00;o5`02o`L00_l700;o2003o`@00ol500Co1@02oa800_l700;o4P03o`@00ol500;o3@02o`D0
0ol400;o1@03o`@00_l=00;o1004oa40000C00;o4@02o`d00_l:00;o5@02o`L00_l300;o1`02o`@0
0_l700;o0P02o`H00_l:00;o2002o`L00_l500;o1P02o`@00_l500;o4P02o`H00_l600;o1P02o`@0
0ol400;o2@02o``00_lG00;o1`02o`L00_l800;o1P02o`D00_l700;o4P02o`L00_lB00Co0`03o`D0
0_l=00;o1P02o`@00_l500;o1@02o`d00_l400Co4@0001<00_lA00;o3@02o`X00_lE00;o0`02o`80
0_l200?o1`02o`@00_l700;o0P02o`H00_l:00;o1`02o`T00_l400;o1P02o`@00_l400;o4`02o`H0
0_l600;o1P02o`D00ol300;o2@02o``00_lG00;o0`02o`800_l700;o2002o`H00_l400?o1`02oa80
2olB00Co0P04o`D00_l200;o2@02o`H00_l400;o1002o`H00_l200;o2@02o`<01OlA00004`02oa40
0_l=00;o2P02oaD00_l200?o0P02o`800_l400Oo2`03o`800_l600;o2P02o`L00_l900;o1002o`H0
0_l400;o0`03oa<00_l600;o1P02o`H00_l600;o0`02o`T00_l<00;o5`02o`800ol200;o1`02o`P0
0_l600;o1002o`@01olB00Wo4`02o`040?l000Co1@02o`800_l900;o1P02o`@00_l300?o1P02o`80
0_l900;o0`02o`030?oo0140000C00;o4002o`d00_l;00;o5@02o`8000?o0?l00P02o`800_l400Oo
1P07o`/00_l:00;o1`02o`T00_l400;o3007oa`00_l600;o1P02o`H00ol=00;o3002oaL00_l20003
o`3o00800_l700;o4002o`@00_l400Oo4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@03o`@0
1ol700Ko2@02o`800ol00`3oo`0A00004`02o`d01?l;00Co3002oaD00_l0103oo`02o`030?oo0080
0_l?00Oo3@02o`X00_l700;o2@02o`@00_l<00Wo6P02o`H00_l600;o1`03o``00_l<00;o5`02o`04
0?oo00;o00<0ool01`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2@09o`D0
2Ol500Ko2@02o`800_l200;o4@0001@00_l<00?o3003o``00_lF00;o00<0ool00P001?l0ool200;o
3P03oa800_l:00;o1`02o`T00_l400;o3002o`D00olI00;o1P02o`H00_l300;o0`02o``00_l700;o
0`02o`<00_lB00;o00<0ool00P001?l0ool700;o4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`03
0?oo00D00_l200;o2@08o`H00_l500?o1002o`800_l900;o00<0ool00`02oa40000D00;o3P02o`d0
0_l;00;o5P02o`030?l0008000Co0?oo0P02o`P00_l400;o1`000ol0000900;o2P02o`L00_l900;o
1002o``00_l600;o6@02o`H00_l600;o0`02o`<00ol;00;o1`02o`<00_l300;o4P02o`030?l00080
00Co0?oo1`02oa000_l400;o2002oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o
1003o`D00_l600;o1002o`800_l200;o1@05o`<00_lA00005003o`h00_l=00;o2P02oaH01?l300Co
0`02o`H00ol400;o1P02o`/00_l:00;o2002o`L00_l500;o3002o`H00_lI00;o1P02o`H00_l300;o
1003o`X00_l700;o0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`H00olE00;o00<0ool05002o`<0
0_l300;o1002o`H00_l500;o1@02o`D00_l600;o1002o`H00_l500Co1002oa40000E00;o3P02o`d0
0_l900;o5`04o`@00ol300?o1004o`@00ol400?o2`02o`X00_l800?o1@03o`D00_l<00;o1@03oaT0
0_l600;o1P02o`<00_l500;o2P02o`L00_l300;o0`02oa801?l400?o1`02oa000_l500?o1004oaD0
1OlD00;o2002o`@00_l600;o1@02o`@00ol500;o1@03o`@00_l600;o1@04o`@00_lA00005P02o`L0
0_l300?o1`02o`<00ol800;o5`04o`D01?l300[o1@09o`H02_l300[o1@09o`<02?l700_o5@0:o`80
1?l400Co0P0:o`D02_l300co4@04o`D01?l200[o1`0:o`<02_lB00Oo5006o`801_l00`3oo`0:o`<0
2_l400_o0`0<o`@01?l200Ko400001L000?o00001@07o`P01ol90003o`0001H01?l500Co1@05o`03
0?oo00L01Ol00`3o000500[o0`0:o`L01Ol500So1`09oaL02_l200Co1004o`802_l500[o0`0<oa40
1?l500Co0P0:o`L02_l500Go00<0ool04P07oa@01_l200Ko00<0ool02_l300Wo1@09o`D03?l400?o
0`06oa00000Q00Co2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(34\\) MGSJIOLR JUZIT MIJG A WFBRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go3006o`T00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko200:o`L01Ol500go0P05o`H00olA00Ko2`04o`H02_l500[o1@08oa<01Ol300Go0P0:o`H0
1_l:00Ko4P06o`<01_lA00;o1002o`@01ol800[o1005o`H02_l900Ko0`02oa40000C00;o2@09o`X0
1_l:00;o5005o`<01Ol300[o100:o`<02Ol700[o1@09o`<03Ol200Go1@04o`l02Ol800So100:o`D0
2_l500So4`05o`<01Ol200[o1009o`L02_l@00Ko0`06oa400_l400;o1007o`P02ol300Go1@0;o`T0
1_l200?o4@0001<00_l900;o1@02o``00_l<00;o5@02o`L00_l300Co1@02o`@00ol500?o0P03o`@0
0ol:00;o2003o`D00ol500;o1P02o`@00_l500?o4@03o`@00ol700;o1002o`D00_l500;o2@02o``0
0_lG00;o1`02o`L00_l800?o1003o`D01?l500;o4P02o`L00_lB00?o1003o`D00_l=00;o1@03o`@0
0_l500?o1002o`d00_l400Co4@0001<00_lA00;o2`02o``00_lE00;o1`02o`<00_l700;o1002o`L0
0_l200;o1P02o`X00_l800;o1`02o`D00_l600;o1002o`D00_lB00;o1P02o`H00_l600;o1003o`@0
0_l900;o3002oaL00_l700;o1`02o`P00_l600;o1@02o`L00_lB00;o1`02oa801?l300?o1@02o`d0
0_l600;o1002o`D00_l500;o3@02o`@01?lA00004`02oa400_l500[o2P02oaD00_l300;o0P02o`80
0ol700;o1002o`L00_l200;o1P02o`X00_l700;o2@02o`@00_l600;o1002o`@00_lC00;o1P02o`H0
0_l600;o1@03o`<00_l900;o3002oaL00_l300;o0P02o`L00_l800;o1P02o`@00ol700;o4P0;oa80
1?l200Co1@02o`800_l900;o1P02o`@00_l400;o1P02o`800_l900;o0`05oa40000C00;o4@02o`D0
2_l:00;o5@02o`800ol200;o0P02o`@01ol;00?o0P02o`H00_l:00;o1`02o`T00_l400;o1P02o`@0
0_l300?o4`02o`H00_l600;o1P02o`H00_l300;o2@02o``00_lG00;o0P03o`800_l700;o2002o`H0
0_l400;o1007oa802OlC00;o00@0o`001?l500;o0P02o`T00_l600;o1002o`<00ol600;o0P02o`T0
0_l300;o00<0ool04@0001<00_l@00;o1P02o`@00_l<00;o5@02o`8000?o0?l00P02o`800_l400Oo
1P07o`/00_l:00;o1`02o`T00_l400;o3007oa`00_l600;o1P02o`H00ol=00;o3002oaL00_l20003
o`3o00800_l700;o4002o`@00_l400Oo4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@03o`@0
1ol700Ko2@02o`800ol00`3oo`0A00004`02o`d01?l800;o0`02o``00_lE00;o00@0ool00_l00`3o
o`0200;o3`07o`d00_l:00;o1`02o`T00_l400;o3009oaX00_l600;o1P02o`L00ol<00;o3002oaL0
0_l0103oo`02o`030?oo00L00_l@00;o1002oah00_l300;o5002o`030?oo00;o00<0ool01@06o`T0
2Ol500Wo1@06o`T00_l200;o0P02oa40000D00;o3003o`X000Co00000_l;00;o5P02o`030?oo0080
00Co0?oo0P02o`h00olB00;o2P02o`L00_l900;o1002o``00_l500?o6@02o`H00_l600;o0`02o`<0
0_l<00;o1`02o`<00_l300;o4P02o`030?oo008000Co0?oo1`02oa000_l400;o7P02o`<00_lD00;o
00<0ool00_l00`3oo`0500;o0P02o`T02?l600;o1@03o`@00_l200;o2@02o`030?oo00<00_lA0000
5002o`h00_l900;o0P02o`/00_lF00;o00<0o`000P001?l0ool200;o2002o`@00_l70003o`0000T0
0_l:00;o1`02o`T00_l400;o3002o`H00_lI00;o1P02o`H00_l300;o0`03o`/00_l700;o0`02o`<0
0_lB00;o00<0o`000P001?l0ool700;o4002o`@00_l800;o5@02o`040?oooa<00_l300;o0`02o`@0
0_l200;o0P02o`D00_l400?o1@02o`H00_l400;o0P02o`800_l500Go0`02oa40000D00?o3P02o`T0
00?o00000_l;00;o5P04o`<01?l300;o1P03o`@00_l600;o2`02o`X00_l800;o1`02o`D00_l<00;o
1P02oaT00_l600;o1P02o`<00_l400?o2P02o`L00_l300;o0`02oa801?l300Co1`02oa000_l500;o
1P03oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`D00_l500;o1@02o`H00_l400;o1P02o`D0
1?l400;o4@0001D00_l>00;o2P001?l0ool:00;o5`04o`@00ol300?o1004o`@00ol400?o2`02o`X0
0_l800?o1@03o`D00_l<00;o1@03oaT00_l600;o1P02o`<00_l500;o2P02o`L00_l300;o0`02oa80
1?l400?o1`02oa000_l500?o1004oaD01OlD00;o2002o`@00_l600;o1@02o`@00ol500;o1@03o`@0
0_l600;o1@04o`@00_lA00005P02o`L00_l300?o2P04o`T00_lG00Co1@04o`<02_l500Wo1P0:o`<0
2_l500Wo0`08o`L02olE00[o0P04o`@01?l200[o1@0:o`<03?lA00Co1@04o`802_l700[o0`0:oa80
1olD00Ko0P06o`030?oo00[o0`0:o`@02ol300co1004o`801_l@00005`000ol0000500Oo3003o`T0
00?o00005P04o`D01?l500Go00<0ool01`05o`030?l000D02_l300[o1`05o`D02?l700Wo5`0:o`80
1?l400Co0P0:o`D02_l300co4@04o`D01?l200[o1`0:o`D01Ol00`3oo`0B00Oo5006o`801_l00`3o
o`0:o`<02Ol500Wo1@0<o`@00ol300Ko400002401?l=00?oo`350000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(35\\) MGSJIOLR JU IT MIJG A WFBRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko200:o`L01Ol500go0P05o`H00olA00Ko2`04oaD02_l500So4`05o`<01Ol200[o1P06o`X0
1_lB00Ko0`06oa400_l400;o1007o`P02_l400Go1P0:o`T01_l300;o4@0001<00_l900Wo1P09o`/0
0_lD00Go0`05o`<02_l400[o0`09o`L02_l500Wo0`0=o`801Ol500Co3`09o`P02?lC00[o1@08oa<0
1Ol300Go0P0:o`@02Ol700[o4006o`<01_lA00;o1002o`@01ol800_o0`05o`D02ol900Ko0P03oa40
000C00;o2@02o`D00_l600;o1@02o`/00_lE00;o1`02o`<01?l500;o1003o`D00ol200?o1003o`X0
0_l800?o1@03o`D00_l600;o1002o`D00olA00?o1003o`L00_l400;o5`02o``00_lG00;o1`02o`L0
0_l800?o1003o`D01?l500;o4P02o`L00_lB00?o1003o`D00_l=00;o1@03o`@00_l500?o1002o`d0
0_l400Co4@0001<00_lA00;o3@02o`X00_lE00;o1`02o`<00_l700;o1002o`L00_l200;o1P02o`X0
0_l800;o1`02o`D00_l600;o1002o`D00_lB00;o1P02o`H00_l600;o5P02o``00_lG00;o1`02o`L0
0_l800;o1P02o`D00_l700;o4P02o`L00_lB00Co0`03o`D00_l=00;o1P02o`@00_l500;o1@02o`d0
0_l400Co4@0001<00_lA00;o3@02o`X00_lE00;o0`02o`800_l200?o1`02o`@00_l700;o0P02o`H0
0_l:00;o1`02o`T00_l400;o1P02o`@00_l400;o4`02o`H00_l600;o1P02oaH00_l<00;o5`02o`<0
0_l200;o1`02o`P00_l600;o1003o`L00_lB00_o4P04o`801?l500;o0P02o`T00_l600;o1002o`@0
0_l600;o0P02o`T00_l300Go4@0001<00_lA00;o3@02o`X00_lE00;o0P03o`800_l200;o1007o`/0
0ol200;o1P02o`X00_l700;o2@02o`@00_l600;o1002o`<00olC00;o1P02o`H00_l600;o5P02o``0
0_lG00;o0P03o`800_l700;o2002o`H00_l400;o1007oa802OlC00;o00@0o`001?l500;o0P02o`T0
0_l600;o1002o`<00ol600;o0P02o`T00_l300;o00<0ool04@0001<00_l@00;o3P02o`X00_lE00;o
0P000ol0o`0200;o0P02o`@01ol600Oo2`02o`X00_l700;o2@02o`@00_l<00Oo7002o`H00_l600;o
5P02o``00_lG00;o0P000ol0o`0200;o1`02oa000_l400;o1007oa800_l500;o4`02o`060?l00?l0
0_l500Ko2@02o`D00ol400Oo1`06o`T00_l200?o00<0ool04@0001<00_l=00Co2002o`@00_l;00;o
5@02o`040?oo00;o00<0ool00P02o`l01ol=00;o2P02o`L00_l900;o1002o``02OlJ00;o1P02o`H0
0_lF00;o3002oaL00_l0103oo`02o`030?oo00L00_l@00;o1002oah00_l300;o5002o`030?oo00;o
00<0ool01@06o`T02Ol500Wo1@06o`T00_l200;o0P02oa40000D00;o3003o`T02?l:00;o5P02o`03
0?oo008000Co0?oo0P02o`h00olB00;o2P02o`L00_l900;o1002o``00_l500?o6@02o`H00_l600;o
5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1002oah00_l300;o5002o`03
0?oo00;o00<0ool01@02o`800_l900So1P02o`D00ol400;o0P02o`T00_l00`3oo`0300;o4@0001@0
0_l>00;o2007o`/00_lF00;o00<0o`000P001?l0ool200;o2002o`@00_l70003o`0000T00_l:00;o
1`02o`T00_l400;o3002o`H00_lI00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P02o`030?l00080
00Co0?oo1`02oa000_l400;o2002oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o
1003o`D00_l600;o1002o`800_l200;o1@05o`<00_lA00005003o`h00_l700;o4002oaH01?l300Co
0`02o`H00ol400;o1P02o`/00_l:00;o2002o`L00_l500;o3002o`H00_lI00;o1P02o`H00_lF00;o
1`02o`<00_l300;o4P04o`<01?l700;o4002o`D00_l600?o5@02o`030?oo01@00_l300;o0`02o`@0
0_l600;o1@02o`D00_l500;o1P02o`@00_l600;o1@04o`@00_lA00005@02o`h00_l700;o3`02oaL0
1?l400?o0`03o`@01?l400?o1003o`/00_l:00;o2003o`D00ol500;o3002o`D00olI00;o1P02o`H0
0_lF00;o1`02o`<00_l300;o4P04o`@00ol700;o4002o`D00ol400Co5@05oa@00_l800;o1002o`H0
0_l500;o1003o`D00_l500?o1002o`H00_l500Co1002oa40000F00;o1`02o`<00ol700;o3P02oaL0
1?l500Co0`0:o`D02Ol600[o0`0:o`D02Ol300So1`0;oaD02_l200Co1004oa402_l300co4@04o`D0
1?l200[o1`0:o`<02_lB00Oo5006o`801_l00`3oo`0:o`<02_l400_o0`0<o`@01?l200Ko400001L0
00?o00001@07o`P02?l80003o`0001H01?l500Co1@05o`030?oo00L01Ol00`3o000500[o0`0:o`L0
1Ol500So1`09oaL02_l200Co1004oa402_l300co4@04o`D01?l200[o1`0:o`D01Ol00`3oo`0B00Oo
5006o`801_l00`3oo`0:o`<02Ol500Wo1@0<o`@00ol300Ko400002401?l900Soo`340000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(36\\) MGSJIOLR JU IT MIJG A WFARFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`D01_l600;o00<0ool0
0ol700Ko200:o`L01Ol500go0P05o`H00olA00Ko2`04oaD02_l500So4`05o`<01Ol200[o1P06o`X0
1_lB00Ko0`06oa400_l400;o1007o`L01_l300_o1P0:o`T01_l300;o4@0001<00_l900Wo2007o`/0
0_lD00Go0`05o`<02_l400[o0`09o`L02_l500Wo0`0=o`801Ol500Co3`09o`P02?lC00[o1@08oa<0
1Ol300Go0P0:o`@02Ol700[o4006o`<01_lA00;o1002o`@01ol700Ko0`0;o`D02ol900Ko0P03oa40
000C00;o2@02o`D00_l700;o1002o`/00_lE00;o1`02o`<01?l500;o1003o`D00ol200?o1003o`X0
0_l800?o1@03o`D00_l600;o1002o`D00olA00?o1003o`L00_l400;o5`02o``00_lG00;o1`02o`L0
0_l800?o1003o`D01?l500;o4P02o`L00_lB00?o1003o`D00_l<00;o1`02o`@00_l500?o1002o`d0
0_l400Co4@0001<00_lA00;o1@02o`H00_l:00;o5@02o`L00_l300;o1`02o`@00_l700;o0P02o`H0
0_l:00;o2002o`L00_l500;o1P02o`@00_l500;o4P02o`H00_l600;o1P02oaH00_l<00;o5`02o`L0
0_l700;o2002o`H00_l500;o1`02oa800_l700;o4P04o`<00ol500;o3002o`L00_l400;o1@02o`D0
0_l=00;o1004oa40000C00;o4@02o`D00_l600;o2P02oaD00_l300;o0P02o`800ol700;o1002o`L0
0_l200;o1P02o`X00_l700;o2@02o`@00_l600;o1002o`@00_lC00;o1P02o`H00_l600;o5P02o``0
0_lG00;o0`02o`800_l700;o2002o`H00_l400?o1`02oa802olB00Co0P04o`D00_l200;o200;o`@0
0_l400;o1P02o`800_l900;o0`05oa40000C00;o4@02o`D00_l600;o2P02oaD00_l200?o0P02o`80
0_l400Oo2`03o`800_l600;o2P02o`L00_l900;o1002o`H00_l400;o0`03oa<00_l600;o1P02o`H0
0_lF00;o3002oaL00_l200?o0P02o`L00_l800;o1P02o`@00_l400Oo4P09oa<00_l0103o0004o`D0
0_l200;o2@09o`D00_l300?o1P02o`800_l900;o0`02o`030?oo0140000C00;o4002o`H00_l600;o
2P02oaD00_l20003o`3o00800_l200;o1007o`H01ol;00;o2P02o`L00_l900;o1002o``01olL00;o
1P02o`H00_lF00;o3002oaL00_l20003o`3o00800_l700;o4002o`@00_l400Oo4P02o`D00_lC00;o
00H0o`00o`02o`D01_l900;o1@02o`D01ol700Ko2@02o`800ol00`3oo`0A00004`02o`d01?l700?o
1002o`/00_lE00;o00@0ool00_l00`3oo`0200;o3`07o`d00_l:00;o1`02o`T00_l400;o3009oaX0
0_l600;o1P02oaH00_l<00;o5`02o`040?oo00;o00<0ool01`02oa000_l400;o7P02o`<00_lD00;o
00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Wo1@06o`T00_l200;o0P02oa40000D00;o3003o`P0
2Ol:00;o5P02o`030?oo008000Co0?oo0P02o`h00olB00;o2P02o`L00_l900;o1002o``00_l500?o
6@02o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1002oah0
0_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`H00_l500?o1002o`800_l900;o
00<0ool00`02oa40000D00;o3P02o`L00_l00`3oo`02o``00_lF00;o00<0o`000P001?l0ool200;o
2002o`@00_l70003o`0000T00_l:00;o1`02o`T00_l400;o3002o`H00_lI00;o1P02o`H00_lF00;o
1`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02oa000_l400;o2002oaD00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1P02o`H00_l400;o0P02o`800_l500Go0`02oa40
000D00?o3P02o`L00_l@00;o5P04o`<01?l300;o1P03o`@00_l600;o2`02o`X00_l800;o1`02o`D0
0_l<00;o1P02oaT00_l600;o1P02oaH00_l700;o0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`H0
0olE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01`02o`H00_l400;o1P02o`D0
1?l400;o4@0001D00_l>00;o1`03o`h00_lG00Co1003o`<00ol400Co1003o`@00ol;00;o2P02o`P0
0ol500?o1@02o``00_l500?o6@02o`H00_l600;o5P02o`L00_l300;o0`02oa801?l400?o1`02oa00
0_l500?o1004oaD01OlD00;o2002o`@00_l600;o1`05o`L00_l500?o1002o`H00_l500Co1002oa40
000F00;o1`02o`<00ol800?o3002oaL01?l500Co0`0:o`D02Ol600[o0`0:o`D02Ol300So1`0;oaD0
2_l200Co1004oa402_l300co4@04o`D01?l200[o1`0:o`<02_lB00Oo5006o`801_l00`3oo`0:o`@0
1ol600_o0`0<o`@01?l200Ko400001L000?o00001@07o`X01ol70003o`0001H01?l500Co1@05o`03
0?oo00L01Ol00`3o000500[o0`0:o`L01Ol500So1`09oaL02_l200Co1004oa402_l300co4@04o`D0
1?l200[o1`0:o`D01Ol00`3oo`0B00Oo5006o`801_l00`3oo`0:o`@01ol600Wo1@0<o`@00ol300Ko
400002401?l=00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(37\\) MESJIOLR JU IT MIJG A WFARFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`02o`h00_lE00Go0`05o`030?oo00[o1002o`03
0?oo00?o1`06o`P02_l700Go1@0=o`801Ol600?o4@06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`H0
1_l:00Ko4P06o`<01_lA00;o1002o`@01ol700Ko0`0;o`H02_l900Ko0`02oa40000C00;o2@09o`T0
0_l?00;o5005o`<01Ol00`3oo`0:o`@02_l300Wo1`0:o`D02Ol300go0P05o`D01?l?00Wo2008oa<0
2_l500So4`05o`<01Ol200[o1009o`L02_l@00Ko0`06oa400_l400;o1007o`L01_l300_o1@0;o`T0
1_l200?o4@0001<00_l900;o1@02o`X00_l>00;o5@02o`L00_l400;o1P02o`@00ol500?o0P03o`@0
0ol:00;o2003o`D00ol500;o1P02o`@00_l500?o4@03o`@00ol700;o1002oaL00_l<00;o5`02o`L0
0_l700;o2003o`@00ol500Co1@02oa800_l700;o4P03o`@00ol500;o3002o`L00_l400;o1@03o`@0
0_l=00;o1004oa40000C00;o4@02o`T00_l>00;o5@02o`L00_l400;o1P02o`@00_l700;o0P02o`H0
0_l:00;o2002o`L00_l500;o1P02o`@00_l500;o4P02o`H00_l600;o1P02oaH00_l<00;o5`02o`L0
0_l700;o2002o`H00_l500;o1`02oa800_l700;o4P04o`<00ol500;o3002o`L00_l400;o1@02o`D0
0_l=00;o1004oa40000C00;o4@02o`T00_l>00;o5@02o`<00_l200;o1002o`800_l200;o1002o`L0
0_l200;o1P02o`X00_l700;o2@02o`@00_l600;o1002o`@00_lC00;o1P02o`H00_l600;o5P02o``0
0_lG00;o0`02o`800_l700;o2002o`H00_l400?o1`02oa802olB00Co0P04o`D00_l200;o200;o`@0
0_l400;o1P02o`800_l900;o0`05oa40000C00;o4@02o`X000?o00003002oaD00_l200?o0P02o`@0
0_l200;o4003o`800_l600;o2P02o`L00_l900;o1002o`H00_l400;o0`03oa<00_l600;o1P02o`H0
0_lF00;o3002oaL00_l200?o0P02o`L00_l800;o1P02o`@00_l400Oo4P09oa<00_l0103o0004o`D0
0_l200;o2@09o`D00_l300?o1P02o`800_l900;o0`02o`030?oo0140000C00;o4002o`/00_l=00;o
5@02o`8000?o0?l00P02o`@01_l;00Oo2`02o`X00_l700;o2@02o`@00_l<00Oo7002o`H00_l600;o
5P02o``00_lG00;o0P000ol0o`0200;o1`02oa000_l400;o1007oa800_l500;o4`02o`060?l00?l0
0_l500Ko2@02o`D00_l500Oo1`06o`T00_l200?o00<0ool04@0001<00_l=00Co3002o`d00_lE00;o
00@0ool00_l00`3oo`0400Ko2@07o`d00_l:00;o1`02o`T00_l400;o3009oaX00_l600;o1P02oaH0
0_l<00;o5`02o`040?oo00;o00<0ool01`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3o
o`0500Ko2P02o`<00_l600Wo1@06o`T00_l200;o0P02oa40000D00;o3003o`h000?o00002P02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o2003oa800_l:00;o1`02o`T00_l400;o3002o`D00olI00;o
1P02o`H00_lF00;o1`02o`<00_l300;o4P02o`030?oo008000Co0?oo1`02oa000_l400;o7P02o`<0
0_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1P02o`D00ol400;o0P02o`T00_l00`3o
o`0300;o4@0001@00_l>00;o3@02o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l400;o
1`000ol0000900;o2P02o`L00_l900;o1002o``00_l600;o6@02o`H00_l600;o5P02o`L00_l300;o
0`02oa800_l00`3o00020004o`3oo`L00_l@00;o1002o`P00_lE00;o00@0oooo4`02o`<00_l300;o
1002o`800_l200;o1`02o`040?ooo`H00_l600;o1002o`800_l200;o1@05o`<00_lA00005003o`h0
0_l<00;o2`02oaH01?l300Co1002o`H00_l400;o1P02o`/00_l:00;o2002o`L00_l500;o3002o`H0
0_lI00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`<01?l700;o4002o`D00_l600?o5@02o`03
0?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00L00_l600;o1002o`H00_l500Co1002oa40
000E00;o3P02o`d000?o00002002oaL01?l400?o1002o`H00_l400?o1003o`/00_l:00;o2003o`D0
0ol500;o3002o`D00olI00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`@00ol700;o4002o`D0
0ol400Co5@05oa@00_l800;o1002o`H00_l700Go1`02o`D00ol400;o1P02o`D01?l400;o4@0001H0
0_l700;o0`03o`H00_l500;o2002oaL01?l500Co00<0ool02_l500Wo1P0:o`<02_l500Wo0`08o`L0
2olE00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko00<0ool0
2_l400Oo1P0;o`<03?l400Co0P06oa00000G0003o`0000D01ol700Wo20000ol0000F00Co1@04o`03
0?oo00[o1`05o`030?l000D02_l300[o1`05o`D02?l700Wo5`0:o`801?l400Co4@0:o`<03?lA00Co
1@04o`802_l700[o1@05o`030?oo01801olD00Ko0P06o`030?oo00[o1007o`H02Ol500co1003o`<0
1_l@00008@04o`P02Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(38\\) METJIOLS JU IT MIJG A WFARFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00[o1@08o`H0
1_l800[o1`05o`D03Ol300;o00<0ool00olF00Ko2`04oaD02_l500So4`05o`<01Ol200[o1P06o`X0
1_lB00Ko0`06oa400_l400;o1007o`L01_l300_o1P0:o`T01_l300;o4@0001<00_l900Wo1`08o`/0
0_lD00Go0`05o`030?oo00[o1@08o`@02Ol700[o1@09o`<03Ol300[o4P09o`P02?lC00[o1@08oa<0
1Ol300Go0P0:o`@02Ol700[o4006o`<01_lA00;o1002o`@01ol700Ko0`0;o`D02ol900Ko0P03oa40
000C00;o2@02o`D00_l600?o1003o`X00_lE00;o1`02o`@00_l600;o2002o`L00ol400?o2P02o`P0
0ol500?o1@02o`H00_l300?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaL00_l700;o1`02o`P0
0ol400?o1@04o`D00_lB00;o1`02oa800ol400?o1@02o``00_l700;o1002o`D00ol400;o3@02o`@0
1?lA00004`02oa400_l500;o1P02o`X00_lE00;o1`02o`@00_l600;o2002o`L00_l600;o2P02o`P0
0_l700;o1@02o`H00_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l700;o1`02o`P0
0_l600;o1@02o`L00_lB00;o1`02oa801?l300?o1@02o``00_l700;o1002o`D00_l500;o3@02o`@0
1?lA00004`02oa400_l500;o1P02o`X00_lE00;o0`02o`800_l400;o0P02o`800_l800;o1`02o`H0
0_l:00;o1`02o`T00_l400;o1P02o`<00_l700;o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`<0
0_l200;o1`02o`P00_l600;o1003o`L00_lB00_o4P04o`801?l500;o0P02o`P02ol400;o1002o`H0
0_l200;o2@02o`<01OlA00004`02oa400_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l700;o1P02o`X00_l700;o2@02o`@00_l600;o2`03oa400_l600;o1P02o`H00_lF00;o3002oaL0
0_l200?o0P02o`L00_l800;o1P02o`@00_l400Oo4P09oa<00_l0103o0004o`D00_l200;o2@09o`D0
0_l300?o1P02o`800_l900;o0`02o`030?oo0140000C00;o4002o`L00_l400;o2`02oaD00_l20003
o`3o00800_l400Ko3002o`l00_l:00;o1`02o`T00_l400;o3P07oaX00_l600;o1P02oaH00_l<00;o
5`02o`8000?o0?l00P02o`L00_l@00;o1002o`@01olB00;o1@02oa<00_l01P3o003o00;o1@06o`T0
0_l500;o1@07o`L01_l900;o0P03o`030?oo0140000C00;o3@04o`T01ol;00;o5@02o`040?oo00;o
00<0ool01006o``00_l?00;o2P02o`L00_l900;o1002o``01olL00;o1P02o`H00_lF00;o3002oaL0
0_l0103oo`02o`030?oo00L00_l@00;o1002oah00_l300;o5002o`030?oo00;o00<0ool01@06o`X0
0_l300;o1P09o`D01_l900;o0P02o`800_lA00005002o``00ol:00Ko2`02oaH00_l00`3oo`020004
o`3oo`@00_l200;o1`02o`<00_l300;o2P02o`X00_l700;o2@02o`@00_l;00?o8@02o`H00_l600;o
5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l@00;o1002oah00_l300;o5002o`03
0?oo00;o00<0ool01@02o`800_l:00;o0`02o`H00_l500?o1002o`800_l900;o00<0ool00`02oa40
000D00;o3P02o`P00_l400;o2P02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`X00_l:00;o1`02o`T00_l400;o2`02o`L000?o00006002o`H00_l600;o5P02o`L00_l300;o
0`02oa800_l00`3o00020004o`3oo`L00_l@00;o1002o`P00_lE00;o00@0oooo4`02o`<00_l300;o
1002o`800_l200;o1`02o`040?ooo`H00_l600;o1002o`800_l200;o1@05o`<00_lA00005003o`h0
0_l600;o1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o2P02o`X00_l800;o1`02o`D0
0_l;00;o1P02oaX00_l600;o1P02oaH00_l700;o0`02o`<00_lB00Co0`04o`L00_l@00;o1@02o`H0
0olE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01`02o`H00_l400;o1P02o`D0
1?l400;o4@0001D00_l>00;o1P02o`H00_l800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`X0
0_l:00;o2003o`D00ol500;o2`03o`@00olJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`@0
0ol700;o4002o`D00ol400Co5@05oa@00_l800;o1002o`H00_l700Go1`02o`D00ol400;o1P02o`D0
1?l400;o4@0001H00_l700;o0`03o`H00ol400?o1`02oaL01?l500Co00<0ool02_l300co1@0:o`<0
2_l500Wo0`08o`T02OlE00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@0
1_l200Ko00<0ool02_l400Oo1P0;o`<03?l400Co0P06oa00000G0003o`0000D01ol800So20000ol0
000F00Co1@04o`030?oo00[o0`0<o`D02_l300[o1`05o`D02?l;00Go00<0o`00500:o`801?l400Co
4@0:o`<03?lA00Co1@04o`802_l700[o1@05o`030?oo01801olD00Ko0P06o`030?oo00[o1007o`H0
2Ol500co1003o`<01_l@00008@04o`X01_oo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(39\\) METIIOLS JU IT MIJG A WFASFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2005o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D03Ol300;o00<0ool00olF00Ko2`04oaD02_l500So4`05o`<01Ol200[o1P06o`X0
1_lB00Ko0`06oa400_l400;o1007o`L01_l300Ko00@0ool01Ol500Oo2@06o`<00_lA00004`02o`T0
2Ol600Oo3@02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l500Wo0`0=o`<02_lB00Wo2008oa<0
2_l500So4`05o`<01Ol200[o1009o`L02_l@00Ko0`06oa400_l400;o1007o`L01_l300Ko00<0ool0
2?l300Oo2@06o`800olA00004`02o`T00_l500;o2`03o``00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2003o`D00ol500;o1P02o`<00ol500?o4@03o`@00ol700;o1002oaL00_l<00;o5`02o`L0
0_l700;o2003o`@00ol500Co1@02oa800_l700;o4P03o`@00ol500;o3002o`L00_l300?o1@03o`@0
0_l=00;o1004oa40000C00;o4@02o`/00ol;00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P0
0_l700;o1@02o`H00_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l700;o1`02o`P0
0_l600;o1@02o`L00_lB00;o1`02oa801?l300?o1@02o``00_l700;o0`02o`L00_l400;o3@02o`@0
1?lA00004`02oa400_l<00;o2`02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`L0
0_l900;o1002o`H00_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l300;o0P02o`L0
0_l800;o1P02o`@00ol700;o4P0;oa801?l200Co1@02o`800_l800_o0`02o`L00_l400;o0P02o`T0
0_l300Go4@0001<00_lA00;o2004o`030?oo00X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o
3@02o`L00_l900;o1002o`H00_l;00?o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`800ol200;o
1`02o`P00_l600;o1002o`@01olB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o
2@02o`<00_l00`3oo`0A00004`02oa000_l700Wo2P02oaD00_l20003o`3o00800_l400Ko3002o``0
0_l=00;o1`02o`T00_l400;o3P07oaX00_l600;o1P02oaH00_l<00;o5`02o`8000?o0?l00P02o`L0
0_l@00;o1002o`@01olB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l900;o
0P03o`030?oo0140000C00;o3@04o`P00_l400?o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o
3002o`d00_l700;o2@02o`@00_l<00Oo7002o`H00_l600;o5P02o``00_lG00;o00@0ool00_l00`3o
o`0700;o4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko
2@02o`800_l200;o4@0001@00_l<00?o2002o`H00_l900;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l700;o3@02o`L00_l900;o1002o`/00olQ00;o1P02o`H00_lF00;o1`02o`<0
0_l300;o4P02o`030?oo008000Co0?oo1`02oa000_l400;o7P02o`<00_lD00;o00<0ool00_l00`3o
o`0500;o0P02o`X00_l300;o1@03o``00_l200;o2@02o`030?oo00<00_lA00005002o`h00_l700;o
1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`L0
0_l900;o1002o`/00_l70003o`0001P00_l600;o1P02oaH00_l700;o0`02o`<00_lB00;o00<0o`00
0P001?l0ool700;o4002o`@00_l800;o5@02o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L0
0_l0103oool500;o1`000ol0000300;o0P02o`800_l500Go0`02oa40000D00?o3P02o`H00_l600;o
2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o3@02o`P00_l700;o1@02o`/00_l600;o
6P02o`H00_l600;o5P02o`L00_l300;o0`02oa801?l300Co1`02oa000_l500;o1P03oaD00_l00`3o
o`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1@04o`@00_lA0000
5@02o`h00_l600;o1P000ol0000700;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l=00;o
2003o`D00ol500;o2`03o`@00olJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`@00ol700;o
4002o`D00ol400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`D01?l400;o
4@0001H00_l700;o0`03o`L00_l400;o2002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l500Wo
0`08o`T02OlE00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko
00<0ool02_l400Oo2009o`<03?l400Co0P06oa00000G0003o`0000D01ol800Oo2@000ol0000F00Co
1@04o`030?oo00[o0`0<o`<02_l500[o1`05o`D02?l;00Go00<0o`00500:o`801?l400Co4@0:o`<0
3?lA00Co1@04o`802_l700[o1@05o`030?oo01801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o
000200co1003o`<01_l@00008@04o`/01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(40\\) METIIOLS JU IT MIJG A WFASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D03Ol300;o00<0ool00olF00Ko2`04oaD02_l500So4`05o`<01Ol200[o1P06o`X0
1_lB00Ko0`06oa400_l400;o1007o`L01_l300Ko00@0ool01Ol500Oo200=oa00000C00;o3@06o`L0
1_l<00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`D02Ol300go0`0:oa802Ol800So4`0:o`D0
2?lC00Go0`05o`802_l400Wo1`0:oa001_l300Ko4@02o`@00_l400Oo1`06o`<01_l00`3oo`08o`<0
1ol800go400001<00_l?00;o2003o`800ol;00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P0
0ol500?o1@02o`H00_l300?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaL00_l700;o1`02o`P0
0ol400?o1@04o`D00_lB00;o1`02oa800ol400?o1@02o``00_l700;o0`03o`D00ol400;o3P02o`H0
0_l@00004`02o`l00_l800;o1002o`/00_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2002o`L0
0_l500;o1P02o`<00_l700;o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`L00_l700;o2002o`H0
0_l500;o1`02oa800_l700;o4P04o`<00ol500;o3002o`L00_l300;o1`02o`@00_l>00;o1P02oa00
000C00;o2@0:o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`L0
0_l900;o1002o`H00_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l300;o0P02o`L0
0_l800;o1P02o`@00ol700;o4P0;oa801?l200Co1@02o`800_l800_o0`02o`L00_l400;o0P02o`X0
0_l600;o400001<00_l900[o1@02o`H00_l:00;o5@02o`800ol200;o1002o`800_l<00;o3002o`d0
0_l700;o2@02o`@00_l600;o2`03oa400_l600;o1P02o`H00_lF00;o3002oaL00_l200?o0P02o`L0
0_l800;o1P02o`@00_l400Oo4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X0
0_l600;o400001<00_l900;o1002o`L00_l600;o2P02oaD00_l20003o`3o00800_l400Ko3002o``0
0_l=00;o1`02o`T00_l400;o3P07oaX00_l600;o1P02oaH00_l<00;o5`02o`8000?o0?l00P02o`L0
0_l@00;o1002o`@01olB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o
600001<00_l:00;o0`02o`L00_l600;o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d0
0_l700;o2@02o`@00_l<00Oo7002o`H00_l600;o5P02o``00_lG00;o00@0ool00_l00`3oo`0700;o
4002o`@00_lN00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0
000D00;o2P001?l00002o`L00_l600;o2@02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1`02o`d00_l700;o2@02o`@00_l;00?o8@02o`H00_l600;o5P02o`L00_l300;o0`02oa80
0_l00`3oo`020004o`3oo`L00_l@00;o1002oah00_l300;o5002o`030?oo00;o00<0ool01@02o`80
0_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`X00_l200;o1`02o`H00_l900;o5P02o`03
0?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l700;o2@02o`@00_l;00;o
1`000ol0000H00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02oa00
0_l400;o2002oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L0
00?o00000`02o`800_l200;o1P02oaP0000D00?o2P000ol00002o`L00_l600;o2@02oaH01?l300Co
1002o`H00_l300;o0`02o`<00_l700;o3@02o`P00_l700;o1@02o`/00_l600;o6P02o`H00_l600;o
5P02o`L00_l300;o0`02oa801?l300Co1`02oa000_l500;o1P03oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2`001?l0ool800;o
1002o`T00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800?o1@03o`D00_l;00?o
1003oaX00_l600;o1P02oaH00_l700;o0`02o`<00_lB00Co1003o`L00_l@00;o1@03o`@01?lE00Go
5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o2P04o`P00ol200?o
2002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l500Wo0`08o`T02OlE00[o0P04o`@01?lA00[o
0`0<oa401?l500Co0P0:o`L02_l300[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So
5@0001L000?o00002@03o`T01_l90003o`0001H01?l500Co00<0ool02_l300co0`0:o`D02_l700Go
1@08o`/01Ol00`3o000D00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`L02_l500Go00<0ool0
4P07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<00ol:00Coo`360000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(41\\) METIIOLS JU IT MILD A WFASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1P09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D03Ol300;o00<0ool00olF00Ko2`04oaD02_l500So4`05o`<01Ol200[o100=o`80
2?lC00Ko0`06oa400_l400;o1007o`L01_l300Ko00@0ool01Ol500Oo200=oa00000C00;o3@06o`H0
2Ol:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`D02Ol300go0`0:oa802Ol800So4`0:o`D0
2?lC00Go0`05o`802_l400go0P0:oa401_l300Ko4@02o`@00_l400Oo1`06o`<01_l00`3oo`08o`<0
1ol800go400001<00_l?00;o3002o`d00_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2003o`D0
0ol500;o1P02o`<00ol500?o4@03o`@00ol700;o1002oaL00_l<00;o5`02o`L00_l700;o2`02o`H0
0_l300;o1004oa800_l700;o4P03o`@00ol500;o3002o`L00_l300?o1@03o`@00_l>00;o1P02oa00
000C00;o3`02o``00_l=00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P00_l700;o1@02o`H0
0_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l700;o1`02o`/00_l600;o0`02o`H0
0_lB00;o1`02oa801?l300?o1@02o``00_l700;o0`02o`L00_l400;o3P02o`H00_l@00004`02o`T0
2_l:00;o3@02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`L00_l900;o1002o`H0
0_l300;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l300;o0P02o`L00_l;00;o1P02o`<0
0_l700;o4@0;oa801?l200Co1@02o`800_l800_o0`02o`L00_l400;o0P02o`X00_l600;o400001<0
0_l900[o2P02o`d00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`L00_l900;o1002o`H0
0_l;00?o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`800ol200;o1`02o`/00_l600;o0`02o`L0
0_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`T0
0_l400;o3002o`d00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`L00_l900;o1002o`h0
1olJ00;o1P02o`H00_lF00;o3002oaL00_l20003o`3o00800_l700;o2`02o`/00_l700;o4P02o`D0
0_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`<00_l<00;o
3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l700;o2@02o`@00_l<00Oo7002o`H0
0_l600;o5P02o``00_lG00;o00@0ool00_l00`3oo`0700;o2`02o`/00_l700;o4`02o`<00_lD00;o
00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`X000Co00000_l<00;o
3002oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d00_l700;o2@02o`@0
0_l;00?o8@02o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l;00;o
2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`80
0_l:00;o600001@00_l:00;o0P02o``00_l<00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o
0`02o`<00_l300;o1`02o`d00_l700;o2@02o`@00_l;00;o1`000ol0000H00;o1P02o`H00_lF00;o
1`02o`<00_l300;o4P02o`030?l0008000Co0?oo1`02o`/00_l;00;o1`02oa@00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o2P000ol00002o``00_l<00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o
2002o`L00_l500;o2`02o`H00_lJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`<01?l700;o
2`02o`/00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o
1@02o`H00_l600;o600001D00_l;0004o`3oo``00_l;00;o5`04o`@00ol400;o1P02o`<00_l300;o
0`02o`L00_l=00;o2003o`D00ol500;o2`03o`@00olJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o
4P04o`@00ol700;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o
1P02o`H00_lH00005P02o`X01?l800?o00<0ool02P02oaL01?l500Co00<0ool02_l300co0`0:o`D0
2_l500Wo0`08o`T02OlE00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`@02?l700[o4`07oa@0
1_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00002@03o`P01_l:0003o`0001H0
1?l500Co00<0ool02_l300co0`0:o`D02_l700Go1@08o`/01Ol00`3o000D00[o0P04o`@01?lA00[o
0`0<oa401?l500Co0P0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l00080
3?l300So5@0002<00ol;00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(42\\) METIIOLS JU IT MILD A WFASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@0:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D03Ol300;o00<0ool00olF00Ko2`04oaD02_l500So4`05o`<01Ol200[o100=o`80
2?lC00Ko0`06oa400_l400;o1007o`L01_l300Ko00@0ool01Ol500Oo200=oa00000C00;o3@06o`D0
2_l:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`D02Ol300go0`0:oa802Ol800So4`0:o`D0
2?lC00Go0`05o`802_l400go0P0:oa401_l300Ko4@02o`@00_l400Oo1`06o`<01_l00`3oo`08o`<0
1ol800go400001<00_l?00;o2002o`D00_l:00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P0
0ol500?o1@02o`H00_l300?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaL00_l700;o1`02o`/0
0_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o``00_l700;o0`03o`D00ol400;o3P02o`H0
0_l@00004`02o`l00_l900?o3`02oaD00_l700;o1002o`H00_l800;o3002o`d00_l800;o1`02o`D0
0_l600;o0`02o`L00_lA00;o1P02o`H00_l600;o5P02o``00_lG00;o1`02o`L00_l;00;o1P02o`<0
0_l600;o4P02o`L00_lB00Co0`03o`D00_l<00;o1`02o`<00_l700;o1002o`h00_l600;o400001<0
0_l900[o2003o`h00_lE00;o0`02o`800_l400;o0P02o`800_l800;o3002o`d00_l700;o2@02o`@0
0_l600;o0`02o`L00_lA00;o1P02o`H00_l600;o5P02o``00_lG00;o0`02o`800_l700;o2`02o`H0
0_l300;o1`02oa402olB00Co0P04o`D00_l200;o200;o`<00_l700;o1002o`800_l:00;o1P02oa00
000C00;o2@0:o`T00ol=00;o5@02o`800ol200;o1002o`800_l<00;o3002o`d00_l700;o2@02o`@0
0_l600;o2`03oa400_l600;o1P02o`H00_lF00;o3002oaL00_l200?o0P02o`L00_l;00;o1P02o`<0
0_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<0
0_l900;o1002o``00ol<00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002o`d00_l700;o2@02o`@0
0_l>00Oo6P02o`H00_l600;o5P02o``00_lG00;o0P000ol0o`0200;o1`02o`/00_l;00;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`X00_l300;o
3@03o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``00_l=00;o1`02o`T00_l400;o3007oa`0
0_l600;o1P02oaH00_l<00;o5`02o`040?oo00;o00<0ool01`02o`/00_l;00;o1`02oa<00_l300;o
5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:0004o`0000;o
3P02o`X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o1`02o`T0
0_l400;o2`03ob400_l600;o1P02oaH00_l700;o0`02o`<00_lB00;o00<0ool00P001?l0ool700;o
2`02o`/00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``0
0_l200;o2P02oaP0000D00;o2P02o`800_l?00;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o
0P02o`<00_l300;o0`02o`L00_l=00;o1`02o`T00_l400;o2`02o`L000?o00006002o`H00_l600;o
5P02o`L00_l300;o0`02oa800_l00`3o00020004o`3oo`L00_l;00;o2`02o`L00_lD00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`X000?o00000_l?00;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o
3@02o`P00_l700;o1@02o`/00_l600;o6P02o`H00_l600;o5P02o`L00_l300;o0`02oa801?l300Co
1`02o`/00_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o
1P02o`D00_l600;o1P02oaP0000E00;o2`001?l0ool800;o1@02o`P00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800?o1@03o`D00_l;00?o1003oaX00_l600;o1P02oaH00_l700;o
0`02o`<00_lB00Co1003o`L00_l;00;o2`02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol600?o
1003o`D00_l600;o1P02oaP0000F00;o2P04o`P00ol300?o1`02oaL01?l500Co00<0ool02_l300co
0`0:o`D02_l500Wo0`08o`T02OlE00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`@02?l700[o
4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00002@03o`T01ol80003
o`0001H01?l500Co00<0ool02_l300co0`0:o`D02_l700Go1@08o`/01Ol00`3o000D00[o0P04o`@0
1?lA00[o0`0<oa401?l500Co0P0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0002<00ol:00Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(43\\) METIIOKS JU IT MILD A WFASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1`05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
3Ol200So4`06o`<01_lA00;o1002o`@01ol700Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`d0
1_l500Wo2`02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l500Wo0`05o`D00ol300[o4P09o`P0
2?lC00[o1@08oa<01Ol300Go0P0:o`@03Ol200[o4@06o`<01_lA00;o1002o`@01ol700Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`l00_l700;o1@02o`/00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2003o`D00ol400;o1@03o`@00ol500?o4@03o`@00ol700;o1002oaL00_l<00;o5`02o`L0
0_l700;o2`02o`H00_l300;o1004oa800_l700;o4P03o`@00ol500;o3002o`L00_l300?o1@03o`@0
0_l>00;o1P02oa00000C00;o3`02o`l00_l:00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P0
0_l700;o1002o`D00_l500;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l700;o1`02o`/0
0_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o``00_l700;o0`02o`L00_l400;o3P02o`H0
0_l@00004`02o`T02_l=00;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`L0
0_l900;o0`02o`@00_l600;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l300;o0P02o`L0
0_l;00;o1P02o`<00_l700;o4@0;oa801?l200Co1@02o`800_l800_o0`02o`L00_l400;o0P02o`X0
0_l600;o400001<00_l900[o3@02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`L0
0_l900;o0`03o`800ol>00?o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`800ol200;o1`02o`/0
0_l600;o0`02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H0
0_l@00004`02o`T00_l400;o3P02o`/00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`L0
0_l900;o0`07o`X01olJ00;o1P02o`H00_lF00;o3002oaL00_l20003o`3o00800_l700;o2`02o`/0
0_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o
2P02o`<00_l;00Co3002oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l700;o2@02o`<0
1Ol:00Oo7002o`H00_l600;o5P02o``00_lG00;o00@0ool00_l00`3oo`0700;o2`02o`/00_l700;o
4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`X0
00Co00000_l;00?o3002oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d0
0_l700;o2@02o`<00_l0103oool800?o8@02o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3o
o`020004o`3oo`L00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o
2P02o`<00_l500?o3002o`800_l:00;o600001@00_l:00;o0P02o`d00_l;00;o5P02o`030?l00080
00Co0?oo1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l200?o1`02o`L0
00?o00006002o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3o00020004o`3oo`L00_l;00;o
2`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003
o`0000<00_l200;o0P02o`H00_lH00005003o`X000?o00000_l>00;o2P02oaH01?l300Co1002o`H0
0_l300;o0`02o`<00_l700;o3@02o`P00_l700;o1002o`<00ol600;o1P02oaX00_l600;o1P02oaH0
0_l700;o0`02o`<00_lB00Co0`04o`L00_l;00;o2`02o`H00_lE00;o00<0ool05002o`<00_l300;o
1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`/000Co0?oo3P02o`T0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@0
0olJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`@00ol700;o2`02o`/00_l400Co5@05oa@0
0_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`X01?l800;o0`03o`P0
0_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1@09o`<01Ol300Go1009oaD02_l200Co1004oa40
2_l300co4@04o`D01?l200[o1008o`L02_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<0
2?lE00005`000ol0000900?o2007o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`L0
1Ol500Go0`05o`H01Ol00`3o000D00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`@02?l700So
5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<00ol:00Coo`360000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(44\\) METIIOKS JU IT MILD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2@06o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
3Ol200So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`d0
1_l900Ko2P02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l500Wo0`05o`D00ol300[o4P09o`P0
2?lC00[o1@08oa<01Ol300Go0P0:o`@03Ol200[o4@06o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`l00_l=00;o3002oaD00_l700;o1002o`H00_l800;o3002o`d0
0_l800?o1@03o`@00_l500?o1003o`D00olA00?o1003o`L00_l400;o5`02o``00_lG00;o1`02o`L0
0_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L00_l300?o1@03o`@0
0_l>00;o1P02oa00000C00;o3`02o`d00_l<00;o5@02o`L00_l400;o1P02o`P00_l<00;o3@02o`P0
0_l700;o1002o`D00_l500;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL00_l700;o1`02o`/0
0_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`h0
0_l600;o400001<00_l900[o1@0:o`X00_lE00;o0`02o`800_l400;o0P02o`800_l800;o3002o`d0
0_l700;o2@02o`<00_l400;o1P02o`L00_lA00;o1P02o`H00_l600;o5P02o``00_lG00;o0`02o`80
0_l700;o2`02o`H00_l300;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@02ol300;o1`02o`@0
0_l200;o2P02o`H00_l@00004`02o`T02_l500[o2P02oaD00_l200?o0P02o`@00_l200;o3002o``0
0_l=00;o1`02o`T00_l300?o0P03o`h00olA00;o1P02o`H00_l600;o5P02o``00_lG00;o0P03o`80
0_l700;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`80
0_l:00;o1P02oa00000C00;o2@02o`@00_l700;o1002o``00_lE00;o0P000ol0o`0200;o1006o``0
0_l<00;o3@02o`L00_l900;o0`07o`X01olJ00;o1P02o`H00_lF00;o3002oaL00_l20003o`3o0080
0_l700;o2`02o`/00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko
2P02oaP0000C00;o2P02o`<00_l800;o0`02o``00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``0
0_l=00;o1`02o`T00_l300Go2P07oa`00_l600;o1P02oaH00_l<00;o5`02o`040?oo00;o00<0ool0
1`02o`/00_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L0
1_l:00;o600001@00_l:0004o`0000;o2@001?l00002o`/00_lF00;o00<0ool00P001?l0ool400;o
0P02o`L00_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o00@0oooo2003ob400_l600;o1P02oaH0
0_l700;o0`02o`<00_lB00;o00<0ool00P001?l0ool700;o2`02o`/00_l700;o4`02o`<00_lD00;o
00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2P02o`80
0_l900;o0P02o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o
3@02o`L00_l900;o0`02o`800ol700;o1`000ol0000H00;o1P02o`H00_lF00;o1`02o`<00_l300;o
4P02o`030?l0008000Co0?oo1`02o`/00_l;00;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o
0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o2P000ol0
0002o`X000?o00000_l;00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2002o`L0
0_l400;o0`03o`H00_l600;o6P02o`H00_l600;o5P02o`L00_l300;o0`02oa801?l300Co1`02o`/0
0_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D0
0_l600;o1P02oaP0000E00;o2`001?l0ool;0004o`3oo`X00_lG00Co1003o`@00_l600;o0`02o`<0
0_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@00olJ00;o1P02o`H00_lF00;o1`02o`<0
0_l300;o4P04o`@00ol700;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@0
0ol500;o1P02o`H00_lH00005P02o`X01?l;00Co2@02oaL01?l500Co00<0ool02_l300co0`0:o`D0
2_l500Wo0`05o`<01Ol400Wo5@0:o`801?l400Co4@0:o`<03?lA00Co1@04o`802_l400So1`0:oa<0
1olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000T00ol<00?o2@000ol0
000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o1`05o`D01Ol300Go1P05o`030?l001@02_l200Co
1004oa402_l300co4@04o`D01?l200[o1008o`L02?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go
00<0o`000P0<o`<02?lE00008`03o``00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(45\\) METIIOKS JU IT MILD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1`05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
3Ol200So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`d0
1_l500Wo2`02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l500Wo0`05o`D00ol300[o4P09o`P0
2?lC00[o1@08oa<01Ol300Go0P0:o`@03Ol200[o4@06o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`l00_l700;o1@02o`/00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2003o`D00ol400;o1@03o`@00ol500?o4@03o`@00ol700;o1002oaL00_l<00;o5`02o`L0
0_l700;o2`02o`H00_l300;o1004oa800_l700;o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D0
0ol400;o3P02o`H00_l@00004`02o`l00_l?00;o2P02oaD00_l700;o1002o`H00_l800;o3002o`d0
0_l800;o1`02o`@00_l500;o1@02o`L00_lA00;o1P02o`H00_l600;o5P02o``00_lG00;o1`02o`L0
0_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@0
0_l>00;o1P02oa00000C00;o2@0:o`d00_l:00;o5@02o`<00_l200;o1002o`800_l200;o2002o``0
0_l=00;o1`02o`T00_l300;o1002o`H00_l700;o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`<0
0_l200;o1`02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L0
0_l400;o0P02o`X00_l600;o400001<00_l900[o3@02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l<00;o3@02o`L00_l900;o0`03o`800ol>00?o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`80
0ol200;o1`02o`/00_l600;o0`02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@0
0_l200;o2P02o`H00_l@00004`02o`T00_l400;o3`02o`X00_lE00;o0P000ol0o`0200;o1006o``0
0_l<00;o3@02o`L00_l900;o0`07o`X01olJ00;o1P02o`H00_lF00;o3002oaL00_l20003o`3o0080
0_l700;o2`02o`/00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko
2P02oaP0000C00;o2P02o`<00_l800;o1002o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``0
0_l=00;o1`02o`T00_l300Go2P07oa`00_l600;o1P02oaH00_l<00;o5`02o`040?oo00;o00<0ool0
1`02o`/00_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L0
1_l:00;o600001@00_l:0004o`0000;o2008o`X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L0
0_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o00@0oooo2003ob400_l600;o1P02oaH00_l700;o
0`02o`<00_lB00;o00<0ool00P001?l0ool700;o2`02o`/00_l700;o4`02o`<00_lD00;o00<0ool0
0_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2P02o`800_l800Oo
2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o1`02o`T0
0_l300;o0P03o`L00_l70003o`0001P00_l600;o1P02oaH00_l700;o0`02o`<00_lB00;o00<0o`00
0P001?l0ool700;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L0
0_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol:0003o`0000;o2002oa00
0_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800;o1`02o`@00_l300?o1P02o`H0
0_lJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`<01?l700;o2`02o`/00_l600;o5@02o`03
0?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D0
0_l;0004o`3oo`P00_l?00;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l=00;o2003o`D0
0ol400;o1003o`D00ol400?o6P02o`H00_l600;o5P02o`L00_l300;o0`02oa801?l400?o1`02o`/0
0_l;00;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H0
0_l:00Co2002o`h00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1@09o`<01Ol300Go1009oaD0
2_l200Co1004oa402_l300co4@04o`D01?l200[o1008o`L02_lC00Oo5006o`801_l00`3oo`0:o`@0
1ol800Wo0`0<o`<02?lE00005`000ol0000900?o2008o`P000?o00005P04o`D01?l00`3oo`0:o`<0
3?l300[o1@0:o`L01Ol500Go0`05o`H01Ol00`3o000D00[o0P04o`@01?lA00[o0`0<oa401?l500Co
0P0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<0
0ol800Soo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(46\\) METIIOKS JU IT MIKD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
1Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D01ol800go400001<0
0_l=00Ko1`07o`/00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1@09o`<01Ol500?o0`0:oa80
2Ol800So4`0:o`D02?lC00Go0`05o`802_l400Go1@03o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300Oo200=oa00000C00;o3`02o`P00_l400;o2`02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l800?o1@03o`@00_l500?o1003o`D00olA00?o1003o`L00_l400;o5`02o``0
0_lG00;o1`02o`L00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l>00;o1P02oa00000C00;o3`02o`L00_l600;o2P02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l800;o1`02o`@00_l500;o1@02o`L00_lA00;o1P02o`H00_l600;o5P02o``0
0_lG00;o1`02o`L00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l>00;o1P02oa00000C00;o2@0:o`D00_l600;o2P02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l<00;o3@02o`L00_l900;o0`02o`@00_l600;o1`02oa400_l600;o1P02o`H0
0_lF00;o3002oaL00_l300;o0P02o`L00_l:00;o1002o`H00_l700;o4@0;oa801?l200Co1@02o`80
0_l200;o100;o`<00_l700;o1002o`800_l:00;o1P02oa00000C00;o2@0:o`D00_l600;o2P02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o1`02o`T00_l300?o0P03o`h00olA00;o1P02o`H0
0_l600;o5P02o``00_lG00;o0P03o`800_l700;o2P03o`800ol600;o1`02oa802OlC00;o00@0o`00
1?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`@00_l700;o1P02o`X0
0_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`L00_l900;o0`07o`X01olJ00;o1P02o`H0
0_lF00;o3002oaL00_l20003o`3o00800_l700;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`<00_l700?o1002o`/00_lE00;o
00@0ool00_l00`3oo`0400Ko3002o``00_l=00;o1`02o`T00_l300Go2P07oa`00_l600;o1P02oaH0
0_l<00;o5`02o`040?oo00;o00<0ool01`02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o
00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:0004o`0000;o1`09o`X00_lF00;o
00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o00@0oooo
2003ob400_l600;o1P02oaH00_l700;o0`02o`<00_lB00;o00<0ool00P001?l0ool700;o2P02o`04
0?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``0
0_l200;o2P02oaP0000D00;o2P02o`800_l700;o00<0ool00_l<00;o5P02o`030?l0008000Co0?oo
1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l200?o1`02o`L000?o0000
6002o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3o00020004o`3oo`L00_l:00;o0P03o`L0
0_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0
000300;o0P02o`800_l600;o600001@00ol:0003o`0000;o2002oa000_lF00Co0`04o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800;o1`02o`@00_l300?o1P02o`H00_lJ00;o1P02o`H00_lF00;o
1`02o`<00_l300;o4P04o`<01?l700;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2`001?l0ool800?o
3P02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`P00ol500?o1002o`@00ol500?o
1003oaX00_l600;o1P02oaH00_l700;o0`02o`<00_lB00Co1003o`L00_l:00;o1003o`D00_l400Co
5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`X01?l900?o
3002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l500Wo0`05o`<01Ol400Wo5@0:o`801?l400Co
4@0:o`<03?lA00Co1@04o`802_l400Go0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo
0`0<o`<02?lE00005`000ol0000900?o2P07o`L000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o
1@0:o`L01Ol500Go0`05o`H01Ol00`3o000D00[o0P04o`@01?lA00[o0`0<oa401?l500Co0P0:o`@0
1Ol300Go0P08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000S00?o
3005ool0``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(47\\) METIIOKS JU IT MIKD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2002o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
1Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D01ol800go400001<0
0_l=00Ko2002o`l00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1@09o`<01Ol500?o0`0:oa80
2Ol800So4`0:o`D02?lC00Go0`05o`802_l400Go1@03o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300Oo200=oa00000C00;o3`02o`/00_l>00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`P00ol500?o1002o`D00ol400?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaL0
0_l700;o1`02o`X00_l500?o1002o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`h00_l600;o400001<00_l?00;o2`02o`h00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2002o`L00_l400;o1@02o`D00_l700;o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`L0
0_l700;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L0
0_l400;o3P02o`H00_l@00004`02o`T02_l900;o3P02oaD00_l300;o0P02o`@00_l200;o0P02o`P0
0_l<00;o3@02o`L00_l900;o0`02o`@00_l600;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL0
0_l300;o0P02o`L00_l:00;o1002o`H00_l700;o4@0;oa801?l200Co1@02o`800_l200;o100;o`<0
0_l700;o1002o`800_l:00;o1P02oa00000C00;o2@0:o`X000?o00003002oaD00_l200?o0P02o`@0
0_l200;o3002o``00_l=00;o1`02o`T00_l300?o0P03o`h00olA00;o1P02o`H00_l600;o5P02o``0
0_lG00;o0P03o`800_l700;o2P03o`800ol600;o1`02oa802OlC00;o00@0o`001?l500;o0P02o`T0
2Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`@00_l<00;o3@02oaD00_l20003o`3o0080
0_l400Ko3002o``00_l=00;o1`02o`T00_l300Oo2P07oaX00_l600;o1P02oaH00_l<00;o5`02o`80
00?o0?l00P02o`L00_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o
1`07o`D01_l:00;o600001<00_l:00;o0`02o``00_l=00;o5@02o`040?oo00;o00<0ool01006o``0
0_l<00;o3@02o`L00_l900;o0`05o`X01olL00;o1P02o`H00_lF00;o3002oaL00_l0103oo`02o`03
0?oo00L00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H0
1ol700Ko2P02oaP0000D00;o2P001?l00002o`d000?o00002P02oaH00_l00`3oo`020004o`3oo`@0
0_l200;o1`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l0103oool800?o8@02o`H00_l600;o
5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l:00;o00@0oooo2002o`L00_lC00;o
0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@0
0_l:00;o0P02o`d00_l;00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o
1`02o`d00_l700;o2@02o`<00_l200?o1`02o`L000?o00006002o`H00_l600;o5P02o`L00_l300;o
0`02oa800_l00`3o00020004o`3oo`L00_l:00;o0P03o`L00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol:0003o`0000;o3@02o`/00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800;o
1`02o`@00_l300?o1P02o`H00_lJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`<01?l700;o
2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o
1P02o`D00_l600;o1P02oaP0000E00;o2`001?l0ool>0003o`0000P00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@00olJ00;o1P02o`H00_lF00;o
1`02o`<00_l300;o4P04o`@00ol700;o2P02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o
1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l:00Co1`02o`D00_l800;o5`04o`D01?l00`3o
o`0:o`<03?l300[o1@0:o`D02Ol300Go0`05o`@02OlE00[o0P04o`@01?lA00[o0`0<oa401?l500Co
0P0:o`@01Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003
o`0000T00ol700Wo20000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o1`05o`D01Ol300Go
1P05o`030?l001@02_l200Co1004oa402_l300co4@04o`D01?l200[o1005o`<01Ol200So5@07oa@0
1_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<00ol700Woo`340000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(48\\) METIIOKS JU IT MIKD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
1Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D01ol800go400001<0
0_l=00Ko1P08o`/00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1@09o`<01Ol500?o0`0:oa80
2Ol800So4`0:o`D02?lC00Go0`05o`802_l400Go1@03o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300Oo200=oa00000C00;o3`02o`L00ol400?o2P02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l800?o1@03o`@00_l500?o1003o`D00olA00?o1003o`L00_l400;o5`02o``0
0_lG00;o1`02o`L00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l>00;o1P02oa00000C00;o3`02o`L00_l600;o2P02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l800;o1`02o`@00_l500;o1@02o`L00_lA00;o1P02o`H00_l600;o5P02o``0
0_lG00;o1`02o`L00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l>00;o1P02oa00000C00;o2@0:o`D00_l600;o2P02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l<00;o3@02o`L00_l900;o0`02o`@00_l600;o1`02oa400_l600;o1P02o`H0
0_lF00;o3002oaL00_l300;o0P02o`L00_l:00;o1002o`H00_l700;o4@0;oa801?l200Co1@02o`80
0_l200;o100;o`<00_l700;o1002o`800_l:00;o1P02oa00000C00;o2@0:o`D00_l600;o2P02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o1`02o`T00_l300?o0P03o`h00olA00;o1P02o`H0
0_l600;o5P02o``00_lG00;o0P03o`800_l700;o2P03o`800ol600;o1`02oa802OlC00;o00@0o`00
1?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`@00_l800;o1002o`/0
0_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`L00_l900;o0`07o`X01olJ00;o1P02o`H0
0_lF00;o3002oaL00_l20003o`3o00800_l700;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`<00_l900Oo2`02oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002o`d00_l700;o2@02o`<01Ol:00Oo7002o`H00_l600;o5P02o``0
0_lG00;o00@0ool00_l00`3oo`0700;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3o
o`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`X000Co00000_l900Ko2`02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l0103oool800?o
8@02o`H00_l600;o5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l:00;o00@0oooo
2002o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`80
0_l:00;o600001@00_l:00;o0P02o`P00_l400;o2P02oaH00_l00`3o00020004o`3oo`@00_l200;o
0P02o`<00_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o0P03o`L00_l70003o`0001P00_l600;o
1P02oaH00_l700;o0`02o`<00_lB00;o00<0o`000P001?l0ool700;o2P02o`800ol700;o1`02oa@0
0_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`80
0_l200;o1P02oaP0000D00?o2P000ol00002o`L00_l600;o2@02oaH01?l300Co1002o`H00_l300;o
0`02o`<00_l700;o3@02o`P00_l700;o1002o`<00ol600;o1P02oaX00_l600;o1P02oaH00_l700;o
0`02o`<00_lB00Co0`04o`L00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@0
0_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l;0004o`3oo`L00_l600;o
2002oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`P00ol500?o1002o`@00ol500?o
1003oaX00_l600;o1P02oaH00_l700;o0`02o`<00_lB00Co1003o`L00_l:00;o1003o`D00_l400Co
5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`X01?l700?o
1003o`L00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1@09o`<01Ol300Go1009oaD02_l200Co
1004oa402_l300co4@04o`D01?l200[o1005o`<01Ol200[o4`07oa@01_l200Ko00<0ool02_l400Oo
2009o`<03?l300So5@0001L000?o00002@03o`P02?l80003o`0001H01?l500Co00<0ool02_l300co
0`0:o`D02_l700Go1@05o`<01Ol600Go00<0o`00500:o`801?l400Co4@0:o`<03?lA00Co1@04o`80
2_l400Go0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE0000
8`03o`T01_oo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(49\\) METIIOKS JU IT MIKD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@05o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<01Ol300Go0P0:o`@0
1Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D01ol800go400001<0
0_l=00Ko1@07o`d00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1@09o`<01Ol500?o0`0:oa80
2Ol800So4`0:o`D02?lC00Go0`05o`802_l400Go1@03o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300Oo200=oa00000C00;o3`02o``00ol<00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`P00ol500?o1002o`D00ol400?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaL0
0_l700;o1`02o`X00_l500?o1002o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`h00_l600;o400001<00_l?00;o3@03o`/00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2002o`L00_l400;o1@02o`D00_l700;o4@02o`H00_l600;o1P02oaH00_l<00;o5`02o`L0
0_l700;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L0
0_l400;o3P02o`H00_l@00004`02o`T02_l<00;o2`02oaD00_l300;o0P02o`@00_l200;o0P02o`P0
0_l<00;o3@02o`L00_l900;o0`02o`@00_l600;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaL0
0_l300;o0P02o`L00_l:00;o1002o`H00_l700;o4@0;oa801?l200Co1@02o`800_l200;o100;o`<0
0_l700;o1002o`800_l:00;o1P02oa00000C00;o2@0:o`P01?l00`3oo`0:00;o5@02o`800ol200;o
1002o`800_l<00;o3002o`d00_l700;o2@02o`<00ol200?o3P03oa400_l600;o1P02o`H00_lF00;o
3002oaL00_l200?o0P02o`L00_l:00?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o
2@09o``00ol400;o0P02o`X00_l600;o400001<00_l900;o1002o`P02Ol:00;o5@02o`8000?o0?l0
0P02o`@01_l<00;o3002o`d00_l700;o2@02o`<01ol:00Oo6P02o`H00_l600;o5P02o``00_lG00;o
0P000ol0o`0200;o1`02o`X01ol700;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D0
0_l700Oo1@06o`X00_lH00004`02o`X00_l300;o2002o`@00ol:00;o5@02o`040?oo00;o00<0ool0
1006o``00_l<00;o3@02o`L00_l900;o0`05o`X01olL00;o1P02o`H00_lF00;o3002oaL00_l0103o
o`02o`030?oo00L00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o
0`02o`H01ol700Ko2P02oaP0000D00;o2P001?l00002o`L00_l600;o2@02oaH00_l00`3oo`020004
o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l0103oool800?o8@02o`H0
0_l600;o5P02o`L00_l300;o0`02oa800_l00`3oo`020004o`3oo`L00_l:00;o00@0oooo2002o`L0
0_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o
600001@00_l:00;o0P02o`L00_l600;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<0
0_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o0P03o`L00_l70003o`0001P00_l600;o1P02oaH0
0_l700;o0`02o`<00_lB00;o00<0o`000P001?l0ool700;o2P02o`800ol700;o1`02oa@00_l0103o
oolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o
1P02oaP0000D00?o2P000ol00002o`L00_l600;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<0
0_l700;o3@02o`P00_l700;o1002o`<00ol600;o1P02oaX00_l600;o1P02oaH00_l700;o0`02o`<0
0_lB00Co0`04o`L00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o
1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l;0004o`3oo`L00_l60003o`0000L0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@0
0olJ00;o1P02o`H00_lF00;o1`02o`<00_l300;o4P04o`@00ol700;o2P02o`@00ol500;o1004oaD0
1OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l:00Co2002o`@0
0_l800;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`D02Ol300Go0`05o`@02OlE00[o0P04o`@0
1?lA00[o0`0<oa401?l500Co0P0:o`@01Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`P0
2Ol300co0`08oaD0000G0003o`0000T00ol800Oo2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<0
2_l500[o1`05o`D01Ol300Go1P05o`030?l001@02_l200Co1004oa402_l300co4@04o`D01?l200[o
1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<0
0ol:00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(50\\) METIIOKS JU IT LIKD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1@08oa<03Ol200[o1005o`H0
0_l200So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`T0
2Ol800Ko3002oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l500Wo0`05o`D00ol300[o4P09o`P0
2?lC00[o1@08oa<03Ol200[o1005o`D00ol200[o4@06o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`T00_l500;o1`03o`800ol;00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`P00ol500?o1002o`D00ol400?o1@03oa400ol400?o1`02o`@00_lG00;o3002oaT0
0_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`h00_l600;o400001<00_lA00;o1P02o`@00_l;00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`P00_l700;o1002o`D00_l500;o1`02oa400_l600;o1P02o`H00_lF00;o3002oaT0
0_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<0
0_l700;o1002o`h00_l600;o400001<00_lA00;o1@02o`H00_l:00;o5@02o`<00_l200;o1002o`80
0_l200;o2002o``00_l=00;o1`02o`T00_l300;o1002o`H00_l700;o4@02o`H00_l600;o1P02oaH0
0_l<00;o6@02o`H00_l600;o2P02o`@00_l600;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@0
2ol300;o1`02o`@00_l200;o2P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o0P03o`80
0_l400;o0P02o``00_l<00;o3@02o`L00_l900;o0`03o`800ol>00?o4@02o`H00_l600;o1P02oaH0
0_l<00;o6@02o`H00_l600;o2P03o`800ol600;o1`02oa802OlC00;o00@0o`001?l500;o0P02o`T0
2Ol<00?o1002o`800_l:00;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaD00_l20003o`3o0080
0_l400Ko3002o``00_l=00;o1`02o`T00_l300Oo2P07oaX00_l600;o1P02oaH00_l<00;o6@02o`h0
0_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o
600001<00_l:00;o1002o`H00_l600;o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d0
0_l700;o2@02o`<01Ol:00Oo7002o`H00_l600;o5P02o``00_lI00;o3P02o`X01Ol900;o1`02oa<0
0_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l900So
1P02o`H00_l900;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`L0
0_l900;o0`02o`040?ooo`P00olQ00;o1P02o`H00_lF00;o1`02o`<00_l300;o5002o`h00_l:00;o
00@0oooo2002o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o
3002o`800_l:00;o600001@00_l900Oo1`02o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o0`02o`<00_l300;o1`02o`d00_l700;o2@02o`<00_l200?o1`02o`L000?o00006002o`H0
0_l600;o5P02o`L00_l300;o0`02oa@00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o2002o``00_l600;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o3@02o`P0
0_l700;o1002o`<00ol600;o1P02oaX00_l600;o1P02oaH00_l700;o0`02o`<00_lD00;o3P02o`X0
0_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H0
0_l500;o1P02o`H00_lH00005@02o`P00_l=00;o1002o`T00_lG00Co1003o`@00_l600;o0`02o`<0
0_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@00olJ00;o1P02o`H00_lF00;o1`02o`<0
0_l300;o5002o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@0
0ol500;o1P02o`H00_lH00005P02o`L00_l=00?o0P03o`P00_lG00Co1@04o`030?oo00[o0`0<o`<0
2_l500[o1@09o`<01Ol300Go1009oaD02_l200Co1004oa402_l300co4@08o`L02_l400Go0`05o`80
2_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So2006o`T0
00?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`L01Ol500Go0`05o`H01Ol00`3o000D00[o
0P04o`@01?lA00[o0`0<oa402?l700[o1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo
2P05o`030?l000803?l300So5@0001l02?l900Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(51\\) METIIOKS JU IS LILD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2@09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1`05o`D01Ol600;o0`02o`030?oo00?o5P06o`/01?lE00[o1002o`030?oo00?o500=o`80
2_l400go0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D01ol800go400001<0
0_l900Wo1`09o`X00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1@09o`<01Ol500?o0`0:oa80
2Ol800So4`0:o`@02_lB00go0P0:o`@03Ol200[o4@06o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`T00_l500;o2`02o`d00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2003o`D00ol400;o1@03o`@00ol500?o4@03o`@00ol700;o1002oaL00_l800?o1@03oa@0
0_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`h00_l600;o400001<00_lA00;o2P02o`d00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2002o`L00_l400;o1@02o`D00_l700;o4@02o`H00_l600;o1P02oaH00_l800;o1`02oa@0
0_l600;o1P02o`/00_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<0
0_l700;o1002o`h00_l600;o400001<00_lA00;o2P02o`d00_lE00;o0`02o`800_l400;o0P02o`80
0_l800;o3002o`d00_l700;o2@02o`<00_l400;o1P02o`L00_lA00;o1P02o`H00_l600;o5P02o`P0
0_l700;o5002o`H00_l600;o2`02o`H00_l300;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@0
2ol300;o1`02o`@00_l200;o2P02o`H00_l@00004`02oa400_l:00;o3@02oaD00_l200?o0P02o`@0
0_l200;o3002o``00_l=00;o1`02o`T00_l300?o0P03o`h00olA00;o1P02o`H00_l600;o5P02oa00
0olD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``0
0ol400;o0P02o`X00_l600;o400001<00_lA00;o2P02o`d00_lE00;o0P000ol0o`0200;o1006o``0
0_l<00;o3@02o`L00_l900;o0`07o`X01olJ00;o1P02o`H00_lF00;o2`07oaD00_l>00;o2`02o`/0
0_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o
2P02o`@00_l;00;o3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l700;o2@02o`<0
1Ol:00Oo7002o`H00_l600;o5P02o`T01olG00;o3P02o`/00_l;00;o1`02oa<00_l300;o5002o`03
0?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l900So2`02o``00_lF00;o
00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o1`02o`T00_l300;o00@0oooo
2003ob400_l600;o1P02oaH00_l800?o7002o`h00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3o
o`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l900Oo3002o``0
0_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o3@02o`L00_l900;o
0`02o`800ol700;o1`000ol0000H00;o1P02o`H00_lF00;o2002o`L000?o00004`02o`h00_l;00;o
2`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003
o`0000<00_l200;o0P02o`H00_lH00005003o`P00_lA00;o3002oaH01?l300Co1002o`H00_l300;o
0`02o`<00_l700;o3@02o`P00_l700;o1002o`<00ol600;o1P02oaX00_l600;o1P02oaH00_l800;o
1P02oaD00_l>00;o2`02o`/00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`03
0?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800;o4@02o`/00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800?o1@03o`@00_l400?o1@03o`@00olJ00;o1P02o`H00_lF00;o
2003o`@00olE00;o3P02o`/00_l;00;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o
1@02o`H00_l600;o600001H00_l700;o3@03o`030?oo00X00_lG00Co1@04o`030?oo00[o0`0<o`<0
2_l500[o1@09o`<01Ol300Go1009oaD02_l200Co1004oa402_l500Wo4P08o`L02_l400So1`0:oa<0
1olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000D02?l700Ko2P000ol0
000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o1`05o`D01Ol300Go1P05o`030?l001@02_l200Co
1004oa402_l700Go00<0o`004@08o`L02_l400So1`08oaD01olD00Ko0P06o`030?oo00[o1007o`X0
1Ol00`3o000200co0`08oaD0000O00So2P03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(52\\) METIINKS JU IS LILD A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go200:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l;00Co5@0:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500Oo200=oa00
000C00;o2@09o`H02_l:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4P09o`P02?lC00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300Oo200=oa00000C00;o2@02o`D00_l700;o1@02o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o4@03o`@00ol700;o1002oaL0
0_l800?o1@03oa@00_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H0
0_l400;o1`02o`<00ol500?o1002o`h00_l600;o400001<00_lA00;o1`03o`l00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D00_l700;o4@02o`H00_l600;o1P02oaH0
0_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H0
0_l400;o1`02o`<00_l700;o1002o`h00_l600;o400001<00_lA00;o2003o`h00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lA00;o1P02o`H0
0_l600;o5P02o`P00_l700;o5002o`H00_l600;o2`02o`H00_l300;o1`02oa402olB00Co0P04o`D0
0_l200;o0P02o`@02ol300;o1`02o`@00_l200;o2P02o`H00_l@00004`02oa400_l900?o3@02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olA00;o
1P02o`H00_l600;o5P02oa000olD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4P09oa<00_l0103o
0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_lA00;o2P03o``00_lE00;o
0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o00<0ool01007o`X01olJ00;o1P02o`H0
0_lF00;o2`07oaD00_l>00;o2`02o`/00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o
1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`@00_l<00?o2`02oaD00_l0103oo`02o`030?oo00@0
1_l<00;o3002o`d00_l900;o0P02o`800_l400Go2P07oa`00_l600;o1P02oaH00_l900Oo5`02o`h0
0_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko
2P02oaP0000D00;o2@08o`d00_l:00;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<0
0_l700;o3@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olQ00;o1P02o`H00_lF00;o2003oa`0
0_l>00;o2`02o`/00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o
1@03o``00_l200;o2P02oaP0000D00;o2@07o`l00_l900;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`@00_l200?o1`02o`L000?o00006002o`H0
0_l600;o5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol800;o5002o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@0
0_l300?o1P02o`H00_lJ00;o1P02o`H00_lF00;o2002o`H00_lE00;o3P02o`/00_l;00;o1P02oaD0
0_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0
000E00;o2002o`d00_l500;o2002oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T0
1?l400;o1002o`@00ol500?o1003oaX00_l600;o1P02oaH00_l800?o1003oaD00_l>00;o2`02o`/0
0_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`L0
0_l=00?o0`03o`L00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`801_l00`3oo`03o`<0
1Ol400Wo5@0:o`801?l400Co4@0:o`D02OlB00So1`0:o`@02?l700[o4`07oa@01_l200Ko00<0ool0
2_l400Oo2009o`<03?l300So5@0001L000?o00001@08o`P01ol80003o`0001H01?l500Co00<0ool0
2_l300co0`0:o`D02_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000D00[o0P04o`@01?lA00[o
1`05o`030?l001402?l700[o1008o`L02?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`00
0P0<o`<02?lE00007`08o`T01Ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(53\\) METIINKS JU IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l;00Co5@0:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`H02Ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4P09o`P02?lC00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l600;o1@02o`/00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o4@03o`@00ol700;o1002oaL0
0_l800?o1@03oa@00_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H0
0_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o4@02o`d00_l:00;o5@02o`L0
0_l400;o1P02o`P00_l<00;o3@02o`T00_l400Co1002o`D00_l500;o1`02oa400_l600;o1P02o`H0
0_lF00;o2002o`L00_lD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa400_l=00;o2P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`T00_l300Go1002o`@00_l600;o1`02oa40
0_l600;o1P02o`H00_lF00;o2002o`L00_lD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02oa40
0_l=00;o2P02oaD00_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o
0P03o`h00olA00;o1P02o`H00_l600;o5P02oa000olD00;o1P02o`H00_l;00;o1P02o`<00_l700;o
4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_lA00;o
3002o`/00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o00<0ool01007o`X0
1olJ00;o1P02o`H00_lF00;o2`07oaD00_l>00;o2`02o`/00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`@00_l:00Co3002oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002o`d00_l900;o0P02o`800_l400Go2P07oa`00_l600;o1P02oaH0
0_l900Oo5`02o`h00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o
0`02o`H01ol700Ko2P02oaP0000D00;o2@08o`X00ol<00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l700;o3@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olQ00;o1P02o`H0
0_lF00;o2003oa`00_l>00;o2`02o`/00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o
0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2@07o`d00_l;00;o5P02o`030?l00080
00Co0?oo1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`@00_l200?o1`02o`L0
00?o00006002o`H00_l600;o5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`04
0?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`80
0_l600;o600001@00ol800;o4`02o`X00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d0
0_l900Co1002o`@00_l300?o1P02o`H00_lJ00;o1P02o`H00_lF00;o2002o`H00_lE00;o3P02o`/0
0_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D0
0_l600;o1P02oaP0000E00;o2002oa<00_l900;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2@04o`@00_l400;o1003o`D00ol400?o6P02o`H00_l600;o5P02o`P00ol400?o5@02o`h0
0_l;00;o2`02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0
000F00;o1`02o`d00_l300?o2002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l400Co0P06o`03
0?oo00?o0`05o`@02OlE00[o0P04o`@01?lA00[o1@09oa802?l700[o1008o`L02_lC00Oo5006o`80
1_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So1`07o`T000?o00005P04o`D0
1?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001@02_l200Co
1004oa402_l700Go00<0o`004@08o`L02_l400So1`08oaD01olD00Ko0P06o`030?oo00[o1007o`X0
1Ol00`3o000200co0`08oaD0000O00So2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(54\\) METIINKS JT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go3006o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l800So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`X01_l:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4P09o`L02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l<00;o3002oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500?o1003o`D00olA00?o1003o`T00_lK00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02oa400_l;00;o3002oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500;o1@02o`L00_lA00;o1P02o`T00_lK00;o2002o`L0
0_lD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa400_l500[o2P02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l<00;o3@02o`T00_l300Go1002o`@00_l600;o1`02oa400_l600;o2@02oa/0
0_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o4@02o`D02_l:00;o5@02o`80
0ol200;o1002o`800_l<00;o3002o`d00_l900;o0`02o`030?oo00@00ol200?o3P03oa400_l600;o
2@02oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o
0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o4@02o`D00_l400;o3002oaD00_l20003
o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaX00_l900;o6`02o`/0
1olE00;o3P02o`/00_l;00;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo
1@06o`X00_lH00004`02o`X00_l400;o1`02o`<00_l<00;o5@02o`040?oo00;o00<0ool01006o``0
0_l<00;o3@02o`T00_l200;o0P02o`@01Ol:00Oo7002o`T00_lK00;o2@07oaL00_l>00;o2`02o`/0
0_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH0000
5002o`T02?l80004o`0000;o2`02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o
1`02o`d00_l900;o00<0ool00`02o`@00_l0103oool800?o8@02o`@00_l300;o0`02oaH00_l800?o
7002o`h00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<0
0_l500?o3002o`800_l:00;o600001@00_l900Oo2@02o`800_l;00;o5P02o`030?l0008000Co0?oo
1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`@00_l200?o1`02o`L000?o0000
6002o`@00_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`/00_l;00;o1`02oa@00_l0103o
oolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o
1P02oaP0000D00?o2002o`l000?o00000_l;00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2@04o`@00_l400;o0`03o`H00_l600;o6P02o`@00_l300;o0`02oaH00_l800;o1P02oaD0
0_l>00;o2`02o`/00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H0
0_l600;o1@02o`H00_l600;o600001D00_l800;o40001?l0ool:00;o5`04o`@00ol400;o1P02o`<0
0_l300;o0`02o`L00_l=00;o2@04o`@00_l400;o1003o`D00ol400?o6P02o`@00_l300;o0`02oaH0
0_l800?o1003oaD00_l>00;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@0
0ol500;o1P02o`H00_lH00005P02o`L00_l@00Co2@02oaL01?l500Co00<0ool02_l300co0`0:o`D0
2_l400Co0P06o`030?oo00?o0`05o`@02OlE00[o00<0ool02_lB00[o1@09oa802?l700[o1008o`L0
2_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So2`03o`T0
00?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`03
0?l001@02_l00`3oo`0:oa802_l700Go00<0o`004@08o`L02_l400So1`08oaD01olD00Ko0P06o`03
0?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So2`03ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(55\\) METIINKS JT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l800So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`H02Ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4P09o`L02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l600;o1@02o`/00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o4@03o`@00ol900;o6`02o`P0
0ol500?o5002o`H00_l600;o2`02o`H00_l300;o1004oa800_l700;o4P03o`@00ol500;o1P02o`@0
0_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_lA00;o3@02o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D00_l700;o4@02o`H00_l900;o6`02o`P0
0_l700;o5002o`H00_l600;o2`02o`H00_l300;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_lA00;o3@02o`X00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lA00;o1P02o`T0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4@0;oa801?l200Co1@02o`80
0_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02oa400_l=00;o2P02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olA00;o
1P02o`T00_lK00;o4003oa@00_l600;o1P02o`/00_l600;o0`02o`L00_lB00Wo4`02o`040?l000Co
1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02oa400_l=00;o2P02oaD00_l20003
o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaX00_l900;o6`02o`/0
1olE00;o3P02o`/00_l;00;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo
1@06o`X00_lH00004`02o`X00_l400;o1`02o`@00_l;00;o5@02o`040?oo00;o00<0ool01006o``0
0_l<00;o3@02o`T00_l200;o0P02o`@01Ol:00Oo7002o`T00_lK00;o2@07oaL00_l>00;o2`02o`/0
0_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH0000
5002o`T02?l700So2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d0
0_l900;o00<0ool00`02o`@00_l0103oool800?o8@02o`@00_l300;o0`02oaH00_l800?o7002o`h0
0_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o
3002o`800_l:00;o600001@00_l900Oo2007o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1002o`800ol700;o1`000ol0000H00;o1002o`<0
0_l300;o5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol800;o3@02oa000_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@0
0_l300?o1P02o`H00_lJ00;o1002o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l;00;o2`02o`H0
0_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H0
0_lH00005@02o`P00_l=00;o3`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T0
1?l400;o1002o`@00ol500?o1003oaX00_l400;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`/0
0_l;00;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H0
0_l700;o3@02o`h00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`801_l00`3oo`03o`<0
1Ol400Wo5@0:o`030?oo00[o4P0:o`D02OlB00So1`0:o`@02?l700[o4`07oa@01_l200Ko00<0ool0
2_l400Oo2009o`<03?l300So5@0001L000?o00001@08o`L02?l80003o`0001H01?l500Co00<0ool0
2_l300co0`0:o`D02_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000D00[o00<0ool02_lB00[o
1`05o`030?l001402?l700[o1008o`L02?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`00
0P0<o`<02?lE00007`08o`L02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(56\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`P01ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l700;o1002o`/00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``00_lK00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``00_lK00;o2002o`L0
0_lD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o
3002oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o
0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaD00_l20003
o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/0
1olE00;o3P02o`/00_l;00;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo
1@06o`X00_lH00004`02o`X00_l400;o1P03o`@00_l;00;o5@02o`040?oo00;o00<0ool01006o``0
0_l<00;o3@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2`02o`/0
0_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH0000
5002o`T02?l600Wo2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1`02o`d0
0_l900;o00<0ool00`02o`@00_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h0
0_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o
3002o`800_l:00;o600001@00_l900Oo1`02o`030?oo00;o3002oaH00_l00`3o00020004o`3oo`@0
0_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o2@05o`<00_l400;o0P03o`L00_l70003o`0001D0
0_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l;00;o2`02o`L00_lD00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`P00_l=00;o4002oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o3@02o`T0
1?l400;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`/0
0_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D0
0_l600;o1P02oaP0000E00;o2002o`d00ol>00;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD0
0_l>00;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H0
0_lH00005P02o`L00_l>00?o3002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l400Co0P06o`03
0?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400So1`0:oa<01olD00Ko0P06o`03
0?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000D02?l900Oo1`000ol0000F00Co1@04o`03
0?oo00[o0`0<o`<02_l500[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o
1`05o`030?l001402?l700[o1008o`L02?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`00
0P0<o`<02?lE00007`08o`/01Ooo0<<0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(57\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`02o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`T00_l?00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l:00;o3P02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500?o1003o`D00olF00;o3002oa/00_l800?o1@03oa@0
0_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`H00_l600;o1P02oa00000C00;o4@02o`T00_l>00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`T00_l400Co1002o`D00_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H0
0_l600;o2`02o`H00_l300;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L0
0_l400;o1P02o`H00_l600;o400001<00_lA00;o2@02o`h00_lE00;o0`02o`800_l400;o0P02o`80
0_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@0
0_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L0
0_l400;o0P02o`800_l600;o1P02oa00000C00;o4@02o`X000?o00003002oaD00_l200?o0P02o`@0
0_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o3002oa/00_l@00?o
5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o
1002o`800_l:00;o1P02oa00000C00;o4@02o`X00_l=00;o5@02o`8000?o0?l00P02o`@01_l<00;o
3002o`d00_l900;o0P03o`030?oo00@01ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2`02o`/0
0_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o
2P02o`@00_l;00;o3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l900;o0P02o`80
0_l400Go2P07oaT00_l<00;o6`02o`T01olG00;o3P02o`/00_l;00;o1`02oa<00_l300;o5002o`03
0?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l900So30000ol0000:00;o
5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`T00_l00`3oo`0300;o
1002o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`/00_l;00;o1`02oa<0
0_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH0000
5002o`T01ol=00;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L0
0_l=00;o2@05o`<00_l400;o0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2002o`L0
00?o00004`02o`h00_l;00;o2`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`P00_lB00;o2`02oaH0
1?l300Co1002o`H00_l300;o0`02o`<00_l700;o3@02o`T01?l400;o1002o`<00ol600;o1P02oaL0
0_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`/00_l;00;o1P02oaD00_l00`3oo`0D00;o
0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2002oa<0
00?o00002002oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T01?l400;o1002o`@0
0ol500?o1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`/00_l;00;o1004oaD0
1OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l700;o3002o`D0
0_l800;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@01?l200Ko00<0ool00ol300Go1009oa<0
2_l300co4P0:o`D02OlB00So1`0:o`@02?l700[o4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<0
3?l300So5@0001L000?o00001@08o`H02Ol80003o`0001H01?l500Co00<0ool02_l300co0`0:o`D0
2_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L0
2_l400So1`08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So
1P09ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(58\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`L02?l;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l600?o1003o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``00_lK00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``00_lK00;o2002o`L0
0_lD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o
3002oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o
0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o4@02o`H00_l400;o2`02oaD00_l20003
o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/0
1olE00;o3P02o`/00_l;00;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo
1@06o`X00_lH00004`02o`X00_l400;o2007o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``0
0_l=00;o2@02o`800_l200;o1005o`X01olI00;o3002oa/00_l900Oo5`02o`h00_l;00;o2`02o`L0
0_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o
2@08o`P01_l;00;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`T0
0_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`/0
0_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o
0P02o`X00_lH00005002o`T01ol800;o1002o`X00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<0
0_l300;o5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol800;o3002o`H00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@0
0_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2`02o`/0
0_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H0
0_l600;o600001D00_l800;o3002o`H00_l800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD0
0_l>00;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H0
0_lH00005P02o`L00_l<00?o1003o`L00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`80
1_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1008o`L02_lC00Oo5006o`80
1_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So1`08o`P000?o00005P04o`D0
1?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co
4P0:o`L01Ol00`3o000A00So1`0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0001l02?l800Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(59\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2005o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2@09o`H01ol=00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l;00?o3002oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500?o1003o`D00olF00;o3002oa/00_l800?o1@03oa@0
0_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`H00_l600;o1P02oa00000C00;o4@02o`/00ol;00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`T00_l400Co1002o`D00_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H0
0_l600;o2`02o`H00_l300;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L0
0_l400;o1P02o`H00_l600;o400001<00_lA00;o3002o`/00_lE00;o0`02o`800_l400;o0P02o`80
0_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@0
0_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L0
0_l400;o0P02o`800_l600;o1P02oa00000C00;o4@02o`P01?l00`3oo`0:00;o5@02o`800ol200;o
1002o`800_l<00;o3002o`d00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa00
0olD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``0
0ol400;o0P02o`X00_l600;o400001<00_lA00;o1P09o`X00_lE00;o0P000ol0o`0200;o1006o``0
0_l<00;o3@02o`T00_l200?o00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h00_l;00;o
2`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o600001<0
0_l:00;o1002o`L00_l400?o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d00_l900;o
0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T01olG00;o3P02o`/00_l;00;o1`02oa<00_l300;o
5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l900So1P02o`H0
0_l900;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`T00_l00`3o
o`0300;o1002o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`/00_l;00;o
1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X0
0_lH00005002o`T01ol700;o1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o
0`02o`<00_l700;o3@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o0`02o`@0
0_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol800;o
3002o`H00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@00_l400;o
0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2`02o`/00_l600;o
5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o
600001D00_l800;o3002o`H000?o00001`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o
3@02o`T01?l400;o1002o`@00ol500?o1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o
3P02o`/00_l;00;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o
600001H00_l700;o3@02o`@00_l800;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@01?l200Ko
00<0ool00ol300Go1009oa<02_l300co4P0:o`D02OlB00So1`0:o`@02?l700[o4`07oa@01_l200Ko
00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00001@08o`L01ol90003o`0001H01?l500Co
00<0ool02_l300co0`0:o`D02_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa80
2_l700Go00<0o`004@08o`L02_l400So1`08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o
000200co0`08oaD0000O00So2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(60\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2`07o`P01_l<00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2P02o`@00_l700?o0P03o`/00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``00_lK00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1P02o`@00_l;00;o5@02o`L0
0_l400;o1P02o`P00_l<00;o3@02o`T00_l400Co1002o`D00_l500;o1`02oaH00_l<00;o6`02o`P0
0_l700;o5002o`H00_l600;o2`02o`H00_l300;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`T00_l300Go1002o`@00_l600;o1`02oaH0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2`02o`H00_l300;o1`02oa402olB00Co0P04o`D0
0_l200;o0P02o`@02ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<00_l900;o1P02o`D0
0_l600;o2P02oaD00_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o
0P03o`h00olF00;o3002oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o
00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`H00_l500;o
1P02o`X00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o00<0ool01007o`X0
1olG00;o3002oa/00_l;00Oo5@02o`h00_l;00;o2`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o
1@06o`T00_l500;o1`07o`D01_l:00;o600001<00_l900?o1002o`H00_l600;o2P02oaD00_l0103o
o`02o`030?oo00@01_l<00;o3002o`d00_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T0
1olG00;o3P02o`/00_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o
1P07o`L01_l:00;o600001@00_l800Wo1P02o`H00_l900;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l700;o3@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<0
0_l300;o5P02o`P00olL00;o3P02o`/00_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`P00_l00`3oo`02o`P00_l600;o
2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o2@05o`<0
0_l400;o0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h0
0_l;00;o2`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D0
0_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`P00_l<00;o1P02o`T00_lF00Co0`04o`@0
0_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l300?o1P02o`H00_lG00;o1`02o`<0
0_l300;o5P02o`P00_l600;o5@02o`h00_l;00;o2`02o`H00_lE00;o00<0ool05002o`<00_l300;o
1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`P00ol<00;o1002o`T0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l400?o1@03o`@0
0olG00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l;00;o2`02o`@01?lE00Go5002o`P0
0_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o2003o`/00ol200?o2002oaL0
1?l500Co00<0ool02_l300co0`0:o`D02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa80
2_l500Wo4P08o`L02_l400So1`0:oa<01olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0
000G0003o`0000L01ol700Ko2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o1003o`<0
1_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o1`05o`030?l001402?l700[o1008o`L0
2?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008`05o`P01?oo0<H0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(61\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2`07o`L02Ol:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2P02o`@00_l;00;o3@02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500?o1003o`D00olF00;o3002oa/00_l800?o1@03oa@0
0_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l:00;o3@02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l900;o1004o`@00_l500;o1@02o`L00_lF00;o3002oa/00_l800;o1`02oa@0
0_l600;o1P02o`/00_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<0
0_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l:00;o3@02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l<00;o3@02o`T00_l300Go1002o`@00_l600;o1`02oaH00_l<00;o6`02o`P0
0_l700;o5002o`H00_l600;o2`02o`H00_l300;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@0
2ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<00_l900;o1P02o`X00_l=00;o5@02o`80
0ol200;o1002o`800_l<00;o3002o`d00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o
6`02oa000olD00;o1P02o`H00_l;00;o1P02o`<00_l700;o4P09oa<00_l0103o0004o`D00_l200;o
2@09o``00ol400;o0P02o`X00_l600;o400001<00_l900;o1P02o`X00_l=00;o5@02o`8000?o0?l0
0P02o`@01_l<00;o3002o`d00_l900;o0P03o`030?oo00@01ol:00Oo5`02o``00_lK00;o2`07oaD0
0_l>00;o2`02o`/00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko
2P02oaP0000C00;o2@03o`@00_l;00;o3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002o`d0
0_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T01olG00;o3P02o`/00_l;00;o1`02oa<0
0_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l800Wo
2`02o``00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o2@02o`03
0?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o2`02o`/0
0_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o
2P02oaP0000D00;o2002o`030?oo00;o3@02o``00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l700;o3@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<0
0_l300;o5P02o`P00_l70003o`0001<00_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol800;o4@02o``00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@0
0_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l;00;o2`02o`H0
0_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H0
0_lH00005@02o`P00ol@00;o2`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`T0
1?l400;o1002o`@00ol500?o1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`/0
0_l;00;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H0
0_l800?o2`03o`030?oo00X00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`801_l00`3o
o`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1008o`L02_lC00Oo5006o`801_l00`3o
o`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000700Oo1P06o`X000?o00005P04o`D01?l00`3o
o`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`L0
1Ol00`3o000A00So1`0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l00080
3?l300So5@0002<01Ol900?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(62\\) METIINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
3Ol200[o100=o`802?lC00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2`07o`H02_l:00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`@01_l200?o0P05o`D0
0ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o100=o`802_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2P02o`@00_l700;o1@02o`X00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``00_lK00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1`03o`l00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``00_lK00;o2002o`L0
0_lD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o2003o`h00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/0
0_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o2@02o`H00_l900?o3@02oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o
3002oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o1`02oa802OlC00;o00@0o`001?l500;o
0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`H00_l:00?o3002oaD00_l20003
o`3o00800_l400Ko3002o``00_l=00;o2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/0
1olE00;o3P02o`/00_l;00;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo
1@06o`X00_lH00004`02o`T00ol400;o3003o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``0
0_l=00;o2@02o`800_l200;o1005o`X01olI00;o3002oa/00_l900Oo5`02o`h00_l;00;o2`02o`L0
0_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o
2009o`d00_l:00;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`T0
0_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`/0
0_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o
0P02o`X00_lH00005002o`P00_l00`3oo`02oa000_l900;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o0`02o`<00_l300;o1`02o`d00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L0
0_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`/00_l;00;o1`02oa@00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o2002oa@00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2@04o`@0
0_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2`02o`/0
0_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H0
0_l600;o600001D00_l800?o3002o`D00_l800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD0
0_l>00;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H0
0_lH00005P02o`P00ol;00?o0`03o`L00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500[o1004o`80
1_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1008o`L02_lC00Oo5006o`80
1_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000700Oo1`07o`P000?o00005P04o`D0
1?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co
4P0:o`L01Ol00`3o000A00So1`0:o`@02?l700So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0002<01Ol800Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(63\\) METHINKS IT IS LILD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@03Ol200So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`/01ol600Wo2`02oa@01Ol300Go00<0ool02_l500So1@04o`<01?l400[o1006o`80
0ol200Go1@03o`<02_lC00[o1@08oa@02_l400[o4P0=o`802_l400go0P0:oa401_l300Ko4@02o`@0
0_l400co0P06o`<01_l00`3oo`08o`<03?l300go400001<00_l:00;o1002o`H00_l500;o2`02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o3@02o`X0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00_l500;o1`02oaH0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2`02o`H00_l300;o1P02oa800_l700;o4P04o`<0
0ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o`d0
0_l:00;o5@02o`<00_l200;o1002o`800_l200;o2002o`T00_l500;o2@02o`T00_l300Go1002o`@0
0_l600;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2`02o`H00_l300;o1`02oa40
2olB00Co0P04o`D00_l200;o0P02o`@02ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<0
0_l900;o1P02o`d00_l:00;o5@02o`800ol200;o1002o`800_l<00;o2@02o`D00_l900;o2@02o`<0
0_l00`3oo`0400?o0P03o`h00olF00;o3002oa/00_l@00?o5002o`H00_l600;o2`02o`H00_l300;o
1`02oa802OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o
2@02o`H00_l<00;o2`02oaD00_l20003o`3o00800_l400Ko3002o`T00_l500;o2@02o`T00_l200?o
00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h00_l;00;o2`02o`L00_lB00;o1@02oa<0
0_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o600001<00_l900?o1002o`X01?l<00;o
5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``0
0_lK00;o2@07oaL00_l>00;o2`02o`/00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko
2P02o`<00_l600Oo1`06o`X00_lH00005002o`P02Ol:00?o3002oaH00_l00`3oo`020004o`3oo`@0
0_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103oool800?o7P02o`L0
0_l300;o0`02oaH00_l800?o7002o`h00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`03
0?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l800;o00<0ool00_l>00;o
2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o2@02o`T0
1Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<0
0_l>00;o2`02o`/00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103o
ool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol800;o4`02o`X00_lF00Co0`04o`@0
0_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L0
0_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2`02o`/00_l600;o5@02o`030?oo01@00_l300;o
0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800?o4P02o`T0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o1003o`D0
0ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2`02o`/00_l400Co5@05oa@0
0_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`P00ol;00;o0`03o`P0
0_lG00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@01?l200Ko00<0ool00ol300Go1009oa<0
2_l300co4P0:o`D02OlB00So1`0:o`@02?l700[o4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<0
3?l300So5@0001L000?o00001`07o`H01ol90003o`0001H01?l500Co00<0ool02_l300co0`04o`<0
1?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o1`05o`030?l00140
2?l700[o1008o`L02?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE0000
8`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(64\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co3006o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo2P06o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o3002o``0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`/0
0_l<00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l500[o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o2@02o`H00_l500[o2P02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o2@02o`T0
0_l300;o00<0ool01003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o
1P02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@0000
4`02o`T00_l600;o1@02o`@00_l<00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`T00ol400;o
1`02o`<00_l<00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@0
1Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool0
0_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`P02Ol80004o`0000;o2`02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@0
0_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L0
0_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o
600001@00_l800;o00<0ool00_l:00;o0P02o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l400;o1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L0
0_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`P00_l?0003o`0000;o2`02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o
1@02o`T00_l900Co1002o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`P00_l600;o
5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`03
0?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800?o3`001?l0ool:00;o5`04o`@00ol400;o
1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o1003oaL00_l700;o
0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o1@02o`@01?lE00Go5002o`P00_l400;o
1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o2003o`h01?l900;o5`04o`D01?l00`3o
o`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo
4P08o`L02_l400Go0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE0000
5`000ol0000700Oo2P03o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o
0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go
0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008`05o`X0
0ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(65\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo1P09o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o1P02o`D0
0_l;00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l=00;o2P02oaD00_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D0
0_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L0
0_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T0
0_l600;o3@02o`X00_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<0
1Ol400;o1002o`H00_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H0
0_l700;o4@0;oa801?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H0
0_l@00004`02o`T00_l600;o3@02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l900;o1P02o`d00_l:00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`T00ol400;o
1`02o`@00_l;00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@0
1Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool0
0_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`P02Ol700So2P02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103o
ool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L00_lC00;o
0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@0
0_l800;o00<0ool00_l900Oo2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o
2002o`d00_l@00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o
1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o
1P02o`H00_lH00005@02o`P00ol<00;o3`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l400;o
1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o1`02o`<00_l300;o5P02o`P00ol400?o
5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o
1P02o`H00_lH00005P02o`P00ol;00;o3P02oaL01?l500Co00<0ool02_l300co0`04o`<01?l400[o
1004o`801_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1005o`<01Ol200[o
4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00001`07o`H02?l80003
o`0001H01?l500Co00<0ool02_l300co0`04o`<01?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go
00<0o`004P0:o`<03?lB00[o1`05o`030?l001402?l700[o1005o`<01Ol200So5@07oa@01_l200Ko
00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<01Ol600Soo`340000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(66\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo2007o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o1`02o`@0
0_l;00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l500;o1P02o`X00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D0
0_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa80
0_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<0
0_l900;o1P02o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T0
0_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X0
0_l400;o1P02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`80
0_l600;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l900;o1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o
1P02o`H00_l:00?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o
0P02o`X00_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaD00_l20003o`3o00800_l400Ko
3002o`T00_l500;o2@02o`T00_l200?o00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h0
0_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o
600001<00_l900?o1002o`H00ol400;o2`02oaD00_l0103oo`02o`030?oo00@01_l<00;o2@09o`T0
0_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T01olG00;o3P02o`X01Ol900;o1`02oa<0
0_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l800Wo
1P09o`X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`@02Ol900;o2@02o`03
0?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o2P02o`04
0?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``0
0_l200;o2P02oaP0000D00;o2002o`030?oo00;o2002o`030?oo00;o3002oaH00_l00`3o00020004
o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o
1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o
1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o0000
0`02o`800_l200;o1P02oaP0000D00?o2002o`d00_l@00;o5P04o`<01?l400;o1P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o
2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H0
0_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`P00ol<00?o3P02oaL01?l400?o
1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o
1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o
1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`P00ol<00?o3002oaL01?l500Co
00<0ool02_l300co0`04o`<01?l400[o1004o`801_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o
1@09oa802?l700[o1005o`<01Ol200[o4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So
5@0001L000?o00001`07o`P01ol70003o`0001H01?l500Co00<0ool02_l300co0`04o`<01?l400[o
1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o1`05o`030?l001402?l700[o
1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0002<0
1Ol:00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(67\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`02o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo2@02o`l00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o2P02o`h0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`T0
0_l>00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l900;o3P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o2@02o`H00_l:0003o`0000`00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l900;o1P02o`X00_l=00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`T00ol400;o
2`02o`d00_lE00;o00@0ool00_l00`3oo`0400Ko3002o`T02Ol900;o2@02o`800_l200;o1005o`X0
1olI00;o3002oa/00_l900Oo5`02o`h00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`03
0?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2009o``000?o00002P02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103o
ool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L00_lC00;o
0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@0
0_l800;o00<0ool00_l>00;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o
2002oa800_l;00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o
1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o
1P02o`H00_lH00005@02o`P00olB0003o`0000P00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o
1003oaD00_l>00;o2P02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o
1@02o`H00_l600;o600001H00_l800?o2P02o`D00_l800;o5`04o`D01?l00`3oo`0:o`<03?l300Co
0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go
0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000700Oo
1@09o`P000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o
0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo
5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008`05o`D02Ooo0<@0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(68\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo1`08o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o1P03o`@0
0ol:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l500;o1P02o`X00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D0
0_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa80
0_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<0
0_l900;o1P02o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T0
0_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X0
0_l400;o1P02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`80
0_l600;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l900;o1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o
1P02o`H00_l:00?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o
0P02o`X00_l600;o400001<00_l900;o1P02o`H00_l400;o2`02oaD00_l20003o`3o00800_l400Ko
3002o`T00_l500;o2@02o`T00_l200?o00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h0
0_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o
600001<00_l900?o1002o`P01ol;00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T0
0_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<0
0_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`P02Ol800Ko
2`02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool0
0`02o`@00_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo
2002o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`80
0_l:00;o600001@00_l800;o00<0ool00_l900;o1002o`X00_lF00;o00<0o`000P001?l0ool400;o
0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o0000
5@02o`L00_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o
00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o
0P02o`H00_lH00005003o`P00_l<00;o1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o
1P02oaD00_l>00;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L0
0_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2003o`/00_l600;o2002oaL01?l400?o
1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o
1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o
1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`P00ol:00?o1003o`L00_lG00Co
1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@01?l200Ko00<0ool00ol300Go1009oa<02_l300co
4P0:o`D02OlB00So1`0:o`@01Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`P02Ol300co
0`08oaD0000G0003o`0000L01ol600So20000ol0000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co
100:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`L01Ol00`3o000A00So
1`0:o`@01Ol300Go0P08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0
000S00Go1`06ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(69\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l;00Oo1P07o`d00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o2`03o``0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`/0
0ol;00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l<00;o2`02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o2@02o`H00_l800Co00<0ool02P02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o
2@02o`T00_l300;o00<0ool01003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X0
0ol200?o1P02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H0
0_l@00004`02o`T00_l600;o1P09o`X00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T0
0_l900;o0P03o`030?oo00@01ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o
4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2@03o`@0
0_l700;o1003o`X00_lE00;o00@0ool00_l00`3oo`0400Ko3002o`T02Ol900;o2@02o`800_l200;o
1005o`X01olI00;o3002oa/00_l900Oo5`02o`h00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3o
o`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2009o`H00_l600;o2@02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@0
0_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L0
0_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o
600001@00_l800;o00<0ool00_l800;o1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l400;o1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L0
0_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`P00_l<00;o1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D0
0_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD0
0_l>00;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3o
o`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2003o`/00_l60003o`0000L00_lG00Co1003o`@0
0_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L0
0_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o1004oaD01OlD00;o2002o`@0
0_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l800?o2`02o`@00_l800;o5`04o`D0
1?l00`3oo`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa80
2_l500Wo4P08o`L02_l400Go0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<0
2?lE00005`000ol0000700Oo1P07o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@0
2_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L0
2_l400Go0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE0000
8`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(70\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o3006o``00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l:00?o0P03o`/0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o2P02o`@0
0_l;00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o3@02o`T0
0_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o3P000ol0000700;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l>00;o2002o`H00_l:00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`h00_l800;o
1P02o`X00_lE00;o00@0ool00_l00`3oo`0400Ko3002o`T02Ol900;o2@02o`800_l200;o1005o`X0
1olI00;o3002oa/00_l900Oo5`02o`h00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`03
0?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o3P000ol0000600;o1P02o`T00_lF00;o
00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o
00@0oooo2003oah00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l700;o
4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0
000D00;o3P02o`L00_l600;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o
3@02o`L00_l600;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co
1002o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l:00;o
0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o
1@02o`H00_l600;o600001D00_l>0003o`0000H00_l400;o2@02oaL01?l400?o1002o`H00_l300;o
0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o1`02o`<00_l300;o
5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o1002o`H00_l700Go
1P03o`@00ol500;o1P02o`H00_lH00005P02o`H00_l500;o1`03o`800ol800;o5`04o`D01?l00`3o
o`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo
4P08o`L02_l400Go0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE0000
5`000ol0000400Wo2006o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o
0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go
0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00007P09o`T0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(71\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2`09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2`09o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l>00;o3@02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`d00_l>00;o3@02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d00_l>00;o3@02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@00_l400;o1P02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L00_lA00_o4P04o`80
1?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o3P000ol0
000<00;o3@02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o2@02o`T00_l300;o00<0ool0
1003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o1P02o`L00_lB00Wo
4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`h00_l=00;o
3@02oaD00_l20003o`3o00800_l400Ko3002o`T00_l500;o2@02o`T00_l200?o00<0ool01007o`X0
1olG00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o
1@06o`T00_l500;o1`07o`D01_l:00;o600001<00_l>00;o3@02o`d00_lE00;o00@0ool00_l00`3o
o`0400Ko3002o`T02Ol900;o2@02o`800_l200;o1005o`X01olI00;o3002oa/00_l900Oo5`02o`h0
0_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko
2P02oaP0000D00;o3P000ol0000;00;o3002oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103oool800?o7P02o`L00_l300;o0`02oaH0
0_l800?o7002o`h00_l:00;o00@0oooo2002o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D0
0_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l>00;o3002o``00_lF00;o00<0o`00
0P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l900Go0`02o`@00_l200?o
1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o
1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003
o`0000<00_l200;o0P02o`H00_lH00005003o`d00_l<00;o3002oaH01?l300Co1002o`H00_l300;o
0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o
5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@0
0_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l>0003o`0000X00_l;00;o
5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o
1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o1@02o`@01?lE00Go
5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o1P02o`D00_l700?o
00<0ool02P02oaL01?l500Co00<0ool02_l300co0`04o`<01?l400[o1004o`801_l00`3oo`03o`<0
1Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1005o`<01Ol200[o4`07oa@01_l200Ko00<0ool0
2_l400Oo2009o`<03?l300So5@0001L000?o00001009o`L01_l:0003o`0001H01?l500Co00<0ool0
2_l300co0`04o`<01?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o
1`05o`030?l001402?l700[o1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0001h02Ol:00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(72\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P0:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2P0:o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l:00;o1@02o`X0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o2`03o`l0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00_l500;o1`02oaH0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<0
0ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l=00;o3003o`h0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<01Ol400;o1002o`H0
0_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`h0
00?o00002`03o`d00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T00_l900;o0`02o`03
0?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l700;o
4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l>00;o
3@03o``00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@0
1ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o3P02o`h00ol;00;o5@02o`040?oo00;o
00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL0
0_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo
1`06o`X00_lH00005002o`h000?o00003@02o`X00_lF00;o00<0ool00P001?l0ool400;o0P02o`L0
0_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<0
0_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3o
o`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o3P02o`l00_l900;o5P02o`03
0?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o1002o`D00_l900;o2@05o`<00_l400;o
0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o
0P03o`L00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool500;o
1`000ol0000300;o0P02o`800_l600;o600001@00ol=00;o3`02o`T00_lF00Co0`04o`@00_l600;o
0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o
0`02oaH00_l800;o1P02oaD00_l>00;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o3P000ol0000600;o
1@02o`P00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o
1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o
1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600;o
1@02o`L00ol300?o1`02oaL01?l500Co00<0ool02_l300co0`04o`<01?l400[o1004o`801_l00`3o
o`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o1005o`<01Ol200[o4`07oa@01_l200Ko
00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00001009o`P01ol80003o`0001H01?l500Co
00<0ool02_l300co0`04o`<01?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`<0
3?lB00[o1`05o`030?l001402?l700[o1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo
2P05o`030?l000803?l300So5@0001h02Ol900Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(73\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2P09o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l900;o1@02o`/0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o4@02o`X0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00_l500;o1`02oaH0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<0
0ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l=00;o4@02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<01Ol400;o1002o`H0
0_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`h0
00?o00003`02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T00_l900;o0`02o`03
0?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l700;o
4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l>00;o
3`02o`/00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@0
1ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o3P02o``01?l<00;o5@02o`040?oo00;o
00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL0
0_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo
1`06o`X00_lH00005002o`h000?o00002P03o``00_lF00;o00<0ool00P001?l0ool400;o0P02o`L0
0_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<0
0_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3o
o`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o3P02o`d00_l;00;o5P02o`03
0?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o1002o`D00_l900;o2@05o`<00_l400;o
0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02o`h00_l:00;o
0P03o`L00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool500;o
1`000ol0000300;o0P02o`800_l600;o600001@00ol=00;o3P02o`X00_lF00Co0`04o`@00_l600;o
0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o
0`02oaH00_l800;o1P02oaD00_l>00;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o3P000ol0000<00;o
2@02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l400?o
1@03o`@00olG00;o1`02o`<00_l300;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l400Co
5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`H00_l500;o
1`02o`<00ol800;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o
0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go0`05o`802_lC00Oo5006o`801_l00`3o
o`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000400Wo1`07o`T000?o00005P04o`D01?l00`3o
o`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa80
2_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go
00<0o`000P0<o`<02?lE00007P09o`T01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(74\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3P06o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o3P06o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l?00;o3002oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`d00_l?00;o3002oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d00_l900[o2P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@00_l400;o1P02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L00_lA00_o4P04o`80
1?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o3P000ol0
000700[o2P02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o2@02o`T00_l300;o00<0ool0
1003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o1P02o`L00_lB00Wo
4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`h00_l800;o
1002o``00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@0
1ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o3P02o`T00_l300;o3002oaD00_l0103o
o`02o`030?oo00@01_l<00;o2@09o`T00_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T0
1olG00;o3P02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o
1P07o`L01_l:00;o600001@00_l>0003o`0000P000Co00000_l;00;o5P02o`030?oo008000Co0?oo
1002o`800_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o
1`02o`<00_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o1`02oa<00_l300;o5002o`03
0?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`h00_l900;o
0P02o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T0
0_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l800;o1`000ol0
000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`d00_l:0003o`0000;o
2`02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l300?o
1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o
5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o
600001D00_l>0003o`0000T000Co0?oo2P02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l400;o
1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o1`02o`<00_l300;o5P02o`P00ol400?o
5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o
1P02o`H00_lH00005P02o`H00_l500;o2P04o`T00_lG00Co1@04o`030?oo00[o0`0<o`<01?l300Co
100:o`@01?l200Ko00<0ool00ol300Go1009oa<02_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go
0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000@02Ol;00?o
2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool00ol300Go
1P05o`030?l001802_l300co4P0:o`L01Ol00`3o000A00So1`0:o`@01Ol300Go0P08oaD01olD00Ko
0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000N00Wo2`03ool0a@000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(75\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2P09o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l900;o1@02o`/0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o4@02o`X0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00_l500;o1`02oaH0
0_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa800_l700;o4P04o`<0
0ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l=00;o4@02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<01Ol400;o1002o`H0
0_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`h0
00?o00003`02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T00_l900;o0`02o`03
0?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l700;o
4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l>00;o
4002o`X00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@0
1ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o3P02o`T00_l400;o2`02oaD00_l0103o
o`02o`030?oo00@01_l<00;o2@09o`T00_l900;o0P02o`800_l400Go2P07oaT00_l<00;o6`02o`T0
1olG00;o3P02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o
1P07o`L01_l:00;o600001@00_l>0003o`0000L02?l:00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<0
0_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o1`02oa<00_l300;o5002o`030?oo00;o
00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`h00_l800Oo2`02oaH0
0_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01Ol300;o
1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<00_l>00;o
2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o3@02o`P00_l@00;o5P04o`<01?l400;o
1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o1P02oaL00_l700;o
0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<0
0_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`h000?o0000
1P02o`l00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o
1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o
1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600;o
1@02o`L00_l>00;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o
0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go0`05o`802_lC00Oo5006o`801_l00`3o
o`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000400Wo1`08o`P000?o00005P04o`D01?l00`3o
o`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o0`0<oa80
2_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol:00Go
00<0o`000P0<o`<02?lE00007P09o`L02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(76\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o3007o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l:00;o1002o`/0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o2@02o`H0
0_l:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o3@02o`T0
0_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o3P000ol0000700;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l>00;o2002o`H00_l:00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`h00_l800?o
1002o`/00_lE00;o00@0ool00_l00`3oo`0400Ko3002o`T02Ol900;o2@02o`800_l200;o1005o`X0
1olI00;o3002oa/00_l900Oo5`02o`h00_l:00Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`03
0?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o3P000ol0000600Wo2P02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103o
ool800?o7P02o`L00_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L00_lC00;o
0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@0
0_l>00;o1`02o`030?oo00;o3002oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001<00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o
3@02o`P00_l@00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o
1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o
1P02o`H00_lH00005@02o`h000?o00001P03o`h00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o
1003oaD00_l>00;o2P02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o
1@02o`H00_l600;o600001H00_l600;o1@02o`P00ol<00;o5`04o`D01?l00`3oo`0:o`<03?l300Co
0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go
0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000400Wo
2@07o`L000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o
0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo
5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00007P09o`/01Ooo0<<0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(77\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@02o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o3@02o`l00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l=00;o3P02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`d00_l=00;o3P02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d00_l=00;o3P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@00_l400;o1P02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L00_lA00_o4P04o`80
1?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o3P000ol0
000<0003o`0000`00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T00_l900;o0`02o`03
0?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l700;o
4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_l>00;o
3@02o`d00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@0
1ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o3P02o`d00_l=00;o5@02o`040?oo00;o
00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL0
0_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo
1`06o`X00_lH00005002o`h000?o000030000ol0000:00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<0
0_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o1`02oa<00_l300;o5002o`030?oo00;o
00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`h00_l=00;o2`02oaH0
0_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01Ol300;o
1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003o`0001<00_l>00;o
2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o3@02o`d00_l;00;o5P04o`<01?l400;o
1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o1P02oaL00_l700;o
0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<0
0_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`h000?o0000
30000ol0000800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o
1002o`@00ol500?o1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o
1@02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o
1P02o`D00_l600;o1@02o`P00_lG00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@01?l200Ko
00<0ool00ol300Go1009oa<02_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go0P0:oa<01olD00Ko
0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000@02Ol600Wo20000ol0000F00Co
1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l00180
2_l300co4P0:o`L01Ol00`3o000A00So1`0:o`@01Ol300Go0P08oaD01olD00Ko0P06o`030?oo00[o
1007o`X01Ol00`3o000200co0`08oaD0000N00Wo1P09ool0a0000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(78\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2`08o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l900?o1003o`X0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l=00;o2@02o`H0
0_l:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o3@02o`T0
0_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o3P000ol0000700;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l>00;o2@02o`@00_l;00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`h00_l:00Oo
2`02oaD00_l0103oo`02o`030?oo00@01_l<00;o2@09o`T00_l900;o0P02o`800_l400Go2P07oaT0
0_l<00;o6`02o`T01olG00;o3P02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l>0003o`0000P01_l;00;o5P02o`030?oo0080
00Co0?oo1002o`800_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P0
0olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o1`02oa<00_l300;o
5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`h0
0_l800;o1002o`X00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o
1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l800;o
1`000ol0000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`80
0_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`d00_l700;o
1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o
0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2P02o`<00ol600;o
1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o
1P02oaP0000E00;o3P000ol0000500;o1P02o`P00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o
1003oaD00_l>00;o2P02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o
1@02o`H00_l600;o600001H00_l600;o1@02o`H00ol400?o1`02oaL01?l500Co00<0ool02_l300co
0`04o`<01?l400[o1004o`801_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o
1005o`<01Ol200[o4`07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o0000
1009o`L02?l80003o`0001H01?l500Co00<0ool02_l300co0`04o`<01?l400[o1003o`<01_l00`3o
o`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o1`05o`030?l001402?l700[o1005o`<01Ol200So
5@07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300So5@0001h02Ol800Koo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(79\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P05o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l<00;o2P07o`d00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`d00_l>00?o3002oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o5P02o``0
0_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l400Co4P02o`L00_lB00?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H00_l@00004`02o`d00_l?00?o2`02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D00_l700;o5P02o``0
0_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d00_l@00;o2`02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@00_l400;o1P02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L00_lA00_o4P04o`80
1?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00000C00;o3P000ol0
000:00Co00<0ool02P02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o2@02o`T00_l300;o
00<0ool01003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o1P02o`L0
0_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`h0
0_l900Wo2P02oaD00_l20003o`3o00800_l400Ko3002o`T00_l500;o2@02o`T00_l200?o00<0ool0
1007o`X01olG00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o
003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o600001<00_l>00;o2@02o`@00ol:00;o5@02o`04
0?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o
2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<0
0_l600Oo1`06o`X00_lH00005002o`h000?o00001P02o`H00_l900;o5P02o`030?oo008000Co0?oo
1002o`800_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o
1`02o`<00_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o1`02oa<00_l300;o5002o`03
0?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`h00_l700;o
1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T0
0_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l800;o1`000ol0
000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`d00_l700;o1P02o`T0
0_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o0`03o`H0
0_l600;o5`02o`L00_l300;o0`02oaH00_l800;o1P02oaD00_l>00;o2P02o`<00ol600;o1P02oaD0
0_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0
000E00;o3P000ol0000500;o1P000ol0000700;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@0
0_l500;o2@02o`T01?l400;o1002o`@00ol500?o1003oaL00_l700;o0`02o`<00_lF00;o2003o`@0
0olE00;o3P02o`X00_l400?o1@02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D0
0_l600;o1P02oaP0000F00;o1P02o`D00_l700;o1002o`P00_lG00Co1@04o`030?oo00[o0`0<o`<0
1?l300Co100:o`@01?l200Ko00<0ool00ol300Go1009oa<02_l300co4P0:o`D02OlB00So1`0:o`@0
1Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000@0
2Ol700Oo2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool0
0ol300Go1P05o`030?l001802_l300co4P0:o`L01Ol00`3o000A00So1`0:o`@01Ol300Go0P08oaD0
1olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000N00Wo2@04ool0aP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(80\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l:00So2006o``00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o1P03o`80
0ol;00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l600;o1002o`/00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D0
0_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D00_l500;o1P02oa80
0_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<0
0_l900;o1P02o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T0
0_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X0
0_l400;o1P02o`L00_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`80
0_l600;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l900;o1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o
1P02o`H00_l:00?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o
0P02o`X00_l600;o400001<00_l:00;o1002o`H00_l600;o2P02oaD00_l20003o`3o00800_l400Ko
3002o`T00_l500;o2@02o`T00_l200?o00<0ool01007o`X01olG00;o3002oa/00_l;00Oo5@02o`h0
0_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D01_l:00;o
600001<00_l;00Oo1P02o`H00_l:00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T0
0_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<0
0_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`X01_l700;o
1P02o`T00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`@02Ol900;o2@02o`03
0?oo00<00_l400;o00@0oooo2003oah00_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o2P02o`04
0?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``0
0_l200;o2P02oaP0000D00;o2@02o`@00_l600;o1P02o`T00_lF00;o00<0o`000P001?l0ool400;o
0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o0000
5@02o`L00_l300;o0`02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o1`02o`L00_lD00;o
00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o
0P02o`H00_lH00005003o`L00_l600;o1@02o`H00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o
0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o
2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H0
0_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l600;o1P02o`@00_l900;o
5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o
1003oaL00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o1@02o`@01?lE00Go
5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o1P03o`@00ol600?o
0P03o`P00_lG00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@01?l200Ko00<0ool00ol300Go
1009oa<02_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o
1007o`P02Ol300co0`08oaD0000G0003o`0000D02?l800Ko2@000ol0000F00Co1@04o`030?oo00[o
0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`L0
1Ol00`3o000A00So1`0:o`@01Ol300Go0P08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o
000200co0`08oaD0000P00Ko2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(81\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l:00So1`09o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o2P02o`d0
0_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`X0
0_l=00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500;o1@02o`L0
0_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l:00;o3@02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`L0
0_lA00_o4P04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o0P02o`800_l600;o1P02oa00
000C00;o2@02o`H00_l:00;o3@02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o2@02o`T0
0_l300;o00<0ool01003o`800ol>00?o5P02o``00_lK00;o4003oa@00_l600;o1P02o`X00ol200?o
1P02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H00_l@0000
4`02o`X00_l400;o2`02o`d00_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l900;o
0P03o`030?oo00@01ol:00Oo5`02o``00_lK00;o2`07oaD00_l>00;o2P07o`L00_l700;o4P02o`D0
0_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2`07o`/00_l=00;o
5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@01Ol:00Oo6@02o``0
0_lK00;o2@07oaL00_l>00;o2P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko
2P02o`<00_l600Oo1`06o`X00_lH00005002o`X01_l<00;o3002oaH00_l00`3oo`020004o`3oo`@0
0_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@00_l0103oool800?o7P02o`L0
0_l300;o0`02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`L00_lC00;o0`02oa@00_l00`3o
o`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l900;o1002o`/0
0_l<00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o1002o`D00_l900;o
2@05o`<00_l400;o0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2002o`L000?o0000
4`02o`h00_l:00;o0P03o`L00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L0
0_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol700;o1P02o`X00_l<00;o
5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o
1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lE00;o
00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH0000
5@02o`L00_l600;o2P02o`/00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o
2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o1003oaD00_l>00;o
2P02o`@00ol500;o1004oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o
600001H00_l600?o1003o`H00ol00`3oo`0:00;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@0
2_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go0`05o`80
2_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So1`06o`X0
00?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o0`05o`H0
1Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo5006o`80
1_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008006o`/00ooo0<H0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(82\\) METHINKS IT IS LIKD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`D0
3?l300go400001<00_l:00So1P0:o`X00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00[o100:oa803Ol200[o1005o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o1P02o`D0
0_l:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l800?o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@01?lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l700?o3`02oaD00_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@02o`D0
0_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L0
0_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T0
0_l600;o2003o`h00_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<0
1Ol400;o1002o`H00_l700;o5P02o``00_lK00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H0
0_l700;o4@0;oa801?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H0
0_l@00004`02o`T00_l600;o2@03o`d00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`T0
0_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o
0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_l:00;o1002o`/00ol<00;o5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l900;o
2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/01ol<00?o
2`02oaD00_l0103oo`02o`030?oo00@01_l<00;o2@09o`T00_l900;o0P02o`800_l400Go2P07oaT0
0_l<00;o6`02o`T01olG00;o3P02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:00Ko3P02o`X00_lF00;o00<0ool00P001?l0
ool400;o0P02o`L00_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o00@0oooo2003oah0
0_l700;o0`02o`<00_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l700;o4`02o`<00_lD00;o
00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2@02o`@0
0_l>00;o2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o
2@02o`T01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003
o`0001<00_l>00;o2P02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`80
0_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l=00;o
2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`@00_l300?o
1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o
5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o
600001D00_l700;o1P02o`H00_l500;o2002oaL01?l400?o1002o`H00_l300;o0`02o`<00_l400;o
1@02o`T00_l900Co1002o`@00_l400?o1@03o`@00olG00;o1`02o`<00_l300;o5P02o`P00ol400?o
5@02o`h00_l:00;o1003o`D00_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o
1P02o`H00_lH00005P02o`H00ol400?o1P03o`<00ol700;o5`04o`D01?l00`3oo`0:o`<03?l300Co
0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l500Wo4P08o`L02_l400Go
0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So
2007o`P000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l400?o0`06o`030?oo00?o
0`05o`H01Ol00`3o000B00[o0`0<oa802_l700Go00<0o`004@08o`L02_l400Go0`05o`802?lE00Oo
5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008006o`X01Ooo0<D0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(83\\) METHINKS IT IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->4.98333,
  AnimationCycleOffset->-0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l400;o00<0ool0
0olD00go0P0:o`@01Ol600;o00<0ool02_l@00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool0
1Ol500co0`0=oa00000C00;o2P08o`H02Ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500Co0`04o`@0
2_l400Ko0P03o`801Ol500?o0`0:oa<02_l500So500:o`@02_lB00go0P0:o`@01Ol500?o00<0ool0
2_l@00Ko0`06oa400_l400;o100<o`801_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@03o`@0
0ol500;o1@02o`/00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D0
0ol400?o1@03oaH00_l<00;o6`02o`P00ol500?o5002o`H00_l600;o2P02o`D00ol400;o1P02oa80
0_l700;o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<0
0_l900;o1P02o`d00_l:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T00_l900;o1004o`@0
0_l500;o1@02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X00_l500;o1@02o`H0
0_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00
000C00;o2@02o`H00_l=00;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T0
0_l900;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@00_l600;o1P02o`X0
0_l400;o1P02o`800_l200;o4P0;oa801?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`80
0_l200;o1P02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l900;o1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l<00;o6`02oa000olD00;o
1P02o`H00_l:00?o0P03o`H00_l200;o5`09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o
0P02o`X00_l600;o400001<00_l:00;o1002o`d00_l;00;o5@02o`8000?o0?l00P02o`@01_l<00;o
2@02o`D00_l900;o2@02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6`02o`/01olE00;o3P02o`X0
1ol700Ko5`02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o
2`07o`X01?l<00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo2@02o`T00_l200;o0P02o`@0
1Ol:00Oo6@02o``00_lK00;o2@07oaL00_l>00;o2P05o`T01_lH00;o0`02oa@00_l00`3oo`02o`03
0?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2P06o`/00ol<00;o5P02o`030?oo0080
00Co0?oo1002o`800_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`040?ooo`P0
0olN00;o1`02o`<00_l300;o5P02o`P00olL00;o3P02o`X00_l0103oool800;o0P02oaP00_l300;o
5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T0
0_l400;o3002o`/00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o
1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l800;o
1`000ol0000C00;o3P02o`X00_l200?o1`02o`800_l200;o5@02o`040?oooa<00_l300;o0`02o`@0
0_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol700;o
1P02o``00_l:00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o
1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o3P02o`X00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o
1P02o`H00_lH00005@02o`L00_l600;o3002o`T00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l800?o
1003oaD00_l>00;o2P02o`@00ol500;o1P02oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o
1@02o`H00_l600;o600001H00_l600?o1003o`H00_l300?o2002oaL01?l500Co00<0ool02_l300co
0`04o`<01?l400[o1004o`801_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00[o1@09oa802?l700[o
1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003
o`0000D02?l700Oo2@000ol0000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko
00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`L01Ol00`3o000A00So1`0:o`@01Ol300Go
00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008006o`X0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "See also the QuickTime movie ",
  StyleBox["Weasel-50-5-0.1.movie",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  " in the directory \[RightGuillemet]Movies\[LeftGuillemet]. The first \
parameter indicates the population size (50), the second and third parameters \
denote mutation radius (1) and mutation rate (0.1), respectively."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Experiment 3:\n\[Dash] 50 individuals, mutation radius: 1, mutation rate: \
0.5"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Iterated selection and mutation", "Subsubsection"],

Cell["We define an objective sentence.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(weaselSentence = encodeSentence["\<METHINKS IT IS LIKE A WEASEL.\>"]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 73, 
      75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We start an evolution experiment with a population size of ",
  StyleBox["m=50",
    FontSlant->"Italic"],
  ", that is, we will have 30 individual sentences per generation. Mutations \
are applied with a probability of ",
  StyleBox["\[Mu]=0.5",
    FontSlant->"Italic"],
  ", the mutation radius is set to ",
  StyleBox["\[Rho]=1",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveSentences[weaselSentence, 50, 1, .5]\)], "Input"],

Cell["\<\
0: Min.: 2137
RSMLASLNSSYOQBIPTCGUAUTBRMJU
1: Min.: 2055
RTNLBSLNTSXOQBJOTCFUAUUBRMIU
2: Min.: 1935
RSMLBSKNTSXNPCJOSDFVAVUCRMIT
3: Min.: 1850
QRLLBSKNTSXOPDJOSEFVAVUBRMIT
4: Min.: 1730
QRLMBRJNTRXPPEJORFFUBVVCQMJT
5: Min.: 1622
QRMLARJNUQWQPEJORGFVBWVDQMIT
6: Min.: 1521
QQNLBQJNUPWPPFJOQGFVAWWEQMIT
7: Min.: 1407
QQNMBQJNVPWQPFKOPFFVAXXEPMIS
8: Min.: 1337
QQOLCQKNVPVQPFKNPFFVAYWEPMHR
9: Min.: 1249
QQOLCPLNVOVRPGLMOEFVAYWEQNHQ
10: Min.: 1165
QPOLCOLOVOVRPHLMNEFVAXWEPNHR
11: Min.: 1097
QOOLDPLOWOVRPHLLNFGWBWWEPOHQ
12: Min.: 1022
QNOLDOLOWOVSPHMKNFFWBWVDPPHQ
13: Min.: 953
QNOLDOLPWNVSPIMJOFFXBXWDOPHQ
14: Min.: 882
PNOLDOKPWMVSOINJOFFYBYVDOPGQ
15: Min.: 829
ONOLDOKPWMWSOJNKOFFYAZVDNPGQ
16: Min.: 754
PMPLDOKPWMXSPKOKOGFYAYWDMPGQ
17: Min.: 718
OMPMEPKPWMXTQKOKNGGZAZWCLQHQ
18: Min.: 672
OMPLEOKOWMWUQKOKNGGZAYXCKPHP
19: Min.: 626
OMPLENLOWMXUQKPKNGG BZXDJPGP
20: Min.: 577
NMQLEMLOWNWTPKQKNFFZBZWDIQFP
21: Min.: 517
NMQLFMMPWNWTPLRJNGFZBZVDIRFO
22: Min.: 468
NLPLFNMPWMWTPLRJMHFZBZVDHRFO
23: Min.: 411
OLPLFNLPXMVUPLSJMHF AZVDGRFO
24: Min.: 376
OKOLFNLPYLWVPLSJLHF AZVEGRFN
25: Min.: 344
OKOKFNLPXLWWPLTKLIF AZWEGQFN
26: Min.: 295
OJOKGNKQXLVWPMUKLIGZAZWEGQFN
27: Min.: 264
OJOJHNLQXMVXPNUKLJGZAZXEFQFN
28: Min.: 241
PJPIHNLQXLUXPNULLJHYAZWEEQFM
29: Min.: 209
PIQJHMLPWLVXONVLLJHYAZWEDREM
30: Min.: 188
OIQJHMKPXLUXNNULLKGYAZVEDREM
31: Min.: 148
OIQJINJPXLUXMOVLKKGYA VDCRDL
32: Min.: 136
OJQJINJPXKUXLOWLKKFYA VCCRDL
33: Min.: 125
OKQJINJPYKTYKPWLKJFYA WCBQDK
34: Min.: 103
NKQJINKPYKTYKQWLJJFZA WDARDK
35: Min.: 89
NKQIINKPZKSYKRXKJJFZA WDARDK
36: Min.: 73
NJRJINKPZJRYJSXKIKEYB WDARDK
37: Min.: 57
NIRJINKQ JRYJSXKJLEZB WDARDK
38: Min.: 47
NHSJINJQZJRZJSXKJLEYB WDASEK
39: Min.: 42
MHTJINIQZJRZJSYLJLEYB WDASEK
40: Min.: 32
MHTJINJQZJR JSZLJLFZB WDASEL
41: Min.: 32
MGUJINJP KS IS KILFZB WDBREL
42: Min.: 31
NFTJIMJP JS IS KILFZC XDAREK
43: Min.: 23
NFTIIMJP IS IR LILFZB XEASFK
44: Min.: 16
NFTHIMJQ IT IR LILFZA XEATFK
45: Min.: 15
NFTHILKR IT IR MILFZA XEATFL
46: Min.: 14
MGTHIMLR IT IR LILF A XEBTFL
47: Min.: 10
MFUHIMLS IT IR MIKF A XEBSFL
48: Min.: 9
MFUHIMLT IT JR LIKF A WEASFL
49: Min.: 10
MFUHINMT IU IR LIKE A WEASFL
50: Min.: 11
METGJNMT IT IR LHJD A WEASEL
51: Min.: 11
MFUGKMLS IU IS LIKE A WEASFL
52: Min.: 9
MFUGKMKS IU IS LIKE A WEASEL
53: Min.: 9
MFTHKMKS IU IS LIKF A VEASEL
54: Min.: 9
NFTGJMKS IU IS LIJF A VEASEL
55: Min.: 10
NFTHIMKT IU ISZLIJF A VEASEM
56: Min.: 7
NFTHINKS IU IS LIKF AZWEASFM
57: Min.: 8
MEUHHOKR JT IS KIKE AZWEASFL
58: Min.: 8
LEUHHOKS IT IS KIKE A WDASFM
59: Min.: 9
LDTHHOKS IT IS LIKEZB WDASFM
60: Min.: 9
MDTGHOKS IT IR LILD A WDASFL
61: Min.: 9
METGHOKR HT IR LJKD A WDASEL
62: Min.: 7
MESHHNKR IT JS LJKD A WDASEL
63: Min.: 8
NETHHOKR IT IS LJKD AZWEASDL
64: Min.: 7
NETHIOKS IT IT KIKD AZWEASDL
65: Min.: 6
METHIOKS IT IT KIJD A WEASDL
66: Min.: 6
MDTHIOKS IT IT KIJD A WEASEL
67: Min.: 8
NDTHHNKS IT IT KHKD A WEAREL
68: Min.: 9
MDTHHMKS IT IT KILD A XEAREL
69: Min.: 10
MDTHIMKSZIT IT LHLD A WEARDM
70: Min.: 10
METIIMKS IT IT LILD B VEARDM
71: Min.: 9
METIIMKS HS IT LIKD A VEARDL
72: Min.: 11
NETIHNKS HS IS MHJD A VEASDL
73: Min.: 9
MDTHIMLS HS IS MIKD AZWEASDL
74: Min.: 9
MDTHJNLT HS IS MIKEZA WEATEL
75: Min.: 7
METIJNKS IT HS MIKEZA WEBTEL
76: Min.: 9
METIJNKS IUZHS MIKEZA WEBSDL
77: Min.: 9
MEUHINKSZIUZHS MIKEZA XEBSEL
78: Min.: 11
MDTIIMJSZITZIS MJKEZA XEBSEL
79: Min.: 10
METIIMJSZHT IS MJJEZA XEASEL
80: Min.: 9
MDTHIMKSZHS IS LIKEZAZWFAREL
81: Min.: 10
MDTGIMKSZHT ISZKIKE AZXFASEL
82: Min.: 8
METGHNKSZIT JRZLIJE A WFASEL
83: Min.: 10
METGHOKSYIT IRZLIJE A WEASEL
84: Min.: 9
NETGHNKSZIS JR LIJE A WFASEL
85: Min.: 7
NETHHNKS IS IR LIJEZA WFASEL
86: Min.: 8
NETHHNKS IS IR LIKDZA WFATEL
87: Min.: 8
METHHNKS IT IRZLJKD A WFATEM
88: Min.: 10
METIHMJS IT IRZLIKD A WFATEM
89: Min.: 9
METHHNJS IS ISZKIKE B WFATEM
90: Min.: 10
METHHNJS IS HT KHKF B WEASEM
91: Min.: 11
METHHNKS JS HT KILF A VFASEM
92: Min.: 12
MDTHINKS JS IT JILF A VEATEL
93: Min.: 10
NETHINKS JSZIS KIKF A VEBTDL
94: Min.: 9
NETHIMKS JSZIS LIKE B WEATDK
95: Min.: 9
METIIMJS JS IS LILE B WEATDL
96: Min.: 10
METIINKS JSZJR LILE B XEASDL
97: Min.: 8
METHINKS JS JSZLILE B XEASDL
98: Min.: 9
METHINJS JT IRZLIKE B XFBSDL
99: Min.: 11
NETHIOJT JT ISZKIKE A XFBSDL
100: Min.: 11
NEUHJOKS JT JSZLIKE A XFBSDL
101: Min.: 9
MFUHJOJS JT IS LIKE A WFBREL
102: Min.: 9
NFTHJOKSZJT IT LIKE A WEBSEK
103: Min.: 10
MFTGJOJSZIT IT LIJE A WEAREK
104: Min.: 12
NFTGJOJSZIT IT LIJE A WFAREK
105: Min.: 11
NESGJNKSZIT IT LIJE A WFARDK
106: Min.: 10
NESGJNKSZIU IT KIKE A WFASDL
107: Min.: 11
NESGJNKSZJT IT LIKE AZWEBTDL
108: Min.: 11
NDTGJNJS ITZIT LIKE AZWEBTDL
109: Min.: 9
METGJNJT IS IT LIKEZA WEBTEL
110: Min.: 9
METGINJT IS IT LIJE A WFBTEL
111: Min.: 9
METGINJT ISZIS LIKE A VFBTEL\
\>", "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitness plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0152295 0.00858001 0.0130578 0.00027621 [
[(20)] .18683 .01306 0 2 Msboxa
[(40)] .35843 .01306 0 2 Msboxa
[(60)] .53003 .01306 0 2 Msboxa
[(80)] .70163 .01306 0 2 Msboxa
[(100)] .87323 .01306 0 2 Msboxa
[(500)] .00273 .15116 1 0 Msboxa
[(1000)] .00273 .28927 1 0 Msboxa
[(1500)] .00273 .42737 1 0 Msboxa
[(2000)] .00273 .56548 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18683 .01306 m
.18683 .01931 L
s
P
[(20)] .18683 .01306 0 2 Mshowa
p
.002 w
.35843 .01306 m
.35843 .01931 L
s
P
[(40)] .35843 .01306 0 2 Mshowa
p
.002 w
.53003 .01306 m
.53003 .01931 L
s
P
[(60)] .53003 .01306 0 2 Mshowa
p
.002 w
.70163 .01306 m
.70163 .01931 L
s
P
[(80)] .70163 .01306 0 2 Mshowa
p
.002 w
.87323 .01306 m
.87323 .01931 L
s
P
[(100)] .87323 .01306 0 2 Mshowa
p
.001 w
.04955 .01306 m
.04955 .01681 L
s
P
p
.001 w
.08387 .01306 m
.08387 .01681 L
s
P
p
.001 w
.11819 .01306 m
.11819 .01681 L
s
P
p
.001 w
.15251 .01306 m
.15251 .01681 L
s
P
p
.001 w
.22115 .01306 m
.22115 .01681 L
s
P
p
.001 w
.25547 .01306 m
.25547 .01681 L
s
P
p
.001 w
.28979 .01306 m
.28979 .01681 L
s
P
p
.001 w
.32411 .01306 m
.32411 .01681 L
s
P
p
.001 w
.39275 .01306 m
.39275 .01681 L
s
P
p
.001 w
.42707 .01306 m
.42707 .01681 L
s
P
p
.001 w
.46139 .01306 m
.46139 .01681 L
s
P
p
.001 w
.49571 .01306 m
.49571 .01681 L
s
P
p
.001 w
.56435 .01306 m
.56435 .01681 L
s
P
p
.001 w
.59867 .01306 m
.59867 .01681 L
s
P
p
.001 w
.63299 .01306 m
.63299 .01681 L
s
P
p
.001 w
.66731 .01306 m
.66731 .01681 L
s
P
p
.001 w
.73595 .01306 m
.73595 .01681 L
s
P
p
.001 w
.77027 .01306 m
.77027 .01681 L
s
P
p
.001 w
.80459 .01306 m
.80459 .01681 L
s
P
p
.001 w
.83891 .01306 m
.83891 .01681 L
s
P
p
.001 w
.90755 .01306 m
.90755 .01681 L
s
P
p
.001 w
.94187 .01306 m
.94187 .01681 L
s
P
p
.001 w
.97619 .01306 m
.97619 .01681 L
s
P
p
.002 w
0 .01306 m
1 .01306 L
s
P
p
.002 w
.01523 .15116 m
.02148 .15116 L
s
P
[(500)] .00273 .15116 1 0 Mshowa
p
.002 w
.01523 .28927 m
.02148 .28927 L
s
P
[(1000)] .00273 .28927 1 0 Mshowa
p
.002 w
.01523 .42737 m
.02148 .42737 L
s
P
[(1500)] .00273 .42737 1 0 Mshowa
p
.002 w
.01523 .56548 m
.02148 .56548 L
s
P
[(2000)] .00273 .56548 1 0 Mshowa
p
.001 w
.01523 .04068 m
.01898 .04068 L
s
P
p
.001 w
.01523 .0683 m
.01898 .0683 L
s
P
p
.001 w
.01523 .09592 m
.01898 .09592 L
s
P
p
.001 w
.01523 .12354 m
.01898 .12354 L
s
P
p
.001 w
.01523 .17878 m
.01898 .17878 L
s
P
p
.001 w
.01523 .2064 m
.01898 .2064 L
s
P
p
.001 w
.01523 .23403 m
.01898 .23403 L
s
P
p
.001 w
.01523 .26165 m
.01898 .26165 L
s
P
p
.001 w
.01523 .31689 m
.01898 .31689 L
s
P
p
.001 w
.01523 .34451 m
.01898 .34451 L
s
P
p
.001 w
.01523 .37213 m
.01898 .37213 L
s
P
p
.001 w
.01523 .39975 m
.01898 .39975 L
s
P
p
.001 w
.01523 .45499 m
.01898 .45499 L
s
P
p
.001 w
.01523 .48262 m
.01898 .48262 L
s
P
p
.001 w
.01523 .51024 m
.01898 .51024 L
s
P
p
.001 w
.01523 .53786 m
.01898 .53786 L
s
P
p
.001 w
.01523 .5931 m
.01898 .5931 L
s
P
p
.002 w
.01523 0 m
.01523 .61803 L
s
P
P
.004 w
.02381 .60332 m
.03239 .58067 L
.04097 .54752 L
.04955 .52405 L
.05813 .4909 L
.06671 .46107 L
.07529 .43317 L
.08387 .40169 L
.09245 .38235 L
.10103 .35804 L
.10961 .33484 L
.11819 .31606 L
.12677 .29534 L
.13535 .27629 L
.14393 .25668 L
.15251 .24204 L
.16109 .22132 L
.16967 .21138 L
.17825 .19867 L
.18683 .18597 L
.19541 .17243 L
.20399 .15586 L
.21257 .14232 L
.22115 .12658 L
.22973 .11691 L
.23831 .10807 L
.24689 .09454 L
.25547 .08598 L
.26405 .07962 L
.27263 .07079 L
.28121 .06499 L
.28979 .05394 L
.29837 .05062 L
.30695 .04758 L
.31553 .04151 L
.32411 .03764 L
.33269 .03322 L
.34127 .0288 L
.34985 .02604 L
.35843 .02466 L
.36701 .0219 L
.37559 .0219 L
.38417 .02162 L
.39275 .01941 L
.40133 .01748 L
.40991 .0172 L
.41849 .01692 L
.42707 .01582 L
.43565 .01554 L
.44423 .01582 L
Mistroke
.45281 .0161 L
.46139 .0161 L
.46997 .01554 L
.47855 .01554 L
.48713 .01554 L
.49571 .01582 L
.50429 .01499 L
.51287 .01527 L
.52145 .01527 L
.53003 .01554 L
.53861 .01554 L
.54719 .01554 L
.55577 .01499 L
.56435 .01527 L
.57293 .01499 L
.58151 .01472 L
.59009 .01472 L
.59867 .01527 L
.60725 .01554 L
.61583 .01582 L
.62441 .01582 L
.63299 .01554 L
.64157 .0161 L
.65015 .01554 L
.65873 .01554 L
.66731 .01499 L
.67589 .01554 L
.68447 .01554 L
.69305 .0161 L
.70163 .01582 L
.71021 .01554 L
.71879 .01582 L
.72737 .01527 L
.73595 .01582 L
.74453 .01554 L
.75311 .01499 L
.76169 .01527 L
.77027 .01527 L
.77885 .01582 L
.78743 .01554 L
.79601 .01582 L
.80459 .0161 L
.81317 .01637 L
.82175 .01582 L
.83033 .01554 L
.83891 .01554 L
.84749 .01582 L
.85607 .01527 L
.86465 .01554 L
.87323 .0161 L
Mistroke
.88181 .0161 L
.89039 .01554 L
.89897 .01554 L
.90755 .01582 L
.91613 .01637 L
.92471 .0161 L
.93329 .01582 L
.94187 .0161 L
.95045 .0161 L
.95903 .01554 L
.96761 .01554 L
.97619 .01554 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06P000?l06P000?l06P000?l06P000?l0
6P0004801?l300;o9003o`<00_lT00;o1002ob@00_l400;o8003o`@00_l400;o6`0004<000?o0000
0P001?l00?lT0005o`000?l00P000ol0000P0004o`00o`8000Co003o8P001?l00?l20004o`00ob00
00?o00000P001?l00?l20004o`00oaX000140005o`000?l00P000ol0000P00Co0P001?l00?lR0004
o`00o`8000Co003o8P001?l00?l20004o`00ob0000?o00000P001?l00?l20004o`00oaX000150004
o`00o`8000?o000080000ol0o`030004o`00ob800ol30004o`00ob<00_l30004o`00ob0000?o0000
0P001?l00?l20004o`00oaX000120004o`00o`8000Co003o8P000ol0o`030004o`00ob8000?o0000
0`001?l00?lR0004o`00o`8000Co003o80000ol000020004o`00o`8000Co003o6P0004<00_l400;o
9002o`@00_lT00?o0`02ob@00_l400;o8002o`D00_l400;o6`000?l06P000?l06P0001/000?o0000
n`0001/000?o0000n`0001/000?o0000n`0001/000?o0000n`0001L0ool2o`40000K0003o`0000H0
00?o00001@000ol000060003o`0000H000?o00001P000ol000060003o`0000D000?o00001P000ol0
00060003o`0000H000?o00001@0;o`<01Ol80003o`0000H000?o00001P000ol000050003o`000080
0ol00`3o0002o`D000?o00001003o`<000?o00000P000ol000050004o`00o`<02?l30003o`3o00H0
0ol600co1@000ol0000500006`000ol0001F00OoWP0001/000?o0000DP04ojD0000K0003o`0004l0
0onY00006`000ol0001=00;o[00001/000?o0000B`02ojh0000K00;oB`000ol0002^00006`000ol0
00190003o`000:l0000K0003o`0004@01Onb00006`000ol000130003o`000;D0000K0003o`0004<0
00?o0000]@0001/000?o0000@P000ol0002f00006`000ol000110003o`000;L0000K00;o@@000ol0
002h00006`000ol0000o0003o`000;T0000K0003o`0003h000?o0000^P0001/000?o0000?002okd0
000K0003o`0003X00_no00006`000ol0000j0003o`000;h0000K0003o`0003T000?o0000_`0001/0
0_li0003o`000<00000K0003o`0003P000?o0000`00001/000?o0000=`000ol0003100006`000ol0
000f0003o`000<80000K0003o`0003D000?o0000``0001/000?o0000=0000ol0003400006`000ol0
000d0003o`000<@0000K00;o=0000ol0003500006`000ol0000b0003o`000<H0000K0003o`000380
00?o0000aP0001/000?o0000<@000ol0003700006`000ol0000`0003o`000<P0000700?o1002o`@0
0_l50003o`0002l000?o0000b@0000X000Co003o0P001?l00?l20003o`00008000?o0000;`000ol0
003900002P001?l00?l20004o`00o`8000?o00000P02obl000?o0000bP0000L00ol30004o`00o`80
00Co003o10000ol0000]0003o`000</000070003o`0000<000Co003o0P001?l00?l40003o`0002d0
00?o0000b`0000L01?l300;o1002o`D000?o0000;0000ol0003<00006`000ol0000/0003o`000<`0
000K0003o`0002`000?o0000c00001/000?o0000:`000ol0003=00006`02ob`000?o0000c@0001/0
00?o0000:P000ol0003>00006`000ol0000Y0003o`000<l0000K0003o`0002T000?o0000c`0001/0
00?o0000:0000ol0003@00006`000ol0000W0003o`000=40000K0003o`0002L000?o0000d@0001/0
0_lW0003o`000=80000K0003o`0002D000?o0000d`0001/000?o000090000ol0003D00006`000ol0
000S0003o`000=D0000K0003o`00028000?o0000eP0001/000?o00008P000ol0003F00006`000ol0
000Q0003o`000=L0000K00;o8P000ol0003G00006`000ol0000Q0003o`000=L0000K0003o`000200
00?o0000f00001/000?o000080000ol0003H00006`000ol0000P0003o`000=P0000K0003o`0001l0
00?o0000f@0001/000?o00007P000ol0003J00006`000ol0000N0003o`000=X0000K00;o7P000ol0
003K00006`000ol0000M0003o`000=/0000K0003o`0001d000?o0000f`0001/000?o000070000ol0
003L00006`000ol0000L0003o`000=`00000103oool400;o1002o`@00_l50003o`0001/000?o0000
g@00008000?o00000P001?l00?l20004o`00o`8000Co003o10000ol0000J0003o`000=h000020003
o`00008000Co003o0P001?l00?l20004o`00o`@00_lK0003o`000=h000020003o`00008000Co003o
0P001?l00?l20004o`00o`@000?o00006@000ol0003O00000P000ol000020004o`00o`8000Co003o
0P001?l00?l40003o`0001T000?o0000g`0000030?oo00D00_l400;o1002o`D000?o000060000ol0
003P00006`000ol0000H0003o`000>00000K0003o`0001P000?o0000h00001/000?o00005`000ol0
003Q00006`02oaP000?o0000h@0001/000?o00005`000ol0003Q00006`000ol0000F0003o`000>80
000K0003o`0001H000?o0000hP0001/000?o00005@000ol0003S00006`000ol0000E0003o`000><0
000K0003o`0001@000?o0000i00001/00_lE0003o`000>@0000K0003o`0001@000?o0000i00001/0
00?o00004`000ol0003U00006`000ol0000C0003o`000>D0000K0003o`0001<000?o0000i@0001/0
00?o00004`000ol0003U00006`000ol0000B0003o`000>H0000K00;o4`000ol0003V00006`000ol0
000B0003o`000>H0000K0003o`00014000?o0000i`0001/000?o00004@000ol0003W00006`000ol0
000A0003o`000>L0000K0003o`00010000?o0000j00001/000?o00003`000ol0003Y00006`02o`l0
00?o0000jP0001/000?o00003P000ol0003Z00006`000ol0000>0003o`000>X0000K0003o`0000d0
00?o0000j`0001/000?o00003@000ol0003[000000@0oooo0`03o`@00_l400;o1@000ol0000=0003
o`000>/000020003o`0000D000Co003o0P001?l00?l20003o`00008000?o00003@000ol0003[0000
0P000ol000050004o`00o`8000Co003o0P000ol0000200;o3P000ol0003[00000P000ol0000200?o
0`001?l00?l20004o`00o`@000?o000030000ol0003/00000P000ol000020003o`0000<000Co003o
0P001?l00?l40003o`0000`000?o0000k00000030?oo00@01?l300;o1002o`D000?o000030000ol0
003/00006`000ol0000<0003o`000>`0000K0003o`0000/000?o0000k@0001/000?o00002`000ol0
003]00006`02o``000?o0000k@0001/000?o00002P000ol0003^00006`000ol0000:0003o`000>h0
000K0003o`0000X000?o0000kP0001/000?o00002P000ol0003^00006`000ol000090003o`000>l0
000K0003o`0000T000?o0000k`0001/00_l:0003o`000>l0000K0003o`0000P000?o0000l00001/0
00?o000020000ol0003`00006`000ol000080003o`000?00000K0003o`0000P000?o0000l00001/0
00?o00001`000ol0003a00006`000ol000070003o`000?40000K00;o20000ol0003a00006`000ol0
00070003o`000?40000K0003o`0000L000?o0000l@0001/000?o00001P000ol0003b00006`000ol0
00060003o`000?80000K0003o`0000H000?o0000lP0001/000?o00001@000ol0003c00006`02o`H0
00?o0000l`0001/000?o000010000ol0003d00006`000ol000040003o`000?@0000K0003o`0000<0
00?o0000m@0001/000?o00000`000ol0003e000000<0ool00_l300;o1002o`@00_l50003o`0000<0
00?o0000m@00008000?o00000P001?l00?l20004o`00o`8000Co003o10000ol000020003o`000?H0
00030005o`000?l00P001?l00?l20004o`00o`8000?o00000P02o`<000?o0000mP0000@000Co003o
0P001?l00?l20004o`00o`8000?o00000P000ol000020003o`000?H000001@3o003o008000Co003o
0P001?l00?l20004o`00o`@000?o00000P000ol0003f00000P02o`@00_l400;o1002o`D000Go0000
o`3i00006`001Ol0003o0?T0000K0005o`000?l0n@0001/000Co003onP0001/000Co003onP0001/0
0_l00`3o003i00006`000ol0o`3k00006`000ol0o`3k00006`000ol0003k00006`000ol0003k0000
6`000ol0003k00006`000ol0003k0000o`0J0000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-12.3652, -230.146, 0.45449, 
  14.118}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] {{40, 100}, {0, 20}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.666667 0.0166667 0 0.0309017 [
[(50)] .16667 0 0 2 Msboxa
[(60)] .33333 0 0 2 Msboxa
[(70)] .5 0 0 2 Msboxa
[(80)] .66667 0 0 2 Msboxa
[(90)] .83333 0 0 2 Msboxa
[(100)] 1 0 0 2 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(2.5)] -0.0125 .07725 1 0 Msboxa
[(5)] -0.0125 .15451 1 0 Msboxa
[(7.5)] -0.0125 .23176 1 0 Msboxa
[(10)] -0.0125 .30902 1 0 Msboxa
[(12.5)] -0.0125 .38627 1 0 Msboxa
[(15)] -0.0125 .46353 1 0 Msboxa
[(17.5)] -0.0125 .54078 1 0 Msboxa
[(20)] -0.0125 .61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(50)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(60)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(70)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(80)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(90)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(100)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .07725 m
.00625 .07725 L
s
P
[(2.5)] -0.0125 .07725 1 0 Mshowa
p
.002 w
0 .15451 m
.00625 .15451 L
s
P
[(5)] -0.0125 .15451 1 0 Mshowa
p
.002 w
0 .23176 m
.00625 .23176 L
s
P
[(7.5)] -0.0125 .23176 1 0 Mshowa
p
.002 w
0 .30902 m
.00625 .30902 L
s
P
[(10)] -0.0125 .30902 1 0 Mshowa
p
.002 w
0 .38627 m
.00625 .38627 L
s
P
[(12.5)] -0.0125 .38627 1 0 Mshowa
p
.002 w
0 .46353 m
.00625 .46353 L
s
P
[(15)] -0.0125 .46353 1 0 Mshowa
p
.002 w
0 .54078 m
.00625 .54078 L
s
P
[(17.5)] -0.0125 .54078 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(20)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .01545 m
.00375 .01545 L
s
P
p
.001 w
0 .0309 m
.00375 .0309 L
s
P
p
.001 w
0 .04635 m
.00375 .04635 L
s
P
p
.001 w
0 .0618 m
.00375 .0618 L
s
P
p
.001 w
0 .09271 m
.00375 .09271 L
s
P
p
.001 w
0 .10816 m
.00375 .10816 L
s
P
p
.001 w
0 .12361 m
.00375 .12361 L
s
P
p
.001 w
0 .13906 m
.00375 .13906 L
s
P
p
.001 w
0 .16996 m
.00375 .16996 L
s
P
p
.001 w
0 .18541 m
.00375 .18541 L
s
P
p
.001 w
0 .20086 m
.00375 .20086 L
s
P
p
.001 w
0 .21631 m
.00375 .21631 L
s
P
p
.001 w
0 .24721 m
.00375 .24721 L
s
P
p
.001 w
0 .26266 m
.00375 .26266 L
s
P
p
.001 w
0 .27812 m
.00375 .27812 L
s
P
p
.001 w
0 .29357 m
.00375 .29357 L
s
P
p
.001 w
0 .32447 m
.00375 .32447 L
s
P
p
.001 w
0 .33992 m
.00375 .33992 L
s
P
p
.001 w
0 .35537 m
.00375 .35537 L
s
P
p
.001 w
0 .37082 m
.00375 .37082 L
s
P
p
.001 w
0 .40172 m
.00375 .40172 L
s
P
p
.001 w
0 .41717 m
.00375 .41717 L
s
P
p
.001 w
0 .43262 m
.00375 .43262 L
s
P
p
.001 w
0 .44807 m
.00375 .44807 L
s
P
p
.001 w
0 .47898 m
.00375 .47898 L
s
P
p
.001 w
0 .49443 m
.00375 .49443 L
s
P
p
.001 w
0 .50988 m
.00375 .50988 L
s
P
p
.001 w
0 .52533 m
.00375 .52533 L
s
P
p
.001 w
0 .55623 m
.00375 .55623 L
s
P
p
.001 w
0 .57168 m
.00375 .57168 L
s
P
p
.001 w
0 .58713 m
.00375 .58713 L
s
P
p
.001 w
0 .60258 m
.00375 .60258 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.07381 .61803 m
.08333 .49443 L
s
.08333 .49443 m
.1 .46353 L
.11667 .43262 L
.13333 .30902 L
.15 .27812 L
.16667 .30902 L
.18333 .33992 L
.2 .33992 L
.21667 .27812 L
.23333 .27812 L
.25 .27812 L
.26667 .30902 L
.28333 .21631 L
.3 .24721 L
.31667 .24721 L
.33333 .27812 L
.35 .27812 L
.36667 .27812 L
.38333 .21631 L
.4 .24721 L
.41667 .21631 L
.43333 .18541 L
.45 .18541 L
.46667 .24721 L
.48333 .27812 L
.5 .30902 L
.51667 .30902 L
.53333 .27812 L
.55 .33992 L
.56667 .27812 L
.58333 .27812 L
.6 .21631 L
.61667 .27812 L
.63333 .27812 L
.65 .33992 L
.66667 .30902 L
.68333 .27812 L
.7 .30902 L
.71667 .24721 L
.73333 .30902 L
.75 .27812 L
.76667 .21631 L
.78333 .24721 L
.8 .24721 L
.81667 .30902 L
.83333 .27812 L
.85 .30902 L
.86667 .33992 L
.88333 .37082 L
.9 .30902 L
Mistroke
.91667 .27812 L
.93333 .27812 L
.95 .30902 L
.96667 .24721 L
.98333 .27812 L
1 .33992 L
Mfstroke
1 .33992 m
1 .33992 L
s
s
s
s
s
s
s
s
s
s
s
s
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06`000?l06`000?l06`000?l06`0003h0
0ol400;o8@02o`@00_lQ0003o`0000<00_lQ00;o1002ob000ol400;o7@03o`@00_l400;o0`000440
00Co003o0P000ol0000M0004o`00o`8000Co003o80000ol000020004o`00oal000Co003o0P001?l0
0?lR0004o`00o`8000?o00006`000ol000020004o`00o`8000Co003o0P00044000Co003o0P000ol0
000M0004o`00o`8000Co003o8@001Ol0003o008000?o00007@001?l00?l20004o`00ob000ol20004
o`00oad000?o00000P001?l00?l20004o`00o`80000n00?o0`001?l00?lO00?o0`001?l00?lQ0005
o`000?l00P000ol0000N00;o0`001?l00?lO0004o`00o`8000Co003o7@000ol000020004o`00o`80
00Co003o0P0003h000?o00000`001?l00?lO0003o`0000<000Co003o8P001?l00?l20003o`0001d0
00Co003o0P001?l00?lO0004o`00o`8000Co003o7@000ol000020004o`00o`8000Co003o0P0003h0
1?l300;o8@03o`<00_lP00Co0`02ob400_l400;o8@02o`@00_lM00;o1@02o`@00_l30000o`0K0000
o`0K0000o`0K0000o`0K00005002ool01@0001<000Co003oo`0400004`001?l00?l40?Ko2@0001<0
00Co003o10000ol000050003o`0000D000?o00001@000ol000050003o`0000D000?o00001P000ol0
00050003o`0000D000?o00001@000ol000050003o`0000D000?o00001P000ol000050003o`0000D0
00?o00001@000ol000050003o`0000D000?o00001P000ol000050003o`0000D000?o00001@000ol0
00050003o`0000D000?o00001P000ol000050003o`0000D000?o00001@000ol000050003o`0000D0
00?o00001P000ol0000700004`001?l00?l40003o`0002D000?o00009P000ol0000V0003o`0002H0
00?o00009P000ol0000V0003o`0000L0000D00;o1@000ol0003l00006`000ol0003l00006`000ol0
003l00006`000ol0003l00006`000ol0003l00006`000ol0003l00006`000ol0003l00006`000ol0
003l00006`000ol0003l00006`000ol0003l00006`000ol0003l00006`000ol0003l00006`000ol0
003l00006`000ol0003l00001`04o`<00_l300?o1@000ol0003l000020000ol0000300;o1P000ol0
00020003o`000?`000090003o`0000X000?o00000P02ood0000:0003o`0000H00ol50003o`000?`0
00070004o`00o`P000?o00001@000ol0003l00002002o`T01?l40003o`000?`0000K0003o`000?`0
000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0
000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0000K0003o`000?`0
000K0003o`000?`0000K0003o`000?`0000C00?o1@000ol0003l00005P000ol000020003o`000?`0
000F0003o`0000800_om00004`03o`D000?o0000o00001<000?o00001@000ol0003l00004`04o`@0
00?o0000o00001/000?o0000o00001/000?o0000o00001/000?o0000o00001/000?o0000o00001/0
00?o0000I`05oi00000K0003o`0006L000Go0000o`2@00006`000ol0001V0003o`00008000?o0000
SP0001/000?o0000IP000ol000030003o`0008d0000K0003o`0006D000?o000010000ol0002=0000
6`000ol0001T0003o`0000D000?o0000S@0001/000?o0000I0000ol000050003o`0008d0000K0003
o`00048000?o00005@000ol000060003o`0000L000?o000080000ol0000U0003o`000440000K0003
o`00048000?o00005@000ol000060003o`0000L000?o000080000ol0000U0003o`00044000080003
o`0000<00_l300?o1@000ol0001200;o5P02o`H000?o000020000ol0000O00;o9`02od8000080003
o`0000<00_l60003o`00008000?o0000@P02oaD000Co003o1@000ol000090003o`0001h000?o0?l0
9@000ol0o`1200002@000ol0000:0003o`0000800_m20004o`00oa@000Co003o10000ol0000:0003
o`0001h000?o0?l09@001?l00?m100002@000ol0000700?o1@000ol000110004o`00oa@000Go0000
o`030003o`0000X000?o00007@001?l00?lU0004o`00od40000:0003o`0000H000?o00001@000ol0
00110005o`000?l04`001Ol0003o008000?o00002`000ol0000M0004o`00obD000Go0000o`100000
1`04o`P01?l40003o`00044000Go0000o`0B0003o`0000<000?o0?l03P000ol0000L0005o`000?l0
8`000ol000020003o`0003h0000K0003o`00044000?o00000P05o`d000?o000010000ol0000=0003
o`0001/000?o00000P000ol0000G0003o`0000L000?o00000`06obL000?o0000400001/000?o0000
@@000ol000060003o`0000/000?o000050000ol0000K0003o`00008000?o00005`000ol000070003
o`0000P000?o00009@000ol0000@00006`000ol000100003o`0000P000?o00002@000ol0000F0003
o`0001X000?o00000`000ol0000F0003o`0000H000?o00002@000ol0000U00;o4@0001/000?o0000
@0000ol000080003o`0000T000?o00005P000ol0000I0003o`0000@000?o00005@000ol0o`070003
o`0000X000?o00008`000ol0o`0A00006`000ol000100003o`0000T000?o000020000ol0000G0003
o`0001P000?o000010000ol0000E0003o`3o00L000?o00002P000ol0000S0004o`00oa00000K0003
o`00040000?o00002P000ol000070003o`0001P000?o00005`000ol000040003o`0001D000?o0?l0
1`000ol0000:0003o`0002<000Go0000o`0?00006`000ol000100003o`0000X000?o00001P000ol0
000I0003o`0001H000?o00001P000ol0000D0003o`3o00H000?o00002`000ol0000S0005o`000?l0
3`0001/000?o00008@000ol0000>00Wo10000ol0000<00Wo70000ol000090003o`0000D01Ol800Go
2`000ol000030005o`000?l01@000ol0000<0003o`0000<000?o00004@05o`D000?o00000`000ol0
000<00006`000ol0000Q0003o`0000h000?o00001@000ol000020003o`00034000?o00002@000ol0
00050003o`0000h000?o00002@000ol000030005o`000?l01@000ol0000<0003o`0000<000?o0000
4@001Ol0003o00D000?o00000`000ol0000<00006`000ol0000P0003o`3o00l000?o00001P001Ol0
003o03@000?o00001`02o`L000?o00003P000ol000080003o`3o00@000Go0000o`040003o`0000d0
00?o00000P000ol0o`0A0003o`0000<000?o00000P000ol000030003o`0000`0000K0003o`000200
00?o0?l03P000ol000070005o`000?l0=0000ol000070003o`3o00D000?o000040000ol000070003
o`3o00<000?o00000`001Ol0003o010000Oo0000o`3o014000?o00000`001Ol0003o00L000?o0000
2`0001/000?o00007`001Ol0003o00d000?o000020001?l00?le0003o`0000D000Co003o1@000ol0
000@0003o`0000H000Go0000o`020003o`0000<000Co003o4@001?l00?l30003o`0000d000?o0000
1@001?l00?l70003o`0000/0000K0003o`0001l000Go0000o`0=0003o`0000P000Co003o=@000ol0
00050004o`00o`D000?o000040000ol000060005o`000?l00P000ol000030004o`00oa4000Co003o
0`000ol0000=0003o`0000D000Co003o1`000ol0000;00003@03o`@00_l50003o`0001h000?o0000
0`000ol0000:0003o`0000T00_lg0003o`0000<000Go0000o`050003o`00010000?o00001@000ol0
00030003o`3o00D000?o0?l04P000ol0o`050003o`0000/000?o00001`000ol0o`080003o`0000X0
000>0003o`00008000Co003o10000ol0000N0003o`0000<000?o00002@000ol0000:00;o=`000ol0
00030003o`00008000Go0000o`0D0003o`0000@000?o00000`02o`L00_lC00;o1@000ol0000;0003
o`0000L00_l90003o`0000X0000>0003o`00008000Co003o1002oah000?o00001@000ol000080003
o`0000/000?o0000=P05o`D000Go0000o`0D0003o`0000<000?o00001@000ol000050003o`000180
00?o00001@000ol000090003o`0000T000?o00001`000ol0000:00003P000ol000020004o`00o`@0
00?o00007@000ol000050003o`0000P000?o0000CP001Ol0003o01@000?o00000`000ol0000Z0003
o`0000T000?o000050000ol0000900003P000ol000020004o`00o`@000?o00007@000ol000060003
o`0000L000?o0000CP001Ol0003o01@000?o00000P000ol0000/0003o`0000P000?o000050000ol0
000900003@02o`D00_l50003o`0001d000?o00001P000ol000060003o`00050000?o0?l05P001Ol0
003o02h000?o00001`000ol0000E0003o`0000T0000K0003o`0001d000?o00001`000ol000050003
o`00050000?o0?l05P001?l00?l`0003o`0000H000?o00005P000ol0000800006`000ol0000L0003
o`0000P000?o00001@000ol0001@0003o`3o01H000Co003o<0000ol000060003o`0001H000?o0000
200001/000?o000070000ol000090003o`0000@000?o0000D0000ol0o`0F0003o`3o038000?o0000
1@000ol0000F0003o`0000P0000K0003o`0001`000?o00002@000ol000030003o`00058000?o0000
5P02oc8000?o000010000ol0000H0003o`0000L0000K0003o`0001`000?o00002P06oe@000?o0000
5P000ol0000b0003o`0000<000?o000060000ol0000700006`000ol0000L0003o`000;8000?o0000
0`000ol0000R00006`000ol0000L0003o`000;<000Go0000o`0U00006`000ol0000L0003o`000;<0
00Go0000o`0U00006`000ol0000K0003o`000;D000Co003o9@0001/000?o00006`000ol0002f0003
o`3o02D0000K0003o`0001/000?o0000]P02obH0000K0003o`0001/000?o0000]`000ol0000T0000
6`000ol0000K0003o`000=h00000103oool300Co0`02o`<00ol50003o`0001/000?o0000gP000080
00?o00000`000ol0000300;o1P000ol000020003o`0001/000?o0000gP00008000?o000010000ol0
000:0003o`0000800_lL0003o`000=h000020003o`0000D000?o00001P03o`D000?o00006P000ol0
003O00000P000ol000020004o`00o`P000?o00001@000ol0000J0003o`000=l000000`3oo`0500;o
2@04o`@000?o00006P000ol0003O00006`000ol0000J0003o`000=l0000K0003o`0001X000?o0000
g`0001/000?o00006P000ol0003O00006`000ol0000J0003o`000=l0000K0003o`0001T000?o0000
h00001/000?o00006@000ol0003P00006`000ol0000I0003o`000>00000K0003o`0001T000?o0000
h00001/000?o00006@000ol0003P00006`000ol0000H0003o`000>40000K0003o`0001P000?o0000
h@0001/000?o00005`000ol0003R00006`000ol0000G0003o`000>80000=00?o0`03o`D000?o0000
5P000ol0003S00003P000ol000050003o`00008000?o00005P000ol0003S00003P000ol000050003
o`0000800_lF0003o`000>@0000>0003o`0000800ol50003o`0001D000?o0000i00000h000?o0000
0P000ol000050003o`0001@000?o0000i@0000d00_l400Co10000ol0000D0003o`000>D0000K0003
o`0001<000?o0000iP0001/000?o00004P000ol0003W00006`000ol0000B0003o`000>L0000K0003
o`00014000?o0000j00001/000?o00004@000ol0003X00006`000ol0000A0003o`000>P0000K0003
o`00014000?o0000j00001/000?o00004@000ol0003X00006`000ol0000A0003o`000>P0000K0003
o`00014000?o0000j00001/000?o00004@000ol0003X00006`000ol0000A0003o`000>P0000K0003
o`00010000?o0000j@0000040?ooo`@000?o00000`02o`<00ol50003o`00010000?o0000j@000080
00?o00000`000ol0000300;o1P000ol000020003o`00010000?o0000j@00008000?o000010000ol0
000:0003o`0000800_lA0003o`000>T000020003o`0000@000?o00001`03o`D000?o000040000ol0
003Y00000P000ol000050003o`0000H000?o00001@000ol0000@0003o`000>T000000`3oo`0400Co
2004o`@000?o000040000ol0003Y00006`000ol0000@0003o`000>T0000K0003o`00010000?o0000
j@0001/000?o000040000ol0003Y00006`000ol0000@0003o`000>T0000K0003o`00010000?o0000
j@0001/000?o000040000ol0003Y00006`000ol0000@0003o`000>T0000K0003o`00010000?o0000
j@0001/000?o00003`000ol0003Z00006`000ol0000?0003o`000>X0000K0003o`0000l000?o0000
jP0001/000?o00003`000ol0003Z00006`000ol0000?0003o`000>X0000=00Co0`02o`D000?o0000
3`000ol0003Z00003P000ol000020004o`00o`@000?o00003`000ol0003Z00003`001Ol0003o0080
00?o00000P02oa0000?o0000jP00010000Co003o0P000ol0003o0080000=0004o`00o`8000Co003o
o`0400003P02o`@00_oo00D0003o01/0003o01/00000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {33.3706, -2.08895, 0.244962, 
  0.132119}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sentences overview", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[interpretSentence/@bestSentences]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("RSMLASLNSSYOQBIPTCGUAUTBRMJU"\)},
          {\("RTNLBSLNTSXOQBJOTCFUAUUBRMI      U"\)},
          {\("RSMLBSKNTSXNPCJOSDFVAVUCRMIT"\)},
          {\("QRLLBSKNTSXOPDJOSEFVAVUBRMIT"\)},
          {\("QRLMBRJNTRXPPEJORFFUBVVCQMJT"\)},
          {\("QRMLARJNUQWQPEJORGFVBWVDQMIT"\)},
          {\("QQNLBQJNUPWPPFJOQGFVAWWEQMIT"\)},
          {\("QQNMBQJNVPWQPFKOPFFVAXXEPMIS"\)},
          {\("QQOLCQKNVPVQPFKNPFFVAYWEPMHR"\)},
          {\("QQOLCPLNVOVRPGLMOEFVAYWEQNHQ"\)},
          {\("QPOLCOLOVOVRPHLMNEFVAXWEPNHR"\)},
          {\("QOOLDPLOWOVRPHLLNFGWBWWEPOHQ"\)},
          {\("QNOLDOLOWOVSPHMKNFFWBWVDPPHQ"\)},
          {\("QNOLDOLPWNVSPIMJOFFXBXWDOPHQ"\)},
          {\("PNOLDOKPWMVSOINJOFFYBYVDOPGQ"\)},
          {\("ONOLDOKPWMWSOJNKOFFYAZVDNPGQ"\)},
          {\("PMPLDOKPWMXSPKOKOGFYAYWDMPGQ"\)},
          {\("OMPMEPKPWMXTQKOKNGGZAZWCLQHQ"\)},
          {\("OMPLEOKOWMWUQKOKNGGZAYXCKPHP"\)},
          {\("OMPLENLOWMXUQKPKNGG BZXDJPGP"\)},
          {\("NMQLEMLOWNWTPKQKNFFZBZWDIQFP"\)},
          {\("NMQLFMMPWNWTPLRJNGFZBZVDIRFO"\)},
          {\("NLPLFNMPWMWTPLRJMHFZBZVDHRFO"\)},
          {\("OLPLFNLPXMVUPLSJMHF AZVDGRFO"\)},
          {\("OKOLFNLPYLWVPLSJLHF AZVEGRFN"\)},
          {\("OKOKFNLPXLWWPLTKLIF AZWEGQFN"\)},
          {\("OJOKGNKQXLVWPMUKLIGZAZWEGQFN"\)},
          {\("OJOJHNLQXMVXPNUKLJGZAZXEFQFN"\)},
          {\("PJPIHNLQXLUXPNULLJHYAZWEEQFM"\)},
          {\("PIQJHMLPWLVXONVLLJHYAZWEDREM"\)},
          {\("OIQJHMKPXLUXNNULLKGYAZVEDREM"\)},
          {\("OIQJINJPXLUXMOVLKKGYA VDCRDL"\)},
          {\("OJQJINJPXKUXLOWLKKFYA VCCRDL"\)},
          {\("OKQJINJPYKTYKPWLKJFYA WCBQDK"\)},
          {\("NKQJINKPYKTYKQWLJJFZA WDARDK"\)},
          {\("NKQIINKPZKSYKRXKJJFZA WDARDK"\)},
          {\("NJRJINKPZJRYJSXKIKEYB WDARDK"\)},
          {\("NIRJINKQ JRYJSXKJLEZB WDARDK"\)},
          {\("NHSJINJQZJRZJSXKJLEYB WDASEK"\)},
          {\("MHTJINIQZJRZJSYLJLEYB WDASEK"\)},
          {\("MHTJINJQZJR JSZLJLFZB WDASEL"\)},
          {\("MGUJINJP KS IS KILFZB WDBREL"\)},
          {\("NFTJIMJP JS IS KILFZC XDAREK"\)},
          {\("NFTIIMJP IS IR LILFZB XEASFK"\)},
          {\("NFTHIMJQ IT IR LILFZA XEATFK"\)},
          {\("NFTHILKR IT IR MILFZA XEATFL"\)},
          {\("MGTHIMLR IT IR LILF A XEBTFL"\)},
          {\("MFUHIMLS IT IR MIKF A XEBSFL"\)},
          {\("MFUHIMLT IT JR LIKF A WEASFL"\)},
          {\("MFUHINMT IU IR LIKE A WEASFL"\)},
          {\("METGJNMT IT IR LHJD A WEASEL"\)},
          {\("MFUGKMLS IU IS LIKE A WEASFL"\)},
          {\("MFUGKMKS IU IS LIKE A WEASEL"\)},
          {\("MFTHKMKS IU IS LIKF A VEASEL"\)},
          {\("NFTGJMKS IU IS LIJF A VEASEL"\)},
          {\("NFTHIMKT IU ISZLIJF A VEASEM"\)},
          {\("NFTHINKS IU IS LIKF AZWEASFM"\)},
          {\("MEUHHOKR JT IS KIKE AZWEASFL"\)},
          {\("LEUHHOKS IT IS KIKE A WDASFM"\)},
          {\("LDTHHOKS IT IS LIKEZB WDASFM"\)},
          {\("MDTGHOKS IT IR LILD A WDASFL"\)},
          {\("METGHOKR HT IR LJKD A WDASEL"\)},
          {\("MESHHNKR IT JS LJKD A WDASEL"\)},
          {\("NETHHOKR IT IS LJKD AZWEASDL"\)},
          {\("NETHIOKS IT IT KIKD AZWEASDL"\)},
          {\("METHIOKS IT IT KIJD A WEASDL"\)},
          {\("MDTHIOKS IT IT KIJD A WEASEL"\)},
          {\("NDTHHNKS IT IT KHKD A WEAREL"\)},
          {\("MDTHHMKS IT IT KILD A XEAREL"\)},
          {\("MDTHIMKSZIT IT LHLD A WEARDM"\)},
          {\("METIIMKS IT IT LILD B VEARDM"\)},
          {\("METIIMKS HS IT LIKD A VEARDL"\)},
          {\("NETIHNKS HS IS MHJD A VEASDL"\)},
          {\("MDTHIMLS HS IS MIKD AZWEASDL"\)},
          {\("MDTHJNLT HS IS MIKEZA WEATEL"\)},
          {\("METIJNKS IT HS MIKEZA WEBTEL"\)},
          {\("METIJNKS IUZHS MIKEZA WEBSDL"\)},
          {\("MEUHINKSZIUZHS MIKEZA XEBSEL"\)},
          {\("MDTIIMJSZITZIS MJKEZA XEBSEL"\)},
          {\("METIIMJSZHT IS MJJEZA XEASEL"\)},
          {\("MDTHIMKSZHS IS LIKEZAZWFAREL"\)},
          {\("MDTGIMKSZHT ISZKIKE AZXFASEL"\)},
          {\("METGHNKSZIT JRZLIJE A WFASEL"\)},
          {\("METGHOKSYIT IRZLIJE A WEASEL"\)},
          {\("NETGHNKSZIS JR LIJE A WFASEL"\)},
          {\("NETHHNKS IS IR LIJEZA WFASEL"\)},
          {\("NETHHNKS IS IR LIKDZA WFATEL"\)},
          {\("METHHNKS IT IRZLJKD A WFATEM"\)},
          {\("METIHMJS IT IRZLIKD A WFATEM"\)},
          {\("METHHNJS IS ISZKIKE B WFATEM"\)},
          {\("METHHNJS IS HT KHKF B WEASEM"\)},
          {\("METHHNKS JS HT KILF A VFASEM"\)},
          {\("MDTHINKS JS IT JILF A VEATEL"\)},
          {\("NETHINKS JSZIS KIKF A VEBTDL"\)},
          {\("NETHIMKS JSZIS LIKE B WEATDK"\)},
          {\("METIIMJS JS IS LILE B WEATDL"\)},
          {\("METIINKS JSZJR LILE B XEASDL"\)},
          {\("METHINKS JS JSZLILE B XEASDL"\)},
          {\("METHINJS JT IRZLIKE B XFBSDL"\)},
          {\("NETHIOJT JT ISZKIKE A XFBSDL"\)},
          {\("NEUHJOKS JT JSZLIKE A XFBSDL"\)},
          {\("MFUHJOJS JT IS LIKE A WFBREL"\)},
          {\("NFTHJOKSZJT IT LIKE A WEBSEK"\)},
          {\("MFTGJOJSZIT IT LIJE A WEAREK"\)},
          {\("NFTGJOJSZIT IT LIJE A WFAREK"\)},
          {\("NESGJNKSZIT IT LIJE A WFARDK"\)},
          {\("NESGJNKSZIU IT KIKE A WFASDL"\)},
          {\("NESGJNKSZJT IT LIKE AZWEBTDL"\)},
          {\("NDTGJNJS ITZIT LIKE AZWEBTDL"\)},
          {\("METGJNJT IS IT LIKEZA WEBTEL"\)},
          {\("METGINJT IS IT LIJE A WFBTEL"\)},
          {\("METGINJT ISZIS LIKE A VFBTEL"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"RSMLASLNSSYOQBIPTCGUAUTBRMJU", "RTNLBSLNTSXOQBJOTCFUAUUBRMI      U", 
        "RSMLBSKNTSXNPCJOSDFVAVUCRMIT", "QRLLBSKNTSXOPDJOSEFVAVUBRMIT", 
        "QRLMBRJNTRXPPEJORFFUBVVCQMJT", "QRMLARJNUQWQPEJORGFVBWVDQMIT", 
        "QQNLBQJNUPWPPFJOQGFVAWWEQMIT", "QQNMBQJNVPWQPFKOPFFVAXXEPMIS", 
        "QQOLCQKNVPVQPFKNPFFVAYWEPMHR", "QQOLCPLNVOVRPGLMOEFVAYWEQNHQ", 
        "QPOLCOLOVOVRPHLMNEFVAXWEPNHR", "QOOLDPLOWOVRPHLLNFGWBWWEPOHQ", 
        "QNOLDOLOWOVSPHMKNFFWBWVDPPHQ", "QNOLDOLPWNVSPIMJOFFXBXWDOPHQ", 
        "PNOLDOKPWMVSOINJOFFYBYVDOPGQ", "ONOLDOKPWMWSOJNKOFFYAZVDNPGQ", 
        "PMPLDOKPWMXSPKOKOGFYAYWDMPGQ", "OMPMEPKPWMXTQKOKNGGZAZWCLQHQ", 
        "OMPLEOKOWMWUQKOKNGGZAYXCKPHP", "OMPLENLOWMXUQKPKNGG BZXDJPGP", 
        "NMQLEMLOWNWTPKQKNFFZBZWDIQFP", "NMQLFMMPWNWTPLRJNGFZBZVDIRFO", 
        "NLPLFNMPWMWTPLRJMHFZBZVDHRFO", "OLPLFNLPXMVUPLSJMHF AZVDGRFO", 
        "OKOLFNLPYLWVPLSJLHF AZVEGRFN", "OKOKFNLPXLWWPLTKLIF AZWEGQFN", 
        "OJOKGNKQXLVWPMUKLIGZAZWEGQFN", "OJOJHNLQXMVXPNUKLJGZAZXEFQFN", 
        "PJPIHNLQXLUXPNULLJHYAZWEEQFM", "PIQJHMLPWLVXONVLLJHYAZWEDREM", 
        "OIQJHMKPXLUXNNULLKGYAZVEDREM", "OIQJINJPXLUXMOVLKKGYA VDCRDL", 
        "OJQJINJPXKUXLOWLKKFYA VCCRDL", "OKQJINJPYKTYKPWLKJFYA WCBQDK", 
        "NKQJINKPYKTYKQWLJJFZA WDARDK", "NKQIINKPZKSYKRXKJJFZA WDARDK", 
        "NJRJINKPZJRYJSXKIKEYB WDARDK", "NIRJINKQ JRYJSXKJLEZB WDARDK", 
        "NHSJINJQZJRZJSXKJLEYB WDASEK", "MHTJINIQZJRZJSYLJLEYB WDASEK", 
        "MHTJINJQZJR JSZLJLFZB WDASEL", "MGUJINJP KS IS KILFZB WDBREL", 
        "NFTJIMJP JS IS KILFZC XDAREK", "NFTIIMJP IS IR LILFZB XEASFK", 
        "NFTHIMJQ IT IR LILFZA XEATFK", "NFTHILKR IT IR MILFZA XEATFL", 
        "MGTHIMLR IT IR LILF A XEBTFL", "MFUHIMLS IT IR MIKF A XEBSFL", 
        "MFUHIMLT IT JR LIKF A WEASFL", "MFUHINMT IU IR LIKE A WEASFL", 
        "METGJNMT IT IR LHJD A WEASEL", "MFUGKMLS IU IS LIKE A WEASFL", 
        "MFUGKMKS IU IS LIKE A WEASEL", "MFTHKMKS IU IS LIKF A VEASEL", 
        "NFTGJMKS IU IS LIJF A VEASEL", "NFTHIMKT IU ISZLIJF A VEASEM", 
        "NFTHINKS IU IS LIKF AZWEASFM", "MEUHHOKR JT IS KIKE AZWEASFL", 
        "LEUHHOKS IT IS KIKE A WDASFM", "LDTHHOKS IT IS LIKEZB WDASFM", 
        "MDTGHOKS IT IR LILD A WDASFL", "METGHOKR HT IR LJKD A WDASEL", 
        "MESHHNKR IT JS LJKD A WDASEL", "NETHHOKR IT IS LJKD AZWEASDL", 
        "NETHIOKS IT IT KIKD AZWEASDL", "METHIOKS IT IT KIJD A WEASDL", 
        "MDTHIOKS IT IT KIJD A WEASEL", "NDTHHNKS IT IT KHKD A WEAREL", 
        "MDTHHMKS IT IT KILD A XEAREL", "MDTHIMKSZIT IT LHLD A WEARDM", 
        "METIIMKS IT IT LILD B VEARDM", "METIIMKS HS IT LIKD A VEARDL", 
        "NETIHNKS HS IS MHJD A VEASDL", "MDTHIMLS HS IS MIKD AZWEASDL", 
        "MDTHJNLT HS IS MIKEZA WEATEL", "METIJNKS IT HS MIKEZA WEBTEL", 
        "METIJNKS IUZHS MIKEZA WEBSDL", "MEUHINKSZIUZHS MIKEZA XEBSEL", 
        "MDTIIMJSZITZIS MJKEZA XEBSEL", "METIIMJSZHT IS MJJEZA XEASEL", 
        "MDTHIMKSZHS IS LIKEZAZWFAREL", "MDTGIMKSZHT ISZKIKE AZXFASEL", 
        "METGHNKSZIT JRZLIJE A WFASEL", "METGHOKSYIT IRZLIJE A WEASEL", 
        "NETGHNKSZIS JR LIJE A WFASEL", "NETHHNKS IS IR LIJEZA WFASEL", 
        "NETHHNKS IS IR LIKDZA WFATEL", "METHHNKS IT IRZLJKD A WFATEM", 
        "METIHMJS IT IRZLIKD A WFATEM", "METHHNJS IS ISZKIKE B WFATEM", 
        "METHHNJS IS HT KHKF B WEASEM", "METHHNKS JS HT KILF A VFASEM", 
        "MDTHINKS JS IT JILF A VEATEL", "NETHINKS JSZIS KIKF A VEBTDL", 
        "NETHIMKS JSZIS LIKE B WEATDK", "METIIMJS JS IS LILE B WEATDL", 
        "METIINKS JSZJR LILE B XEASDL", "METHINKS JS JSZLILE B XEASDL", 
        "METHINJS JT IRZLIKE B XFBSDL", "NETHIOJT JT ISZKIKE A XFBSDL", 
        "NEUHJOKS JT JSZLIKE A XFBSDL", "MFUHJOJS JT IS LIKE A WFBREL", 
        "NFTHJOKSZJT IT LIKE A WEBSEK", "MFTGJOJSZIT IT LIJE A WEAREK", 
        "NFTGJOJSZIT IT LIJE A WFAREK", "NESGJNKSZIT IT LIJE A WFARDK", 
        "NESGJNKSZIU IT KIKE A WFASDL", "NESGJNKSZJT IT LIKE AZWEBTDL", 
        "NDTGJNJS ITZIT LIKE AZWEBTDL", "METGJNJT IS IT LIKEZA WEBTEL", 
        "METGINJT IS IT LIJE A WFBTEL", "METGINJT ISZIS LIKE A VFBTEL"}]]], 
  "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation ...", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MapIndexed[
      Show[Graphics[
            Text["\<(\>"<>ToString[First[#2]]<>"\<) \>"<>
                interpretSentence[#1], {0, 0}], 
            DefaultFont \[Rule] {"\<Courier\>", 24}], 
          AspectRatio \[Rule] .1]&, bestSentences]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(1\\) RSMLASLNSSYOQBIPTCGUAUTBRMJU)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002olH00_l400?ol@0001`00_lJ00;oa@0:oo00
000K00;o7002olD01Ol200;ol00001/00_lL00;oa@000ol0003f00006`02o`T02Ol:00;o5@05o`H0
0ol0103oo`05o`D01Ol300Go0P0Co`<01_l200;o00<0ool00ol500go0P06o`<00_l400;o00<0ool0
0ol600;o00<0ool00ol800So2005o`T01Ol600[o1@0:o`@02?l800So2005o`X01_l900Co1@06o`<0
1_l500Co1`08o`D02_l400Go1P03o`030?oo00?o0`05o`<01_l;00Co700001X00_l:00Wo2`02oa@0
1Ol500Co00<0ool02?l300Go0`05o`804ol300Ko0P0:o`<03Ol200Ko0P03o`@02_l400[o1P08o`H0
2Ol500Wo100;o`@02_l400So2008o`H02Ol600[o1@08o`<01_l300Ko0`08o`D02?l500_o0`05o`D0
1?l00`3oo`03o`<01Ol00`3oo`07o`P02?lJ00006P02o`h00_l>00;o5P02o`D00ol300?o1@03o`<0
0_l700;o1P02o`H00_l200;o1`02o`@00ol500?o1@02o`H00_l300;o1004o`@00ol500?o0`03o`D0
0ol800;o2003o`D00ol300?o1@03o`D00_l500?o1`02o`X00_l?00;o2003o`D00ol400Co1@02o`D0
0_l400;o1@02o`L00_l500;o1002o`P00_l:00;o1@03o`@00_l500?o1002o`L00_l200?o1003o`L0
0_l400;o6P0001X00_l>00;o3P02oaH00_l500;o1002o`L00_l300;o1`02o`H00_l600;o0P02o`L0
0_l400;o1`02o`D00_l600;o0`02o`@01?l400;o1`02o`<00_l700;o2002o`P00_l700;o0`02o`L0
0_l500;o1P02o`L00_l:00;o3`02o`P00_l700;o1002o`L00_l400;o1P02o`@00_l700;o1002o`H0
0_l700;o2P02o`H00_l400;o1@02o`D00_l700;o0P02o`H00_l600;o1P02oaT0000J00;o3P02o`h0
0_lF00;o1002o`D00_l700;o0`02o`<00_l200;o1P02o`H00_l200_o1002o`L00_l500;o1P02o`<0
0_l300Go1002o`L00_l300;o1`02o`P00_l700;o2@02o`030?oo00T00_l400;o1P02o`L00_l:00;o
3`02o`L00ol<00?o1`02o`@00_l600;o100;o`@00_l600;o1`02o`X00_l600;o1002o`@00_l600;o
0`02o`800_l200;o1P02o`H00_l600;o6@0001X00_l>00;o3P02oaH00_l300?o3@03o`<00_l200?o
0P02o`H00_l600;o0`09o`d00ol500;o1P02o`<00_l300;o00<0ool03003o`/00ol800;o1`02o`T0
0_l00`3oo`0900;o1002o`H00_l700;o2P07o`X00_l700;o3@02o`@01ol300;o1P02o`D02Ol500;o
1P02o`L00_l:00;o1P02o`@00_l300?o1P02o`800ol200;o0P02o`H00_l600;o1P02oaT0000J00;o
3P02o`h00_lF00Oo2@07o`@00_l20003o`3o00800_l600;o2`02o`D00_l800Oo1P02o`/00_l200?o
00<0ool01`07o`L01ol900?o1P02o`T00_l00`3oo`0900;o1002o`D00ol700;o2P09o`P00_l700;o
3@02o`@01ol300;o1P02o`D00_l500;o1@02o`H00_l700;o2P02o`D00ol400Oo1`02o`8000?o0?l0
0P02o`X00_l600;o1P02oaT0000J00;o3P02o`h00_lF00Wo1@07o`H00_l0103oo`02o`030?oo00H0
0_l<00;o0`02o`L01ol800;o2`02o`800_l200;o1@07o`L01ol:00Co1P02o`T00_l00`3oo`0900;o
1009o`P00_l:00;o1@03o`L00_l700;o3@02o`h00_l600;o1P02o`<00_l600;o1P02o`L00_l:00Wo
1@09o`D00_l0103oo`02o`030?oo00X00_l600;o1P02oaT0000K00;o3@02o`d00_lG00;o1@03o`<0
0ol;00;o00<0ool00P001?l0ool600;o3002o`<00_l600?o3@02o`/00_l00`3oo`0300;o1003o`/0
0ol>00Ko1@02o`T00_l00`3oo`0900;o1008o`T00_l:00;o1P02o`800_l300;o0`02o`800_l=00;o
3P02o`H00_l600;o0`02o`H00_l600;o0P02o`<00_l300;o1@08o`H00_l500?o1002o`030?oo0080
00Co0?oo2P02o`H00_l600;o6@0001/00_l=00;o3@02oaL00_l600;o0`02o`L000?o00000P02o`03
0?l0008000Co0?oo1P02o`d00_l0103oool600;o1`000ol0000400;o2`05o`<00_l400;o1`000ol0
000200;o1`000ol0000500;o0P02o`D00_l900;o00@0oooo2002o`@00_l400?o2002o`X00_l600;o
0P02o`<00_l300;o0P03o`L00_l300;o2002o`@00_l600;o1`02o`040?ooo`H00_l600;o0P02o`<0
0_l300;o1@02o`@00ol500;o1P02o`@00_l00`3o00020004o`3oo`X00_l600;o1P02oaT0000K00?o
3002o`d00_lG00;o1P02o`<00_l600;o1004o`<01?l600;o3@02o`030?oo00L00_l600;o1P02o`/0
1?l400;o1002o`H00_l400;o1P02o`H00ol300;o1@02o`L00_l300;o1`02o`D00_l500;o2002o`X0
0_l600;o0P02o`<00_l300;o0`02o`L00_l400;o1P03o`@00_l600;o1`02o`030?oo00L00_l600;o
0P02o`<00_l300;o1@02o`D00_l500;o1P02o`@01?l300Co2P02o`H00_l600;o6@0001`00_l<00;o
3002oaP00_l500?o0`03o`@00ol400Co1003o`H00_l=00Go1`03o`@00ol600;o2`04o`@00_l400?o
1003o`@00ol400?o1P02o`@00_l500?o1@03o`@00_l500;o1P02o`@00ol800;o2P02o`D00ol200;o
0`02o`<00_l300?o1@03o`@00ol400Co1002o`H00_l700Go1`02o`H00_l200;o0`02o`<00_l500;o
1003o`D00_l500?o1004o`@00ol:00;o1P02o`H00_lI00007@02o`L00ol00`3oo`0;00;o5`0;o`D0
2Ol300Co1@04o`802?l700Oo2@09o`<02?l700Co0P06o`@02Ol500Wo1005o`801Ol400Wo1@09o`@0
2_l500[o100;o`<03?l400[o1@0:o`<01?l400Co0`07o`L01?l400Co00<0ool02_l300[o100;o`@0
1?l500Co100:o`801?l400Co600001h000?o00001@06o`/000?o00005P09o`T01Ol00`3o000200Co
1@04o`802?l700Oo2`05o`030?l000802?l700?o0`06o`H01Ol00`3o000600Go00<0o`000`05o`80
1Ol600Go2@05o`H02Ol600[o1009o`D03?l600Go00<0ool01`05o`030?oo00<01?l400Co0`07o`L0
1?l400Co00<0ool02_l300Wo1@09o`H01?l500Co100:o`801?l400Co600002T00ooo0<h0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(2\\) RTNLBSLNTSXOQBJOTCFUAUUBRMIU)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002olH00_l400?ol@0001`00_lJ00;oa@0:oo00
000K00;o7002olD01Ol200;ol00001/00_lL00;oa@000ol0003f00006`02o`P02_l:00;o5@05o`H0
0ol200So1@06o`<00_l300go00<0ool02?l600;o00<0ool00ol500go0P06o`<00_l500So1@02o`03
0?oo00?o1P05o`801Ol600Go2@05o`H02_l600Ko2`05o`L02?l800Go1P07o``01?l500Ko0`06o`D0
1?l:00Co1P0:o`@01Ol600?o00<0ool00ol300Go0P0:o`P01?lL00006P02o`T02_l;00;o5005o`D0
1?l200So1@06o`800ol300go00<0ool02Ol500[o0`0=o`801_l200?o1@08o`D02_l400Go0P05o`@0
2Ol500Wo100;o`<02Ol800Wo1@08o`H02Ol400Oo2P08o`<01_l300Ko0`08o`H02?l400_o0`05o`D0
1?l00`3oo`03o`<01Ol200[o1P08oaX0000J00;o2P02o`D00_l;00;o5P02o`D00ol700;o2@02o`@0
1?l600;o1P02o`<00_l500?o1003o`D00ol500;o1P02o`<00_l400Co2002o`P00ol500?o1003o`@0
0ol400?o1@03o`<00ol500?o1@02o`D00ol200?o1003o`H00ol500?o1`02o`P00ol500?o1@02o`d0
0_l400;o1@02o`L00_l500;o1002o`H00_l400;o1P02o`D00ol400;o1@03o`@00_l700;o1`02o`X0
0_l400;o6P0001X00_l;00?o4002oaH00_l500;o2002o`T00_l400Co1P02o`H00_l300;o1P02o`@0
0_l700;o1@02o`H00_l300;o1004o`P00_l800;o1`02o`D00ol200?o1@02o`L00_l300;o1`02o`D0
0_l600;o0P02o`H00_l600;o1`02o`L00_l800;o1`02o`D00_l<00;o1P02o`@00_l700;o1002o`H0
0_l400;o1P02o`D00_l600;o1002o`D00_l500;o1`02o`L00_l900;o1P02oaT0000J00;o3003o`l0
0_lF00;o1002o`T00_l900;o0`05o`H00_l600;o0`02o`H00_l400;o1`02o`D00_l600;o0`02o`<0
1Ol800;o2002o`L00_l600;o0P02o`D00_l900;o00<0ool02@02o`@00_l600;o0P02o`H00_l500;o
2@02o`H00_l700?o3P02o`800_l800;o1P02o`@02ol400;o1P02o`@00_l600;o1@02o`H00_l400;o
1002o`H00_l300;o0P02o`L00_l900;o1P02oaT0000J00;o3@03o`h00_lF00;o0`03o`T00_l900;o
0`02o`030?oo00H00_l600;o0`02o`H00_l<00?o1@02o`H00_l300;o0`02o`030?oo00P00_l@00?o
1`04o`H00_l900;o00<0ool02@02o`@00_l600;o0P02o`H00_l500;o2@02o`H00_l700;o3`02o`80
0_l800;o1P02o`D02Ol500;o1P02o`@00_l600;o1@02o`H00_l400;o0`03o`H00_l200?o0P02o`L0
0_l900;o1P02oaT0000J00;o3P03o`d00_lF00Oo2P02o`T00_l200?o00<0ool01P02o`/00_l500?o
1`07o`H00_l;00;o0P03o`030?oo00P00_l;00Oo2004o`H00_l900;o00<0ool02@02o`@00_l500?o
2P02o`D00_l900;o1P02o`L00_l?00Ko2002o`H00_l500;o1@02o`D00_l600;o1002o`H00_l500;o
1@03o`@01ol700;o0P000ol0o`0200;o1`02o`T00_l600;o6@0001X00_l?00?o3002oaH02Ol800;o
2@02o`800_l200;o1P02o`/02Ol600Oo2002o`/00_l200;o0P02o`P00_l900Oo2P03o`L00_l900;o
00<0ool02@02o`@02Ol;00;o1@02o`T00_l600;o1`02o`l01_l800;o1P02o`H00_l300;o1P02o`H0
0_l400;o1P02o`D02Ol500Wo1@02o`040?oo00;o00<0ool01`02o`T00_l600;o6@0001/00_l?00;o
2`02oaL00_l500?o0P02o`<00_l300;o1002o`030?oo00<00_l600;o2`08o`H00ol=00;o2`02o`03
0?oo00<00_l300;o0`02o`<00_l300?o3`04o`H00_l900;o00<0ool02@02o`@02?l<00;o1@02o`T0
0_l00`3oo`0300;o0`02o`800_l?00;o0P02o`P00_l600;o1P02o`<00_l600;o1P02o`@00_l600;o
1@08o`H00_l500?o1002o`030?oo008000Co0?oo1`02o`T00_l600;o6@0001/00_l@00;o2P02oaL0
0_l600;o0P02o`<00_l300;o1005o`<00_l600;o2`02o`@00ol500;o1`000ol0000400;o2`05o`<0
0_l300;o0`02o`<00_l300;o1`000ol0000500Ko1@02o`T00_l0103oool800;o1002o`@00ol;00;o
1@02o`T00_l00`3oo`0300;o0`02o`800ol700;o1@02o`800_l200;o1002o`H00_l700;o00@0oooo
1P02o`H00_l400;o1P02o`D00_l400?o1@02o`H00_l400;o00<0o`000P001?l0ool700;o2@02o`H0
0_lI00006`03o`l00_l:00;o5`02o`H00_l200;o0`02o`<00_l400Co1002o`H00_l;00;o1@02o`D0
0_l600;o1P02o`/01?l400;o0`02o`<00_l300;o0`02o`H00_l600?o0P03o`D00_l700;o0`02o`L0
0_l500;o1@02o`/00_l600;o1`02o`800_l300;o0`02o`<00_l700;o1@02o`H00_l400;o1P02o`L0
0_l00`3oo`0700;o1P02o`@00_l600;o1@02o`D00_l500;o1P02o`@01?l300Co1`02o`T00_l600;o
6@0001`00_l800;o1@02o`T00_lH00;o1@03o`800_l300;o0`02o`@01?l400;o1P02o`/00_l400?o
1@03o`@00ol600;o2`04o`@00_l300;o0`02o`<00_l300?o1003o`H00_l400;o1@03o`D00ol400;o
1@02o`H00_l400?o2`02o`H00ol500?o0P02o`<00_l300;o0`03o`D00ol500;o1P02o`@00_l600;o
1`05o`L00_l600;o1002o`H00_l500;o1003o`D00_l500?o1004o`@00ol700;o2@02o`H00_lI0000
7@02o`L00ol300?o2002oaL02ol300co0`04o`801_l200So1P0:o`L02Ol300So1`04o`801_l200co
1009o`@01Ol200Go1009o`D02Ol400[o1`0:o`@02Ol300co100:o`<03?l300Co1004o`<01ol700Co
1004o`801?l400Co0P0:o`@02ol400Co1@04o`802_l400Co1004oaP0000N0003o`0000H01ol90003
o`0001H02Ol500co0`03o`<01_l200So1P09o`X01Ol00`3o000200So1`03o`<01_l200co1P05o`03
0?l000<01Ol200Go1P05o`T01Ol600Wo200:o`H01Ol500co1P05o`030?oo00<03?l300Co1004o`<0
1ol700Co1004o`801?l400Co0P09o`D02Ol600Co1@04o`802_l400Co1004oaP0000X00Goo`3=0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(3\\) RSMLBSKNTSXNPCJOSDFVAVUCRMIT)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ool0`@0001`00_lJ00;oo`3000006`02oa`0
0_oo0;l0000K00;o7002ool0_`0001/00_l:00Go3@02oaD01Ol600?o00@0ool01Ol500Go0`05o`80
3Ol00`3oo`08o`H00_l00`3oo`03o`D01Ol600;o0P06o`<00_l500So1@02o`030?oo00?o1P05o`80
1Ol300Ko0`02o`802?l;00Go1`06o`/01Ol600;o00<0ool00ol600So1P07o``00_l700Ko0`06o`D0
0_l<00Co2P05o`D01Ol600?o00<0ool00ol300Go0P0:o`D02?lK00006P02o`T02Ol<00;o5005o`D0
1?l00`3oo`08o`<01Ol300Go0P0=o`030?oo00Wo1@0:o`<01Ol500?o0P06o`800ol500So1@0:o`@0
1Ol200Go0`06o`800ol200So2@09o`<02Ol800Wo100:o`@02_l400Oo2`04o`H01_l300Ko1004o`T0
2?l600Wo0`05o`D01?l00`3oo`03o`<01Ol200[o1@08oa/0000J00;o2@02o`D00_l<00;o5P02o`D0
0ol300?o1@03o`<00_l700;o1P02o`H00_l300;o1@03o`@00ol500?o1002o`D00ol400;o1004o`P0
0_l800?o1@03o`@00ol400?o1@02o`@01?l400;o3003o`D00ol200?o1003o`H00ol500?o0`03o`D0
0ol400;o1004o`D00_l>00Co2002o`L00_l600Co2@02o`@00_l500?o1@03o`@00_l500?o1002o`L0
0_l700;o3002oah0000J00;o4@02o`/00_lF00;o1@02o`@00_l700;o0`02o`L00_l600;o1P02o`<0
0_l600;o1002o`L00_l400;o1@02o`D00_l400Co2002o`P00_l700;o1@03o`800ol600;o1004o`@0
0_l<00;o1`02o`800_l600;o1P02o`L00_l300;o1`02o`@00_l600;o1@02o`h01?l800;o1`02o`H0
1?l800;o1P02o`@00_l700;o1002o`D00_l500;o1`02o`L00_l<00;o7P0001X00_lA00;o2`02oaH0
0_l400;o1@02o`L00_l300;o0`02o`800_l600;o1P02o`<00_l600;o1002o`L00_l400;o1002o`H0
0_l300Go2002o`P00_l700;o1P02o`800_l700;o0`05o`@00_l;00?o2`02o`H00_l500;o2@02o`80
0_l700;o1002o`L00_l400;o0P02o`T00_l200;o1`0;o`D00_l200;o1`02o`H00_l300?o3@02o`@0
0_l600;o0`02o`800_l700;o3002oah0000J00;o4@02o`/00_lF00;o0`03o`d00ol300;o0P03o`80
0_l600;o1P02o`<00_l600;o3003o`@00ol200?o1P02o`<00_l00`3oo`0800;o4003o`L01?l800;o
0`02o`030?oo00@01ol600;o3002o`H00_l500;o2@02o`X00ol400;o1`02o`@00_l200;o2@02o`80
0_l800Wo1P02o`800_l700;o1P02o`<00_l>00;o0`03o`H00_l200?o0P02o`L00_l<00;o7P0001X0
0_l@00;o3002oaH01ol900Oo1002o`8000?o0?l00P02o`H00_l;00;o1@03o`L01ol500Oo1`02o`80
0ol00`3oo`0800;o2`07o`P01?l800;o0P03o`030?oo00@02Ol400;o5002o`D00_l900;o1@07o`D0
0_l700;o1006o`P00ol200?o1`02o`D00_l500?o0P03o`H00_l600;o0`02o`h01ol700;o0P000ol0
o`0200;o1`02o``00_lN00006P02o`d01?l=00;o5P09o`D01ol600;o00@0ool00_l00`3oo`0600;o
2`09o`H01ol700Go2@02o`800_l200;o2002o`T01ol:00?o2@02o`800_l200;o1002o`D00ol300;o
5002o`D00_l900;o0`07o`L00_l700;o1006o`P00_l400;o2002o`<00_l600;o1002o`H00_l600;o
0`02o`h02Ol500;o00@0ool00_l00`3oo`0700;o3002oah0000K00;o3003o`d00_lG00;o1@03o`<0
0ol;00;o00<0ool00P001?l0ool600;o2`08o`H00ol<00;o00@0oooo2002o`030?oo00<00_l300;o
0`02o`<00_l300?o3`04o`P00_l00`3oo`0300;o1002o`H00_l300;o5002o`D00_l900;o0P03o``0
0_l700;o1002o`800_l800;o1002o`P00_l300;o1P02o`@00_l600;o1P02o`<00_l>00;o1@03o`@0
0_l00`3oo`020004o`3oo`L00_l700;o0`02o`<00_lI00006`02o`h00_l<00;o5`02o`H00_l300;o
1`000ol0000200;o00<0o`000P001?l0ool600;o2`02o`@00ol500;o1`000ol0000300;o0P03o`L0
1Ol300;o0`02o`<00_l300;o0`02o`L000?o00001@06o`L01Ol300;o1002o`H00_l300?o1`02o`X0
0_l500;o2@02o`800_l70003o`0000<00_l700;o1002o`800_l200;o0`02o`H00_l800;o00@0oooo
1@02o`H00_l500;o1P02o`<00ol700;o1002o`H00_l400;o00<0o`000P001?l0ool700;o1`02o`<0
0_l300;o6@0001/00ol>00;o2`02oaL00_l600;o0`02o`H00_l400Co0`04o`H00_l;00;o1@02o`D0
0_l600;o1@02o`<00ol600Co1002o`<00_l300;o0`02o`<00_l600;o1P03o`800ol600Co1002o`@0
0_l600;o1002o`L00_l:00;o1P02o`L00_l300;o1P02o`D00_l600;o1@02o`H00_l300;o1P02o`P0
0_l00`3oo`0600;o1P02o`D00_l600;o1002o`L00_l400;o1P02o`@01?l300Co1`02o`L00_l300;o
0`02oaT0000L00;o3P02o`X00_lH00;o1@03o`<00ol400?o1004o`@00ol600;o2`02o`@00ol500?o
1003o`D00_l400?o1@04o`@00_l300;o0`02o`<00_l300?o1003o`H00_l400;o1P04o`@00_l400;o
1@03o`@00ol500?o2P02o`H00ol500?o0`03o`@00ol500;o1004o`D00_l600;o0P03o`H00ol700Go
1@03o`H00ol400;o1P02o`@00ol500?o1002o`D00ol400Co1003o`L00_l700;o0`02o`<00_lI0000
7@02o`L00_l300?o2@02oaL02ol500Wo0`04o`D01?l200So1P0:o`L02Ol300Go0`05o`801?l200Ko
0P0<o`@02Ol400Go0P05o`<01?l200Ko00<0ool02Ol600[o1@0:o`@02Ol500Wo100:o`@03?l00`3o
o`04o`801_l300Oo1@06o`801_l200Co1004o`@02_l200_o1004o`D01?l200[o0`0<oaT0000N0003
o`0000D01ol:0003o`0001H02Ol900Go00<0o`000P04o`D01?l200So1P09o`X01Ol00`3o000200Go
0`05o`800ol300Ko0P0<o`H01Ol00`3o000300Go0P05o`<00ol300Ko00<0ool01ol:00Go00<0ool0
1@0:o`H01Ol900Go00<0o`000`08o`H03?l00`3oo`04o`801_l300Oo1@06o`801_l200Co1004o`H0
1Ol00`3oo`0200Wo1P04o`D01?l200[o0`0<oaT0000X00Coo`3>0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(4\\) QRLLBSKNTSXOPDJOSEFVAVUBRMIT)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?oo`2N00007002oaX00_lI00[o
o`2M00006`02oa`00_lI00Go0P02ool0W@0001/00_lL00;o6@000ol0003o0:<0000K00;o3006o`X0
0_lI00Go1@05o`H04?l200go00<0ool02?l600;o00<0ool00ol500Go1P02o`801_l300;o1@08o`D0
0_l00`3oo`03o`H01Ol200Go1P05o`D02?l800So1`06o`/01Ol600;o00<0ool00ol500co0`07o``0
0_l700Ko0`06o`D00_l<00Co1P0:o`@01Ol600?o00<0ool00ol300Go0P0:o`D02?lK00006P02o`d0
1_l;00;o5P09o`<01Ol5017o0P0=o`030?oo00Wo1@0:o`<01Ol500?o0P06o`800ol500So1@0:o`@0
1Ol200Go1009o`<02?l800[o0`09o`P02Ol400[o0`0<o`<01ol;00Co1P06o`<01_l400Co2@08o`@0
2ol300Go1@04o`030?oo00?o0`05o`802_l500So6`0001X00_l?00;o3@02oaD00ol500?o1002o`D0
0ol500;o1P02o`D00_l600;o0`02o`D00ol400?o1@03o`@00_l500?o1002o`@01?l800;o2003o`D0
0ol400?o1003o`@00ol500?o1002o`d00_l400Co0P03o`@00ol600?o1@03o`<00ol500?o1002o`H0
0_l500;o3P04o`P00_l700;o1P04o`T00_l400;o1P02o`D00ol400;o1@03o`@00_l700;o1`02o``0
0_lN00006P02o`l00_l=00;o5@02o`L00_l400;o1@02o`H00_l600;o1@02o`H00_l300;o1P02o`@0
0_l700;o1002o`D00_l500;o1004o`P00_l800;o1`02o`D00ol200?o1@02o`L00_l400;o3@02o`H0
0_l200;o1P02o`H00_l700;o0`02o`L00_l400;o1P02o`D00_l>00Co2002o`L00_l600Co2002o`H0
0_l500;o1P02o`@00_l500;o1@02o`L00_l700;o3002oah0000J00;o2@0:o`/00_lD00;o2@02o`<0
0_l400;o1`02o`H00_l500;o1P02o`<00_l600;o1002o`L00_l400;o1002o`H00_l300Go2002o`P0
0_l700;o1P02o`800_l500;o2@02o`<00_l=00;o1`02o`030?oo00H00_l500;o2@02o`800_l700;o
1002o`800_l200;o1@02o`800_l900;o0P02o`L02ol500;o0P02o`L00_l600;o1@02o`H00_l400;o
1002o`H00_l300;o0P02o`L00_l<00;o7P0001X00_l900[o2`02oa@00_l900;o0`02o`<00ol700;o
1P02o`D00_l600;o0`02o`H00_l<00?o1003o`800ol600;o0`02o`030?oo00P00_l@00?o1`04o`H0
0_l900;o0`07o`P00_l700;o00<0ool01P02o`D00_l900;o2P03o`@00_l200;o2@02o`800_l900;o
0P02o`P02Ol600;o0P02o`L00_l600;o1@02o`H00_l400;o0`03o`H00_l200?o0P02o`L00_l<00;o
7P0001X00_l900;o1002o`d00_lD00;o2@02o`<01ol800;o3@02o`/00_l500?o1`07o`D01ol700;o
0P03o`030?oo00P00_l;00Oo2004o`H00_l900;o0`09o`H00_l700;o2@02o`D00_l900;o1@07o`D0
1_l900Ko2003o`800ol700;o1@02o`D00ol200?o1P02o`H00_l500;o1@03o`@01ol700;o0P000ol0
o`0200;o1`02o``00_lN00006P02o`X00_l300;o3@02oa@00_l900;o0`09o`H00_l=00;o2`09o`H0
1ol700Go2@02o`800_l200;o2002o`T01ol:00?o1`02o`T00_l300;o1@03o`D00_l700;o2@02o`D0
0_l900;o0`07o`L01_l900Ko2002o`@00_l800;o0`02o`H00_l400;o1P02o`H00_l500Wo1@09o`D0
0_l0103oo`02o`030?oo00L00_l<00;o7P0001/00_l:0004o`0000;o3002oaD00_l900;o0`02o`D0
0ol500;o3@02o`/02?l600?o3002o`040?ooo`P00_l00`3oo`0300;o0`02o`<00_l300;o0`03o`l0
1?l600;o2@02o`<00_l600;o1@02o`L00_l900;o1@02o`T00_l200?o3002o`800_l900;o0P02o`P0
0_l400;o2002o`<00_l600;o1002o`H00_l600;o1@08o`H00_l500?o1002o`030?oo008000Co0?oo
1`02o`L00_l300;o0`02oaT0000K00;o2P02o`800_l<00;o5@03o`P00_l300;o1P02o`D00_l=00;o
2`02o`@00ol500;o1`000ol0000300;o0P03o`L01Ol300;o0`02o`<00_l300;o0`02o`L000?o0000
1@06o`D00_l900;o0`02o`H00_l500;o1`02o`T00_l500;o2@02o`800_l70003o`0000<00_l200;o
0P02o`D00_l200;o0P02o`<00_l600;o2002o`040?ooo`D00_l600;o1@02o`H00_l500;o1003o`D0
0_l600;o1002o`030?l0008000Co0?oo1`02o`L00_l300;o0`02oaT0000K00?o2P000ol00002o``0
0_lF00;o1`02o`@00_l600;o1@02o`d00_l;00;o1@02o`D00_l600;o1@02o`<00ol600Co1002o`<0
0_l300;o0`02o`<00_l600;o1P03o`800ol500;o1`02o`@00_l600;o1@02o`H00_l:00;o1P02o`L0
0_l300;o1P02o`D00_l600;o1@02o`H00_l300;o1P02o`P00_l00`3oo`0600;o1P02o`D00_l600;o
1@02o`D00_l500;o1P02o`@01?l300Co1`02o`L00_l300;o0`02oaT0000L00;o2`001?l0ool;00;o
6002o`D00_l500;o1@03o`D00_l=00;o2`02o`@00ol500?o1003o`D00_l400?o1@04o`@00_l300;o
0`02o`<00_l300?o1003o`H00_l400;o1@03o`D00ol400;o1@03o`D00_l400Co2P02o`H00ol500?o
0`03o`@00ol500;o1P02o`D00_l600;o0P03o`H00ol700Go1@03o`H00ol400;o1P02o`D00_l400?o
1@02o`D00ol400Co1003o`L00_l700;o0`02o`<00_lI00007@02o`X01?l:00;o6@09o`<02ol300So
1`08o`H02_l700Wo0`05o`<01Ol200Co0P06o`803?l400Wo1005o`801Ol400Wo0`0;o`D02_l600[o
1009o`D02Ol300co0`0<o`030?oo00Co0P06o`<01ol500Ko0P06o`801?l400Co0P0:o`@02ol400Co
1@04o`802_l300co6@0001h000?o00002@03o`X000?o00006P05o`D02Ol500So1`08o`H02Ol:00Go
00<0o`000P05o`<01Ol200?o0`06o`803?l600Go00<0o`000`05o`801Ol600Go1@09o`L02?l800[o
1P05o`T01Ol00`3o000200co0`0<o`030?oo00Co0P06o`<01ol500Ko0P06o`801?l400Co0P09o`D0
2Ol600Co1@04o`802_l300co6@0002X00ooo0<d0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(5\\) QRLMBRJNTRXPPEJORFFUBVVCQMJT)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?oo`1A00;o1003od@0000L00;o
6P02oaT02_oo05002_m300006`02oa`00_lI00Go0P02ool0D@05o`800_m300006`02oa`00_lI0003
o`000?l0E`000ol0001900006`02o`X01Ol=00;o6@05o`D01Ol6013o0P05o`<01Ol00`3oo`08o`D0
1Ol600?o0P06o`L01_l300;o1@08o`@01Ol600?o00<0ool00ol200Go0P08o`H02?l700co1006o`/0
1Ol500Go1P0:o`P01ol<00Co1P0:o`T00_l<00;o3005o`T01Ol600Go0`05o`<01_l800So6`0001X0
0_l900Wo3002oaH02Ol300Go1@0Ao`801Ol300Go00<0ool02Ol400Go1@0=o`H01_l200?o1@08o`@0
1Ol500Co00<0ool00ol200Go0P08o`H02?l700co0P09o`P02Ol300Go1@0;o`P01ol:00So100;o`L0
1?l:00Co2@09o`D02Ol400Go0`05o`030?oo00Oo1`08oa/0000J00;o2@02o`D00_l<00;o5@03o`D0
0ol400;o1@03o`D00_l600;o0`02o`L00_l400;o1@03o`D00_l500?o0P03o`@00ol600;o1004o`P0
0_l900;o1@03o`@00ol400?o1@02o``00_l=00;o1P02o`800ol400?o1P03o`D00ol400;o1@03o`@0
0_l=00;o3@02o`@00_l600;o1@03o`H01?l:00Co2003o`D00ol300?o1@03o`@00_l700;o0P03o`@0
0ol900;o7P0001X00_lA00;o2`02oaD00_l700;o1002o`D00_l600;o1P02o`<00_l700;o1002o`H0
0_l500;o1@02o`<00_l600;o1P02o`@01?l800;o2@02o`D00_l600?o0P03o`H00_l<00;o3@02o`H0
0_l200;o1P02o`H00_l700;o1002o`D00_l500;o3@02o``00_l600;o1@02o`H00_l600Co2P04o`P0
0_l700;o0`02o`L00_l400;o1`02o`800_l600;o2@02oah0000J00;o4@02o`/00_lD00;o2@02o`<0
0_l400;o1`02o`H00_l300;o0`02o`800_l400;o1P02o`D00_l400;o1002o`H00_l600;o0`05o`P0
0_l900;o1002o`P00_l200;o1`02o``00_l=00;o0P02o`800_l200;o1P02o`D00_l900;o0`02o`@0
0_l600;o0P02o`T00_l200;o2002o`H00_l500;o1P02o`D00_l200;o2002o`800_l600?o2`02o`T0
0_l300;o0`02o`800_l200;o1P02o`T00_lN00006P02oa400_l;00;o5002o`T00_l300;o0`03o`L0
0_l600;o0`02o`800ol200;o1002o`H00_l500;o0`03o`@00_l600;o1P02o`<00_l00`3oo`0800;o
2@02o`<00ol900Co2007o`L01ol800;o0P02o`H00_l600;o1@02o`T00_l300;o0`03o`H00_l200;o
2@02o`800_l800;o1P02o`D00_l600;o1@02o`800_l800;o0P02o`H00_l<00;o2@02o`<00_l200?o
0P02o`800_l600;o2@02oah0000J00;o4@02o`/00_lD00;o2@02o`<01ol800;o2`02o`8000?o0?l0
0P02o`@00_l500?o1@07o`d00_l600;o0P03o`030?oo00P00_l900Oo2P04o`P02Ol500Wo1P06o`h0
0_l500;o2@02o`<01ol700Ko2@06o`P00_l600;o1@02o`D00ol400?o0P03o`H00ol200?o1@02o``0
0_l900;o0`02o`8000?o0?l00P02o`X00_l900;o7P0001X00_l:00;o1002o``00_lD00;o2@02o`<0
2Ol600;o2`02o`040?oo00;o00<0ool01009o`H02Ol;00;o1P02o`800_l200;o2002o`T02Ol800?o
2@02o`D00ol400;o1@03o`D01_l>00;o1@02o`T00_l300Wo1@06o`T01_l800;o1P02o`D02Ol500;o
1002o`H00_l400;o1@02o``00_l900;o0`02o`040?oo00;o00<0ool02P02o`T00_lN00006`02o`T0
2?l;00;o5@02o`T00_l300;o1@03o`D00_l;00;o00<0ool00P001?l0ool400So1`02o`D00ol:00;o
1P02o`030?oo00<00_l300;o0`02o`<00_l400;o1@03o`L01?l800;o1P02o`@00_l600;o1@02o`80
0_l>00;o1@02o`T00_l300;o1@03o`@00_l200;o2@02o`800_l800;o1P02o`D02?l600;o1002o`H0
0_l400;o1@02o``00_l900;o0`02o`030?oo008000Co0?oo2P02o`@00_l300;o0`02oaT0000K00;o
2@07o``00_lE00?o2002o`<00_l600;o1@02o`/00_l00`3o00020004o`3oo`@00_l400?o1P02o`H0
0_l:00;o1P05o`<00_l300;o0`02o`<00_l400;o1P02o`H01_l700;o1P02o`@00_l600;o1@02o`80
0_l200;o2P02o`D00_l900;o0`02o`H00_l400;o0P02o`800_l500;o0P02o`800_l400;o1P02o`D0
0_l400?o1002o`H00_l400;o1P02o`@00ol700;o0P03o`P00_l300;o00<0o`000P001?l0ool:00;o
1002o`<00_l300;o6@0001/00ol800;o4@02oaH00_l700;o1002o`H00_l500;o2`04o`<01?l400;o
1@02o`H00_l600;o2P02o`H01?l400;o0`02o`<00_l300;o1002o`H00_l500?o0P03o`H00_l600;o
1002o`H00_l500;o1P02o`X00_l600;o1`02o`@00_l600;o1002o`H00_l500;o1P02o`@00_l600;o
1@02o`D00_l400;o1P02o`@00_l600;o1@02o`L00_l300;o1`02o`@01?l300Co2P02o`@00_l300;o
0`02oaT0000L00;o2002oa000_lH00;o1@02o`D00_l500?o1@02o`/01?l400?o1002o`@00ol600;o
1@03o`X00_l600Co1002o`<00_l300;o0`02o`@00_l500?o1@02o`@00_l600;o1@03o`@00_l500?o
1@02o`H00_l:00;o1P03o`D00ol400;o1@03o`@00_l600;o1@02o`H00_l400;o1P02o`D00_l400?o
0`03o`H00ol200?o1P03o`@00ol500?o1002o`D00_l500Co1003o`X00_l400;o0`02o`<00_lI0000
7@02o`L00_l?00;o6@09o`<02ol300So1`04o`D01?l00`3oo`08o`D02ol600[o0P04o`801_l200co
0P0;o`@01Ol200Go0P0;o`<02ol400co1@0:o`@02Ol300_o0`0<o`<03?l300Co1004o`802_l300Ko
0P0<o`801_l400[o1009o`@01?l500Co100:o`030?oo00[o6@0001h000?o00001@08o`T000?o0000
6P05o`D02Ol500So1`04o`D01?l00`3oo`07o`H02Ol800[o0P03o`<01_l200co0P09o`H01Ol200Go
0P09o`D02Ol600co1@0:o`H01Ol500Wo1@0<o`<03?l300Co1004o`802Ol400Ko0P0<o`801_l600Go
00<0ool01P05o`H01?l500Co100:o`030?oo00[o6@0002H02?oo0<`0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(6\\) QRMLARJNUQWQPEJORGFVBWVDQMIT)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?oN002o`@00olD00;o1003ok80
0_l400?oA00001`00_lJ00;o6@0:ogL02_lC00[o/@0:od<0000K00;o7002oaT01Ol200;oN005o`80
0_lD00Go0P02ok801Ol200;o@`0001/00_lL00;o6@000ol0001n0003o`0001X000?o0000^0000ol0
001900006`02o`/01?l=00;o6@05o`D01Ol600So0`05o`804ol300Ko00<0ool00ol600?o0P06o`L0
1_l300;o2004o`T01Ol800;o1002o`P01Ol500So1`0<o`@01_l;00Go1@05o`H00ol400Ko1@07o``0
0_l800[o1P02o`@00_l900;o2@08o`T01Ol600Go0`05o`802_l500So6`0001X00_l;00Oo3002oaH0
2Ol300Go1@09o`<01Ol201?o0`06o`030?oo00?o1@0=o`H01_l200?o1P08o`D02Ol600;o1002o`H0
2Ol300So1`0<o`802Ol800Wo0`05o`D01?l200[o0`07o`/01?l700_o1@02o`@00_l800Co200:o`D0
2Ol400Go0`05o`802_l500So6`0001X00_l:00;o1002o``00_lE00?o1@03o`@00_l500?o0`02o`L0
0_l600;o1P02o`800_l700;o1@02o`D00ol200?o1003o`H00_l400Co1P02o`@00_l400?o1@03o`@0
0ol400?o1003o`D00ol400;o3@02o`H00_l200?o1003o`H00ol500?o1002o`D00ol300Co1@02o`D0
0_l>00Co2@02o`D00ol300?o1003o`L01?l900;o1004o`<00ol500?o1002o`L00_l700;o3002oah0
000J00;o2@02o`H00_l;00;o5@02o`L00_l400;o1@02o`@00_l700;o1P02o`H00_l200;o1`02o`D0
0_l500;o0`02o`H00_l600;o1004o`D00_l600;o0`02o`L00_l400Co0`03o`@00_l700;o1002o`d0
0_l600;o0P02o`H00_l600;o1`02o`@00_l500;o1002o`L00_l500;o3P04o`T00_l600;o0`04o`<0
0ol700Co2@02o`H00_l300;o1`02o`@00_l700;o1`02o``00_lN00006P02o`T00_l600;o2`02oa@0
0_l900;o0`02o`@00_l500;o0`02o`800_l600;o1P02o`802ol500;o1002o`@00_l600;o1P02o`<0
1Ol500;o1P02o`800_l900;o0`04o`801?l300;o2@02o`<00_l=00;o0P02o`800_l200;o1P02o`D0
0_l900;o0`02o`@00_l400?o1`02o`D00_l200;o2@02o`800_l800;o1P02o`<01?l200Co1P02o`80
0_l800;o1`02o`030?oo00T00_l300;o0`02o`800_l700;o3002oah0000J00;o2@02o`H00_l;00;o
5002o`T00_l300;o0`03o`D00_l200?o0P02o`H00_l600;o0`09o`H00_l300?o1002o`H00_l600;o
0`02o`030?oo00D00_l600;o0P02o`T00_l300;o00@0o`001?l300;o2@02o`<01ol800;o0P02o`H0
0_l600;o1@02o`T00_l300;o0`03o`@00_l400Oo1002o`800_l900;o0P02o`P00_l600;o0`02o`04
0?l000Co1P02o`800_l800;o1`02o`030?oo00T00_l300;o0P03o`800_l700;o3002oah0000J00;o
2@02o`H00_l;00;o5002o`T00_l300Oo1P02o`8000?o0?l00P02o`H00_l;00;o1@02o`H01ol=00;o
1P02o`800ol00`3oo`0500;o1P02o`800_l900;o0`02o`060?l00?l00_l300;o2@02o`<02Ol600Ko
3P02o`D00_l900;o0`07o`D00_l400Oo1006o`P00ol200?o1`02o`D00ol300;o00H0o`00o`02o`D0
0ol200?o1`02o`L00_l00`3oo`0900;o0`02o`8000?o0?l00P02o`L00_l<00;o7P0001X00_l900?o
1002o``00_lD00;o2@02o`<02Ol400;o00@0ool00_l00`3oo`0600;o3002o`<00_l700Wo2`02o`H0
0_l200;o0P02o`D00_l600;o0P02o`T00_l300;o00<0ool00_l00`3oo`0300;o2@02o`<00_l500?o
1@06o`h00_l500;o2@02o`<02Ol300;o3`06o`P00_l400;o1`09o`@00_l00`3oo`02o`030?oo00D0
0_l400;o1`02o`L00_l00`3oo`0900;o0`02o`040?oo00;o00<0ool01`02o``00_lN00006`02o`P0
2Ol;00;o5@02o`T00_l300;o1@03o`<00_l00`3oo`020004o`3oo`H00_l<00;o0`02o`L00_l500?o
2P02o`H00_l00`3oo`0300;o1@02o`H00_l200;o2@02o`<00_l00`3oo`02o`030?oo00<00_l900;o
0`02o`H00_l500;o0P02o`h00_l500;o2@02o`<00_l500?o0P02o`l00_l200;o2002o`@00_l700So
1@02o`030?oo00;o00<0ool01@02o`@00_l700;o1`02o`030?oo00T00_l300;o00<0ool00P001?l0
ool700;o1`02o`<00_l300;o6@0001/00_l800;o00<0ool00_l=00;o5@03o`P00_l300;o1P02o`<0
0_l00`3o00020004o`3oo`H00_l=00;o00@0oooo1`02o`H00_l:00;o1P05o`<00_l500;o1P02o`80
0ol800;o0P02o`<00_l300;o0P03o`P00_l300;o1P02o`D00_l200;o0P02o`X00_l500;o2@02o`<0
0_l600;o0P02o`P00_l500;o0P02o`800_l300;o1P02o`H00_l400?o0`02o`<00_l300;o0`02o`H0
0_l600;o1`02o`040?ooo`P00_l300;o00<0o`000P001?l0ool700;o1`02o`<00_l300;o6@0001/0
0ol800;o4@02oaH00_l700;o1002o`H00_l300Co0`04o`H00_l=00;o00<0ool02002o`H00_l:00;o
1P04o`@00_l500;o1P02o`<00_l700;o0`02o`<00_l300;o0`02o`L00_l400;o1P02o`D00_l600;o
2P02o`H00_l700;o1002o`H00_l300;o1P03o`D00_l600;o0`02o`H00_l600;o1@02o`<00_l300;o
0`02o`<00_l600;o1P02o`H00_l300;o1`02o`@01?l300Co1`02o`L00_l300;o0`02oaT0000L00;o
2003o`l00_lH00;o1@02o`D00_l500?o0`04o`@00ol600;o3@05o`P00_l500?o2P02o`H01?l400;o
1@02o`H00_l400;o1@02o`@00_l800;o1002o`D00_l500;o1@03o`D00_l600;o2P02o`H00ol500?o
1002o`D00ol300?o1004o`D00_l600;o0P03o`H00ol500;o1003o`<00_l800;o0P03o`H00ol500;o
1004o`@00_l500;o1@04o`@00ol700;o1`02o`<00_l300;o6@0001d00_l800?o3@02oaT02Ol300_o
0`04o`D01?l200So1`07o`L02ol600[o0P04o`801_l300Co1004o`<02Ol300Ko0P06o`<02Ol300_o
100<o`D02_l400Wo0`0;o`D02_l300co00<0ool01?l200Ko0P0:o`<01_l200co0P06o`<02_l500Wo
1004o`D01?l200[o0`0<oaT0000N0003o`0000L01ol80003o`0001X01Ol500Wo1@04o`D01?l200So
1`07o`L02Ol800[o0P03o`<01_l300Co1004o`D01Ol500Ko0P06o`D01Ol500Wo1P0<o`D02_l600Go
1@09o`T01Ol00`3oo`0300co00<0ool01?l200Ko0P09o`@01_l200co0P06o`<02?l900Go1P04o`D0
1?l200[o0`0<oaT0000Z00Goo`3;0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(7\\) QQNLBQJNUPWPPFJOQGFVAWWEQMIT)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?o1@02o`@00ola00;o1003oiD0
0_l400?oJP02o`@00om400007002oaX00_lI00[o100:oc002_nD00[oJ@0:od<0000K00;o7002oaT0
1Ol200;o1@05o`800_la00Go0P02oiD01Ol200;oJP05o`800_m300006`02oa`00_lI0003o`0000/0
00?o0000=`000ol0002K0003o`00070000?o0000B@0001/00_l;00;o3`02oaT01Ol900Go1P06o`<0
0_l300go00<0ool02?l900Go1`06o`L01_l300;o2004o`D02?l900;o1002o`@02?l600So1`07o`T0
1_l;00Go2@05o`T01_l500Oo3002o`L01_l300Ko0P02o`@00_l600;o1002o`D03?l600Go1P05o`<0
1Ol200[o1@08oa/0000J00;o3002oa000_lF00Wo1@09o`@01_l200?o0`0=o`030?oo00Wo1P09o`<0
2Ol600Ko0P03o`H02?l300So2@02o`@00_l400So1P08o`L01ol700Wo2009o`D02Ol500[o0`07o`/0
1?l600Ko0`06o`800_l400;o1P02o`@00_l500co1009o`@01Ol300Go0P0:o`D02?lK00006P02o`d0
0_l?00;o5@03o`D00ol300?o1@03o`@00_l400Co1P02o`H00_l300;o1@03o`@00ol500?o0P03o`@0
0ol600;o1004o`H00_l400;o1@02o``00ol400?o1@02o``00_l=00;o2P03o`@00ol600?o1@03o`<0
0ol500?o0`04o`D00_l500;o3P04o`P00_l700;o0`03o`@00ol400?o1003o`H00_l600;o0`03o`D0
0ol400;o1`02o`L00_l<00;o7P0001X00_l=00;o3`02oaD00_l700;o0`02o`L00_l400;o1004o`H0
0_l600;o0`02o`H00_l400;o1`02o`800_l600;o1P02o`@01?l500;o1P02o`@00_l<00Co0`03o`D0
0_l<00;o3@02o`X00_l600;o1P02o`L00_l300;o1`02o`<00_l700;o1@02o`h01?l800;o1`02o`<0
1?l300?o1004o`<00ol600;o1P02o`<00_l700;o1002o`L00_l700;o3002oah0000J00;o3@02o`l0
0_lD00;o2@02o`030?oo00T00_l300;o0`05o`H00_l600;o0`02o`H00_l300;o2@02o`030?oo00H0
0_l600;o0`05o`D00_l600;o1002o``01?l200Co1@02o``00_l=00;o0P02o`H00_l600;o1@02o`T0
0_l00`3oo`0900;o00@0oooo1`02o`D00_l200;o2@02o`800_l700_o0`04o`801?l400Co0P04o`H0
0_l200;o0P02o`800_l900;o0`02o`<00_l200;o1`02o``00_lN00006P02o`h000?o00003@02oa@0
0_l900;o00<0ool02@02o`<00_l300;o00<0ool01P02o`H00_l300;o1P02o`<00_l900;o00<0ool0
1P02o`H00_l300;o00<0ool01@02o`H00_l400Oo1`02o`040?l000Co1@07o`L01ol800;o0P02o`H0
0_l600;o1@02o`T00_l00`3oo`0900;o00<0ool01007o`@00_l200;o2@02o`800_l800Wo1002o`04
0?l000Co1002o`040?l000Co1P02o`800_l600;o2@02o`<00_l200?o0P02o`L00_l<00;o7P0001X0
0_l>00;o3P02oa@00_l900;o00<0ool02@02o`<00_l200?o00<0ool01P02o`/00_l500?o0`02o`T0
0_l900;o1P02o`800ol00`3oo`0500;o1P02o`@02Ol500;o00H0o`00o`02o`D02Ol500Wo1P06o`h0
0_l500;o2@02o`030?oo00T00_l00`3oo`0400Oo1006o`P00ol200?o1`02o`D00_l400;o00H0o`00
o`02o`@00_l01P3o003o00;o1P06o`H00_l900;o0`02o`8000?o0?l00P02o`L00_l<00;o7P0001X0
0_l>00;o3P02oa@00_l900;o00<0ool02@02o`<00_l200;o0P02o`H00_l;00Wo1002o`T00_l900;o
1P02o`800_l200;o1@02o`H00_l400;o1@03o`@00_l00`3oo`02o`030?oo00D00_l500?o1002o`D0
0ol500Ko3P02o`D00_l900;o00<0ool02@02o`030?oo00l01_l800;o1002o`P00_l300;o1@02o`03
0?oo00;o00<0ool01002o`030?oo00;o00<0ool01P06o`H00_l900;o0`02o`040?oo00;o00<0ool0
1`02o``00_lN00006`02o`h000?o00002`02oaD00_l900;o00<0ool02@02o`<00_l00`3oo`0300;o
1P02o`/02?l500;o2@02o`T00_l600;o00<0ool00`02o`D00_l600;o1002o`H00_l400;o00<0ool0
0_l00`3oo`0500;o1P02o`@00_l600;o1@02o`800_l>00;o1@02o`T00_l00`3oo`0900;o00<0ool0
3`02o`800_l800;o1002o`P00_l300;o1@02o`030?oo00;o00<0ool01002o`030?oo00;o00<0ool0
1P02o`800_l600;o2@02o`<00_l00`3oo`020004o`3oo`L00_l700;o0`02o`<00_lI00006`02o`h0
0_l<00;o5@03o`P00_l0103oool800;o0`05o`<00_l600;o2`02o`@00ol400?o2002o`T00_l600Go
0`02o`D00_l600;o1002o`H00_l300;o0`02o`<00_l400;o1P02o`@00_l600;o1@02o`800_l200;o
2P02o`D00_l900;o00@0oooo2002o`030?oo00P00_l500;o0P02o`800_l300;o1P02o`P00_l0103o
ool400;o0`02o`<00_l200;o0`02o`<00_l500;o0P02o`800_l200?o2002o`<00_l00`3o00020004
o`3oo`L00_l700;o0`02o`<00_lI00006`03o`d00_l<00;o5P02o`L00_l300;o1`02o`@01?l400;o
1P02o`/00_l500;o1@02o`L00_l:00;o1P04o`@00_l500;o1P02o`@00_l600;o0`02o`<00_l300;o
1002o`H00_l400;o1P02o`D00_l600;o2P02o`H00_l700;o0`02o`L00_l300;o1P03o`D00_l600;o
0`02o`H00_l800;o00<0ool01@02o`<00_l300;o0P02o`<00_l300;o1@02o`H00_l300;o1`02o`@0
1?l300Co1`02o`L00_l300;o0`02oaT0000L00;o3P000ol0000900;o6002o`D00_l500;o1@02o`D0
1?l400;o1P02o`/00_l400?o1P02o`D00_l;00;o1P04o`@00_l500;o1P02o`@00_l500?o0`02o`P0
0_l400;o1@03o`@00_l500?o1@02o`H00_l:00;o1P03o`D00ol400;o1@02o`@00ol400Co1@02o`H0
0_l200?o1P03o`L01Ol500;o2002o`800_l800;o1@02o`H00_l400;o1@02o`D01?l400?o1`02o`L0
0_l300;o0`02oaT0000M00;o1P02o`D00_l900;o6@09o`D02Ol400Co0P06o`802?l600[o1`09o`H0
2_l200Co0P06o`<01?l400Co00<0ool02Ol300Ko0P06o`030?oo00Wo0`0;o`@03?l500[o1009o`D0
2Ol500[o0`0<o`030?oo00Co0P06o`<01ol500Ko0P0<o`801_l200co1009o`@01?l500Co0P0:o`<0
3?lI00007P000ol0000400Wo2@000ol0000J00Go2@05o`H00ol300Ko0P08o`H02Ol:00Go200:o`80
0ol300Ko0`04o`@01?l00`3oo`07o`D01_l200Ko00<0ool01ol500Wo1P0<o`D02_l600Go2@05o`T0
1Ol00`3oo`0300co00<0ool01?l200Ko0`07o`D01_l200co0P06o`803?l600Go1P04o`D01?l200[o
0`0<oaT0000U00Woo`3<0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(8\\) QQNMBQJNVPWQPFKOPFFVAXXEPMIS)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?o1@02o`@00ola00;o1003odd0
0_l400?oo`0001`00_lJ00;o6@0:o`@02_l`00[oC00:ooh0000K00;o7002oaT01Ol200;o1@05o`80
0_la00Go0P02odd01Ol200;ooP0001/00_lL00;o6@000ol0000;0003o`0003L000?o0000D`000ol0
003o00D0000K00;o2`04o`d00_lI00Go2@05o`H01_l300;o0`05o`<01Ol00`3oo`08o`T01Ol700Ko
1`06o`<00_l800;o1`08o`T00_l400;o2005o`D02?l700Oo1`05o`H00_l600Go1@08o`H01ol800Oo
3002o`L01_l300_o0P05o`801Ol200Go0`0<o`802?l700Go0`05o`802_l400;o00<0ool00olL0000
6P02o`X02?l<00;o5P09o`D02Ol400Ko0P03o`<01Ol300Go00<0ool02Ol600Wo0`09o`H01_l200?o
1`04o`H02?l900;o1002o`H02Ol300So1`07o`L01Ol500?o1009o`<02?l600Oo2007o`/01?l600Ko
0`0;o`801Ol200Go0P05o`<03?l200So1`05o`<01Ol200[o100:oaX0000J00;o2@03o`@00ol;00;o
5@03o`D00ol300?o1@03o`@00_l400Co1002o`L00_l400;o1@03o`@00ol500?o0P03o`@00ol600;o
1004o`L01?l800;o3003o`@00ol400?o1@03o`@00_l=00;o3002o`D00ol400?o1@03o`@00_l<00;o
3@02o`h01?l800;o1`02o`<00ol400?o1003o`@00ol600;o1P02o`@00_l<00;o1`02o`L00_l800?o
1@03oaT0000J00;o2@02o`H00_l;00;o5@02o`L00_l300;o1`02o`@00_l400Co1002o`L00_l400;o
1P02o`@00_l700;o0P02o`H00_l600;o1004o`L01?l800;o3004o`<00ol400;o1`02o`@00_l=00;o
3002o`D00_l500;o1`02o`@00_l<00;o3@02o`h01?l800;o1`02o`@00ol200?o1P03o`800ol700;o
1P02o`@00_l<00;o1`02o`L00_l800;o1`02oaT0000J00;o2@02o`H00_l;00;o5002o`T00_l00`3o
o`0900;o0`02o`<01Ol400;o0`02o`800_l400;o1P02o`<00_l900;o00<0ool01P02o`H00_l300Go
1P02o`800_l700;o3004o`801?l300;o2@02o`<00_l=00;o0P02o`P00_l400;o1@02o`T00_l300;o
3002o`800_l900;o0P02o`T00_l200;o1`0;o`D00_l200;o2002o`800_l800;o0P02o`800_l400;o
3002o`<00_l200;o1`02o`P00_l700;o6@0001X00_l900;o1P02o`/00_lD00;o2@02o`030?oo00T0
0_l300;o0`02o`030?oo00@00_l200?o0P02o`@00_l600;o0`02o`T00_l00`3oo`0600;o1P02o`<0
0_l00`3oo`0600;o0P02o`L01ol700;o00@0o`001?l300;o2@02o`<01ol800;o0P02o`P00ol200?o
1@02o`T00_l300Oo1`02o`800_l900;o0P02o`T00_l200;o2009o`L01?l:00Co2@02o`800_l800Oo
1`02o`800ol200;o1`02oa000olI00006P02o`X00_l400;o3002oa@00_l900;o00<0ool02@02o`<0
0_l200?o00<0ool01002o`8000?o0?l00P02o`@00_l500?o0`02o`T00_l900;o1P02o`800ol00`3o
o`0500?o0P03o`H02Ol500;o00H0o`00o`02o`<00_l900;o0`09o`H01_l800Oo1P02o`T00_l300Wo
1@06o`T01_l800?o0P03o`L00_l500;o1`04o`X01?l900Ko2009o`D00_l20003o`3o00800_l700;o
2`07oaX0000J00;o2`07o``00_lD00;o2@02o`030?oo00T00_l300;o0P02o`800_l400;o00@0ool0
0_l00`3oo`0400Wo1002o`T00_l900;o1P02o`800_l200;o1@02o`@00_l600;o1@03o`@00_l00`3o
o`02o`030?oo00<00_l900;o0`02o`D00ol500Ko2005o`P00_l900;o0`02o`D00ol400Ko2@06o`P0
0_l400;o2002o`<00_l800?o2`03o`X01_l800;o1@03o`@00_l0103oo`02o`030?oo00L00_l900Oo
700001/00_l:00Ko3002oaD00_l900;o00<0ool02@02o`<00_l00`3oo`0300;o1002o`030?oo0080
00Co0?oo1008o`D00_l900;o2@02o`H00_l00`3oo`0300;o1@02o`@00_l600;o1P02o`@00_l00`3o
o`02o`030?oo00<00_l900;o0`02o`H00_l500;o0P02o`P00_l0103oool700;o2@02o`<00_l600;o
1002o`800_l900;o0P02o`P00_l400;o2002o`<00_l800Co2P04o`T00_l200;o2002o`H00_l400;o
00<0ool00P001?l0ool700;o2003ob40000K00;o2@02o`@00_l;00;o5@03o`P00_l0103oool800;o
0`05o`<00_l400;o00<0o`000P001?l0ool400;o1003o`@00ol800;o2@02o`H01Ol300;o1002o`H0
0_l500;o1P02o`<00_l300;o0`02o`800ol800;o0`02o`H00_l500;o0P02o`800_l400;o0P03o`H0
0_l900;o0`02o`H00_l400;o0P02o`800_l500;o0P02o`800_l300;o1P02o`P00_l0103oool700Ko
2006o`P00_l200;o0P02o`@00_l600;o1002o`030?l0008000Co0?oo1`02o`P00_l70003o`0001P0
000K00?o1`02o`H00_l:00;o5P02o`L00_l300;o1`02o`@01?l400;o1004o`<01?l400;o1@02o`D0
0_l700;o2P02o`H01?l400;o1002o`H00_l500;o1P02o`<00_l300;o0`02o`<00_l700;o1002o`H0
0_l500;o1P02o`@00_l300?o1P02o`L00_l400;o1P02o`@00_l600;o1@02o`H00_l300;o1P02o`P0
0_l00`3oo`0700?o0P03o`H00ol200?o1`02o`H00_l400;o1P02o`@01?l300Co1`02o`P00_l600;o
6P0001`00_l700;o1P02o`T00_lH00;o1@02o`D00_l500;o1@04o`@00_l400Co1003o`@00_l400?o
1P02o`D00_l;00;o1P04o`@00_l300?o1P03o`@00_l500?o0`02o`P00_l400;o1@02o`D00_l500?o
1@02o`H00_l400;o1003o`D00ol500?o1002o`D00ol400;o1P02o`D00_l600;o0P03o`H00ol700Go
1`02o`@00_l600;o1002o`L00_l600;o1002o`D00ol400Co1003o`L00_l800?o1003oaX0000M00;o
1P03o`@00ol800;o6@09o`D02Ol400Co0P06o`801?l500Co00<0ool02?l700Wo1P0:o`801?l200Ko
00<0ool01?l200Ko00<0ool02Ol300Ko0P06o`<02Ol300_o100<o`801Ol300Go1009o`<02ol300co
0`0<o`030?oo00Co0P06o`<01ol600Go0P05o`801Ol200Go0`0<o`802ol400Co1@04o`802_l500Wo
6P0001h000?o00001@08o`T000?o00006P05o`T01Ol600?o0`06o`801?l500Co00<0ool01ol:00Go
200:o`800ol300Ko00<0ool01?l200Ko00<0ool01ol500Ko0P06o`D01Ol500Wo1P0<o`801Ol300Go
1P05o`D02Ol500co0`0<o`030?oo00Co0P06o`<01ol600Go0P05o`801Ol200Go0`0<o`802Ol600Co
1@04o`802_l700Go00<0o`006@0002L01_oo0<d0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(9\\) QQOLCQKNVPVQPFKNPFFVAYWEPMHR)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?o1@02o`@00ola00;o1003odd0
0_l400?oo`0001`00_lJ00;o6@0:o`@02_l`00[oC00:ooh0000K00;o7002oaT01Ol200;o1@05o`80
0_la00Go0P02odd01Ol200;ooP0001/00_lL00;o6@000ol0000;0003o`0003L000?o0000D`000ol0
003o00D0000K00;o2005o`l00_lI00Go2@05o`T01Ol600go1@05o`X01Ol500Go1P02o`801_l300;o
2002o`L02?l<00;o2`05o`D02?l700Oo1`05o`H00_l300Ko0`02o`802?l600Oo2007o``00_l700Ko
0`06o`802?l600;o1002o`D03?l200So1`05o`<01Ol200Co0`04o`801Ol600?o5`0001X00_l900Oo
3P02oaH02Ol500Wo1@09o`@03Ol300Wo1P09o`<01Ol500?o0P06o`800ol700Co1P08o`/01?l800Wo
0`08o`L01ol700Go1@03o`<01_l200?o0P08o`H01ol800Oo2`04o`H01_l300Ko0P08o`H00_l400;o
1@0<o`802?l700Go0`05o`801?l300Co0P05o`D01?lG00006P02o`h00ol=00;o5@03o`D00ol300?o
1@03o`<00ol500?o1P02o`H00_l200?o1@03o`@00ol500?o1002o`D00ol400;o1004o`L01?l800;o
3`04o`L00ol500?o1002o`d00_l<00;o1@03o`D00_l400Co1002o``00_l=00;o3P04o`P00_l700;o
1`02o`P00ol400?o1P02o`H00_l400;o3002o`L00_l400;o1@02o`D00_l500?o6@0001X00_l?00?o
3002oaD00_l700;o0`02o`L00_l300;o1`02o`H00_l600;o0P02o`L00_l400;o1`02o`@00_l500;o
1@02o`@01?l700Co2002o`l01?l700;o1`02o`@00_l=00;o3002o`D00_l600;o1004o`@00_l<00;o
3@02o`h01?l800;o1`02o`L00_l800Co0`03o`H00_l600;o1002o``00_l700;o1002o`D00_l500;o
1@02oaX0000J00;o4002o``00_lD00;o2@02o`030?oo00T00_l00`3oo`0900;o1@02o`H00_l0103o
ool<00;o2@02o`<00_l400;o1P02o`<01Ol600;o0P02o`L00_l>00;o0P02o`D00_l900;o0`02o`d0
0_l200;o2002o`@00_l700;o0`05o`@00_l<00;o0P02o`T00_l200;o2@02o`800_l700_o1`02o`P0
1?l200Co1P02o`800_l200;o1002o``00_l300;o0P02o`@00_l500;o1@02o`@00_lK00006P02o``0
1?l00`3oo`0;00;o5002o`T00_l00`3oo`0900;o00<0ool02@02o`D00_l600;o00<0ool03@02o`T0
0_l300?o0P03o`H00_l300;o00<0ool01P02o`800_l700Oo2@02o`800_l500;o2@02o`<01ol800;o
0P02o`P00ol200?o1`02o`<00_l00`3oo`0400Oo1`02o`800_l900;o0P02o`T00_l200;o2009o`P0
0_l800;o00@0o`001?l600;o0P02o`P01ol700;o0P03o`800_l400;o1@02o`D00_l300?o6`0001X0
0_l:00Wo2`02oa@00_l900;o00<0ool02@02o`030?oo00T00_l500;o2@02o`d00_l900;o0`07o`L0
0_l200?o00<0ool01@03o`800ol600Wo1P03o`800ol400;o2@02o`<02Ol600Ko2007o`P00_l200?o
00<0ool01009o`D01_l900Ko2003o`800ol700;o1@02o`P00ol700;o00H0o`00o`02o`H01_l800Wo
1@02o`8000?o0?l00P02o`@00_l500;o1@07oa`0000J00;o2P02o`@00ol;00;o5002o`T00_l00`3o
o`0900;o00<0ool02@02o`D00_l900;o3@02o`T00_l300Go2@02o`800_l200;o1@02o`@00_l600;o
1@03o`D00_l400;o1002o`T00_l300;o1@03o`D01_l800Go2P02o`800_l200;o1002o`D00ol400Ko
2@06o`P00_l400;o2002o`<00_l800Co1`02o`030?oo00;o00<0ool01P06o`P00_l500?o1002o`04
0?oo00;o00<0ool01009o`D02OlJ00006`02o`P00_l600;o2P02oaD00_l900;o00<0ool02@02o`03
0?oo00T00_l500;o2@02o`d00_l900;o0`02o`040?ooo`P00_l00`3oo`0300;o1@02o`@00_l600;o
1P02o`D00_l400;o1002o`T00_l300;o1P02o`D00_l200;o2002o`040?ooo`T00_l00`3oo`0300;o
1002o`H00_l400;o0P02o`T00_l200;o2002o`@00_l800;o0`02o`L01_l600;o00<0ool00_l00`3o
o`0600;o0P02o`P00_l600;o1002o`030?oo008000Co0?oo1009o`D00_l500?o6@0001/00_l800;o
1P02o`X00_lE00?o2002o`040?ooo`P00_l00`3oo`0900;o1@02o`T00ol700;o0`03o`P00_l300;o
0P03o`L01Ol300;o1002o`H00_l500;o1P02o`@00_l600;o0`03o`P00_l300;o1P02o`D00_l200;o
0P02o`@00_l200?o2005o`<00_l400;o1P02o`@00_l200;o0P02o`D00_l200;o0P02o`<00_l600;o
2002o`040?ooo`L00_l200;o1@02o`<00_l300;o1@02o`800_l200;o1002o`H00_l400;o00<0o`00
0P001?l0ool400;o1@02o`D00_l600;o6@0001/00ol700;o1P02o`X00_lF00;o1`02o`<00_l700;o
0`02o`L00_l600;o2P02o`L00_l400;o1`02o`@00_l300?o1P04o`@00_l400;o1P02o`D00_l600;o
1002o`H00_l400;o1`02o`@00_l600;o1@02o`H00_l400;o0`03o`L01?l400;o1002o`H00_l400;o
1P02o`D00_l600;o0`02o`H00_l800;o00<0ool01`03o`<00_l400;o0`02o`<00_l500;o1P02o`@0
0_l600;o1004o`<01?l400;o1@02o`D00_l600;o6@0001`00_l700;o1P000ol0000800;o6002o`D0
0_l500;o1@02o`@00ol500?o1P02o`X00ol500?o1@02o`D00_l500;o1003o`D01?l400;o0`03o`H0
0ol400;o1@03o`<00ol600?o1002o`D00_l500;o1@03o`D00_l600;o1002o`@00ol600Co1002o`@0
0_l500?o1002o`H00_l500;o1P02o`800ol600?o1`05o`L00_l400;o1002o`P00_l500;o1P02o`@0
0_l500?o1004o`@00ol400;o1@02o`D00_l500?o6@0001d00_l700;o1002o`T00_lI00Wo1@09o`D0
2Ol400So200:o`D02Ol300Go0`05o`801?l200Ko00<0ool01?l200Ko00<0ool02Ol300Ko0P06o`<0
2Ol300_o100<o`801Ol300Go0`04o`801_l00`3oo`09o`<03?l300co00<0ool01?l200Ko0`07o`H0
1Ol200Go00<0ool01?l200Ko0P0<o`802ol400Co1@04o`801?l300Co0P0;oaX0000N0003o`0000D0
1ol:0003o`0001X01Ol900Go2@05o`H02?l:00Go00<0ool01`05o`D01Ol300Go0P03o`<01_l00`3o
o`04o`801_l00`3oo`07o`D01_l200Ko1@05o`D02Ol600co0P05o`<01Ol300?o0`06o`030?oo00Oo
1@0<o`<03?l00`3oo`04o`801_l300Oo1P05o`801Ol00`3oo`04o`801_l200co0P09o`H01?l500Co
0P04o`<01?l200Wo700002P01?oo0<h0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(10\\) QQOLCPLNVOVRPGLMOEFVAYWEQNHQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?o1@02o`@00ooo04@00_l400?o
8P02o`@00olA00005@02obP00_lI00[o100:ool0@`0:ob402_l@00005002obX00_lI00Go0P02o`D0
1Ol200;oo`1400Go0P02ob801Ol200;o400001@00_lZ00;o6@000ol0000;0003o`000?l0BP000ol0
000X0003o`0001H0000D00;o2@09o`P01?l<00;o6@05o`T01Ol:00Go1@0=o`H01Ol500So1P0=o`<0
1_l300;o1`02o``01Ol:00;o1`05o`H00ol00`3oo`06o`X01_l500go00<0ool00ol300Go1@05o`H0
3?l200Oo3@02o`H01_l300Ko0P08o`L00_l400;o100<o`L01Ol600Ko0`02o`<01?l300Co1`05oa@0
000C00;o2P09o`L01_l<00;o5P09o`D02Ol600Wo0`0=o`@02Ol300So1P0=o`<01_l200?o1P04o`T0
2Ol700Co1P05o`D01?l00`3oo`06o`P02_l300go00<0ool00ol300Go0`09o`@03?l200Oo3004o`D0
1_l300Ko0P08o`L00_l400;o100<o`D02Ol400Ko0P03o`<01?l300Co1@09oa80000C00;o3P02o`T0
0ol200?o2`02oaD00ol500?o0`03o`D00ol400?o1@03o`D00_l600;o0`03o`D00ol400;o3@02o`H0
0_l400;o1004o`H01?l800?o1@03o`H01?l800;o1@03o`D00_l;00Co1@02o`H00_l600;o0P02o`L0
0_l300?o1@03o`D00_l600;o1002o`l01?l700;o1`02o`L00_l900?o1003o`D00_l600;o1003o`D0
0ol400;o1004o`@00_l500;o1@03o`D00olA00004`02o`h00_l900;o1002o`/00_lE00;o1`02o`<0
0_l700;o1002o`L00_l500;o1P02o`<00_l700;o1002o`d00_l600;o1002o`@01?l600Co2002o`L0
0_l600Co2002o`D00_l600;o2`02o`L00_l600;o1P02o`800_l700;o0`02o`L00_l500;o1P02o`@0
0_l?00Co1`02o`L00_l700;o2@04o`<00ol500;o1P02o`@00_l700;o1002o`@01?l400;o1@02o`D0
0_l700;o4@0001<00_l>00;o2002o`H00_l:00;o5002o`T00_l00`3oo`0900;o0P02o`T00_l400;o
1P02o`800ol=00;o3@02o`H00_l400;o0`05o`D00_l200;o1P02o`T00_l400;o0P02o`L00_l400;o
1`02o`X00ol700;o1P02o`H00_l200;o0`02o`800_l200;o2@02o`@00_l200;o0P02o`@00_l200;o
2P02o`800_l600_o1`02o`T01?l200Co1@02o`800_l200;o0`02o`T00_l300;o0`05o`@00_l500;o
1002o`T00_l@00004`02o`h00_l800;o1P02o`X00_lD00;o2@02o`030?oo00T00_l200;o2@02o`@0
0_l600;o0P02o`h01ol800;o1P02o`@00_l300;o00<0ool01@02o`800_l600;o2@02o`@00_l200;o
1`02o`<00ol700Oo1@02o`@01ol500;o1P02o`800_l200?o0P02o`800_l900;o1002o`800_l800;o
0P02o`X00_l200;o1`09o`P00_l900;o00@0o`001?l500;o0P02o`L00_l900;o0`02o`<00_l00`3o
o`0400;o1@02o`@00_l900;o400001<00_l>00;o2002o`H00_l:00;o5002o`T00_l00`3oo`0900;o
0P02o`T00_l400;o2P02o`h02Ol600;o3002o`800ol00`3oo`0400?o0P03o`D00_l900;o0`03o`80
0ol600Oo2009o`<00_l400Oo1@02o`X00_l20003o`3o00800_l200;o2@02o`@01_l800Ko2@03o`80
0ol600;o1@02o`P00ol800;o00H0o`00o`02o`D01_l700;o2@02o`<00_l200?o00<0ool01002o`D0
0_l400;o2@02oa00000C00;o3P02o`P00_l600;o2P02oa@00_l900;o00<0ool02@02o`800_l900;o
1002o`X00_l>00;o1@03o`D00_l<00;o0P02o`800_l400;o1002o`D00_l900;o0`02o`@00_l600Wo
1P02o`D00ol200;o4002o`X00_l0103oo`02o`030?oo00800_l900;o1006o`P01_l900;o1002o`L0
0_l300;o2004o`P00_l00`3oo`02o`030?oo00D01_l700;o2@02o`<00_l200;o0P02o`@02Ol400;o
2@02oa00000D00;o3@02o`P00_l600;o2@02oaD00_l900;o00<0ool02@02o`800_l900;o1002o`X0
0_l>00;o1P02o`D00_l<00;o00<0ool00`02o`@00_l400;o1@02o`T00_l300;o1002o`H00_l500?o
1@02o`H00_l200;o4002o`X00_l00`3oo`020004o`3oo`800_l900;o1002o`800_l800;o0P02o`T0
0_l400;o1`02o`<00_l700Ko1`02o`030?oo00;o00<0ool01@02o`800_l700;o2@02o`<00_l00`3o
o`0300;o1009o`@00_l900;o400001@00_l=00;o2002o`H00_l900;o5@03o`P00_l0103oool800;o
0P02o`T00_l400;o2P03o`L00_l400;o1P02o`D00_l<00Go0`02o`<00_l600;o1002o`T00_l200;o
1P02o`D00_l600;o1@02o`H00_l200;o2002o`H00_l:00;o00<0o`000P001?l0ool200;o2@02o`@0
0_l200;o0P02o`@00_l200;o0P02o`@00_l600;o1`02o`040?ooo`L00_l200;o1P02o`<00_l300;o
1002o`800_l200;o0`03o`P00_l300Go0`02o`@00_l500;o1003o`P00_l@00005003o``00_l800;o
1P02o`T00_lF00;o1`02o`<00_l700;o1002o`L00_l500;o2`02o`L00_l400;o1P02o`D00_l<00Co
1002o`<00_l600;o1@02o`L00_l300;o1P02o`D00_l600;o1@02o`H00_l300;o1P03o`H00_l:00Co
0`04o`<00_l700;o1@02o`H00_l400;o1P02o`@00_l600;o1`02o`030?oo00L00ol300;o1@02o`<0
0_l300;o1002o`H00_l400;o1`02o`@01?l400;o1002o`D00_l500;o1`02oa40000E00;o3002o`T0
0_l400;o2@02oaP00_l500;o1@02o`D00_l500?o1@03o`D00_l;00?o1@03o`@00_l500?o1@02o``0
1?l400;o0P03o`H00ol400?o1@03o`800ol600?o1002o`D00ol500;o1@03o`<00ol400Co1P02o`X0
1?l400?o0`03o`D00ol500;o1P02o`@00_l600;o0`03o`H00ol600Go1`02o`@00_l500;o2002o`@0
0_l600;o1@02o`D00_l500Co1002o`@00_l500;o1P02o`D00_lB00005P02o`L00ol00`3oo`0900?o
0P03o`P00_lI00Wo1@09o`H02Ol300So2@0:o`802ol300So2004o`803?l200Ko1009o`801_l200Ko
00<0ool02Ol400_o1@0:o`<02?l600Co1@04o`<02Ol400co0P0<o`801_l200Ko0P07o`H01Ol200Go
0P06o`801_l00`3oo`0:o`D02Ol400Co0P06o`801?l300Co1@09oa80000G0003o`0000D01_l:00Ko
2@000ol0000J00Go2@05o`X01Ol500So2`05o`030?oo00802Ol500So2003o`<03?l200Ko1P05o`@0
1_l200Ko00<0ool01ol600Wo2@05o`030?oo00<02?l600Co1@04o`D01Ol600co0P0<o`801_l200Ko
0P07o`H01Ol200Go0P06o`801_l00`3oo`0:o`L01Ol600?o0`06o`801?l300Co1`05oa@0000R00?o
2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(11\\) QPOLCOLOVOVRPHLMNEFVAXWEPNHR)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`2G00005@02obP00_lI00[o
o`2F00005002obX00_lI00Go0P02ool0UP0001@00_lZ00;o6@000ol0003o09`0000D00;o2@09o`H0
2Ol900;o6@05o`D02?l;00Go1@0=o`H01Ol900Go1@0=o`H01Ol:00;o3005o`X00_l700Go1P03o`03
0?oo00Ko1`04o`<01?l300go00<0ool00ol300Go0P06o`<00_l300co0P07o`d00_l600Ko0`0;o`80
1Ol500;o1002o`@03?l300So1`06o`<00_l300Co0`04o`<01Ol600?o3`0001<00_l:00Wo1P09o`X0
0_lF00Wo0`08o`T02Ol300go1009o`D02Ol300go1009o`L01?l900Wo1`04o`H01Ol500Co00<0ool0
1_l700Co0`04o`<03Ol00`3oo`03o`<01Ol200Ko0P03o`<03?l200Oo3004o`D01_l300_o0P05o`D0
0_l400;o100<o`<02?l700Ko0P03o`<01?l300Co0`05o`D01?l?00004`02o`h00_l=00;o3@02oaD0
0ol500?o1002o``00ol500?o1@02o`H00_l300?o1@03o`<00ol500?o1@02o`H00_l300?o1@03o`H0
1?l800?o1@03o`H01?l800;o1@03o`D00_l<00;o1@02o`L00_l600;o0P02o`L00_l400;o1004o`D0
0_l600;o1002o`l01?l700;o1`02o`<00ol400?o1@03o`@00ol500;o1P02o`D00_l<00;o1004o`@0
0_l500;o1P02o`D00olA00004`02o`h00_l=00;o3@02oaD00_l700;o1002o``00_l700;o1@02o`H0
0_l300;o1`02o`<00_l700;o1@02o`H00_l300;o1`02o`H01?l800;o1`02o`H01?l800;o1@02o`H0
0_l<00;o1@02o`L00_l600;o0P02o`L00_l400;o1004o`D00_l600;o1002o`l01?l700;o1`02o`@0
0ol200?o1P04o`<00ol500;o1P02o`D00_l<00;o1004o`@00_l500;o1P02o`D00_lB00004`02o`h0
0_l=00;o3@02oa@00_l900;o0`02o`/00_l900;o1002o`H00_l200?o2`02o`T00_l400;o1P02o`80
0_l900;o1002o`800_l600;o2@02o`@00_l200;o1`02o`@00_l700;o3002o`D00_l700;o1P02o`80
0_l300;o0P02o`@00_l300Go1@02o`800_l200;o1002o`800_l:00;o0P02o`H02ol500;o0P02o`L0
1?l200Co1@02o`800_l200;o1@02o``00_l300Go1002o`D00_l600;o1002oa<0000C00;o3P02o`d0
0_l=00;o5002o`T00_l300Oo1P02o`T00_l400;o1P02o`800_l<00;o2@02o`@00_l600;o0P02o`T0
0_l400;o0P02o`H00_l900;o1002o`800_l700;o0`03o`L01ol700;o1@02o`L00_l600;o0P02o`80
0ol200;o1002o`<00_l00`3oo`0500;o0P02o`P00_l200;o2P02o`800_l700Wo1`04o`P00_l0103o
0004o`D00_l200;o2@07o`L00_l300;o00<0ool01002o`D00_l600;o0`03oa<0000C00;o3P02o`d0
0_l=00;o5002o`T00_l300Wo1002o`T00_l400;o2P02o``00_l900;o1002o`X00_l900;o0`03o`80
0ol500;o2@02o`<00ol200?o1P07o`P02Ol500;o1@02o`L00_l:00;o0P000ol0o`0200;o1002o`80
0ol00`3oo`0500Ko2006o`T00ol200?o1P02o`D00_l700Co2002o`060?l00?l00_l500Ko2@09o`D0
0_l200?o00<0ool01002o`D00_l600Oo500001<00_l>00;o3@02o`d00_lD00;o2@02o`<00_l500?o
0`02o`T00_l400;o2P02o``00_l900;o1002o`X00_l900;o0`02o`@00_l500;o2@02o`<00_l400;o
1P09o`H00_l500?o1009o`L00_l:00;o00@0ool00_l00`3oo`0400;o0P02o`800_l500Ko2006o`T0
0_l400;o1`02o`<00_l800?o2@02o`030?oo00;o00<0ool01@06o`T00_l500?o1002o`800_l200;o
1009o`H02OlB00005002o`d00_l=00;o3002oaD00_l900;o0`02o`H00_l300;o2@02o`@00_l:00;o
3002o`T00_l400;o2P02o`T00_l300;o1002o`D00_l900;o0`02o`@00_l600;o1@03o`D00_l600;o
1009o`L00_l:00;o00<0ool00P001?l0ool400;o00<0ool00`02o`D00_l200;o2002o`800_l900;o
1002o`L00_l300;o2004o`P00_l00`3oo`02o`030?oo00D00_l200;o2@02o`H00_l400;o00<0ool0
0`02o`@02Ol600;o1@03oa40000D00;o3@02o`d00_l<00;o5@03o`P00_l300;o1P02o`<00_l900;o
1002o`X00ol700;o0P02o`T00_l400;o2P02o`T00_l200;o1P02o`@00_l900;o0P02o`H00_l500;o
1P02o`D00_l600;o1002o`D00_l700;o2P02o`030?l0008000Co0?oo1005o`<00_l500;o0P02o`80
0_l400;o0P02o`800_l400;o1P02o`L00_l0103oool700Ko1P02o`<00_l300;o1002o`800_l200;o
1@02o`H00_l400Go0`02o`@00_l500;o1P02o`H00_lA00005003o``00_l=00;o3002oaH00_l700;o
1002o`H00_l400;o1`02o`D00_l;00;o1`02o`<00_l700;o1@02o`/00_l700;o0`02o`H00_l500;o
1`02o`<00_l600;o1@02o`H00_l500;o1P02o`@00_l500;o1`02o`X01?l300Co1004o`@00_l500;o
1P02o`@00_l600;o1002o`H00_l700;o00<0ool01`03o`800ol500;o0`02o`<00_l400;o1P02o`D0
0_l600;o1004o`@00_l400;o1@02o`H00_l600;o4@0001D00_l<00;o3@02o`/00_lH00;o1@02o`D0
0_l500?o1003o`D00ol500;o2`03o`D00ol300?o1@03o`D00_l;00?o1@03o`800ol600?o1003o`D0
0ol200?o1P03o`@00_l500?o1@02o`D00ol400;o1@02o`L00_l:00Co1003o`@01?l400;o1@02o`H0
0_l400;o1P02o`<00ol600?o1P05o`L00_l400;o1@02o`P00_l400;o1P02o`D00_l500?o1004o`@0
0_l400;o1@02o`H00_l500?o4@0001H00_l700?o00<0ool02@03o`030?oo00X00_lI00Wo0`0;o`H0
2Ol300So2@0:o`@02Ol300So2@09o`801_l200Ko1009o`801_l200Ko00<0ool02Ol400_o1004o`<0
1?l300So1P04o`D01?l200Co0P06o`803?l200co0P06o`801_l200Oo1P05o`801Ol200Ko0P06o`03
0?oo00[o0`0;o`@01?l200Ko0P04o`<01?l300_o4P0001L000?o00001@06o`T01_l:0003o`0001X0
1Ol500Wo2P05o`D02?l;00Go00<0ool01P05o`D02?l;00Go1006o`801_l600Go1006o`801_l00`3o
o`07o`H02Ol600Co0`04o`<02?l600Co1@04o`800ol300Ko0P0<o`803?l200Ko0P06o`801ol600Go
0P05o`801_l200Ko00<0ool02_l300Wo1P03o`<01_l200Co0`04o`<02OlD00008P03o``00ooo0<H0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(12\\) QOOLDPLOWOVRPHLLNFGWBWWEPOHQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`1m00;o1003oa40000E00;o
:002oaT02_oo07`02_l@00005002obX00_lI00Go0P02ool0O@05o`800_l@00005002obX00_lI0003
o`000?l0P`000ol0000F00005002o`T02Ol500[o2@02oaT01Ol900Go2P05o`D03Ol300So1@08o`H0
3Ol600Go1`02o`@00_l900Go2P02o`L01Ol600?o00<0ool01_l700Co0`04o`<03Ol00`3oo`0;o`80
1_l300;o0`07o`/01_l700;o1002o`@02_l600;o1002o`L00_l400;o100<o`<02?l:00Go1P04o`<0
1?l700Go500001<00_l:00Wo1@0:o`X00_lF00Wo1@09o`H02Ol300go0`0:o`<02?l600go1009o`D0
0_l400;o1`09o`L01?l600Go1@04o`030?oo00Ko1`04o`<01?l300go00<0ool02ol200Ko0P03o`<0
1ol900[o1@02o`@00_l400_o1@02o`@00_l700;o1002o`@03?l300So2009o`@01?l300Co1@09oa80
000C00;o3P02o`T00_l500;o2P02oaD00ol500?o0`03o`D00ol400?o1@03o`D00_l600;o1002o`@0
1?l400;o3@02o`H00_l300?o1@03o`<00ol400?o1@03o`D00ol600Co2002o`D00ol500;o3002o`D0
0_l700;o1P02o`@00_l600;o0`02o`@01?l500;o2`04o`D00_l400?o1003o`D00_l500?o0`03o`@0
0ol500?o1003o`D00_l600;o1@02o`/00ol500?o1002o`D00_l500?o1@03oa40000C00;o3P02o`X0
0ol?00;o5@02o`L00_l300;o1`02o`@00_l700;o1@02o`H00_l400;o1P02o`@00_l=00;o1P02o`<0
0_l700;o0`04o`<00ol500;o1`02o`H01?l800;o1@02o`H00_l<00;o1@02o`L00_l600;o1002o`H0
0_l300;o1004o`D00_l;00;o1`02o`@01?l300?o1@02o`H00_l300Co0`03o`D01?l300?o1@02o`H0
0_l500;o2`02o`L00_l400;o1@02o`D00_l700;o4@0001<00_l>00;o2`03o`h00_lD00;o2@02o`03
0?oo00T00_l200;o2@02o`@00_l600;o1002o`L00_l300;o3@02o`H00_l200;o2@02o`801?l200Co
1002o`T00_l400;o0P02o`L00_l400;o1`02o``00_l500;o1`02o`H00_l400;o1P02o`<00_l300Go
1@02o`800_l600?o1`02o`@01?l200Co1@02o`H00_l300Co0P04o`D01?l200Co1@02o`800_l200;o
1@02o`X00_l900;o0`02o`D00_l400;o2@02oa00000C00;o3P02o``00ol=00;o5002o`T00_l00`3o
o`0900;o0P02o`T00_l400;o1P02o`@00_l700;o0`07o`P00_l600;o0P02o`T00_l200;o00@0o`00
1?l400;o2@02o`@00_l200;o1`02o`<00ol700Oo1`02o`D00_l700;o1P02o`@00_l600;o0`02o`<0
0_l00`3oo`0500;o0P02o`H00_l400Oo0`02o`040?l000Co1@02o`H00_l300;o00@0o`001?l500;o
00@0o`001?l500;o0P02o`T01ol500;o2@02o`<00_l500;o1002o`T00_l@00004`02o`h00_l=00?o
3002oa@00_l900;o00<0ool02@02o`800_l900;o1002o``00_l700;o0`09o`H00_l:00;o2@02o`80
0_l01P3o003o00;o1002o`T00_l300?o0P03o`H01ol800Wo1@02o`D00_l700;o3002o`/00_l200?o
00<0ool01@06o`H00_l400Oo0`02o`060?l00?l00_l500;o1@03o`<00_l01P3o003o00;o1@02o`06
0?l00?l00_l500Ko2@09o`<00_l900;o0`02o`D00_l400;o2@02oa00000C00;o3P02o`h00ol;00;o
5002o`T00_l00`3oo`0900;o0P02o`T00_l400;o3002o`L00_l300;o1@03o`D00_l:00;o2@02o`80
0_l00`3oo`02o`030?oo00@00_l900;o0`02o`@00_l600Wo1P02o`D00ol400Wo1`02o``00_l;00;o
0P02o`800_l500Ko1P02o`h00_l00`3oo`02o`030?oo00D02Ol400;o00<0ool00_l00`3oo`0500;o
00<0ool00_l00`3oo`0500Ko2@02o`D00ol200;o2@02o`<02Ol400;o2@02oa00000D00;o3@02o`l0
0_l:00;o5@02o`T00_l00`3oo`0900;o0P02o`T00_l400;o3002o`L00_l300;o1P02o`D00_l:00;o
2@02o`800_l00`3oo`02o`030?oo00@00_l900;o0`02o`@00_l600;o1@03o`D00_l600;o1009o`L0
0_l<00;o2`02o`030?oo00<00_l500;o0P02o`H00_l>00;o00<0ool00_l00`3oo`0500So1@02o`03
0?oo00;o00<0ool01@02o`030?oo00;o00<0ool01@02o`800_l900;o1P02o`800_l900;o0`09o`@0
0_l900;o400001@00_l=00;o4002o`T00_lE00?o2002o`030?oo00T00_l200;o2@02o`@00_l<00;o
1`02o`<00_l600;o1@02o`X00_l900;o00<0ool00`02o`<00_l300;o2@02o`800_l600;o1@02o`H0
0_l500;o1P02o`@00_l500;o1`02o``00_l;00Go0`02o`D00_l200;o0P02o`800_l800;o0`02o`<0
0_l300;o1002o`@00ol300;o0`02o`<00_l300;o0`02o`<00_l400;o0P02o`800_l500;o1P02o`80
0_l900;o0`02o`D00_l400?o2002oa00000D00?o3002oa000_l900;o5P02o`L00_l300;o1`02o`@0
0_l700;o1@02o``00_l600;o1002o`H00_l500;o2`02o`L00_l200;o0`02o`<00_l400;o1`02o`<0
0_l600;o1@02o`H00_l500;o1P02o`@00_l500;o1`02o``00_l;00Co1002o`D00_l600;o0`02o`H0
0ol300;o0`02o`<00_l400;o1@02o`<00_l300;o0`02o`<00_l300;o0`02o`@00_l600;o1@02o`H0
0_l300;o1`02o`@00_l500;o1@02o`L00_lA00005@02o``00_l900;o1@02o`P00_lH00;o1@02o`@0
0ol500?o1003o`D00ol500;o3002o`@01?l400;o1@03o`D00_l;00?o1@03o`800_l800;o1003o`D0
0ol200?o1P03o`@00_l500?o1@02o`D00ol400;o1@02o`L00_l<00;o2`04o`@00_l500;o1P02o`<0
0ol400Co0`02o`P00_l400;o1003o`<00_l800;o0`02o`P00_l400;o1P02o`D00_l500?o0`03o`D0
0ol400;o1@02o`H00_l500;o4P0001H00_l700?o00<0ool02@03o`<00ol700;o6@09o`D02Ol600Wo
0`08o`P02_l300_o0`08o`T02Ol200Ko0P06o`@02Ol200Ko0P06o`030?oo00Wo100;o`@01?l300Co
0`08o`H02?l700Co0P06o`803?l400[o0P06o`801_l00`3oo`08o`<01_l200Ko00<0ool01?l200Ko
00<0ool02_l300_o1@09o`@01?l300Co1@09oa80000G0003o`0000D01_l:00Oo20000ol0000J00Go
2@05o`X01Ol500So2008o`D02Ol500So2`05o`@01_l200Ko1P05o`@01_l200Ko00<0ool01ol600Wo
1P04o`<01?l300So1P08o`L00ol300Ko0P0<o`H01Ol00`3oo`0200Ko0P06o`030?oo00Oo1006o`80
1_l00`3oo`04o`801_l00`3oo`0:o`<02Ol900Go1P04o`<01?l700Go500002800ol;00Goo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(13\\) QNOLDOLOWOVSPHMKNFFWBWVDPPHQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`1m00;o1003oa40000E00;o
:002oaT02_oo07`02_l@00005002obX00_lI00Go0P02ool0O@05o`800_l@00005002obX00_lI0003
o`000?l0P`000ol0000F00005002o`T02Ol700Go3002oaT01Ol600Ko0`02o`L01Ol500go0`08o`T0
1Ol500go1P05o`L00_l400;o2@05o`X00_l800;o00<0ool00ol600So1`04o`<01?l300Go0`05o`03
0?oo00?o1P02o`801_l300;o0`07o`L01ol:00;o1002o`@02_l600;o1002o`X00_l800So1P08o`H0
2?l700Co0`04o`L01OlD00004`02o`X02Ol500Wo2`02oaH02Ol400Ko0P03o`D02Ol300go0`0:o`D0
2Ol300go1009o`D00_l400;o1`09o`L01?l700[o1008o`L01?l300Co0`05o`<01Ol00`3oo`03o`D0
0ol200Ko0P03o`<01ol700Oo2P02o`@00_l400_o1@02o`@00_l900Co1`0:o`@02?l600So1`04o`<0
1?l500Wo4P0001<00_l>00;o2002o`D00_l;00;o5@03o`D00ol400;o1004o`@00ol500?o1@02o`H0
0_l400;o1004o`<00ol500?o1@02o`H00_l300?o1@03o`<00ol400?o1@03o`D00ol600Co1`03o`D0
0ol500;o3002o`D00_l500;o1`02o`@00_l500?o1002o`@01?l500;o3002o``00ol400?o1@02o`D0
0ol300?o1003o`P01?l800;o1004o`D00_l<00;o3002o`D00_l500?o1@03oa40000C00;o3P02oa00
0_l:00;o5@02o`L00_l400;o1004o`@00_l700;o1@02o`H00_l400;o1P02o`<00_l700;o1@02o`H0
0_l300;o1`02o`<01?l300?o1@02o`L00_l600Co1`02o`L00_l500;o3002o`D00_l500;o1`02o`@0
0_l500;o1@02o`@01?l500;o3002o``01?l300?o1@02o`H00_l300Co0`03o`P01?l800;o1P02o`D0
0_l<00;o3002o`D00_l500;o1`02oa40000C00;o3P02oa000_l:00;o5002o`T00_l300;o0`05o`<0
0_l900;o1002o`H00_l400;o1`02o`030?oo00T00_l400;o1P02o`800_l900;o0P04o`801?l400;o
2@02o`@00_l200;o1P02o`L00_l500;o3002o`D00_l500;o0`02o`800_l400;o1002o`H00_l300Go
1@02o`800_l800;o0P02o`P01?l200Co1@02o`H00_l300Co0P04o`L00_l200;o1`02o`L00_l400;o
3002o``00_l500;o1002o`T00_l@00004`02o`h00_l@00;o2P02oa@00_l900;o0`02o`<00_l00`3o
o`0300;o2@02o`@00_l600;o1002o`L00_l00`3oo`0900;o1002o`H00_l200;o2@02o`800_l0103o
0004o`@00_l900;o1002o`800_l>00?o1@07o`L00_l500;o1@02o`800ol200;o1003o`800ol600;o
0`02o`030?oo00D00_l200;o2002o`800_l800;o00@0o`001?l500;o1P02o`<00_l0103o0004o`L0
0_l200;o1`02o`L00_l400Oo1`07o`L00_l500;o1002o`T00_l@00004`02o`h00_l?00;o2`02oa@0
0_l900;o0`02o`800ol00`3oo`0300;o2@02o`@00_l<00;o1`02o`030?oo00T00_l400;o2P02o`T0
0_l200;o00H0o`00o`02o`@00_l900;o0`03o`800ol800Oo1P09o`D00_l500;o1@02o`8000?o0?l0
0P02o`@01ol700;o0P03o`030?oo00D01_l800Ko2002o`060?l00?l00_l500;o1@03o`<00_l01P3o
003o00;o1P03o`800ol600;o1`02o`@02Ol500Wo1@02o`D00_l400;o2@02oa00000C00;o3P02o``0
1?l<00;o5002o`T00_l300;o0P02o`800_l300;o2@02o`@00_l<00;o1`02o`030?oo00T00_l400;o
2P02o`T00_l200;o00<0ool00_l00`3oo`0400;o2@02o`<00_l400;o1P07o`P00_l500?o1009o`D0
0_l0103oo`02o`030?oo00@01Ol900;o0P02o`800_l500Ko2006o`P00_l00`3oo`02o`030?oo00D0
2Ol400;o00<0ool00_l00`3oo`0600;o1002o`H00_l700;o1002o`D00ol400;o1@03o`@02Ol400;o
2@02oa00000D00;o3@02o``00ol<00;o5@02o`T00_l300;o00<0ool00`02o`<00_l900;o1002o``0
0_l700;o00<0ool02@02o`@00_l:00;o2@02o`800_l00`3oo`02o`030?oo00@00_l900;o0`02o`@0
0_l500?o3@02o`H00_l400Wo1@02o`030?oo008000Co0?oo1002o`040?ooo`P00_l00`3oo`0300;o
1@02o`800_l800;o0P02o`P00_l00`3oo`02o`030?oo00D02?l500;o00<0ool00_l00`3oo`0600;o
1002o`H00_l700;o1002o`H00_l400;o1P02o`@02Ol400;o2@02oa00000D00;o3@02o`h00_l;00;o
5@03o`P00_l300Go0`02o`<00_l900;o1002o``00_l700;o00<0ool02@02o`@00_l:00;o2@02o`03
0?oo00<00_l300;o0`02o`T00_l200;o1P02o`@00_l70003o`0000@00_l600;o1002o`D00_l500;o
00<0o`000P001?l0ool400;o0P03o`L01Ol300;o1@02o`800_l200;o1002o`800_l200;o0`02o`<0
0_l300;o1002o`@00ol300;o0`02o`<00_l400;o1P02o`D00_l700;o1002o`H00_l400;o1P02o`@0
0_l500;o1003o`P00_l@00005003o``00_l?00;o2P02oaH00_l700;o1004o`@00_l400;o1`02o`D0
0_l<00;o1P02o`<00_l700;o1@02o`/00_l700;o0P02o`<00_l300;o1002o`L00_l300;o1P02o`@0
0_l600;o1P02o`H00_l400;o1@02o`D01?l300Co1002o`<00ol600Co1002o`D00_l600;o1002o`H0
0_l300;o0`02o`<00_l400;o1@02o`<00_l300;o0`02o`@00_l600;o1@02o`H00_l500;o1P02o`@0
0_l600;o1002o`D00_l500;o1`02oa40000E00;o3002o`l00_l900;o6002o`D00_l500Co1002o`@0
0ol500?o1@02o``00_l400Co0`03o`D00ol500;o2`03o`D00ol200;o2002o`@00ol500?o0P03o`H0
0ol300?o1003o`H00_l500?o1002o`D00_l500Co1003o`@00_l400?o1@04o`@00_l500;o1P02o`@0
0_l600;o0`02o`P00_l400;o1003o`<00_l800;o0`03o`H00ol400;o1004o`D00_l500?o1002o`D0
0ol400;o1@02o`H00_l500;o4P0001H00_l700?o00<0ool02@02o`<00ol800;o6@09o`@01?l200Ko
1009o`<02?l800[o1@09o`<02?l900Wo0P06o`801_l400Wo0P06o`801_l300Wo100;o`@01?l300Co
0`04o`D01?l00`3oo`03o`<01Ol200Co0P06o`803?l200co0P06o`801_l00`3oo`08o`<01_l200Ko
00<0ool01?l200Ko0P0:o`@02ol300_o1004o`<01?l500Wo4P0001L000?o00001@06o`T01ol90003
o`0001X01Ol600?o0`06o`H01Ol500So2008o`T01Ol500So2`05o`@01_l200Ko1P05o`@01_l200Ko
1@05o`030?l000<02Ol600Co0`04o`<01?l500Co00<0ool00ol300Go0P03o`<01_l200co0P0<o`80
1_l200Ko00<0ool01ol400Ko0P06o`030?oo00Co0P06o`802?l600Wo1@09o`H01?l300Co1`05oa@0
000R00?o2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(14\\) QNOLDOLPWNVSPIMJOFFXBXWDOPHQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`1m00;o1003oa40000E00;o
:002oaT02_oo07`02_l@00005002obX00_lI00Go0P02ool0O@05o`800_l@00005002obX00_lI0003
o`000?l0P`000ol0000F00005002o`T02Ol900Ko2@02oaT01Ol600Ko0`02o`L01Ol500go0`08o`T0
1Ol500go0P08o`P00_l400;o1P06o`<00_l700;o2002o`030?oo00?o1P08o`L02_l400Go0`05o`<0
1_l:00Go1P07o`L01ol800Go0P05o`802_l400Go0P05o`D00_l400;o1@08o`X01Ol500So1`04o`<0
1?l700Go500001<00_l:00Wo2@06o`X00_lF00Wo1006o`800ol500Wo0`0=o`<02_l500Wo0`0=o`80
2?l800;o1002o`H01_l200?o1P04o`L02_l400So1`0:o`@01Ol300Go00<0ool01ol700Wo1007o`L0
1ol800Go0P05o`802ol300Go0P05o`D00_l400;o1@0:o`H02Ol300So1`04o`<01?l500Wo4P0001<0
0_l>00;o3P02o``00_lE00?o1@03o`@00_l400Co1003o`D00ol500;o1P02o`@00_l400Co0`03o`D0
0ol500;o1P02o`@00_l;00?o1003o`H00_l400Co1P04o`L00ol500?o1@02o`l00_l900;o1`02o`80
0ol400?o1@03o`D00ol500;o3002o``00ol400?o1@02o`D00ol300?o1003o`D00ol400?o1@02o`@0
1?l400?o1@03o`@00_l<00;o1@02o`D00ol500?o4@0001<00_l>00;o3P02o``00_lE00;o1`02o`@0
0_l400Co1002o`L00_l500;o1P02o`@00_l600;o0`02o`L00_l500;o1P02o`@00_l;00Co0`03o`H0
0_l400Co1P04o`L00_l700;o1@02o`l00_l900;o1`02o`800_l600;o1@02o`L00_l500;o3002o`d0
0ol200?o1P02o`H00_l400?o0P03o`H01?l300?o1@02o`H00_l400;o1`02o`@00_l<00;o1@02o`D0
0_l700;o4@0001<00_l>00;o200:o`X00_lD00;o2@02o`<00_l300Go0`02o`T00_l400;o1P02o`@0
0_l700;o00<0ool02@02o`@00_l600;o1002o`/01?l200Co1P02o`<01Ol500;o0P02o`H00_l700;o
1@02o`l00_l900;o0`02o`800_l200;o1P02o`@00_l900;o1002o`800_l800;o0P02o`X00_l200;o
1`02o`H00_l500;o0P02o`L01?l200Co1@02o`L00_l200;o2@02o`<00_l<00;o1@02o`@00_l900;o
400001<00_l>00;o200:o`X00_lD00;o2@02o`<00_l300;o00<0ool00`02o`T00_l400;o1P02o`@0
0_l700;o00<0ool02@02o`@00_l600;o1007o`H00_l0103o0004o`H00_l300;o00<0ool01@02o`80
0_l>00?o1@07o`X00_l900;o0P03o`800_l200;o1P02o`@00_l900;o1002o`800_l800;o0P02o`/0
1?l800;o1P02o`H01?l800;o00@0o`001?l500;o1`02o`800_l900;o0`07o`L00_l500;o1002o`T0
0_l@00004`02o`h00_l800;o1002o``00_lD00;o2@02o`<00_l200?o00<0ool00`02o`T00_l400;o
3002o`L00_l00`3oo`0900;o1002o``02Ol400;o00H0o`00o`02o`H00_l200?o00<0ool01003o`80
0ol800Oo1P09o`P00_l900;o0P000ol0o`0200;o2P02o`@00_l900;o1006o`P01_l;00Co2002o`D0
0ol600Co2002o`060?l00?l00_l500;o1`02o`800_l900;o0`09o`D00_l500;o1002o`T00_l@0000
4`02o`h00_l900;o0`02o``00_lD00;o2@02o`<00_l200;o0P02o`<00_l900;o1002o``00_l700;o
00<0ool02@02o`@00_l<00;o1@03o`<00_l00`3oo`02o`030?oo00H00_l200;o0P02o`@00_l400;o
1P07o`P00_l500?o1`02o`T00_l0103oo`02o`030?oo00X00_l400;o2@02o`@01_l800Ko2`03o`T0
2Ol700?o2@02o`030?oo00;o00<0ool01@02o`L00_l200;o2@02o`<00_l500?o1009o`@00_l900;o
400001@00_l=00;o2P001?l00002o`/00_lE00;o2@02o`<00_l00`3oo`0300;o0`02o`T00_l400;o
3002o`L00_l00`3oo`0900;o1002o``00_l600;o0`02o`030?oo00;o00<0ool01P02o`030?oo00<0
0_l400;o1002o`D00ol=00;o1P02o`L00_l900;o00<0ool00P001?l0ool:00;o1002o`T00_l400;o
0P02o`P00_l200;o2`04o`P02?l800Co2002o`030?oo00;o00<0ool01@02o`L00_l200;o2@02o`<0
0_l600;o1009o`@00_l900;o400001@00_l=00;o2P02o`800_l;00;o5@03o`P00_l300Go0`02o`<0
0_l900;o1002o``00_l700;o00<0ool02@02o`@00_l<00;o1P02o`800_l300;o0`02o`D01Ol300;o
0`02o`H00_l400;o1`000ol0000400;o1P02o`L00_l900;o00<0o`000P001?l0ool:00;o1002o`T0
0_l400;o0P02o`800_l400;o0P02o`800_l600Ko1`02o`@00ol600Ko1P02o`<00_l300;o1002o`L0
0_l200;o2@02o`<00_l600;o1002o`D00_l400?o2002oa00000D00?o3002o`/000?o00000_l;00;o
5P02o`L00_l400Co1002o`@00_l700;o1@02o``00_l600;o0`02o`L00_l500;o3002o`H00_l200;o
0`02o`<00_l500Co1002o`<00_l600;o1002o`H00_l600;o1P02o`L00_l900Co0`04o`X00_l500;o
1`02o`D00_l600;o1002o`H00_l500?o0P03o`H00_l500;o1@03o`800ol500;o0`02o`<00_l400;o
1P02o`@00_l700;o1002o`H00_l400;o1@02o`D00_l700;o4@0001D00_l<00;o30001?l0ool:00;o
6002o`D00_l500Co1002o`@00ol500?o1@02o``00_l400Co0`03o`D00ol500;o3002o`D00ol200;o
2002o`D01?l400;o0P03o`H00ol300?o1003o`H00_l500?o1`02o`T01?l400?o2P02o`D00ol500?o
1@02o`H00_l400;o1P02o`D00_l400;o1P02o`@00ol500;o1002o`D00_l800;o1002o`@01?l400?o
1@03o`@00_l500?o1002o`D00_l600;o1@02oa80000F00;o1`03o`030?oo00`01?l900;o6@09o`@0
1?l200Ko1009o`<02?l800[o1@09o`<02?l700_o0P06o`801_l300Co0P0<o`801_l300Wo100;o`@0
2_l400Co1@04o`@02_l300Wo100<o`803?l300Go0P05o`802_l400Go0P05o`801_l200Ko0P0:o`H0
2Ol300_o1004o`<01?l500Wo4P0001L000?o00001@06o`d00ol90003o`0001X01Ol600?o0`06o`H0
1Ol500So2008o`T01Ol500So1`09o`@01_l200Ko0`03o`<03?l200Ko1@05o`030?l000<02Ol600[o
1004o`D01?l400[o1@05o`H03?l200co0`05o`801Ol200Wo1@05o`801Ol200Ko0P06o`802?l:00Go
1@09o`H01?l300Co1`05oa@0000R00?o3@03ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(15\\) PNOLDOKPWMVSOINJOFFYBYVDOPGQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0X002o`@00olA00005@02obP00_oo09l0
2_l@00005002obX00_oo09l01Ol200;o400001@00_lZ00;oo`2O0003o`0001H0000D00;o2@09o`L0
1Ol<00;o5@08o`L01_l300;o1`05o`D03Ol300So2@05o`D01Ol600;o0P08o`P00_l400;o1@05o`<0
1Ol600;o2002o`030?oo00?o2P05o`H02_l500Ko0`02o`@01_l:00Go1P07o`L01ol:00So100:o`H0
2?l:00;o2008o`X01Ol500So2P06o`T01OlD00004`02o`X02Ol500Wo2`02oa@02?l700Ko0P03o`D0
2Ol300go0`0:o`D02Ol300Go1@03o`802?l800;o1002o`D01Ol300Go1@04o`L02_l600Wo100:o`D0
1_l200?o0P09o`L02Ol400Oo1`07o`X02?l400_o1@08o`T01?l700[o1P09o`<02?l800[o1@09oa80
000C00;o3P02o`P00_l500;o2`02oaH00_l<00;o1004o`@00ol500?o1@02o`H00_l400;o1004o`<0
0ol500?o1002o`D00ol500;o2`03o`@00ol500;o1`02o`H01?l700?o1@03o`@00ol500?o1`02o`X0
0_l400Co0P03o`@00ol500?o1@03o`D00_l<00;o4002o`T00_l500?o1`02o``01?l800;o1004o`@0
0ol500?o1002o`/01?l500;o1003o`D00olA00004`02o`h00_l@00;o2P02oaH00_l<00;o1004o`@0
0_l700;o1@02o`H00_l400;o1P02o`<00_l700;o1002o`D00_l600;o2`04o`<00ol500;o1`02o`H0
1?l700;o1`02o`@00_l700;o1`02o`X00_l400Co0P02o`H00_l500;o1`02o`D00_l<00;o4002o`T0
0_l600;o1`02o``01?l800;o1P02o`@00_l700;o1002o`/00_l700;o1002o`L00_lA00004`02o`h0
0_l@00;o2P02oaH00_l<00;o0`05o`<00_l900;o1002o`H00_l400;o1`02o`030?oo00T00_l300;o
1002o`L00_l;00Co0P04o`D00_l300;o0P02o`D00_l200;o1P02o`L00_l300;o2@02o`H00_l:00;o
0`05o`800_l600;o1002o`T00_l400;o0P02o`P00_l200;o3002o`T00_l600;o1`02o`/00_l200;o
1`02o`L00_l200;o2@02o`<00_l:00?o1`02o`<00_l900;o400001<00_l>00;o4002o`X00_lF00Oo
1`02o`<00_l00`3oo`0300;o2@02o`@00_l600;o1002o`L00_l00`3oo`0900;o0`03o`800ol700Oo
1P02o`040?l000Co1@02o`800ol200;o1@02o`800_l>00?o0`02o`T00_l600;o2P02o`<00_l00`3o
o`0200;o1P02o`@00_l900;o1002o`800_l800;o0P02o``00_l900;o1P02o`L00_l;00;o0P02o`L0
0_l700;o0P02o`T00_l300Oo1@02o`@01ol200;o2@02oa00000C00;o3P02oa000_l:00;o5P09o`D0
0_l200?o00<0ool00`02o`T00_l400;o3002o`L00_l00`3oo`0900;o0`07o`P02Ol400;o00H0o`00
o`02o`D00_l20003o`3o00800_l400?o0P03o`P01ol400;o2@02o`H00_l:00;o0P03o`030?oo00X0
0_l400;o2@02o`@01_l800Ko3003o`P00_l500?o1`03o`T00ol200?o1P02o`L00_l200;o2@02o`<0
2Ol300;o1007o`800_l900;o400001<00_l>00;o2@02o`@00_l;00;o5P02o`D00ol400;o0P02o`80
0_l300;o2@02o`@00_l<00;o1`02o`030?oo00T00_l300Go2P02o`D00ol300;o00<0ool00_l00`3o
o`0500;o00@0ool00_l00`3oo`0400;o1002o`H01ol600;o2@02o`H00_l:00;o0P02o`800_l:00;o
1002o`T00_l400Ko2006o`/01?l800Wo1`04o`T00_l400;o1P02o`L00_l200;o2@02o`<00_l500?o
0P02o`d00_l900;o400001@00_l=00;o2@08o`X00_lG00;o1P02o`@00_l00`3oo`0300;o0`02o`T0
0_l400;o3002o`L00_l00`3oo`0900;o0`02o`040?ooo`T00_l600;o0`02o`030?oo00;o00<0ool0
1@02o`030?oo008000Co0?oo1002o`@00_l500?o2`02o`T00_l600;o2P02o`030?oo00<00_l:00;o
1002o`T00_l400;o0P02o`P00_l200;o2P06o`L02?l700Ko2002o`@00_l600;o1`02o`800_l900;o
0`02o`H00_l200;o3@02o`T00_l@00005002o`d00_l900Oo2`02oaL00_l600;o1005o`<00_l300;o
2@02o`@00_l<00;o1`02o`030?oo00T00_l300;o0P03o`P00_l600;o0P02o`<00_l300;o1002o`03
0?l0008000Co0?oo0`02o`H00_l400;o1`000ol0000200;o2@02o`H00_l:00Go0`02o`X00_l400;o
2@02o`@00_l200;o0P02o`@00_l200;o0P02o`H00_l200;o1`02o`@00ol600;o0P02o`L00_l600;o
1@02o`L00_l200;o2@02o`<00_l600;o0P02o`P00_l300?o2002oa00000D00?o3002o`T00_l@00;o
5`02o`H00_l400Co1002o`@00_l700;o1@02o``00_l600;o0`02o`L00_l400;o0`03o`L00_l600;o
0P02o`<00_l300;o1004o`<01?l300;o1P02o`@00_l600;o1@02o`L00_l700;o2P04o`@00_l:00;o
1@02o`L00_l500;o1P02o`@00_l600;o1@03o`<00_l600;o1@02o`D00ol300;o1P02o`H00_l500;o
1P02o`@00_l700;o1002o`H00_l300;o1P03o`@00_l700;o4@0001D00_l<00;o2@02o`l00_lH00;o
1@03o`@01?l400;o1003o`D00ol500;o3002o`@01?l300?o1@03o`@00_l400?o1P02o`D00ol200;o
2002o`@01?l400?o0P03o`H00ol300?o1003o`D00ol500?o1`02o`X01?l400;o2P02o`D00ol500?o
1@02o`H00_l400;o1P02o`D00_l400;o1P02o`@00ol500;o1002o`D00ol600?o1002o`@01?l400?o
1@03o`@00_l500?o0`03o`@01?l500;o1@02oa80000F00;o1`03o`030?oo00T00_l>00;o5`0;o`@0
1?l200Ko1009o`<02?l800[o1@09o`<01Ol300Go0P0;o`801_l200Ko0P04o`D02_l200Ko0`09o`H0
2Ol400[o1@04o`801_l400[o0`09o`@03?l200co0`05o`801Ol200[o1005o`801Ol200Ko0P06o`80
2_l600Wo0`0;o`D02_l500Wo4P0001L000?o00001@06o`T02?l80003o`0001H02Ol600?o0`06o`H0
1Ol500So2008o`T01Ol500Go0`05o`802Ol400Ko0P06o`801?l500[o0P06o`D01Ol00`3o000700Go
1P0:o`D00ol300Ko100:o`D01Ol600co0P0<o`<01Ol200Go0P09o`D01Ol200Go0P06o`801_l200So
2P05o`D02Ol900Go00<0ool01`05oa@0000R00?o2@08ool0a0000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(16\\) ONOLDOKPWMWSOJNKOFFYAZVDNPGQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0X002o`@00olA00005@02obP00_oo09l0
2_l@00005002obX00_oo09l01Ol200;o400001@00_lZ00;oo`2O0003o`0001H0000D00;o2@09o`P0
1?l<00;o6@05o`H01_l300;o1`05o`D03Ol300So2@05o`D01Ol600;o0P08o`P00_l400;o1@05o`<0
1Ol300;o1002o`D00_l00`3oo`03o`X01Ol700Ko2006o`<00_l200Go1P02o`D01Ol600Oo1`07o`X0
2?l300Ko0`06o`030?oo00So2@02o`P02?l700Ko0`02o`802?l:00Ko2@05oa@0000C00;o2P09o`L0
1ol;00;o5P09o`@01_l200?o1@09o`<03Ol300[o1@09o`<01Ol500?o0P08o`P00_l400;o1@05o`<0
1Ol300;o1002o`D02_l600Wo0`09o`L01_l200?o0P05o`D00ol300Wo1007o`L01ol:00So0`06o`<0
1_l00`3oo`08o`P01?l700[o1@06o`800ol200So200:o`D02OlB00004`02o`h00_l900;o1002o`/0
0_lE00?o1@03o`@00_l400Co1003o`D00ol500;o1P02o`@00_l400Co0`03o`D00ol400;o1@03o`D0
0_l;00?o1003o`D00_l700;o0`03o`@00ol400?o1@03o`@00ol500?o0P03o`@00ol700;o1004o`@0
0_l500?o0`03o`D00ol500;o3002oa000_l800;o1`02o`@00_l500;o2004o`P00_l400Co1@02o`@0
1?l400;o2`04o`D00_l400?o1@03oa40000C00;o3P02o`P00_l600;o2P02oaD00_l700;o1002o`@0
1?l400;o1`02o`D00_l600;o1002o`H00_l300;o1`02o`@00_l500;o1P02o`/01?l300?o1@02o`L0
0_l300Co0`03o`@00_l700;o1002o`L00_l200;o1P02o`L00_l400Co1002o`D00_l400;o1`02o`D0
0_l<00;o4002o`P00_l700;o1003o`@00_l800Co2002o`H00_l500;o1004o`@00_l;00;o1`02o`@0
0_l700;o4@0001<00_l>00;o2002o`H00_l:00;o5002o`T00_l300;o0`05o`<00_l900;o1002o`H0
0_l400;o1`02o`030?oo00T00_l300;o1002o`L00_l;00Co0P04o`D00_l300;o0P02o`<01?l200Co
1002o`L00_l300;o2@02o`030?oo00H00_l700;o0`05o`@00_l400;o1002o`T00_l400;o0P02o`P0
0_l200;o3002o`P02ol500?o0`02o`L00_l200;o1`02o`L00_l400;o0`05o`@00_l:00?o1`02o`<0
0_l900;o400001<00_l>00;o2002o`H00_l:00;o5002o`T00_l300;o0`02o`030?oo00<00_l900;o
1002o`H00_l400;o1`02o`030?oo00T00_l300?o0P03o`L01ol600;o00@0o`001?l500;o0P03o`80
0_l300;o00@0o`001?l<00?o0`02o`T00_l00`3oo`0600;o1`02o`<00_l00`3oo`0400?o0P03o`@0
0_l900;o1002o`800_l800;o0P02o``00_l900Wo1`02o`<00_l700;o0P02o`L00_l700;o1002o`<0
0_l00`3oo`0400Oo1@02o`@01ol200;o2@02oa00000C00;o3P02o`P00_l600;o2P02oa@00_l900;o
0`02o`800ol00`3oo`0300;o2@02o`@00_l<00;o1`02o`030?oo00T00_l300Oo2009o`@00_l01P3o
003o00;o1@02o`8000?o0?l00P02o`<00_l01P3o003o00;o1`07o`@00_l900;o2@02o`L00_l200?o
00<0ool01007o`D00_l900;o1006o`P01_l<00?o2002o`D00_l700?o2P03o`800ol600;o1`02o`@0
0_l200?o00<0ool01009o`<00_l400Oo0P02o`T00_l@00004`02o`h00_l800?o1002o`/00_lD00;o
2@02o`<00_l200;o0P02o`<00_l900;o1002o``00_l700;o00<0ool02@02o`<01Ol:00;o1@03o`<0
0_l00`3oo`02o`030?oo00D00_l0103oo`02o`030?oo00<00_l00`3oo`02o`030?oo00D01ol600;o
2@02o`T00_l700;o0P02o`800_l400Go1`02o`T00_l400Ko2006o`/01?l900;o0`02o`T00ol900;o
1002o`H00_l700;o1002o`800_l200;o1002o`D00ol200;o3@02o`T00_l@00005002o`d00_l800Wo
2P02oaD00_l900;o0`02o`030?oo00<00_l300;o2@02o`@00_l<00;o1`02o`030?oo00T00_l300;o
00@0oooo2@02o`H00_l300;o00<0ool00_l00`3oo`0500;o00<0ool00P001?l0ool300;o00<0ool0
0_l00`3oo`0400?o2`02o`T00_l900;o1`02o`030?oo00<00_l400;o00@0oooo1P02o`T00_l400;o
0P02o`P00_l200;o2P06o`P00_l300;o1@02o`<00_l900;o1002o`H00_l700;o1002o`030?oo00<0
0_l400;o1P02o`800_l=00;o2@02oa00000D00;o3@02o`P00_l00`3oo`02o``00_lE00;o2@02o`<0
1Ol300;o0`02o`T00_l400;o3002o`L00_l00`3oo`0900;o0`02o`800ol800;o1P02o`800_l300;o
0`02o`@00_l00`3o00020004o`3oo`800_l300;o0`02o`<00_l70003o`0000800_l900;o2@02o`L0
1Ol300;o1002o`800ol500;o2@02o`@00_l200;o0P02o`@00_l200;o0P02o`H00_l200;o2@02o`04
0?ooo`D00_l300?o1`02o`H00_l500;o1`02o`@01Ol300;o1002o`H00_l200;o2002o`<00ol800;o
400001@00ol<00;o2@02oa000_lF00;o1`02o`@01?l400;o1002o`L00_l500;o3002o`H00_l300;o
1`02o`@00_l300?o1`02o`H00_l200;o0`02o`<00_l400Co0`04o`800_l300;o0`02o`<00_l600;o
1@02o`L00_l:00;o1`04o`@00_l400;o0`03o`D00_l700;o1@02o`H00_l400;o1P02o`D00ol300;o
2002o`030?oo00H00_l400?o1P02o`H00_l500;o1P02o`D01?l400;o1002o`H00_l300;o1P03o`@0
0_l700;o4@0001D00_l<00;o2@03o`h00_lG00?o1@03o`@01?l400;o1003o`D00ol500;o3002o`@0
1?l300?o1@03o`@00_l400?o1P02o`D00ol200;o2002o`@01?l400?o0P02o`P00_l300?o1003o`D0
0ol500?o2P02o`L01?l400;o1002o`@00ol400?o1@03o`D00_l600;o1002o`H00_l500;o1002o`P0
1Ol600;o1@02o`D00ol600?o1002o`@01?l500Co1002o`@00_l500?o0`03o`@01?l500;o1@02oa80
000F00;o1`03o`030?oo00X00ol<00;o6@09o`@01?l200Ko1009o`<02?l800[o1@09o`<01Ol300Go
0P0;o`801_l200Ko0P04o`D02_l200Ko0`09o`H02Ol600[o0`04o`801_l00`3oo`03o`<01Ol300Wo
100<o`803?l300Go0P05o`<01ol700[o0`06o`801_l200[o1@04o`801_l00`3oo`09o`D02_l500Wo
4P0001L000?o00001@06o`/01ol70003o`0001X01Ol600?o0`06o`H01Ol500So2008o`T01Ol500Go
0`05o`802Ol400Ko0P06o`801?l500[o0P06o`D01Ol00`3o000700Go200:o`<00ol300Ko00<0ool0
0ol300Go1@05o`H03?l200co0`05o`801Ol300Oo1`0:o`<01_l200Ko0P08o`L00ol300Ko00<0ool0
1ol900Go00<0ool01`05oa@0000R00?o3@05ool0``000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(17\\) PMPLDOKPWMXSPKOKOGFYAYWDMPGQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0X002o`@00olA00005@02obP00_oo09l0
2_l@00005002obX00_oo09l01Ol200;o400001@00_lZ00;oo`2O0003o`0001H0000D00;o2@09o`P0
0_l>00;o5@08o`H01Ol300Go0P08o`H03Ol300So2@05o`D01Ol600;o0P08o`P00_l400;o1@05o`<0
1Ol00`3oo`03o`801Ol300;o00<0ool00ol600So1P05o`H00_l600Go1@05o`H00_l500Go2P06o`@0
1ol:00So0`06o`<01_l200So1`02o`@00_l500So1P05o`<01Ol00`3oo`06o`X01_l900Go500001<0
0_l:00Wo2002o`l00_lD00So1P05o`<01Ol200So1P0=o`<02_l500Wo0`05o`D00ol200So2002o`@0
0_l500Go0`05o`030?oo00?o0P05o`<02_l400So1P05o`D00ol400Wo0`05o`D00ol300Wo1P0:o`80
1ol:00So0`06o`<01_l200So1`02o`@00_l500[o1005o`<01Ol00`3oo`06o`P02_l500Wo4P0001<0
0_l>00;o3002o`h00_lF00;o2`02o`L00_l500;o3@02o`H00_l400;o1004o`<00ol500?o1002o`D0
0ol500;o2`03o`@00ol500;o1`02o`<00ol400?o1003o`D00ol500;o3002o`D00ol400?o1@03o`@0
0_l500?o0`03o`D00ol400Co1@02o`@00_l@00;o2002o`L00_l700;o2@03o`@00ol500;o1004o`@0
0_l700;o1002o`/01?l500;o1003o`D00olA00004`02o`h00_l<00;o3P02oaH00_l;00;o1`02o`D0
0_l=00;o1P02o`@00_l600;o0`02o`L00_l400;o1@02o`H00_l;00Co0`03o`D00_l700;o1003o`80
0ol500;o1`02o`D00_l<00;o1@02o`D00_l700;o1002o`D00_l400;o1`02o`@00_l700;o1002oa00
0_l800;o1`02o`L00_l900Co0`03o`D00_l600;o1002o`L00_l400;o2`02o`L00_l400;o1`02oa40
000C00;o3P02o``00_l>00;o5P02o`/00_l300;o0P02o`D00_l=00;o1P02o`@00_l700;o00<0ool0
2@02o`<00_l400;o1`02o`/01?l200Co1@02o`<00_l200;o1@02o`800_l600;o1`02o`D00_l<00;o
1002o`D00_l900;o0`02o`@00_l400;o2@02o`800ol700;o1002o`800_l<00;o200;o`L00_l900Co
0P04o`D00_l700;o0`02o`<00_l200;o1002o`X00ol700;o0`02o`T00_l@00004`02o`h00_l=0003
o`0000`00_lF00Oo1P02o`800ol200;o1@07o`P00_l600;o1002o`L00_l00`3oo`0900;o0`03o`80
0ol700Oo1P02o`040?l000Co1@02o`800ol200;o1P04o`l00ol500Oo1`03o`800ol500;o2@02o`<0
0ol200?o1002o`T00_l200;o1007o`<00_l200;o3002o`T02Ol800;o2@02o`040?l000Co1@02o`L0
0_l300;o0P03o`800_l400Oo1@02o`@01ol200;o2@02oa00000C00;o3P02o`d00_l=00;o5P09o`@0
0_l20003o`3o00800_l500Wo1P02o``00_l700;o00<0ool02@02o`<01ol800Wo1002o`060?l00?l0
0_l500;o0P000ol0o`0200;o1P04o`X01ol600Wo1@07o`H00_l900;o0`07o`D00_l900;o0P02o`@0
1ol300Ko3003o`P00_l500;o2003o`P00_l01P3o003o00;o1@02o`L00_l300;o0P000ol0o`0200;o
1009o`<00_l400Oo0P02o`T00_l@00004`02o`h00_l=00;o3@02oaH00_l500?o0`02o`040?oo00;o
00<0ool01@02o`D00ol500;o3002o`L00_l00`3oo`0900;o0`05o`X00_l500?o0`02o`030?oo00;o
00<0ool01@02o`040?oo00;o00<0ool01P03o`T01ol800;o1@03o`@01Ol800;o2@02o`<01Ol700;o
2@02o`800_l>00Ko2`04o`T00_l300;o2004o`P00_l00`3oo`02o`030?oo00D00_l700;o0`02o`04
0?oo00;o00<0ool01002o`D00ol200;o3@02o`T00_l@00005002o`d00_l>0003o`0000X00_lG00;o
1P02o`<00_l00`3oo`020004o`3oo`D00_l600;o1@02o``00_l700;o00<0ool02@02o`<00_l0103o
ool900;o1P02o`<00_l00`3oo`02o`030?oo00D00_l00`3oo`020004o`3oo`H01?l700?o3@02o`H0
0_l400;o00@0oooo1`02o`T00_l300;o00@0oooo1P02o`T00_l200;o3P02o`800_l:00Ko2002o`<0
0_l700Ko1`02o`030?oo00;o00<0ool01@02o`L00_l300;o00<0ool00P001?l0ool400;o1P02o`80
0_l=00;o2@02oa00000D00;o3@02o`h00_l;00;o5`02o`H00_l300;o00<0o`000P001?l0ool500;o
1P02o`D00_l<00;o1`02o`030?oo00T00_l300;o0P03o`P00_l600;o0P02o`<00_l300;o1002o`03
0?l0008000Co0?oo1@06o`H00_l70003o`0000@00_l600;o1002o`800ol600;o2@02o`<00_l200?o
1@02o`T00_l200;o2002o`@00_l200;o0P02o`H00_l200;o2@02o`040?ooo`L00_l200;o1P02o`<0
0_l300;o1002o`L00_l300;o00<0o`000P001?l0ool400;o1P02o`800_l800;o0`03o`P00_l@0000
5003o``00_l>00;o2`02oaL00_l600;o0`04o`<01?l500;o1P02o`D00_l<00;o1P02o`<00_l700;o
1002o`<00ol700;o1P02o`800_l300;o0`02o`@01?l300Co1003o`800ol500;o1P02o`H00_l600;o
1002o`<00ol600;o1`02o`@00_l300?o1@02o`L00_l400;o1P03o`@00_l600;o1@03o`<00_l800;o
00<0ool01`03o`<00_l500;o0`02o`<00_l400;o1P02o`@01?l300Co1002o`H00_l300;o1P03o`@0
0_l700;o4@0001D00_l<00;o3`000ol0000800;o6002o`D00ol300Co1003o`D00_l500?o1@02o``0
0_l400Co0`03o`D00ol400;o1003o`H00_l500?o0P02o`P00_l400Co1003o`@00_l400;o1@03o`@0
0ol600;o1@03o`@00_l400?o1@03o`D00ol400;o1003o`@00ol500?o1003o`@01?l400;o1P02o`D0
0_l400;o2005o`L00_l400;o1@02o`P00_l400;o1004o`@01?l400?o1002o`D00ol300?o1004o`D0
0_l500;o4P0001H00_l700?o00<0ool02002o`D00_l800;o5`0;o`<01?l500Co0P0;o`<02?l800[o
1@09o`<01Ol300Go0P0;o`801_l200Ko0P04o`D01?l00`3oo`03o`801Ol400Wo100;o`<01Ol300Go
1009o`<01Ol300Go0`09o`H02_l200co0`05o`801Ol300Oo1P05o`801Ol200Ko0P06o`802_l400Co
1@04o`030?oo00Wo1@0:o`D02OlB00005`000ol0000500Ko2009o`P000?o00005P09o`D01?l500Co
0P09o`D02?l800So2@05o`D01Ol300Go0P09o`@01_l200Ko0P04o`D01?l00`3oo`03o`801Ol600Go
00<0o`000`09o`D01Ol300Go1P05o`D01Ol300Go1@05o`X01Ol00`3oo`0200co0`05o`801Ol300Oo
1P05o`801Ol200Ko0P06o`802?l600Co1@04o`030?oo00Oo2@05o`030?oo00L01OlD00008P03o`P0
2Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(18\\) OMPMEPKPWMXTQKOKNGGZAZWCLQHQ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02olL00_l400?o/P02o`@00olD00;o1003oa40
000E00;o:002olH02_na00[o4`0:oa00000D00;o:P02olH01Ol200;o/P05o`800_lD00Go0P02oa00
000D00;o:P02olH000?o0000^0000ol0000J0003o`0001H0000D00;o2@09o`P01?l<00;o6@05o`D0
1Ol300Go0P08o`H01Ol300Go0P0<o`802?l600Go1P02o`802?l800;o1002o`D01Ol300Go00<0ool0
0ol200Go1008o`T01Ol500Go1P02o`H01Ol500Go1P02o`801_l300;o1`06o`P01_l600[o0P06o`<0
1_l00`3oo`08o`H00_l400;o2005o`H03Ol500Go1P04o`<01?l700Go500001<00_l:00Wo1P08o`/0
0_lF00Wo0`05o`<01Ol200So1P05o`<01Ol200co0P08o`H01Ol500?o0P08o`P00_l400;o1@05o`<0
1Ol00`3oo`03o`801Ol400So1`09o`<01Ol500?o1009o`<01Ol500?o0P06o`800ol500[o100:o`@0
2_l200Ko0`06o`030?oo00So1P02o`@00_l600Wo100=o`<02Ol400Co0`04o`D02OlB00004`02o`h0
0_l800?o1003o`X00_lE00?o1@03o`<00_l700;o1@02o`/00_l700;o1@02o`H00_l400;o3002o`D0
0ol500;o2`03o`@00ol500;o1`02o`<00ol400?o2002o`T00ol500?o1002o`D00ol400?o1@03o`@0
0_l500?o1002o`@01?l400Co1@02o`<01?l500;o1@02o`D00_l400;o1`02o`@00_l500;o1@03o`@0
0ol400?o1@03o`H00_l600;o0P03o`D00ol400;o1@02o`D00ol500?o4@0001<00_l>00;o2002o`H0
0_l:00;o5@02o`L00_l300;o1`02o`D00_l;00;o1`02o`D00_l600;o1002o``00_l500;o1P02o`/0
1?l300?o1@02o`L00_l400?o0P03o`T00_l900;o1`02o`@00_l500;o1@02o`L00_l400;o1@02o`D0
0_l400Co1002o`L00_l300;o1`02o`D00ol400;o1002o`L00_l400?o1002o`D01?l300?o1002o`L0
0_l600;o1P02o`800_l700;o1002o`D00_l500;o1`02oa40000C00;o3P02o`P00_l600;o2P02oa@0
0_l900;o0P02o`<00_l200;o1@02o`/00_l300;o0P02o`D00_l200;o0P02o`@00_l<00;o1002o`L0
0_l;00Co0P04o`D00_l300;o0P02o`D00_l200;o2P02o`P00_l900;o0`02o`@00_l500;o2@02o`<0
0_l400;o1P02o`<01Ol300?o1`02o`800ol700;o1P03o`<00_l400_o1@03o`<00_l500Co0P04o`<0
0ol?00;o1P02o`030?oo00T00_l300;o1@02o`@00_l900;o400001<00_l>00;o2002o`H00_l:00;o
5002o`T00_l200;o0P03o`800_l500Oo1P02o`800ol200;o1@02o`800_l800Oo1`03o`800ol700Oo
1P02o`040?l000Co1@02o`800ol200;o1P04o`/00_l800;o2@02o`<00ol200?o1@02o`T00_l300?o
0P03o`H00_l300;o00<0ool00`02o`@01ol00`3oo`0400Oo1P02o`<00_l500Wo1`02o`<00_l500;o
00@0o`001?l300;o4002o`H00_l00`3oo`0900;o0`02o`D00_l400;o2@02oa00000C00;o3P02o`T0
0_l400;o2`02oa@00_l900;o0P02o`8000?o0?l00P02o`D02Ol400;o0P000ol0o`0200;o1@06o`P0
2Ol500Oo2009o`@00_l01P3o003o00;o1@02o`8000?o0?l00P02o`H01?l;00;o2002o`T00_l300Oo
1P02o`T00_l300Oo1`02o`800ol00`3oo`0300;o1007o`030?oo00@01ol600?o2@02o`D00_l700?o
2@02o`060?l00?l00_l300;o4002o`T00_l900;o0`02o`D00_l400;o2@02oa00000C00;o3P02o`X0
1ol;00;o5002o`T00_l200;o00@0ool00_l00`3oo`0500;o1@03o`<00_l0103oo`02o`030?oo00D0
1_l800;o1@03o`@01Ol:00;o1@03o`<00_l00`3oo`02o`030?oo00D00_l0103oo`02o`030?oo00H0
0ol<00;o2002o`T00_l300Go2002o`T00_l300Go2@02o`800_l200;o0`02o``00_lB00?o2@02o`<0
0_l900?o2002o`030?oo00;o00<0ool00`02oa000_l900;o2@02o`<02Ol400;o2@02oa00000D00;o
3@02o`X01_l;00;o5@02o`T00_l200;o00<0ool00P001?l0ool500;o1P02o`<00_l00`3oo`020004
o`3oo`D00_l200;o2002o`H00_l400;o00@0oooo2@02o`H00_l300;o00<0ool00_l00`3oo`0500;o
00<0ool00P001?l0ool600Co1P02o`<00_l300;o0`02o`T00_l300;o00@0oooo1`02o`T00_l300;o
00@0oooo2002o`030?oo00<00_l300;o3002o`h00_l300;o2@02o`<00_l500;o0`02o`P00_l00`3o
o`02o`030?oo00<00_l@00;o2@02o`T00_l300Wo1002o`T00_l@00005002o`d00_l900;o1002o`X0
0_lE00;o2@02o`800_l00`3o00020004o`3oo`D00_l600;o0`02o`030?l0008000Co0?oo1@02o`80
0_l200;o1002o`H00_l400;o0P03o`P00_l600;o0P02o`<00_l300;o1002o`030?l0008000Co0?oo
1@06o`D00_l300;o0`02o`<00ol800;o0`02o`800ol600;o2@02o`<00_l200?o1`05o`<00_l300;o
2002o`800_l800;o1002o`<00ol900;o00@0oooo1@02o`<00ol600;o0`02o`<00_l200?o1`02o`H0
0_l900?o2002o`<00_l500;o1003o`P00_l@00005003o``00_l800;o1P02o`T00_lF00;o1`02o`<0
1?l300Co1@02o`H00_l300Co0`04o`D00_l600;o1002o`H00_l400;o0`03o`L00_l600;o0P02o`<0
0_l300;o1004o`<01?l400?o0P03o`@00_l300;o0`02o`@00_l700;o1002o`<00ol600;o1`02o`@0
0_l300?o1P04o`@00_l400;o1P03o`<00_l600?o1002o`@00ol800;o00<0ool01P02o`@00ol500;o
0`02o`<00_l300;o1`02o`H00_l:00;o1`02o`@00_l500;o1@02o`L00_lA00005@02o``00_l800;o
1P02o`P00_lG00?o1@03o`<01?l400?o1@02o`D00ol300Co1003o`D00_l600;o1002o`D00ol400;o
1003o`H00_l500?o0P02o`P00_l400Co1003o`@00_l400;o1002o`<00_l300;o1@02o`D00_l500;o
1003o`D00ol500?o1002o`@00ol500Co1002o`@00ol400Co0`03o`@01?l400;o1@02o`P01Ol600;o
1@02o`D00_l800;o0`03o`D00ol600;o2`02o`D00_l500;o1@02o`H00_l500;o4P0001H00_l700?o
00<0ool02003o`@00ol700;o6@09o`<01?l500Co0P0;o`<01?l500Co0P0<o`802ol300Go0`05o`80
2ol200Ko0P06o`801?l500Co00<0ool00ol200Go0P0<o`D02Ol300Go0`05o`@02Ol300Go0`05o`80
1?l200Ko100:o`@02_l400[o1007o`L02_l300Ko0P06o`<02_l300So2009o`@01?l300Co1@09oa80
000G0003o`0000D01_l900So20000ol0000J00Go1@04o`D01?l200Wo1@04o`D01?l200co0P09o`D0
1Ol300Go0P09o`@01_l200Ko0P04o`D01?l00`3oo`03o`801Ol200co1`05o`D01Ol300Go1P05o`D0
1Ol300Go0P03o`<01_l600Go00<0ool01P05o`030?oo00@02_l400Oo1`0:o`<01_l200Ko1@05o`03
0?oo00<02?l:00Go1P04o`<01?l700Go500002800ol:00Koo`350000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(19\\) OMPLEOKOWMWUQKOKNGGZAYXCKPHP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02olL00_l400?oj@0001D00_lX00;oaP0:onP0
000D00;o:P02olH01Ol200;oj00001@00_lZ00;oaP000ol0003^00005002o`T02Ol500Go3P02oaT0
1Ol500Go0`05o`802?l600go0P0<o`H01Ol500Go1P02o`H01Ol700;o1002o`D01Ol300Go0`02o`@0
0_l900Co2P05o`D01Ol600;o1P05o`D01Ol600;o0P06o`<00_l700Ko2006o`H02_l200Ko0`06o`80
2?l500Go0P05o`H01Ol600Go1P02o`030?oo00Ko1`04o`<01?l300So5@0001<00_l:00Wo1@07o`d0
0_lF00Wo0`05o`<01Ol200So1P0=o`803?l400Wo0`05o`D00ol400Wo1@02o`@00_l500Go0`05o`<0
0_l400;o1`08o`H02Ol300Go1@03o`@02Ol300Go1@03o`801_l200?o1@0:o`@02_l400[o0P06o`<0
1_l200So1@05o`801Ol400Wo1005o`D00ol00`3oo`06o`L01?l300Co0`08oaD0000C00;o3P02o`d0
0ol<00;o5@03o`D00ol300;o1`02o`D00_l=00;o1P02o`@00_l600;o0`03o`D00ol400;o1@03o`@0
0ol500?o0`03o`@00ol500;o1`02o`<00ol400?o1P02o`@00_l500?o1@03o`@00_l500?o1003o`D0
0ol400;o1@03o`@00_l400Co1004o`D00_l300Co1@02o`D00_l500;o1002o`L00_l700;o2@03o`@0
0ol400?o1@03o`D00_l500?o1002o``00_l500;o1P02oaT0000C00;o3P02o`h00ol;00;o5@02o`L0
0_l300;o1`02o`D00_l=00;o1P02o`@00_l600;o0`02o`L00_l400;o1@02o`D00_l700;o0`04o`<0
0ol500;o1`02o`<01?l300?o1@02o`H00_l400;o1`02o`@00_l500;o1@02o`L00_l400;o1@02o`D0
0_l400Co1002o`L00_l300;o1`02o`D00ol400;o1002o`L00_l700;o2P03o`800ol500;o1`02o`D0
0_l500;o1@02o``00_l500;o1P02oaT0000C00;o3P02o`l00_l;00;o5002o`T00_l200;o0`02o`80
0_l500;o3@02o`H00_l400;o0P02o`800_l200;o2@02o`<00_l400;o1@02o`T00_l200Co0P04o`D0
0_l300;o0P02o`<01?l200Co1@02o`H00_l300;o2@02o`<00_l400;o1@02o`T00_l300;o1002o`H0
0_l300Go0`03o`L00_l200?o1`02o`H00ol300;o100;o`L00_l;00;o0P02o`D00ol>00;o1002o`H0
0_l<00;o1@02o`H00_lI00004`02o`h00_l;00Co00<0ool02P02oa@00_l900;o0P02o`800ol200;o
1@07o`P00_l600;o1002o`800_l600;o2@02o`<00ol200?o1@02o`T00_l200;o00@0o`001?l500;o
0P03o`800_l300;o00@0o`001?l500;o1P02o`<00_l900;o0`03o`800ol500;o2@02o`<00ol200?o
1P02o`<00_l00`3oo`0300;o1007o`030?oo00@01ol600;o0`02o`D02Ol800;o3004o`H00_l?00?o
0P03o`H01ol700;o1@02o`H01olD00004`02o`h00_l900Wo2P02oa@00_l900;o0P02o`8000?o0?l0
0P02o`D02Ol600;o3006o`H00_l900;o0`07o`H00_l900;o0P02o`060?l00?l00_l500;o0P000ol0
o`0200;o0`02o`060?l00?l00_l500;o1P02o`<00_l900;o0`07o`H00_l900;o0`07o`L00_l200?o
00<0ool00`02o`@01ol00`3oo`0400Oo1P03o`T00_l500;o2003o`/01?l600;o3`07o`L02Ol500;o
1@02o`H02OlB00004`02o`h00_l900;o1003o`X00_lD00;o2@02o`800_l0103oo`02o`030?oo00D0
0_l500?o1@02o``01_l600;o2@02o`<01Ol800;o2@02o`800_l00`3oo`02o`030?oo00D00_l0103o
o`02o`030?oo00<00_l00`3oo`02o`030?oo00D00_l600;o0`02o`T00_l300Go2002o`T00_l300Go
2@02o`800_l200;o0`02o``00_lB00?o2@02o`<00_l800Co2`03o`L00_l?00Go2@02o`D00ol400Wo
1P02o`D00olA00005002o`d00_l800;o1P02o`T00_lE00;o2@02o`800_l00`3oo`020004o`3oo`D0
0_l600;o1@02o``00_l200;o1P02o`T00_l300;o00@0oooo1`02o`T00_l200;o00<0ool00_l00`3o
o`0500;o00<0ool00P001?l0ool300;o00<0ool00_l00`3oo`0500;o1P02o`<00_l900;o0`02o`04
0?ooo`L00_l900;o0`02o`040?ooo`P00_l00`3oo`0300;o0`02o``00_l>00;o0`02o`T00_l300;o
1`06o`X01?l600;o3`02o`040?ooo`P00_l600;o1009o`H00_l600;o4@0001@00_l=00;o2002o`H0
0_l900;o5@02o`T00_l200;o00<0o`000P001?l0ool500;o1P02o`D00_l<00;o0P02o`800_l200;o
2@02o`<00_l200?o1P02o`T00_l00`3oo`0300;o0`02o`@00_l00`3o00020004o`3oo`800_l300;o
0`02o`@00_l600;o0`03o`P00_l300;o0P03o`H00_l900;o0`02o`800ol700Go0`02o`<00_l800;o
0P02o`P00_l400;o0`03o`T00_l0103oool700;o0P02o`T01_l500?o1`02o`D00_l200?o1`02o`H0
0_l400;o1@02o`H00_l600;o4@0001@00ol<00;o2002o`H00_l900;o5P02o`L00_l300Co0`04o`D0
0_l600;o1@02o``00_l600;o0`02o`L00_l400;o0`03o`H00_l700;o0P02o`<00_l300;o1004o`<0
1?l200;o0`02o`<00_l400;o1P02o`@00_l700;o1002o`<00ol600;o1`02o`@00_l300?o1P04o`@0
0_l400;o1P03o`<00_l600?o1002o`@00ol800;o00<0ool01`03o`<00_l700?o0P03o`D00_l700;o
1@02o`<00ol600;o1P02o`@00_l500;o1P02o`H00_lA00005@02o``00_l800;o1P000ol0000700;o
5`03o`D00ol300Co1003o`D00_l500?o1@02o``00_l600;o0`03o`D00ol400;o1003o`D00ol500?o
0P02o`P00_l400Co1003o`800_l800;o1002o`H00_l500;o1@02o`D00_l400?o1@03o`D00ol400;o
1003o`D01?l400;o1003o`@01?l300?o1004o`@00_l500;o2005o`L00_l400;o1`02o`@00_l500?o
1@03o`D00_l400?o1@02o`D00ol400;o1@02o`H00_l500?o4@0001H00_l700?o00<0ool02@02o`@0
0_l800;o6@09o`<01?l500Co0P0;o`<02?l700co1009o`<01Ol300Go1009o`801_l200Ko0P04o`D0
2_l200Ko0P04o`@01?l400Wo0`05o`<01Ol400Wo0`05o`<01Ol200Co0P06o`@02_l400[o100:o`@0
1ol600Go0P05o`<01Ol200Go100:o`<01Ol300Go00<0ool02Ol400Co0`04o`<02olB00005`000ol0
000500Ko2@07o`T000?o00006P05o`D01?l500Co0P09o`D02?l700co1P05o`D01Ol300Go1P05o`@0
1_l200Ko0P04o`D02_l200Ko0P04o`@01?l600Go1@05o`<01Ol600Go1@05o`<01Ol200?o0`06o`H0
1Ol00`3oo`0600Go00<0ool0100:o`@01ol600Go0P05o`<01Ol200Go1P05o`030?oo00<01Ol300Go
00<0ool01ol600Co0`04o`<02OlD00008P03o`/01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(20\\) OMPLENLOWMXUQKPKNGG BZXDJPGP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02olL00_l400?oj@0001D00_lX00;oaP0:onP0
000D00;o:P02olH01Ol200;oj00001@00_lZ00;oaP000ol0003^00005002o`P02_l800Co3002oaT0
1Ol500Go0`05o`802?l600go0P0<o`<01_l300;o0P0=o`H01Ol700;o1002o`D01Ol300Go00<0ool0
0ol200Go1`04o`X01Ol500Go1P02o`802?l600Go1P02o`801_l300;o1`06o`P01_lC00[o1@0:o`@0
1Ol200Go0`08o`P01_l600So2P06o`D02?lE00004`02o`T02_l700Ko3002oaH02Ol300Go0`05o`80
2?l600go0P0<o`<01_l200?o0P0=o`@02Ol500;o1002o`D01Ol300Go00<0ool00ol200Go1@08o`H0
2Ol300Go1@03o`802?l600Go1@03o`801_l200?o1@0:o`@02_lA00_o100:o`@01Ol200Go0`0:o`@0
2Ol500So200:o`<02?lE00004`02o`X00_l500;o1P03o`800ol;00;o5@03o`D00ol300;o1`02o`D0
0_l=00;o1P02o`@00_l600;o1002o`@01?l500;o1P02o`<00ol500?o0`03o`@00ol500;o1`02o`<0
0ol400?o1P02o`@00_l500?o1@03o`@00_l500?o1@02o``00_l500?o1002o`@01?l400Co1@02o`<0
1?l500;o4`02o`D00ol400;o1@02o`D00ol400?o1@02o`@01?l300?o1003o`H00_l;00Co1@02o`D0
0_lI00004`02o`/00ol;00;o1002o`/00_lE00;o1`02o`<00_l700;o1@02o`d00_l600;o1002o`H0
0_l400;o1004o`D00_l600;o0`02o`L00_l300Co0`03o`D00_l700;o1003o`800ol600;o1P02o`@0
0_l700;o1002o`D00_l600;o3002o`D00_l500;o1004o`@00_l700;o0`02o`L00_lC00;o1P02o`@0
0ol400;o1P03o`800ol600;o1P02o`<00_l600;o1P02o`/00_l700;o1@02oaT0000C00;o3003o`T0
0_l600;o2P02oa@00_l900;o0P02o`<00_l200;o1@02o`d00_l600;o1002o`800_l200;o1002o`<0
1Ol500;o1P02o`800_l900;o0P04o`801?l500;o0`02o`800_l500;o0P02o`L00_l600;o0`02o`T0
0_l300;o1002o`L00_l<00;o1002o`H00_l300Go0`03o`L00_l200?o1`02oa<00_l600;o1@03o`<0
0_l700;o0P02o`L00_l700;o0P02o`H00_l600;o2P03o`L00_l500;o6@0001<00_l=00?o2002o`H0
0_l:00;o5002o`T00_l200;o0P03o`800_l500Oo2002o`H00_l400;o0P02o`P00_l300;o00<0ool0
1@02o`H00_l200;o2@02o`800_l0103o0004o`D00_l200?o0P02o`H01?l800;o1P02o`<00_l900;o
0`03o`800ol700Oo1`03o`800ol600;o0`02o`030?oo00<00_l400Oo00<0ool01007oa800_l600;o
1P02o`<00_l800Co2002o`L00_l200;o1P02o`H01ol500;o1007o`@01olD00004`02o`h00ol700;o
1P02o`X00_lD00;o2@02o`800_l20003o`3o00800_l500Wo1P02o``01_l800;o0P03o`030?oo00D0
0_l:00;o2@02o`800_l01P3o003o00;o1@02o`8000?o0?l00P02o`H01?l800;o1P02o`<00_l900;o
0`07o`P02Ol500Oo1`02o`800ol00`3oo`0300;o1007o`030?oo00@01olB00;o1@03o`H00ol<00Co
2002o`L00_l:00;o1P09o`<00_l400Oo1009oa80000C00;o3`03o`H00_l600;o2P02oa@00_l900;o
0P02o`040?oo00;o00<0ool01@02o`D00ol500;o3006o`P00_l200;o0P02o`D00_l:00;o2@02o`80
0_l00`3oo`02o`030?oo00D00_l0103oo`02o`030?oo00H00ol900;o1P02o`<00_l900;o0`05o`X0
0_l500?o1005o`T00_l200;o0P02o`<00_l<00;o7@09o`P00ol;00?o2@02o`L00_l:00;o1P02o`D0
0ol200;o3`02o`D00olA00005002o`l00_l600;o1P02o`T00_lE00;o2@02o`800_l00`3oo`020004
o`3oo`D00_l600;o1@02o``00_l200;o2002o`030?oo00<00_l500;o2P02o`T00_l200;o00<0ool0
0_l00`3oo`0500;o00<0ool00P001?l0ool600Co2002o`H00_l300;o2@02o`<00_l0103oool900;o
1P02o`@00_l0103oool800;o00<0ool00`02o`<00_l<00;o7@08o`D00_l300;o2`04o`P00_l700;o
2P02o`H00_l600;o0P02o`l00_l600;o4@0001@00_l@00;o1@02o`H00_l900;o5@02o`T00_l200;o
00<0o`000P001?l0ool500;o1P02o`D00_l<00;o0P02o`800_l400Go0`02o`D00_l:00;o2@02o`03
0?oo00<00_l300;o1002o`030?l0008000Co0?oo1@06o`L00_l600;o0`03o`P00_l300;o0P03o`P0
0_l600;o1002o`800ol700Go0`02o`<00_l800;o0P02o`P00_lC00;o1003o`@00_l300?o2@06o`L0
0_l700;o2P02o`H00_l600;o0P02o`P00_l500;o1P02oa40000D00?o3`02o`D00_l600;o2@02oaH0
0_l700;o0`04o`<01?l500;o1P02o`D00_l<00;o1P02o`@01?l400;o1@02o`/00_l700;o0P02o`<0
0_l300;o1004o`<01?l400?o0P03o`H00_l600;o1002o`L00_l400;o0`03o`L00_l600;o1002o`<0
0ol600Co1002o`@00_l600?o0`02o`H00olC00;o1@02o`@00_l400?o1`03o`800ol600;o1P02o`/0
0_l600;o1P02o`<00_l600?o1@02o`H00_lA00005@02o`P00_l500;o1P02o`@00_l900;o5`03o`D0
0ol300Co1003o`D00_l500?o1@02o``00_l600;o1004o`@00_l500;o2`03o`D00ol200;o2002o`@0
1?l400?o1002o`@00_l600;o1P02o`D00_l500;o1@02o`@00ol600;o1@03o`@00_l400?o1@04o`@0
0_l400?o1004o`<00ol400Co4`02o`@00ol400;o1@02o`L00_l400;o1P02o`@01?l;00;o1P02o`D0
0ol300?o1004o`D00_l500?o4@0001H00_l700?o0`03o`H00ol200?o2002oaT02Ol300Co1@04o`80
2ol300So1`0<o`<01?l200Ko00<0ool01_l900Wo0P06o`801_l200Co1@04o`030?oo00?o0P05o`<0
1?l400Co1009o`<01Ol300Go0P0;o`<01Ol300Go0P04o`801_l400[o100:oa402_l500[o1005o`80
1Ol300[o1`0:o`030?oo00Wo1@0:o`<02olB00005`000ol0000600Oo2006o`T000?o00006P05o`D0
1?l500Co0P09o`D02?l700co0`03o`<01_l00`3oo`06o`/01Ol400Ko0P06o`801?l500Co00<0ool0
0ol200Go0`04o`@01?l600Go1@05o`<01Ol200Wo1@05o`<01Ol200?o0`06o`H01Ol00`3oo`0600Go
00<0ool04@09o`H02_l400Go0P05o`<02?l900[o00<0ool01ol900Go00<0ool00`09oa@0000Q00Go
2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(21\\) NMQLEMLOWNWTPKQKNFFZBZWDIQFP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oY002o`@00onE00;o1003obh0
000E00;o:002ocH02_nS00[oU00:obd0000D00;o:P02ocH01Ol200;oY005o`800_nE00Go0P02obd0
000D00;o:P02ocH000?o0000ZP000ol0002K0003o`0003<0000D00;o200:o`H02Ol900;o5P06o`<0
0_l200Go0`05o`H01Ol500go0P0<o`801Ol300Go00<0ool02ol600Go1`02o`@00_l600Ko0`02o`@0
0_l400;o1P08o`D02?l600Go1P02o`H01Ol500Go1P02o`801_l300;o0`07o`L01ol900[o0`0:o`D0
2_l600;o1002o`D02?l700[o1`05o`D01ol800So5@0001<00_l900[o1P09o`X00_lE00Ko0P03o`80
1Ol300Go1009o`<03Ol200co0P05o`<01Ol00`3oo`0;o`@02Ol500;o1002o`H01_l200?o1002o`@0
0_l600So1@08o`H01Ol500?o1009o`<01Ol500?o0P06o`800ol300Oo1`07o`T02_l300_o100:o`H0
0_l400;o1@0:o`D02_l500Wo0`07o`P02?lE00004`02o`X00_l500;o2P02o`d00_lF00;o1004o`<0
0_l700;o1003o`D00ol500;o1P02o`@00_l600;o0`02o`L00_l500;o1P02o`<00ol500?o0`03o`@0
0ol600;o1004o`<00ol400?o2002o`X00_l<00;o1@03o`@00ol500?o1002o`D00ol400;o1004o`D0
0_l<00;o3@02o`D00_l500;o1@03o`@00_l500;o1@03o`@00ol500;o1004o`P00_l800?o1@03o`@0
0_l=00;o6@0001<00_l;00?o3`02o`d00_lF00;o1004o`<00_l700;o1002o`L00_l500;o1P02o`@0
0_l600;o0`02o`L00_l500;o1P02o`<00_l700;o0`04o`<00ol600;o1004o`<01?l300?o2002o`X0
0_l<00;o1@02o`D00_l700;o1002o`D00_l500;o1004o`D00_l<00;o3@03o`@00_l500;o1P02o`@0
0ol400;o1@04o`<00ol500;o1P02o`P00_l800;o1`02o`@00_l=00;o6@0001<00_l<00?o3P02o`d0
0_lF00;o0`05o`<00_l300;o0P02o`<00_l900;o1002o`H00_l400;o0P02o`800_l300;o0`02o`80
0_l500;o1P02o`800_l900;o0P04o`801?l600;o0`05o`<01?l200Co2002o`X00_l<00;o1002o`D0
0_l900;o0`02o`@00_l600;o0`05o`D00_l200;o2002o`800_l:00?o0`02o`D00_l600;o1@03o`<0
0_l500Co0P04o`D00_l700;o1`02o`L00_l900;o0`02o`800_l900;o6@0001<00_l=00?o3@02o`d0
0_lF00;o0`02o`030?oo00<00_l200?o0P02o`<00_l900;o1002o`H00_l400;o0P02o`L00_l200?o
0P02o`D00_l600;o0P02o`T00_l200;o00@0o`001?l600;o0`02o`030?oo00<00_l0103o0004o`P0
0_l:00Oo1`03o`800ol500;o2@02o`<00ol200?o1P02o`<00_l00`3oo`0500;o0P02o`P00_l200;o
2`02o`<00_l500;o1P02o`H00_l300;o1@02o`040?l000Co1@02o`L00_l700;o1`02o`T00_l300;o
0P02o`T01olD00004`02o`h00ol<00;o3@02oaH00_l200?o00<0ool00`02o`8000?o0?l00P02o`<0
0_l900;o1002o``01_l700;o0P000ol0o`0200;o1@02o`X00_l900;o0P02o`060?l00?l00_l600;o
0P03o`030?oo00<00_l01P3o003o00;o2002o`X02Ol500Oo1P02o`T00_l300Oo1`02o`800ol00`3o
o`0500Ko2006o`/00ol900;o1@03o`H00ol900;o00H0o`00o`02o`D00_l700;o1`02o`L00_l900;o
0`06o`T02OlB00004`02o`l00ol;00;o3@02oaH00_l200;o0P02o`<00_l0103oo`02o`030?oo00<0
0_l900;o1002o``01_l700;o00@0ool00_l00`3oo`0500;o2P02o`T00_l200;o00<0ool00_l00`3o
o`0600;o0P02o`800_l300;o00<0ool00_l00`3oo`0800;o2P02o`D00ol400Go2002o`T00_l300Go
2@02o`800_l200;o1@06o`P01_l<00?o2009o`P00ol800;o00<0ool00_l00`3oo`0500;o1`02o`L0
0_l700;o2@02o`<01_l900;o1@03oa40000D00;o3`02o`/00_l<00;o5`02o`030?oo00<00_l300;o
00<0ool00P001?l0ool300;o2@02o`@00_l<00;o0P02o`L00_l00`3oo`020004o`3oo`D00_l:00;o
2@02o`800_l00`3oo`02o`030?oo00H00_l00`3oo`0300;o0`02o`030?oo00;o00<0ool00`02o`<0
0_l300;o1@02o`H00_l400;o00@0oooo1`02o`T00_l300;o00@0oooo2002o`030?oo00<00_l500;o
0P02o`P00_l200;o2002o`<00_l800So1@02o`<00_l800;o00<0ool00_l00`3oo`0500;o1`02o`L0
0_l700;o2@02o`<00_l200;o2@02o`H00_lA00005002oa000_l:00;o3002oaL01Ol300;o0`02o`03
0?l0008000Co0?oo0`03o`P00_l400;o3002o`800_l200;o0`02o`030?l0008000Co0?oo1@02o`X0
0_l900;o00<0ool00`02o`<00_l500Go0`02o`800_l300;o0`02o`800_l300;o0`02o`D00_l600;o
1002o`800ol600?o2002o`<00_l200?o1`05o`<00_l500;o0P02o`800_l400;o0P02o`800_l400;o
0`03o`L00_l400?o1002o`<00ol600;o0`02o`<00_l400;o1`02o`L00_l700?o2002o`<00_l200;o
0P02o`D00_l600;o4@0001@00ol?00;o2P02o``00_lG00Co1002o`<01?l300Co1002o`L00_l500;o
3002o`H00_l300Co0`04o`D00_l;00;o1`02o`800_l300;o0`02o`D01?l400;o0P02o`<00_l300;o
0P02o`<00_l300;o1@02o`H00_l400;o0`03o`H00_l700;o1002o`<00ol600Co1002o`D00_l600;o
1002o`H00_l400;o1003o`H00_l500;o1002o`@00ol500;o0`02o`<00_l400;o1P02o`P00_l800;o
1`02o`@00_l600;o1@02o`H00_lA00005@02o`P00_l500;o2P02o`/00_lH00Co1002o`<01?l400?o
1@02o`D00_l600;o3002o`H00_l300Co1003o`D00_l;00?o1@03o`800_l800;o1@04o`@00_l200;o
2002o`800_l300;o0`02o`D00_l500?o1002o`@00ol600;o1@02o`D00_l400?o1@04o`@00_l500;o
1P02o`@00_l600;o1002o`D00_l600;o1003o`@00_l500;o1@02o`P00_l400;o1004o`P00_l900;o
1@02o`D00_l600;o1@02o`D00olA00005P02o`L00ol300?o1P03o`030?oo00X00_lH00Co0P06o`03
0?oo00;o1@04o`@02Ol300So1`0<o`801?l500Co00<0ool01_l900Wo0P06o`801_l300Co0P0<o`80
1_l00`3oo`0:o`<02ol300Go0`05o`@02Ol300Go0`05o`801?l200Ko0P0<o`803?l400[o0`0:o`D0
2_l300Ko0P06o`802_l500[o1@09o`<03?l300_o4P0001L000?o00001P07o`L01_l:0003o`0001L0
0ol300Ko00<0ool00_l500Co1P05o`D02?l700co0P04o`D01?l00`3oo`06o`/01Ol400Ko0P06o`<0
0ol300co0P06o`030?oo00[o0`09o`D01Ol300Go1P05o`D01Ol300Go0P03o`<01_l200co0P0<o`@0
2_l300Wo1P0:o`<01_l200Ko0P08o`L02_l700Go1@0<o`<02OlD00008@05o`/00ooo0<H0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(22\\) NMQLFMMPWNWTPLRJNGFZBZVDIRFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o200:o`D0
2_l900;o5P06o`<00_l200Go0`05o`H01Ol500go0P07o`L01Ol300Go00<0ool00ol300Go0P08o`P0
0_l400;o1P06o`<00_l400;o1002o`H02?l500So1P0=o`801Ol600?o0P06o`L01_l300;o1`06o`@0
1ol900[o0`0:o`D02_l900;o2008o`L02_l300Go1P0:o``01OlD00004`02o`T02_l500[o2P02oaD0
1_l200?o0P05o`<01Ol400Wo0`0=o`801ol700Go0`05o`030?oo00?o0`05o`802?l800;o1002o`H0
1_l200?o1002o`@00_l600So1@08o`H03Ol200Go1@0=o`H01_l200?o1@0:o`801ol900[o0`0;o`@0
2_l800Co1`0:o`D02_l300Go1@0;o`X02OlB00004`02o`X00_l500;o1P02o`D00_l:00;o5P02o`@0
1?l300;o1`02o`@00ol500?o1@02o`H00_l400;o2`02o`L00_l300;o1`02o`D00_l;00?o1003o`H0
0_l400Co0`03o`@00ol800;o2P02o`d00_l600;o1002o`D00ol200?o1003o`H00_l400Co1004o`D0
0_l400;o3@02o`D00_l500;o1@03o`@00_l500;o2004o`P00_l400Co2002o`T00_l500?o1002o``0
0ol500?o4@0001<00_l;00?o3003o`l00_lF00;o1004o`<00_l700;o1002o`L00_l500;o1P02o`@0
0_l;00;o1`02o`<00_l700;o1@02o`/01?l300?o1P02o`@01?l300Co0`03o`P00_l:00;o3@02o`H0
0_l400;o1@02o`<00_l600;o1P02o`@01?l400;o1`02o`@00_l=00?o1002o`D00_l600;o1003o`@0
0_l800Co2002o`H00_l800;o2@02o`D00_l500;o3002o`L00_lA00004`02o``00ol<00?o3P02oaH0
0_l300Go0`02o`<00_l200;o0`02o`T00_l400;o1P02o`@00_l200;o1`02o`<00_l200;o0`02o`<0
0_l200;o1@02o`/01?l200Co1P02o`<01Ol300Co0P04o`P00_l:00;o3@02o`H00_l400;o1002o`@0
0_l600;o1P02o`<01Ol300?o1`02o`@00_l200;o2P03o`<00_l500;o1P02o`D00ol300;o1`02o`80
0_l700;o1`02o`L00_l900;o1002o`H00_l200;o1`02o`T00_l@00004`02o`d00ol<00?o3@02oaH0
0_l300;o00<0ool00`02o`800ol200;o0`02o`T00_l400;o1P02o`@00_l200;o1`02o`800ol200;o
0`02o`800ol200;o1@07o`H00_l0103o0004o`H00_l300;o00<0ool00`02o`040?l000Co2002o`X0
1ol800;o1P02o`@00_l300?o1002o`H00_l600;o0`02o`030?oo00<00_l400Oo0`02o`800_l;00;o
0`02o`D00_l600;o1P02o`<00_l700;o0P02o`L00_l700;o1`02o`T00_l300?o1P02o`800_l700;o
2@02oa00000C00;o3P03o``00ol<00;o5P02o`800ol00`3oo`0300;o0P000ol0o`0200;o0`02o`T0
0_l400;o3006o`L00_l20003o`3o00800_l300;o0P000ol0o`0200;o1@09o`@00_l01P3o003o00;o
1P02o`800ol00`3oo`0300;o00H0o`00o`02o`P00_l:00Wo1P02o``01ol=00;o1P02o`800ol00`3o
o`0300;o1007o`<01_l;00?o2@02o`D00ol600?o2P03o`800ol600;o1`02o`L00_l900Oo1`06o`L0
0_l900;o400001<00_l?00?o3003o`/00_lF00;o0P02o`800_l300;o00@0ool00_l00`3oo`0300;o
2@02o`@00_l<00Ko1`02o`040?oo00;o00<0ool00`02o`040?oo00;o00<0ool01@02o`D00ol300;o
00<0ool00_l00`3oo`0600;o0P02o`800_l300;o00<0ool00_l00`3oo`0800;o2P02o`D00ol500;o
3009o`/00_l600;o0P02o`800_l300;o3P06o``00ol800Wo2003o`T00_l400;o1P02o`L00_l700;o
2@09o`D01_l700;o2@02oa00000D00;o3`02o`d00_l:00;o5`02o`030?oo00<00_l300;o00<0ool0
0P001?l0ool300;o2@02o`@00_l<00;o0P02o`L00_l00`3oo`020004o`3oo`<00_l00`3oo`020004
o`3oo`D00_l600;o0`02o`030?oo00;o00<0ool01P02o`030?oo00<00_l300;o00<0ool00_l00`3o
o`0300;o0`02o`<00_l500;o1P02o`D00_l<00;o1@03o`X00_l600;o00<0ool00`02o`<00_l>00;o
0P02o`P00_l300;o2008o`D00_l300;o2@02o`@00_l600;o1`02o`L00_l900;o1@03o`@00_l200;o
1`02o`T00_l@00005002oa000_l=00;o2@02oaL01Ol300;o0`02o`030?l0008000Co0?oo0`03o`P0
0_l400;o3002o`800_l200;o0`02o`030?l0008000Co0?oo0`02o`030?l0008000Co0?oo1@02o`H0
0_l200;o0`02o`<00_l500Go0`02o`800_l300;o0`02o`800_l300;o0`02o`D00_l600;o1@02o``0
0_l600;o2P02o`H01Ol300;o0`02o`P00_l400;o0P02o`800_l400;o0`03o`L00_l400?o1002o`<0
0ol700;o1P02o`D00_l700;o1`02o`T00_l600;o1002o`800_l200;o0`02o`T00_l@00005003o`l0
0_l=00;o2@02oaL01?l400;o0`04o`<01?l400;o1`02o`D00_l<00;o1P02o`<01?l300Co0`04o`<0
1?l500;o1P02o`800_l300;o0`02o`D01?l400;o0P02o`<00_l300;o0P02o`<00_l300;o1@02o`H0
0_l500;o3002o`H00_l:00;o1P04o`@00_l400;o1P03o`@00_l600;o1002o`@00ol600;o1@02o`@0
0_l400?o1P02o`H00_l500;o1P02o`P00_l900;o1P02o`@00_l600;o1002o`L00_lA00005@02o`P0
0_l500;o1P02o`D00_l800;o6004o`@00_l300Co1003o`D00_l500;o1P02o``00_l600;o0`04o`@0
0ol300Co1003o`D00_l500?o0P02o`P00_l500Co1002o`800_l800;o0P02o`<00_l300;o1@02o`D0
0ol500;o3002o`D00ol:00;o1P04o`@00_l400?o1004o`@00_l600;o1002o`D00_l600;o1003o`@0
0_l500;o1@03o`H00ol400;o1004o`P00_l900;o1@03o`@00_l600;o1003o`D00olA00005P02o`L0
0ol300?o1P03o`<00ol700;o6004o`801_l00`3oo`02o`D01?l400Wo0`08o`L03?l200Co1@04o`03
0?oo00;o1@04o`802ol200Ko0P06o`<01?l200co0P06o`030?oo00[o0`0;o`<02?l700_o1P0:o`80
1?l200Ko100:o`803?l400[o0`0:o`D02_l300Ko0P06o`802_l500[o0`0;o`<03?l500Wo4P0001L0
00?o00001P07o`P01ol80003o`0001L00ol300Ko00<0ool00_l500Co1P05o`D02?l700co0P04o`D0
1?l00`3oo`02o`D01?l200Wo1006o`801_l300?o0`0<o`801_l00`3oo`0:o`<02Ol500So1`09o`P0
2_l200?o0`06o`H01Ol00`3oo`0200co100:o`<02Ol600[o0`06o`801_l200So1`0:o`<02Ol500co
1`05oa@0000Q00Go2P05ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(23\\) NLPLFNMPWMWTPLRJMHFZBZVDHRFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1`05o``00_lF00Ko0`02o`803Ol200So1P0=o`80
1ol800Ko0`02o`801Ol300Go0P08o`P00_l400;o1@05o`<01Ol300;o1002o`H02?l500So1P0=o`80
1Ol600?o0P06o`H01Ol300Go0`04o`<01?l200Oo2@0:o`<02_l500[o2@02o`P02?l700Co0`04o`80
1Ol600[o3005oa@0000C00;o2@0:o`D02Ol;00;o5@06o`800ol200go0P08o`H03Ol200Oo2006o`80
0ol200Go0`05o`802?l800;o1002o`D01Ol300Go0`02o`@00_l600So1@08o`H03Ol200Go1@0=o`D0
1Ol300Go0`04o`<01?l200Oo2@0:o`<02ol400[o2004o`L02_l500Co0`04o`801Ol500_o2P09oa80
000C00;o2P02o`D00_l500;o1@02o`/00_lF00;o1004o`D00_l600;o1002o`d00_l600;o1002o``0
0_l400Co0`02o`L00_l500;o2`03o`@00ol500;o1`02o`<00ol400?o2002o`X00_l=00;o1P02o`@0
0_l500?o0P03o`@00ol500;o1`02o`D00_l500;o1@02o`d00_l500;o1@02o`D00ol400;o1@02o`P0
1?l800;o1004o`D00_l500;o1@02o`D00ol400;o3003o`D00olA00004`02o`/00olB00;o2P02oaH0
0_l400Co1@02o`H00_l400;o3@02o`H00_l400;o3002o`@01?l300;o1`02o`D00_l;00Co0`03o`D0
0_l700;o0`04o`<00ol800;o2P02o`d00_l600;o1002o`D00_l300;o1P02o`D00_l700;o1@02o`D0
0_l500;o3@03o`@00_l500;o1P02o`@00ol400;o2004o`P00_l600;o1@02o`D00_l500;o1@02o`D0
0_l<00;o1`02oa40000C00;o3003oa400_l:00;o5P02o`<01Ol500;o1P02o`@00_l=00;o1P02o`@0
0_l200;o2002o`<01Ol300;o0`02o`800_l500;o2`04o`801?l500;o0`02o`800_l300Co0P04o`P0
0_l:00;o3@02o`H00_l400;o1002o`@00_l600;o1@02o`<00_l200;o1@02o`D00_l500;o0P02o`X0
0ol300;o1@02o`H00_l500?o0`02o`L00_l200;o1`02o`L00_l400;o1@02o`D00_l400;o1P02o`80
0_l700;o2@02oa00000C00;o3@03oa000_l:00;o5P02o`<00_l00`3oo`0500;o1P02o`@01ol800;o
1P02o`@00_l200;o2002o`<00_l00`3oo`0300;o0P03o`800_l500Oo1P02o`040?l000Co1@02o`80
0ol200;o0`02o`040?l000Co2002o`X01ol800;o1P02o`@00_l300?o1002o`H00_l500;o0P03o`80
0_l500;o1@02o`D00_l200;o2`02o`<00_l500;o1P02o`H00_l300;o1`02o`800_l700;o1`02o`@0
0_l500;o1@02o`<00ol600;o0P02o`L00_l900;o400001<00_l>00?o3P02o`/00_lF00;o0P03o`03
0?oo00D00_l<00Wo1P02o``01_l800;o0P03o`030?oo00<00_l20003o`3o00800_l500Wo1002o`06
0?l00?l00_l500;o0P000ol0o`0200;o0`02o`060?l00?l00_l800;o2P09o`H00_l<00Oo3@02o`D0
0_l20003o`3o00800_l500;o1@02o`D01_l;00?o2@02o`D00ol600?o2P03o`800ol600;o1`02o`@0
0_l500;o1@07o`L01_l700;o2@02oa00000C00;o3`03o`X01?l<00;o5P02o`800_l200;o1@02o``0
0_l500?o1@02o``01_l800;o0P02o`800_l300;o00@0ool00_l00`3oo`0500;o1@03o`<00_l00`3o
o`02o`030?oo00D00_l0103oo`02o`030?oo00<00_l00`3oo`02o`030?oo00P00_l:00;o1@03o`D0
0_l<00Wo2`02o`D00_l0103oo`02o`030?oo00D02Ol500Ko3003o`P02Ol800?o2@02o`@00_l600;o
1`02o`@02Ol500Wo1@06o`L00_l900;o400001@00_l?00;o2P03o``00_lG00;o00<0ool00`02o`D0
0_l<00;o1P02o`D00_l<00;o0P02o`P00_l00`3oo`0300;o0`02o`030?oo008000Co0?oo1@02o`H0
0_l300;o00<0ool00_l00`3oo`0500;o00<0ool00P001?l0ool300;o00<0ool00_l00`3oo`0300;o
0`02o`<00_l500;o1P02o`D00_l<00;o1@03o`X00_l500;o00<0ool00P001?l0ool500Wo1@02o`80
0_l800;o0`02o`P02?l500;o0`02o`T00_l400;o1P02o`L00_l400Wo1@02o`D00ol400;o0P02o`L0
0_l900;o400001@00_l@00;o2`02o`/00_lG00Go0`02o`D00_l<00;o1P02o`D00_l<00;o0P02o`80
0_l400Go0`02o`<00_l00`3o00020004o`3oo`D00_l600;o0P02o`<00_l300;o1002o`030?l00080
00Co0?oo0P02o`<00_l300;o0P02o`<00_l300;o1@02o`H00_l500;o3002o`H00_l:00;o1@02o`03
0?l0008000Co0?oo1@02o`D00_l500;o0P02o`800_l400;o0`03o`L00_l400?o1002o`<00ol700;o
1P02o`D00_l700;o1002o`D00_l500;o1P02o`@00_l200;o0P02o`<00_l900;o400001@00ol?00;o
3002o`X00_lG00Co1002o`D00_l<00;o1P02o`D00_l<00;o1P02o`@01?l400;o0`04o`<01?l500;o
1P02o`800_l300;o0`02o`@01?l300Co0P02o`<00_l300;o0P02o`<00_l300;o1@02o`H00_l500;o
3002o`H00_l:00;o1@04o`<01?l500;o1@02o`D00_l600;o1002o`@00ol600;o1@02o`@00_l400?o
1P02o`H00_l500;o1P02o`D00_l500;o1@02o`H00_l400;o1P02o`@00_l700;o4@0001D00_l800;o
1@02o``00_l900;o6004o`@00_l500;o3002o`D00ol500;o3002o`H00_l400Co1002o`<01?l400?o
1@02o`D00ol200;o2002o`@01?l400?o0P02o`P00_l200;o0`02o`<00_l500;o1@03o`D00_l<00;o
1@03o`X00_l500Co1003o`D00_l500;o1@02o`H00_l400;o1@02o`H00_l400?o1002o`D00_l500?o
1P03o`@00_l400Co1@02o`D00_l500;o1@03o`@00_l600;o1003o`D00olA00005P02o`L00ol300?o
1P02o`<00ol800;o6004o`801_l00`3oo`06o`L02ol300So1`0<o`<01?l200Ko00<0ool00_l500Co
0P0;o`801_l200Ko0P04o`D02_l200Ko00<0ool02_l300_o0`08o`L02ol600[o00<0ool00_l500Co
0`04o`<01?l200co100:o`<02_l500[o0`06o`801_l200[o1@04o`<01?l200_o0`0<o`D02OlB0000
5`000ol0000600Oo1`07o`T000?o00005`03o`<01_l00`3oo`06o`L02Ol500So1`0<o`<00ol300Ko
00<0ool00_l500Co0P09o`@01_l200Ko0P04o`D02_l200Ko00<0ool02_l300Wo1@08o`L02Ol800[o
00<0ool00_l500Co0`04o`<01?l200co100:o`<02Ol600[o0`06o`801_l200So1`04o`<01?l200Wo
1@0<o`L01OlD00008@05o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(24\\) OLPLFNLPXMVUPLSJMHF AZVDGRFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o2@06o`T00_lI00Go1@0=o`802?l600go0P07o`P0
1_l300;o0P0=o`802?l600Go0P05o`<01Ol300Go1P02o``01?l600So1P0=o`<00_l00`3oo`03o`L0
1_l600Go0`05o`<01?l300Co0P07oaD01_l300Ko00<0ool02?l900;o2008o`X01_l400Go1P0:o``0
1OlD00004`02o`T02_l900Ko2P02oaH02Ol300go0P08o`H03Ol200Oo2006o`800ol200go0P08o`H0
1Ol200Go0`05o`<01Ol500Co2@08o`@02?l600go0`0:o`<02Ol500Go0`05o`<01?l300Co0P07oaD0
1_l300Ko00<0ool02?l800Co1`0:o`H02_l200Go1@0;o`X02OlB00004`02o`X00_l500;o2`02o``0
0_lE00?o1@03o`D00_l600;o1002o`d00_l600;o1002o``00_l400Co1@02o`H00_l400;o2`03o`@0
0ol500;o1`02o`H01?l900;o1002o`H00_l=00;o1P02o`<00ol500?o0P03o`@00ol500;o1`02o`D0
0_l500;o1@02oaX00_l700;o1002o`D00_l800Co2002o`@01?l400Co1@02o`@00_l500?o1002o``0
0ol500?o4@0001<00_l;00?o4002o``00_lE00;o1`02o`D00_l600;o1002o`d00_l600;o1002o``0
0_l400Co1@02o`H00_l400;o3003o`800ol600;o1`02o`H01?l800;o1P02o`D00_l=00;o1P02o`<0
0_l700;o0P02o`H00_l500;o1`02o`D00_l500;o1@02oaX00_l700;o1003o`@00_l800Co2002o`H0
0_l400;o1`02o`@00_l500;o1@02o``00_l700;o4@0001<00_l<00?o2@0:o`X00_lD00;o2@02o`@0
0_l600;o1002o`d00_l600;o1002o`800_l800;o0`05o`D00_l600;o1002o`d00_l200;o1`02o`<0
0_l200;o1@02o`800_l700;o1P02o`D00_l=00;o1P02o`<00_l700;o0P02o`H00_l500;o0`02o`80
0_l500;o1@02o`D00_l200;o5P0;o`D00ol300;o1`02o`800_l700;o1`02o`800ol700;o1002o`@0
0_l600;o0P02o`L00_l900;o400001<00_l=00?o200:o`X00_lD00;o2@02o`@00_l600;o1007o`P0
0_l600;o1002o`800_l800;o0`02o`030?oo00D00_l600;o1007o`T01?l800;o0P03o`800_l500;o
0P02o`L00_l600;o1@07o`P00_l600;o2`03o`800_l600;o1@02o`800ol200;o1@02o`D00_l500;o
0P02oaL02Ol700;o0`02o`L00_l200;o1`02o`L00_l200;o1007o`<00_l300?o1P02o`800_l700;o
2@02oa00000C00;o3P03o`L00_l400;o3002oa@00_l900;o1002o``02Ol600;o3006o`P00_l200?o
00<0ool01@02o``02Ol700Co2002o`8000?o0?l00P02o`@00ol200?o1P02o`H00_l500Wo1P02o`h0
1ol;00;o1@02o`8000?o0?l00P02o`D00_l500;o1@06oaL00_l500;o1`03o`X00ol200?o1P02o`L0
0_l200;o1007o`<01ol700Ko1`02o`T00_l@00004`02o`l00ol700;o0`02o``00_lD00;o2@02o`@0
0_l<00;o1@03o`D00_l<00Ko2002o`800_l200;o1@02o``00_l500?o1P03o`T00_l0103oo`02o`03
0?oo00@00_l400;o1P02o`H00_l500;o1@03o`D00_l<00Oo3@02o`D00_l0103oo`02o`030?oo00D0
2Ol500Ko6002o`<00_l900?o2@02o`@00_l600;o1`02o`800_l>00Wo1@06o`L00_l900;o400001@0
0_l?00;o20001?l00002o`/00_lE00;o2@02o`@00_l<00;o1P02o`D00_l<00;o0P02o`P00_l00`3o
o`0300;o1@02o``00_l600;o1P04o`P00_l00`3oo`020004o`3oo`@00_l400;o1P02o`H00_l500;o
1P02o`D00_l;00?o4P02o`D00_l00`3oo`020004o`3oo`D02Ol500;o0P02oaP00_l300;o1@02o`<0
0_l900;o1002o`H00_l700;o0P02o`h00_l500?o1002o`800_l700;o2@02oa00000D00;o4002o`L0
0_l200;o2`02oaD00_l900;o1002o``00_l600;o1@02o``00_l200;o0P02o`@01Ol300;o1@02o``0
0_l600;o1@06o`L00_l00`3o00020004o`3oo`<00_l600;o1@02o`H00_l500;o1P02o`D00_l;00;o
1`000ol0000900;o1@02o`030?l0008000Co0?oo1@02o`D00_l500;o0P02o`800_lE00;o00@0oooo
1@02o`<00ol700;o1P02o`D00_l700;o0P02o`P00_l400;o1P02o`@00_l200;o0P02o`<00_l900;o
400001@00ol?00;o20000ol00002o`/00_lF00;o1`02o`D00_l<00;o1P02o`D00_l<00;o1P02o`@0
1?l400;o1@02o``00_l600;o1003o`800ol600Co0`04o`<00_l600;o1@02o`H00_l500;o1P02o`D0
0_l;00;o1P02o`/00_l500Co0`04o`D00_l500;o1@02o`H00_lE00;o00<0ool01P02o`@00ol600;o
1P02o`D00_l600;o1002o`H00ol400;o1P02o`@00_l600;o1002o`L00_lA00005@02o`P00_l500;o
2@001?l0ool:00;o5`03o`D00ol500;o3002o`D00ol500;o3002o`H00_l400Co1002o`D00_l<00;o
1@03o`@00_l400;o1P04o`@00ol200?o1P03o`@00_l600;o1@02o`D00ol500;o2`03o`@00ol;00;o
1@04o`@00ol500;o1@02o`D00_l600;o5@05o`H00_l500;o1@03o`H00ol400;o1004o`@00ol400Co
1002o`D00ol400;o1P02o`@00ol500?o4@0001H00_l700?o0`03o`T01?l900;o6@09o`<02?l700_o
0`08o`L03?l300Co0P06o`030?oo00Ko1`0;o`<01Ol200Go0`04o`D02_l200Ko0P04o`@01?l200_o
0`08o`T02Ol600[o00<0ool00_l500Co0`04o`<01?l200co4P07o`L02_l300Ko0P06o`802_l600[o
0P0;o`<03?l500Wo4P0001L000?o00001P07o`/00ol90003o`0001X01Ol500So1`09o`D02?l700co
0`03o`<01_l00`3oo`06o`L02Ol500Go0P05o`<01?l500[o0P06o`801?l400Co0P09o`D02?l;00Go
00<0o`001@0:o`030?oo00;o1@04o`<01?l300Co0P0<oa801ol700[o0`06o`801_l200So2P05o`03
0?oo00802Ol500co1`05oa@0000Q00Go3003ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(25\\) OKOLFNLPYLWVPLSJLHF AZVEGRFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1`05o``00_lI00Go1@05o`H00_l600Go1@0=o`80
1ol800Ko0`02o`803Ol200So2008o`D03Ol300;o1002o`T00_l800So1P0=o`<00_l00`3oo`03o`L0
1_l600go0`04o`<01?l200Oo5@06o`<01_l00`3oo`08o`T00_l700co1`06o`@01Ol600[o2@06o`<0
0_lA00004`02o`T02_l500Wo2`02oaH02Ol300Go1@03o`@02Ol300go0P07o`P01_l200?o0P0=o`80
2?l800So1@0=o`<00_l400;o2004o`L02?l600go0`0:o`<02Ol500go0`04o`<01?l200Oo5@06o`<0
1_l00`3oo`08o`P01?l600co1@0:o`801Ol500_o2@06o`800olA00004`02o`X00_l500;o1@02o`D0
0_l;00;o5@03o`D00ol400;o1@03o`@00ol500?o1@02o`H00_l400;o3002o`@01?l500;o1P02o`@0
0_l?00;o2`02o`H00_l200?o1003o`L01?l900;o3@02o`H00_l300?o1@03o`800ol400?o1`02o`H0
0_l400;o1@02o`D00_lJ00;o1`02o`@00_l500;o2004o`P00_l600;o1004o`D00_l400;o1@03o`@0
0_l=00;o1004oa40000C00;o2`03oa800_l:00;o5@02o`L00_l400;o1@02o`D00_l700;o1@02o`H0
0_l400;o3002o`@01?l500;o1P02o`@00_l?00;o2`02o`H00_l200Co0`03o`L01?l900;o3@02o`H0
0_l300;o1`02o`800_l600;o1`02o`H00_l400;o1@02o`D00_lJ00;o1`02o`@00ol400;o2004o`P0
0_l600;o1002o`L00_l400;o1@02o`D00_l=00;o1004oa40000C00;o3003oa400_l:00;o5002o`T0
0_l300;o1002o`D00_l900;o1002o`H00_l400;o0P02o`P00_l300Go1@02o`H00_l400;o3`02o`/0
0_l600;o0P04o`801?l600;o0P02o`P00_l=00;o1P02o`<00_l700;o0P02o`H00_l700;o1P02o`@0
0_l500;o1@02o`800_lF00_o1@03o`<00_l700;o0P02o`L00_l200;o0P02o`<00ol700;o1002o`@0
0_l600;o0P02o`T00_l300Go4@0001<00_l=00?o4002o`X00_lD00;o2@02o`<00ol200?o1@02o`T0
0_l400;o1P02o`@00_l200;o2002o`<00_l00`3oo`0500;o1P02o`@01ol:00;o2`02o`H00_l200;o
00@0o`001?l600;o0P02o`P01ol800;o1P02o`/00ol200;o1P02o`L00_l600;o1002o`D00_l500;o
0P02oaL02Ol700;o0`02o`L00_l200;o1`02o`800_l700;o1007o`<00_l300?o1P02o`800_l900;o
0`02o`030?oo0140000C00;o3P03o`l00_l:00;o5002o`T00_l300Oo1P02o`T00_l400;o3006o`P0
0_l200?o00<0ool01@02o``02Ol800?o2P02o`X00_l01P3o003o00;o1@03o`800ol700Wo1P02o`h0
1ol;00;o1`02o``00_l500;o1@06oaL00_l500;o1`03o`X00ol200?o1P06o`L00_l400Oo0`07o`L0
1_l900;o0P03o`030?oo0140000C00;o3`03o`L00_l400;o2`02oa@00_l900;o0`05o`P00_l900;o
1002o``01_l800;o0P02o`800_l500;o3002o`D00ol600Co2P02o`X00_l00`3oo`02o`030?oo00D0
0_l400;o1`02o`D00ol500;o3007o`d00_l700;o3009o`D01_lH00;o0`02o`T00ol900;o1002o`H0
1_l700;o3P09o`D01_l900;o0P02o`800_lA00005002o`l00_l700So2P02oaD00_l900;o0`02o`04
0?ooo`L00_l900;o1002o``00_l200;o2002o`030?oo00<00_l500;o3002o`H00_l500Ko2@02o`X0
0_l00`3oo`02o`030?oo00D00_l400;o1`02o`H00_l500;o2`03oa800_l700;o3009o`D00_l200;o
6002o`<00_l500;o0`02o`T00_l400;o1P02o`800_l700;o3P02o`D00ol400;o0P02o`T00_l00`3o
o`0300;o4@0001@00_l@00;o1P07o`/00_lE00;o2@02o`<00_l200?o1P02o`T00_l400;o3002o`80
0_l200;o1005o`<00_l500;o3002o`H00_l500;o0P02o`T00_l900;o0`02o`<00_l300;o1P02o`H0
0_l600;o1@02o`/00_l70003o`0000T00_l700;o3002o`D00_l500;o0P02o`800_lE00;o00@0oooo
1@02o`<00ol700;o1P02o`D00_l200;o0P02o`<00_l800;o1002o`H00_l400;o0P02o`800_l500Go
0`02oa40000D00?o3`02o`H00_l@00;o5P02o`L00_l400;o0`03o`H00_l700;o1@02o``00_l600;o
1004o`@00_l500;o3002o`H00_l400?o0`02o`P00_l900;o0`02o`<00_l300;o1P02o`H00_l600;o
1@02o`/00_l600;o2`02o`L00_l<00;o1@02o`D00_l600;o5@02o`030?oo00H00_l400?o1P02o`H0
0_l500;o1P02o`@00_l600?o1002o`H00_l400;o1P02o`D01?l400;o4@0001D00_l800;o1@02o`H0
0_l?00;o5`03o`D00ol400;o1003o`D00ol500?o1@02o``00_l600;o1004o`@00_l500;o3002o`D0
0ol400;o1002o`P00_l900;o2002o`800ol600?o1@02o`D00ol500;o2`03o`@00ol;00;o1`02o``0
0_l500;o1@02o`H00_lE00Go1P02o`D00_l500?o1P03o`@00_l600;o1003o`@01?l400;o1@03o`@0
0_l600;o1@04o`@00_lA00005P02o`L00ol300?o1P02o`h00_lI00Wo0`05o`<01Ol400Wo0`08o`L0
3?l300Co0P06o`030?oo00Ko1`0;o`<01Ol200Go0`08o`D01_l200co0P06o`802ol300So2@09o`H0
2_l00`3oo`06o`P01?l300Co0P0<oa801ol700[o0`06o`801_l00`3oo`0:o`D02_l200_o0`0<o`@0
1?l200Ko400001L000?o00001P07o`L02?l80003o`0001X01Ol500Go0`05o`H01Ol500So1`0<o`<0
0ol300Ko00<0ool01_l700Wo1@05o`801Ol300So1@06o`803?l200Ko0P09o`D02?l;00Go00<0o`00
1@0:o`030?oo00Ko2004o`<01?l200co4P07o`L02_l300Ko0P06o`030?oo00[o1`05o`030?oo0080
2Ol500co1003o`<01_l@00008@05o`P02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(26\\) OKOKFNLPXLWWPLTKLIF AZWEGQFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o200:o`P0
1?l<00;o6@05o`D01Ol600;o1P05o`D01Ol600;o0P07o`P01_l300;o0P0=o`802?l600Go0P05o`<0
3Ol300;o1002o`H00_l400;o1@08o`H03Ol400So1005o`H00_l00`3oo`0;o`<02_l300Oo5@06o`<0
1_l00`3oo`08o`H00_l400;o100<o`L01_l800Go1@07o`T01_l300;o4@0001<00_l900[o1`07o`/0
0_lF00Wo0`05o`D00ol400Wo0`05o`D00ol200Oo2006o`800ol200go0P08o`H01Ol200Go0`0=o`<0
0_l400;o1P02o`@00_l500So1P0=o`@02?l400Go1@03o`030?oo00_o0`0:o`<01olE00Ko0`06o`03
0?oo00So1P02o`@00_l400co1@0:o`@02Ol300Oo2@06o`800olA00004`02o`X00_l500;o1P02o`@0
0_l;00;o5@03o`D00ol400;o1@03o`@00ol500?o1002o`D00ol500;o3002o`@01?l500;o1P02o`@0
0_l;00?o1003o`L00_l600;o0P03o`@00ol400?o1003o`H00_l=00;o1P02o`L00_l900;o1@03o`D0
0_l600;o1`02o`T00_lJ00;o1`02o`@00_l500;o1@03o`@00ol500;o1P02o`@01?l500;o0`03o`D0
0ol400;o3@02o`@01?lA00004`02o`/00ol:00;o1P02o`X00_lE00;o1`02o`@00_l500;o1@02o`L0
0_l400;o1@02o`H00_l<00;o1004o`D00_l600;o1002o``00ol200?o2002o`H00_l200Co0`03o`@0
1?l300?o1P02o`d00_l600;o1`02o`T00_l500;o1P02o`H00_l700;o2@02oaX00_l700;o1003o`@0
0_l500Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@00_l=00;o1004oa40000C00;o3003o`T0
0_l600;o2P02oa@00_l900;o0`02o`@00_l500;o2@02o`<00_l400;o1`02o`800_l800;o0`05o`D0
0_l600;o1002o`d00_l200;o2@02o`H00_l200Co0P04o`@01?l200Co1P02o`d00_l600;o1`02o`T0
0_l400;o1`02o`H00_l700;o2@02o`800_lF00_o1@03o`<00_l500Co0P04o`D00_l200;o0P02o`<0
0ol700;o0P02o`T00_l300;o0P02o`T00_l300Go4@0001<00_l=00?o2002o`H00_l:00;o5002o`T0
0_l300?o0P03o`D00_l900;o0`03o`800ol700;o0P02o`P00_l300;o00<0ool01@02o`H00_l400Oo
2@04o`X00_l600;o0P02o`040?l000Co1002o`040?l000Co1P07o`P00_l600;o1`02o`T00ol200?o
1`02o`H00_l700;o2@02o`800_lG00Wo1`02o`<00_l500;o00@0o`001?l500;o0P02o`L00_l400Oo
00<0ool02@02o`<00_l200;o2@02o`<00_l00`3oo`0A00004`02o`h00ol700;o1P02o`X00_lD00;o
2@02o`<01ol600;o2@02o`<01ol800Ko2002o`800ol00`3oo`0500;o3009o`L01?l:00;o2P02o`06
0?l00?l00_l400;o00H0o`00o`02o`H02Ol600;o3`02o`T01ol800;o3`02o`T01_lG00;o1@02o`L0
0ol900;o00H0o`00o`02o`D01_l700;o1007o`030?oo00T00_l300Ko2@02o`800ol00`3oo`0A0000
4`02o`l00ol600?o1002o`/00_lD00;o2@02o`<01Ol800;o2@02o`<01Ol:00Ko2002o`800_l200;o
1@02o``00_l500?o1P03o`/00_l:00;o00<0ool00_l00`3oo`0400;o00<0ool00_l00`3oo`0600;o
1@03o`D00_l?00;o2@05o`X00_l?00;o2@06oaP00_l300;o2@03o`P00_l00`3oo`02o`030?oo00D0
1_l700;o3002o`T00_l300Ko2@02o`800_l200;o4@0001@00_l?00;o1P09o`X00_lE00;o2@02o`<0
0_l0103oool700;o2@02o`<00_l0103oool900;o0P02o`P00_l00`3oo`0300;o1@02o``00_l600;o
1P04o`X00_l:00;o00<0ool00_l00`3oo`0400;o00<0ool00_l00`3oo`0600;o1P02o`D00_l:00;o
0`02o`<00_l400;o00@0oooo2@02o`l00_l900;o0P02oaP00_l300;o1@02o`<00_l800;o00<0ool0
0_l00`3oo`0500;o0P02o`L00_l<00;o2@02o`<00_l200;o2@02o`030?oo00<00_lA00005002oa00
0_l500;o00<0ool00_l<00;o5@02o`T00_l300;o0P03o`H00_l900;o0`02o`800ol800;o0P02o`80
0_l400Go0`02o`D00_l<00;o1P02o`D01_l900;o2@02o`<00_l300;o0P02o`<00_l300;o1@02o`H0
0_l500;o2P02o`<00_l300;o1002o`800ol800;o3`02o`T00_l200;o0P02oaD00_l0103oool500;o
0`03o`H00_l300;o0`02o`@00_l200;o0P02o`<00_l800;o0P03o`P00_l300;o0P02o`800_l500Go
0`02oa40000D00?o3`02o`H00_l@00;o5P02o`L00_l400;o0`03o`H00_l700;o1002o`<00ol700;o
1P02o`@01?l400;o1@02o``00_l600;o1003o`800ol800;o2@02o`<00_l300;o0P02o`<00_l300;o
1@02o`H00_l500;o2P02o`<00_l300;o1002o`<00ol700;o3`02o`T00_l600;o5@02o`030?oo00H0
0_l400?o1@02o`<00_l300;o1002o`H00_l400;o1P03o`<00_l700;o1002o`H00_l500Co1002oa40
000E00;o2002o`D00_l600?o3P02oaL00ol500?o1002o`@00ol500?o1@03o`@00_l400?o1P02o`H0
0_l400Co1002o`D00_l<00;o1@03o`@00_l400;o2002o`T00_l800;o0P02o`P00_l500;o1@03o`D0
0_l:00;o0`02o`<00_l400;o1003o`H00_l?00;o2@02o`H00_lE00Go1P02o`D00_l500;o2002o`@0
0_l600;o1003o`@01?l400;o1@02o`D00_l600;o1@04o`@00_lA00005P02o`L00ol300?o1`03o``0
0_lI00Wo0`05o`<01Ol400Wo0`05o`<01Ol200co0`04o`801_l00`3oo`06o`L02ol300Go0P05o`<0
2?l500Ko0P0<o`801_l200_o0`08o`L03?l200Go0`05o`030?oo00Ko200:o`<03?lB00Oo1`0:o`<0
1_l200Ko00<0ool02_l500[o1009o`<03?l400Co0P06oa00000G0003o`0000H01ol900Oo1`000ol0
000J00Go1@05o`<01Ol600Go1@05o`<01Ol200co0`03o`<01_l00`3oo`06o`L02Ol500Go0P05o`<0
2?l500Ko0P0<o`801_l200Wo1@08o`L03?l200Go0`05o`030?oo00Ko200:o`<03?lB00Oo1`0:o`<0
1_l200Ko00<0ool02_l700Go00<0ool01P05o`D03?l400?o0`06oa00000Q00Go3005ool0``000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(27\\) OJOKGNKQXLVWPMUKLIGZAZWEGQFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?onP02o`@00ol^00005@02obP0
0_mn00[on@0:obd0000D00;o:P02ogh01Ol200;onP05o`800_l]00005002obX00_mn0003o`000?l0
0@000ol0000c00005002o`P02_l800;o3P02oaT01Ol700Ko2`05o`D01Ol600;o1P06o`D01_l300;o
0P05o`H00_l600Go1@05o`801Ol300go1P02o`T00_l400;o1@08o`H01Ol300Go1`04o`D01Ol600;o
00<0ool02ol300[o1`06o`H02_l200Ko0`06o`030?oo00So1P02o`@00_l400co1`06o`P01Ol500Oo
2@06o`<00_lA00004`02o`T02_l800;o3`02oaH02Ol300Wo2009o`<01Ol500?o100:o`<01_l200?o
0P05o`D00ol400Wo0`05o`801Ol300go1@04o`P00_l400;o1@08o`H01Ol300Go1@08o`<01Ol500?o
00<0ool02ol300[o1@0:o`@02_l200Ko0`06o`030?oo00So1P02o`@00_l400co1@0:o`@02Ol300Oo
2@06o`800olA00004`02o`X00_l500;o2@02o`h00_lE00?o1@03o`800ol400?o1P03o`D00ol400;o
1@03o`@01?l500;o1002o`@01?l400;o1@03o`@00ol500?o0`03o`@00ol700;o1P02o`D01?l700?o
1003o`H00_l;00;o1`02o`H00_l400;o1@02o`D00ol500;o1P02o`L00_l800Co1@02o`D00_l500;o
1002o`L00_l400;o1@02o`D00ol400?o1@02o`H00_l400Co1@02o`<00ol500?o1002o`d00_l400Co
4@0001<00_l;00?o3P02o`h00_lE00;o1`02o`800_l600;o1P02o`L00_l400;o1@02o`D00_l700;o
1002o`@01?l400;o1@02o`D00_l700;o1003o`800ol800;o1P02o`D01?l700Co0`03o`H00_l;00;o
1`02o`D00_l600;o1002o`D00_l600;o1P02o`L00_l800;o1`02o`D00ol400;o1002o`L00_l400?o
1002o`D01?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`d00_l400Co4@0001<00_l<00?o
3@02o`h00_lD00;o2@02o`030?oo00H00_l500;o2@02o`<00_l400;o1@03o`L00_l400;o0`05o`@0
0_l400;o1@02o`T00_l400;o0P02o`T00_l600;o1002o`800_l600Co0P04o`H00_l;00;o0`02o`80
0_l500;o1P02o`@00_l400;o1`02o`H00_l700;o1`03o`L00_l600?o0`02o`@02ol500?o0`02o`D0
1?l200Co1@02o`800_l200;o0`03o`L00_l200;o2@02o`<00_l200;o2@02o`<01OlA00004`02o`d0
0ol=0003o`0000`00_lD00;o2@02o`030?oo00H00_l500;o2@02o`<00ol200?o1@02o`@01ol300;o
0`02o`030?oo00@00ol200?o1@02o`T00_l500Co2P02o`H00_l400;o0P02o`H00_l0103o0004o`H0
1ol600;o0P03o`800_l500;o1P02o`@00ol200?o1`02o`H00_l700;o1`02o`@01ol600;o0`02o`D0
2Ol700;o0`02o`D00_l0103o0004o`D00_l200;o1`02o`@01ol00`3oo`0900;o0`02o`800_l900;o
0`02o`030?oo0140000C00;o3P03o``00_l=00;o5002o`T00_l900;o1@02o`T00_l300Oo1P02o`@0
1ol300;o0P03o`030?oo00@01ol600;o2@02o`D01?l:00;o2`03o`800ol500;o00H0o`00o`02o`H0
2Ol400;o0P000ol0o`0200;o1@02o`H00_l400Oo2002o`l00_l700;o1007o`H00ol900;o1@02o`L0
0ol900;o00H0o`00o`02o`D01_l700;o1007o`030?oo00T00_l300Ko2@02o`800ol00`3oo`0A0000
4`02o`l00ol;00;o3@02oa@00_l900;o2@02o`D00_l900;o0`05o`P00_l>00;o0P02o`800_l400Go
2002o`T00_l500?o2`02o`/00_l400;o1@02o`030?oo00;o00<0ool01P02o`D00ol300;o00@0ool0
0_l00`3oo`0500;o1P02o`@01Ol:00;o3`02o`L00_lB00?o2@02o`<00_l900?o2002o`030?oo00;o
00<0ool01@06o`L00_l<00;o2@02o`<01_l900;o0P02o`800_lA00005002o`l00_l<0003o`0000X0
0_lE00;o2@02o`T00_l500;o2@02o`<00_l0103oool700;o3P02o`030?oo00<00_l400;o00@0oooo
1`02o`T00_l500Co2P02o`/00_l400;o1@02o`030?oo00;o00<0ool01P02o`H00_l300;o00<0ool0
0P001?l0ool500;o1P02o`@00_l0103oool900;o3`02o`L00_l>00;o0`02o`T00_l300;o1@02o`<0
0_l800;o00<0ool00_l00`3oo`0500;o0P02o`L00_l<00;o2@02o`<00_l200;o2@02o`030?oo00<0
0_lA00005002oa000_l;00;o2`02oaD00_l900;o2@02o`D00_l900;o0`02o`800ol600;o2002o`@0
1Ol300;o1002o`800ol600?o2002o`@01_l900;o2P02o`H00_l300;o0`02o`<00_l500;o1P02o`<0
0_l00`3o00020004o`3oo`D00_l600;o1002o`800ol800;o3`02o`L00_l800;o1002o`<00ol900;o
00@0oooo1@02o`<00ol600;o0`02o`<00_l400;o0P02o`800_l300;o2002o`800ol800;o0`02o`80
0_l200;o1@05o`<00_lA00005003o`l00_l;00;o2`02oaH00_l700;o2P02o`H00_l700;o1002o`<0
0ol600;o1P03o`@01?l400;o1002o`<00ol600;o1`02o`@00ol200?o2002o`X00_l600;o0`02o`<0
0_l300;o1@02o`H00_l300Co0`04o`D00_l600;o1002o`<00ol700;o3`02o`P00_l600?o1002o`@0
0ol800;o00<0ool01P02o`@00ol500;o0`02o`<00_l400;o1P02o`@00_l600?o0`02o`L00_l400;o
1P02o`D01?l400;o4@0001D00_l800;o1@02o``000?o00002002oaL00ol500?o2P02o`H00ol500?o
1002o`@00ol500?o1004o`@01?l400;o1002o`@00ol600;o1@02o`D00_l400;o2002o`T00ol600?o
0P02o`P00_l500;o1@03o`<01?l400?o1@02o`H00_l400;o1003o`H00_l?00;o2003o`@01?l400;o
1@02o`P01Ol600;o1@02o`D00_l800;o1002o`H00_l400?o1004o`@00_l500;o1@02o`H00_l500Co
1002oa40000F00;o1`03o`<00ol500;o1@02o`P00_lI00Wo1P0:o`@02Ol300Go0`05o`@02_l300Co
0P06o`030?oo00?o0`05o`@02Ol300Go0P05o`<02?l500Ko0P0<o`801_l200_o0`04o`D01?l300Co
1004o`030?oo00?o0`05o`030?oo00Ko200:o`D02_l400[o1007o`L02_l300Ko0P06o`030?oo00[o
1@0:o`@02Ol300co1004o`801_l@00005`000ol0000600Oo1P09o`P000?o00006P05o`P02_l600Go
1@05o`<01Ol600Go00<0ool00`03o`<01_l00`3oo`03o`<01Ol600Go1@05o`801Ol300So1@06o`80
3?l200Ko0P09o`D01?l500Co0`04o`@01?l00`3oo`03o`<01Ol00`3oo`06o`P02_l700Go00<0ool0
100:o`@01ol700[o0`06o`801_l00`3oo`0:o`L01Ol00`3oo`0600Go1@0<o`@00ol300Ko40000240
1Ol700Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(28\\) OJOJHNLQXMVXPNUKLJGZAZXEFQFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?onP02o`@00ol^00005@02obP0
0_mn00[on@0:obd0000D00;o:P02ogh01Ol200;onP05o`800_l]00005002obX00_mn0003o`000?l0
0@000ol0000c00005002o`P02_l800Co3002oaT01Ol700Ko2`05o`L01_l800Co0`04o`<01_l300;o
0P0=o`H01Ol500Go0P05o`<01Ol300Go1P02o`L01Ol200Go0`08o`L01_l300;o2004o`D01Ol600;o
00<0ool02ol400Ko2P06o`H02_l200Ko0`06o`030?oo00So1005o`801Ol200co0`07o`/01Ol500Oo
2@06o`<00_lA00004`02o`T02_l600So2`02oaH02Ol300Wo2009o`<02Ol700Co0`04o`<01_l200?o
0P0=o`@02Ol300Go0P05o`<01Ol300Go1@04o`H01Ol200Go0`08o`L01_l200?o1P08o`<01Ol500?o
00<0ool02ol200Wo1`0:o`@02_l200Ko0`06o`030?oo00So1005o`801Ol200co0`07o`T02Ol300Oo
2@06o`800olA00004`02o`X00_l500;o1@03o`@00ol:00;o5@03o`D00ol200?o1003o`H00ol500?o
0P03o`@00ol700;o1@02o`D00_l400Co1@02o`H00_l300?o1@03o`<00ol400?o1@02o`L00_l600Co
1`03o`@00ol600;o3002o`@01?l600;o1002o`D00_l500?o1@02o`H00_l200?o1003o`D01?l500;o
1@02o`D00_l400;o1`02o`@00_l500;o1@03o`@00ol500;o1P02o`D00_l;00?o1@03o`@00_l=00;o
1004oa40000C00;o2`03o`X00_l600;o2P02oaD00_l700;o0P02o`H00_l600;o1`02o`800_l600;o
1`02o`D00_l500;o1004o`D00_l600;o0`02o`L00_l400?o0P03o`H00_l700;o1P04o`P00ol200?o
1`02o``00_l400Co1@02o`H00_l400;o1@02o`H00_l600;o0P02o`H00_l500;o1`02o`D00ol400;o
1002o`L00_l400?o1002o`H00ol200?o1P02o`H00_l500;o2`02o`L00_l400;o3@02o`@01?lA0000
4`02o``00ol900;o1P02o`X00_lD00;o2@02o`030?oo00H00_l500;o2@02o`030?oo00H00_l700;o
1@02o`D00_l300Go1@02o`H00_l200;o2@02o`@00_l200;o1`02o`<00_l200;o1@02o`800_l800;o
0P02o`P00_l<00;o0`05o`D00_l600;o1002o`@00_l700;o1P02o`800_l600;o1003o`L00_l600?o
0`02o`@02ol500?o0`02o`L00_l200;o1`02o`800_l200;o1@02o`800_l600;o2@02o`<00_l200;o
2@02o`<01OlA00004`02o`d00ol800;o1P02o`X00_lD00;o2@02o`030?oo00H00_l500;o2@02o`03
0?oo00H00_l700;o1@02o`D00_l300;o00<0ool01@02o`H00_l200;o2@02o`D01?l800;o0P03o`80
0_l500;o0P02o`T01?l900Oo1`02o`<00_l00`3oo`0500;o1P02o`@00ol200?o1`02o`H00_l200;o
1P02o`@00_l400Oo1P02o`<00_l500Wo1`02o`<00_l800Co2002o`800_l900;o0P02o`H00_l900;o
0`02o`800_l900;o0`02o`030?oo0140000C00;o3P03o`P00_l400;o2`02oa@00_l900;o2@02o`D0
0_l900;o2@02o`L00_l500;o1@02o`800ol00`3oo`0500;o2P02o`T00_l500Co2002o`8000?o0?l0
0P02o`@00ol200?o2004o`T02Ol500;o0P03o`030?oo00D00_l600;o1007o`P00_lB00;o1002o`@0
1ol600?o2@02o`D00_l700?o3004o`P01_l900Ko1P02o`T00_l300Ko2@02o`800ol00`3oo`0A0000
4`02o`l00ol800Oo2`02oa@00_l900;o2@02o`D00_l900;o2@02o`L02Ol500;o0P02o`800_l500;o
2P02o`T00_l500?o2@02o`040?oo00;o00<0ool01002o`@00_l800?o2P02o`D00ol400;o0P02o`80
0_l500;o1P02o`@01Ol:00;o4P02o`@00_lB00?o2@02o`<00_l900?o2`03o`T01_l900Ko1P02o`T0
0_l300Ko2@02o`800_l200;o4@0001@00_l?00;o2006o`/00_lE00;o2@02o`T00_l500;o2@02o`T0
0_l700Wo1@02o`030?oo00<00_l500;o2P02o`T00_l500Co2002o`030?oo008000Co0?oo1002o`@0
0_l800Co2@02o`H00_l400;o00<0ool00`02o`D00_l600;o1002o`040?ooo`T00_lB00;o1002o`h0
0_l300;o2@02o`<00_l500;o0`02o`/01?l800;o0P02o`T00_l200;o1P02o`T00_l300;o0P02o`T0
0_l00`3oo`0300;o4@0001@00_l@00;o1P02o`@00_l:00;o5@02o`T00_l900;o1@02o`T00_l900;o
1`02o`D00_l500Go0`02o`D00_l:00?o2002o`@01_l700;o00<0o`000P001?l0ool300;o1P02o`H0
1_l800;o1P02o`@01Ol300;o1@02o`H00_l400;o0P03o`P00_lB00;o1002o`P00_l400;o0`03o`T0
0_l0103oool500;o0`03o`T01_l700;o0P02o`800_l500;o0P02o`800_l200?o2002o`<00_l200;o
0P02o`D01Ol300;o4@0001@00ol?00;o1@02o`H00_l900;o5P02o`L00_l:00;o1P02o`L00_l:00;o
1`02o`D00_l500Co1002o`D00_l;00;o1`02o`@00ol200?o1P04o`<01?l300;o1P02o`D00ol200?o
1`02o`H00_l400Co1002o`D00_l600;o1002o`<00ol700;o4P02o`D00_l600?o1002o`@00ol800;o
00<0ool01P02o`@00ol700?o0P03o`H00_l600;o1@02o`H00_l300;o1`02o`@00_l600;o1@04o`@0
0_lA00005@02o`P00_l500;o1@02o`H00_l800;o5`03o`D00ol:00;o1P03o`D00ol:00;o1`02o`D0
0_l500Co1002o`D00_l<00;o1@02o`D00_l400;o1P04o`@00ol200?o1P03o`@00_l400;o1`02o`D0
0ol400Co1002o`D00_l600;o1002o`@00ol600;o4P02o`D00ol400Co1002o`D00_l800Go1P02o`D0
0_l700;o1002o`H00_l600;o1@02o`H00_l400;o1@02o`D00_l600;o1@04o`@00_lA00005P02o`L0
0ol300?o1@03o`@00ol700;o6@09o`H02_l400Wo1P0:o`<01?l300Co0`04o`801_l00`3oo`06o`T0
2Ol300Go0P05o`<01?l500[o0P06o`030?oo00?o0P05o`<02ol400Co0P06o`<01?l400Co00<0ool0
0ol300Go00<0ool01_l:00[o0`0:o`@02_l400Oo1`0:o`@01Ol200Go0P0<o`<03?l400Wo0`0<o`@0
1?l200Ko400001L000?o00001P07o`L02?l80003o`0001X01Ol800[o1P05o`P02_l300Co0`04o`<0
0ol300Ko00<0ool01_l;00Go1@05o`801Ol300Co1@0:o`801_l00`3oo`03o`801Ol300Wo1P03o`<0
1_l300Co1004o`030?oo00?o0`05o`030?oo00Ko2P0:o`D01Ol00`3oo`0400[o1007o`L02_l400Go
0P05o`803?l300co1P05o`D03?l400?o0`06oa00000Q00Go2@06ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(29\\) PJPIHNLQXLUXPNULLJHYAZWEEQFM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?onP02o`@00ol^00005@02obP0
0_mn00[on@0:obd0000D00;o:P02ogh01Ol200;onP05o`800_l]00005002obX00_mn0003o`000?l0
0@000ol0000c00005002o`P02_l500Go3P02oaD02?l800Ko1`08o`L02_l500Co0`04o`<01_l300;o
0P0=o`H01Ol500Go0P05o`<03Ol600Co1@05o`801Ol300So1`06o`<00_l800Co1@0=o`030?oo00_o
1006o`L01?l300Co1@08o`<01_l300Ko00<0ool02?l600;o1002o`@03?l300co1P05o`D01ol800Go
0`05oa00000C00;o2@0:o`D01ol=00;o5008o`H02Ol600So1`0:o`D01?l300Co0`06o`800ol200go
1009o`<01Ol200Go0`0=o`@02?l300Go0P05o`<02?l700Ko0P03o`H02?l300go00<0ool02ol200Wo
1P04o`<01?l500So0`06o`<01_l00`3oo`08o`H00_l400;o100<o`<03?l400Wo0`07o`P01Ol300Go
400001<00_l:00;o1@02o`X00ol<00;o5P02o`X00ol400?o1`02o`l00_l:00;o1@02o`D00_l400Co
1@02o`H00_l300?o1@03o`<00ol400?o1`02o`H00_l400;o1002o`@00ol400?o1P02o``00_l400Co
1P02o`@00_l600;o1P02o`@00_l600;o0P03o`@00ol600;o1@02o`T00_l800;o1`02o`@00_l500;o
1@03o`@00ol500;o1P02o`D00_l600;o0`03o`D00ol400;o3002o`L00_lA00004`02o`/00ol@00?o
2`02oaH00_l:00;o1P02o`L00_l?00;o2P02o`D00_l500;o1004o`D00_l600;o0`02o`L00_l400?o
0P03o`P00_l600;o0`02o`H00_l400?o0P03o`L00_l<00;o1004o`D00_l600;o1@02o`H00_l400;o
1P02o`800_l600;o1P02o`D00_l900;o2002o`L00_l400?o1002o`D01?l300?o1@02o`H00_l500;o
1P02o`<00_l700;o1002o``00_l700;o4@0001<00_l<00?o4002o`/00_lF00;o2P02o`H00_l700;o
3`02o`X00_l500;o1@02o`<01Ol500;o1P02o`800_l900;o1002o`800_l900;o1P02o`<00_l600;o
1@02o`800_l800;o3002o`<01Ol500;o1P02o`D00_l600;o1002o`H00_l200;o1P02o`H00_l500;o
2@02o`P02ol500?o0`02o`D01?l200Co1@02o`800_l200;o1@02o`800_l200;o0P02o`T00_l300;o
0P02o`P00_l300;o0P02oa40000C00;o3@03o`/01?l00`3oo`0:00;o5P07o`D00_l600;o1`07o`X0
0_l:00;o1@02o`D00_l300;o00<0ool01@02o`H00_l200;o2@02o`D01?l:00;o1P02o`<00_l600;o
1P04o`T01ol700;o0`02o`030?oo00D00_l600;o1@02o`H00_l400;o1P02o`800_l600;o1P02o`D0
0_l900;o2@09o`L00_l300;o1@02o`040?l000Co1@02o`800_l900;o0P02o`H00_l900;o0`02o`80
0_l800;o0P03o`800_lA00004`02o`h00ol800Wo2P02oaH02Ol;00;o1`09o`P00_l:00;o1@02o`D0
0_l200?o00<0ool01@02o`X00_l900;o1@04o`X00_l;00;o1P02o`H01?l900Wo1@02o`800ol00`3o
o`0500;o1P02o`D00_l<00;o4P02o`H00_l500;o2@03o`P00_l500;o1`03o`T00_l01P3o003o00;o
1@06o`T01_l600;o2@02o`<01_l800;o0P000ol0o`0200;o4@0001<00_l?00?o1`02o`@00ol:00;o
5P02o`D00ol:00;o1`02o`D00ol700;o2P09o`D00_l200;o0P02o`D00_l:00;o2@02o`D00ol;00;o
2`02o`H00_l600?o2P02o`D00ol400;o0P02o`800_l500;o1P02o`D00_l<00;o4P02o`H02Ol800Co
2@02o`<00_l900?o2002o`030?oo00;o00<0ool01@06o`T01_l600;o2@02o`<01_l800;o00@0ool0
0_l00`3oo`0A00005002o`l00_l600;o1P02o`T00_lG00;o1P02o`X00_l700;o1P02o`L00_l:00Wo
1@02o`030?oo00<00_l500;o2P02o`T00_l500Co2P02o`/00_l600;o1P04o`T00_l600;o1002o`03
0?oo00<00_l500;o1P02o`D00_l<00;o4P02o`H02Ol700Ko2002o`<00_l500;o0`02o`P00_l00`3o
o`02o`030?oo00D00_l200;o2@02o`800_l600;o2@02o`<00_l200;o2002o`030?oo008000Co0?oo
4@0001@00_l@00;o1@02o`H00_l900;o5`02o`H00_l:00;o1`02o`H00_l700;o2P02o`D00_l500Go
0`02o`D00_l:00?o2002o`@01_l900;o2`02o`H00_l500Ko2002o`H00_l400Go0`02o`D00_l600;o
1@02o``00_lB00;o1P02o`D00_l700;o0P02o`T00_l0103oool500;o0`03o`H00_l300;o0`02o`@0
0_l200;o0P02o`D00_l200;o0P02o`800ol800;o0`02o`800_l200;o1002o`030?l0008000Co0?oo
4@0001@00ol?00;o1@02o`H00_l900;o5`02o`H00_l:00;o1`02o`H00_l700;o2P02o`D00_l500Co
1002o`D00_l;00;o1`02o`@00ol200?o2002o`/00_l600;o1003o`800ol700;o1P02o`@01?l400;o
1@02o`H00_l500;o3002oa800_l600;o1@02o`H00ol300;o2002o`030?oo00H00_l400?o1@02o`<0
0_l300;o1002o`H00_l500;o1P02o`<00_l700;o1002o`H00_l400Co0`04oa40000E00;o2002o`D0
0_l500;o1P000ol0000700;o6002o`D00ol:00;o1`02o`D00ol700;o2P02o`D00_l500Co1002o`D0
0_l<00;o1@02o`D00_l400;o2002o`/00_l600;o1002o`@00_l700;o1@03o`@01?l400;o1@02o`H0
0_l500;o3002oa800_l600;o1@02o`H00_l400;o2005o`H00_l500;o1@02o`P00_l400;o1P02o`D0
0_l600;o1002o`D00_l500;o1P02o`@01?l400?o4@0001H00_l700?o0`03o`H00_l400;o2002oaL0
2ol600[o0P0;o`@02_l500Co0`04o`<01?l200Ko00<0ool01_l900Wo0`05o`801Ol300So1`04o`@0
1?l00`3oo`03o`801Ol300_o1004o`801_l300Co1004o`030?oo00Ko1P08o`X02_l200Co0`04o`<0
1Ol200Go0`07o`L02_l300Ko0P06o`030?oo00[o0`0<o`@02Ol300co0`04o`D01?l@00005`000ol0
000600Oo1`07o`T000?o00005P09o`P02_l200Wo1P0:o`D01?l300Co0`03o`<01_l00`3oo`06o`/0
1Ol500Go0P05o`<02?l700Co1004o`030?oo00?o0P05o`<02Ol600?o0`06o`<01?l400Co00<0ool0
1_l600So2P0:o`801?l300Co0`05o`801Ol300Oo1`0:o`<01_l200Ko00<0ool02_l300co1P05o`D0
3?l300Co1@04oa00000Q00Go2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(30\\) PIQJHMLPWLVXONVLLJHYAZWEDREM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2P05o`/0
1?l<00;o5@08o`L02_l800Go1`06o`P01?l300Co0P05o`<01Ol00`3oo`0;o`802?l800;o1002o`D0
3Ol600;o1`05o`801Ol700Go1P06o`<00_l800;o1`0=o`030?oo00_o1006o`L01?l300Co1@08o`<0
1_l300Ko00<0ool02?l600;o1002o`@03?l400So1@05o`H03ol300Go0`05oa00000C00;o2@09o`P0
1_l<00;o5008o`L02_l600Wo0`09o`L01?l300Co0P05o`<01Ol00`3oo`0;o`802?l800;o1002o`D0
3Ol500Co1P05o`801Ol500Wo1006o`800ol700Co1P0=o`030?oo00_o0P09o`H01?l300Co1@08o`<0
1_l300Ko00<0ool02?l600;o1002o`@03?l400[o0`05o`D04?l300Go0`05oa00000C00;o2@02o`D0
0_l700?o0P03o`/00_lF00;o3`02o`T00ol500?o0P03o`@00ol700;o1@02o`@00_l700;o1@02o`H0
0_l400;o2`03o`@00ol700;o1P02o`D01?l700?o1003o`D00ol500?o1002o`@01?l700Co2@02o`H0
0_l400;o1P02o`800ol400?o1P02o`D00_l900;o2002o`L00_l400;o1@02o`D00ol400?o1@02o`H0
0_l500;o1004o`@00_l500?o1002o`H00_l400;o1`02oa40000C00;o4@02o`H00_l400;o2`02oaH0
0_l?00;o2@02o`L00_l200;o1P02o`L00_l500;o1002o`L00_l500;o1P02o`@00_l;00Co0`03o`L0
0_l600;o1@04o`P00ol200?o1P02o`L00_l400;o1004o`L01?l900;o1P02o`@00_l600;o0P02o`H0
0_l600;o1@02o`T00_l800;o1`02o`@00ol400;o1@04o`<00ol500;o1P02o`D00_l600;o1002o`D0
0_l500;o1P02o`@00_l700;o4@0001<00_lA00;o1@02o`H00_l:00;o5P02o`l00_l800;o2@02o`03
0?oo00H00_l700;o1@02o`@00_l300;o0P02o`D00_l600;o1002o`/01?l200Co1`02o`H00_l400;o
0P02o`P00_l200;o1P02o`T00_l300;o0`05o`H00_l200;o2002o`H00_l400;o1P02o`800_l600;o
1P02o`D00_l900;o200;o`D00ol300;o1@04o`801?l500;o0P02o`800_l500;o1`02o`<00_l400;o
1P02o`800_l200;o1002o`<00_l200;o4@0001<00_lA00;o1@02o`H00_l:00;o5P07o`X00_l800;o
2@02o`030?oo00H00_l700;o1@02o`@00_l200?o0P02o`D00_l600;o1007o`H00_l0103o0004o`L0
0_l600;o1002o`800_l900Co1`02o`T00_l300;o0`02o`030?oo00H00_l200;o2002o`H00_l400;o
1P02o`800_l600;o1P02o`D00_l900;o2@09o`L00_l300;o1@02o`040?l000Co1@02o`800_l900;o
1`02o`<00_l300?o1P02o`800_l800;o0P03o`800_lA00004`02oa000_l600;o1P02o`X00_lF00Wo
2002o`P00_l900;o2@02o`L00_l500;o1002o`8000?o0?l00P02o`D00_l<00Wo1002o`060?l00?l0
0_l700;o2`03o`800ol800Co1`02o`T00_l300;o0P03o`030?oo00D00ol200?o1`02o``00_lB00;o
1P02o`D00_l900?o2002o`D00_l700?o2@02o`060?l00?l00_l500Ko2@02o`L00_l300Oo1`06o`P0
0_l20003o`3o00800_lA00004`02o`d01?l700;o1P02o`X00_lF00;o1@03o`L00_l800;o2@02o`T0
0_l700Wo1002o`040?oo00;o00<0ool01@02o``00_l500?o0`02o`030?oo00;o00<0ool01`02o`/0
0_l400;o2003o`P00_l900;o0`02o`800_l200;o1@02o`@00_l700;o3002oa800_l600Wo2004o`T0
0_l300;o2@03o`P00_l00`3oo`02o`030?oo00D01_l900;o1`02o`<02Ol500Ko2002o`040?oo00;o
00<0ool04@0001@00_l<00?o2002o`H00_l900;o5`02o`H00_l700;o2002o`T00_l900;o1`09o`@0
0_l00`3oo`020004o`3oo`D00_l<00;o1P02o`<00_l00`3oo`02o`030?oo00L00_l;00;o1002o`P0
1?l700;o2@02o`<00_l00`3oo`0300;o1@02o`@00_l700;o3002oa800_l600Wo1`06o`P00_l300;o
1@02o`<00_l800;o00<0ool00_l00`3oo`0500;o0P02o`T00_l700;o0`02o`D00ol400;o0P02o`P0
0_l00`3oo`020004o`3ooa40000D00;o3P02o`L00_l600;o2@02oaL00_l600;o1`02o`P00ol800;o
2@02o`L00_l500;o1002o`030?l0008000Co0?oo1@02o``00_l600;o0P02o`<00_l300;o1P02o`X0
0_l600;o1P06o`H00_l900;o0`05o`<00_l400;o1P02o`H00_l<00;o4P02o`H00_l500;o1`02o`80
0_l900;o00@0oooo1@02o`<00ol600;o0`02o`<00_l400;o0P02o`800_l500;o1`02o`<00_l600;o
1002o`800_l200;o1002o`030?l0008000Co0?oo4@0001@00ol>00;o1P02o`H00_l900;o5`02o`H0
0_l700;o2@02o`L00_l:00;o1`02o`D00_l400Co0`04o`D00_l<00;o1P02o`800_l300;o0`02o`H0
0_l:00;o1P02o`D00ol200?o1P02o`L00_l400Co1002o`@00_l600;o1P02o``00_lB00;o1P02o`D0
0_l600?o0`02o`P00_l00`3oo`0600;o1003o`D00_l300;o0`02o`@00_l600;o1@02o`H00_l400;o
1P02o`@00_l600;o1004o`<01?lA00005@02o`h00_l700;o1002o`T00_lH00;o1@03o`L00_l:00;o
1@02o`/00_l700;o1@02o`@01?l400?o1@02o``00_l500?o0P02o`P00_l600;o2@03o`H00ol400;o
1002o`H00ol500?o1004o`@00_l300?o1P03o`D00_l<00;o4P02o`H00_l500;o1P02o`@00_l800Go
1P02o`D00_l500;o2002o`@00_l600;o1@02o`@01?l400;o1@03o`@00_l600;o1004o`@00olA0000
5P02o`L00_l300?o1`03o`800ol800;o5`0;o`@02_l600Wo1P0:o`<01?l300Co0P04o`D01?l00`3o
o`06o`L02ol200Ko0P06o`802?l500Ko0P06o`030?oo00?o0P05o`D02Ol400Co0P06o`030?oo00Co
0P06o`030?oo00Ko1P08o`X02_l200Co0`04o`<01Ol200Go0`07o`L02_l300Ko0P06o`030?oo00[o
100:o`<02ol300co0`04o`D01?l@00005`000ol0000500Oo2@06o`T000?o00005P09o`H02_l800Go
200:o`<01?l300Co0P04o`D01?l00`3oo`06o`L02Ol400Ko0P06o`802?l500Ko0P06o`030?oo00?o
0P05o`L01Ol600?o0`06o`030?oo00Co0P06o`030?oo00Ko1P08o`X02_l200Co0`04o`<01Ol200Go
0`07o`L02_l300Ko0P06o`030?oo00[o1008o`D02Ol500co0`04o`D01?l@00008@04o`/01?oo0<H0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(31\\) OIQJHMKPXLUXNNULLKGYAZVEDREM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2P05o`T0
2Ol900;o6@05o`H02_l800Go1`06o`P01?l300Co0P05o`<01Ol00`3oo`03o`H00_l200So1P05o`80
1Ol300go1P04o`D01Ol200Go1006o`<00_l300Ko0`02o`P01?l500go00<0ool02ol200Go1P02o`D0
1_l700So0`06o`<01_l00`3oo`08o`T00_l700co1008o`D01Ol600oo0`05o`<01Ol@00004`02o`T0
2Ol700Wo2P02oaH02Ol400[o1P09o`<02Ol700Co0`04o`801Ol300Go00<0ool00ol500?o0P08o`H0
1Ol200Go0`0=o`@02?l300Go0P05o`@01_l200?o0`06o`800ol600So0`0=o`030?oo00_o0P05o`D0
0ol300[o1@08o`<01_l300Ko00<0ool02?l800Co1P0<o`@02_l300Go1@0@o`<01Ol300Go400001<0
0_l900;o1@02o`/00_l=00;o5@03o`D00ol700;o2@03o`D00ol200?o1003o`L00_l500;o1002o`L0
0_l400;o1@03o`D00_l;00?o1003o`L00_l600;o1002o`@00_l400?o1003o`H00_l400Co1002o`@0
1?l600;o1002o`H00_l600;o1002o`H00_l400;o1@03o`<01?l500;o2002o`P00_l700;o1002o`D0
0_l800Co2002o`H00_l500;o1004o`@00_l500?o1002o`H00_l400;o1`02oa40000C00;o4@02o`X0
0_l=00;o5@02o`L00_l700;o2@02o`L00_l200;o1P02o`L00_l500;o1002o`L00_l400;o1@02o`H0
0_l<00?o0P03o`P00_l600;o0`02o`H00_l400?o0P03o`L00_l400Co1002o`@01?l500;o1P02o`D0
0_l600;o1002o`H00_l400;o1@02o`@00_l700;o2002o`P00_l700;o1003o`@00_l800Co2002o`H0
0_l500;o1P02o`@00_l500;o1@02o`H00_l400;o1`02oa40000C00;o4@02o`X00_l=00;o5002o`T0
0_l600;o2002o`T00_l00`3oo`0600;o1`02o`D00_l400;o0`02o`800_l400;o1002o`L00_l=00;o
0P02o`T00_l600;o0`02o`H00_l500;o0P02o`P00_l300Go1002o`<01Ol500;o1P02o`D00_l600;o
1002o`H00_l400;o1002o`@00ol700;o2002o`P02ol500?o0`02o`L00_l200;o1`02o`800_l200;o
1@02o`L00_l300;o1002o`H00_l200;o0P02o`@00_l300;o0P02oa40000C00;o4@02o`X00_l=00;o
5002o`T00_l600;o2002o`T00_l00`3oo`0600;o1`02o`D00_l400;o0P03o`800_l400?o0P03o`L0
1ol900Co2P02o`H00_l300;o1P02o`H01?l900;o0`02o`030?oo00@00_l300;o00<0ool01@02o`H0
0_l500;o1P02o`@00_l600;o1003o`800ol400;o1007o`L00_l900Wo1`02o`<00_l700;o0P02o`L0
0_l200;o2@02o`L00_l300;o0`03o`H00_l200;o2002o`800ol200;o4@0001<00_l@00;o2`02o`d0
0_lD00;o2@02o`H00_l800;o2@02o`T00_l700;o1@02o`@00_l20003o`3o00800_l400Oo2009o`L0
1?l:00;o2`02o`H00_l600Co2@02o`800ol00`3oo`0400;o0P03o`030?oo00D00_l600;o1@02o``0
0_l<00Oo1@02o`@01ol700?o2002o`D00_l700?o2P03o`800ol600Ko2@02o`L00_l300Oo1`06o`P0
0_l20003o`3o00800_lA00004`02o`d01?l<00;o3@02oa@00_l900;o1P02o`P00_l900;o2@02o`L0
2Ol400;o00@0ool00_l00`3oo`0400Go2P02o`D00ol600?o2`02o`/00_l600;o1P03o`X00_l200;o
0P02o`@00_l200;o0P02o`D00_l600;o1@02o``00_l<00Go1`02oa401?l900;o0`02o`T00ol900;o
1002o`H01_l900;o1`02o`<02Ol500Ko2002o`040?oo00;o00<0ool04@0001@00_l<00?o3@02o``0
0_lE00;o2@02o`H00_l800;o2@02o`T00_l700Wo1002o`030?oo008000Co0?oo1002o`040?ooo`T0
0_l600;o1P04o`X00_l;00;o1P02o`H01?l900;o00<0ool00`02o`@00_l00`3oo`0300;o1@02o`H0
0_l500;o3002o``00_l0103oool600;o4006o`P00_l300;o1@02o`<00_l900;o1002o`H00_l200;o
2@02o`L00_l300;o1@03o`@00_l200;o2002o`030?oo008000Co0?oo4@0001@00_l>00;o3002o``0
0_lE00;o2@02o`H00_l800?o2002o`T00_l700;o1@02o`@00_l00`3o00020004o`3oo`@00_l200?o
2002o`H00_l500Ko2@02o`/00_l600;o1@06o`P01Ol300;o1005o`<00_l500;o1P02o`D00_l<00;o
3002o`800ol500;o2002o`H00_l200;o2@02o`040?ooo`D00_l300?o1`02o`H00_l500;o0P02o`80
0_l500;o1`02o`<00_l600;o1002o`800_l200;o1002o`030?l0008000Co0?oo4@0001@00ol>00;o
2`02o``00_lF00;o1`02o`L00_l900;o1`02o`X00_l700;o1@02o`@01?l300Co1002o`<00ol700;o
1P02o`@00ol200?o2002o`/00_l600;o1003o`800ol700Co1002o`@01?l400;o1@02o`H00_l500;o
3002o``00_l300?o1@02o`H00ol500?o0`02o`P00_l00`3oo`0600;o1003o`H00_l600;o1@02o`H0
0_l500;o1P02o`@00_l600;o1002o`H00_l400Co0`04oa40000E00;o3P02o`/00_l;00;o5`03o`D0
0ol700;o2P02o`D00_l;00;o1`02o`D00_l400Co1003o`@00_l400?o1P02o`D00ol400;o1002o`P0
0_l;00;o1P02o`@00_l400;o1`04o`@00_l400Co1002o`D00_l600;o1@02o``00_l<00;o1003o`@0
0ol400Co1@02o`@00_l800Go1P02o`D00_l500?o1P03o`@00_l600;o1@02o`@01?l400;o1@03o`@0
0_l600;o1004o`@00olA00005P02o`L00_l300?o1`03o`030?oo00X00_lI00Wo100:o`H02Ol600[o
0`04o`<01?l200Co1@04o`030?oo00?o0`05o`802ol300Go0P05o`<02?l700Co1004o`030?oo00?o
0P05o`@01?l200Ko0P04o`801_l300Co1004o`030?oo00Ko1P08o`L01Ol300Go0`0:o`<01Ol200Go
0`07o`L02_l300Ko0P06o`030?oo00[o100:o`<02ol300co0`04o`D01?l@00005`000ol0000500Oo
2006o`X000?o00006P05o`H02_l800Go200:o`<01?l300Co0P04o`D01?l00`3oo`03o`<01Ol200Wo
1@05o`801Ol300So1`04o`@01?l00`3oo`03o`801Ol400?o0`06o`800ol300Ko0`04o`@01?l00`3o
o`06o`H02?l700Go0`05o`D01Ol00`3oo`0300Go0P05o`<01ol700[o0`06o`801_l00`3oo`0:o`@0
2?l500Wo1@0<o`<01?l500Co400002401?l<00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(32\\) OIQJINJPXLUXMOVLKKGYA VDCRDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2P05o`P0
2_l900;o6@05o`H02_l800Go1`06o`P02_l400Ko0`02o`@01_l700So1P05o`801Ol300go1P04o`D0
1Ol200Go0`05o`<01Ol500Go2`02o`L03Ol00`3oo`03o`H00_l200Go1P02o`D01_l700So0`06o`<0
1_lD00;o2008o`X01Ol500Go1P03o`030?oo00Ko1P0=oa00000C00;o2@09o`H02_l:00;o5P09o`@0
2_l600Wo0`09o`L02_l400Ko0P03o`802Ol600So1P05o`801Ol300go1008o`<01Ol200Go0`05o`<0
1Ol300Wo2004o`H03Ol00`3oo`03o`D00ol200Go1@03o`<02_l500So0`06o`<01_lC00Co1`0:o`H0
2Ol300Go1@04o`030?oo00So100=oa00000C00;o2@02o`D00_l700;o1@02o`X00_lE00?o1@03o`L0
0_l900?o1@03o`800ol400?o2P02o`T00_l400Co0P03o`@00ol700;o2`03o`@00ol700;o1P02o`@0
0_l400;o1003o`@00ol500;o1`02o`<00ol500?o1`04o`T00_l600;o0`02o`D00ol500;o1@03o`<0
1?l500;o2002o`P00_l700;o5@04o`P00_l400Co1003o`D00ol400;o1@03o`@00_l400Co1P02o`H0
0_l@00004`02oa400_l700?o3`02oaD00_l700;o1`02o`T00_l700;o0P02o`H00_l:00;o2@02o`@0
1?l200;o1P02o`L00_l<00?o0P03o`P00_l600;o0`02o`H00_l400?o0P03o`H00_l700;o0`02o`L0
0_l700Co2@02o`H00_l300;o1@02o`H00_l500;o1002o`L00_l800;o2002o`L00_lE00Co2002o`H0
0_l400;o1`02o`@00_l500;o1@02o`H00_l600;o1P02oa00000C00;o4@02o`P00ol>00;o5002o`T0
0_l600;o2002o`T00_l00`3oo`0600;o2P02o`T00_l300Go0P02o`H00_l700;o3@02o`800_l900;o
1P02o`<00_l600;o1@02o`800_l700;o0`02o`800_l200;o2@02o`D00_l200;o2002o`H00_l300;o
1002o`L00_l400;o1003o`L00_l800;o200;oa@00_l200;o1`02o`L00_l200?o3@02o`@00_l600;o
1`02o`D00_l600;o400001<00_lA00;o2@03o`d00_lD00;o2@02o`H00_l800;o2@02o`030?oo00H0
0_l:00;o2@02o`<00_l00`3oo`0200;o1P02o`L01ol900Co2P02o`H00_l300;o1P02o`H01?l800;o
0P03o`800_l200;o2@02o`D00_l200;o2002o`H00_l300?o0P03o`L00ol200?o1002o`@01ol700;o
2@09oaD00_l200;o1`02o`L00_l200;o3P02o`<00ol600;o1`02o`D00_l600;o400001<00_l@00;o
2`03o``00_lD00;o2@02o`H00_l800;o2@02o`T00_l:00;o2@02o`800ol00`3oo`0:00;o1`09o`L0
1?l:00;o2`02o`H00_l600Co2002o`8000?o0?l00P02o`800_l900;o1003o`800ol700;o2`07o`P0
1ol500;o1007o`L00ol800;o1@02oa@00ol200?o1P02o`L00_l200;o3P07o`L00_l700;o1@02oaP0
000C00;o3@04o`d00ol;00;o5002o`T00_l600;o2002o`T00_l900;o2P02o`T00_l200;o0P02o`X0
0_l700;o1@03o`H00ol;00;o2`02o`H00_l600?o2@02o`040?oo00;o00<0ool00P02o`T00_l400;o
1002o`L00_l;00Go2P05o`L00_lA00Co2@02o`<00_lE00;o1002o`H00_l700;o0P02o`h02Ol500;o
1`02o`D00_lH00005002o``00ol?00;o2P02oaD00_l900;o1P02o`P00_l900;o2@02o`X00_l900;o
00<0ool00`02o`X00_l700;o1P02o`H01?l:00;o2`02o`H00_l600Co2002o`030?oo008000Co0?oo
0P02o`T00_l400;o1002o`L00_l;00;o00@0oooo2@02o`040?ooo`H00_l@00Ko2002o`<00_lE00;o
1002o`H00_l700;o0P02o`h00_l500?o1002o`L00_l500;o600001@00_l>00;o3`02o`T00_lE00;o
2@02o`H00_l800?o2002o`T00_l:00;o2@05o`<00_l:00;o1`02o`H00_l500Ko2@02o`/00_l600;o
1@06o`L00_l00`3o00020004o`3oo`800_l900;o0`02o`H00_l600;o2`02o`800ol800;o0P03o`D0
0_l800;o1P02o`800_l900;o00@0oooo5002o`H00_l500;o1`02o`800ol700;o1002o`H00_l400;o
1`02o`D00_lH00005003o`h00_l>00;o2@02oaH00_l700;o1`02o`T00_l700;o2P02o`X00_l900Co
1002o`X00_l700;o1P02o`@00ol200?o2002o`/00_l600;o1003o`800ol600Co0`04o`<00_l700;o
1002o`H00_l600;o2`02o`<00ol700;o0`03o`D00_l600?o1@03o`<00_l800;o00<0ool05@02o`H0
0_l500;o1P02o`@00_l700;o1002o`H00_l400;o1P02o`H00_lH00005@02o`h00_l700;o1@02o`P0
0_lG00?o1@03o`L00_l:00;o1@02o`/00_l:00;o2@04o`@00_l:00;o1`02o`D00ol400;o1002o`P0
0_l;00;o1P02o`@00_l400;o1P04o`@00ol300?o1@03o`<00ol600?o1@02o`/00_l400?o1P02o`@0
0ol400?o1004o`D00_l400;o2005oa@00ol600?o1002o`@01?l400?o1@03o`@00_l500?o1002o`@0
1?l600;o600001H00_l700;o0`03o`L00ol300?o1`02oaT02Ol400[o1P09o`H02_l300[o1004o`80
1_l400[o0P0;o`<01Ol200Go0`08o`L01?l400Co00<0ool00ol200Go0`04o`D01?l300Wo0`06o`80
1_l00`3oo`06o`H01Ol300Go0P05o`<01Ol300[o0`05o`801Ol300Oo5006o`801_l200[o1P0:o`80
2ol400[o1008oaD0000G0003o`0000D01ol900Oo20000ol0000J00Go1P0:o`P01Ol800[o0`0:o`@0
0ol300Ko100:o`802Ol500Go0P05o`<02?l700Co1004o`030?oo00?o0P05o`<01?l500Co1@05o`D0
1_l200Ko00<0ool01_l600Go0`05o`801Ol300Go1@05o`030?oo00<01Ol200Go0`07oa@01_l200Ko
0P08o`X01Ol00`3oo`0200Wo1P08o`H02?lE00008@04o`/01Ooo0<D0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(33\\) OJQJINJPXKUXLOWLKKFYA VCCRDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2P05o`X0
1Ol<00;o6@05o`L01_l;00Go1`06o`P02_l400Ko0`02o`@01_l700So1P05o`801Ol300Go1P02o`H0
1?l500Go0P05o`<03Ol500Go2002o`@00_l400go00<0ool00ol600;o0P05o`H00_l00`3oo`05o`X0
2?l300Ko0`06oa@00_l;00Go2P05o`D01Ol600?o00<0ool01_l600go400001<00_l900Wo1P09o`/0
0_lF00Wo0`09o`P02Ol300Wo1`0:o`@01_l200?o0P09o`H02?l600Go0P05o`<01Ol500?o1008o`<0
1Ol200Go0`0=o`<02Ol600;o1002o`@03Ol00`3oo`03o`D00ol200Go1@03o`030?oo00Go2P08o`<0
1_l300Ko4`04o`P02Ol600Wo0`05o`D01?l00`3oo`08o`@03Ol@00004`02o`T00_l500;o1P02o`D0
0_l;00;o5@03o`D00ol200?o1003o`H00ol500?o0P03o`@00ol:00;o2@02o`@01?l200?o1003o`L0
0_l;00?o1003o`H00_l500?o1@02o`@00_l400?o1003o`L00_l600;o0P03o`D00ol400?o1003o`H0
0_l600;o0`02o`D00ol500;o1@03o`@00_l@00;o2002o`L00_lE00Co1`03o`D00ol400?o1@03o`@0
0_l500?o1002o`@01?l600;o1P02oa00000C00;o4@02o`d00_l:00;o5@02o`L00_l200;o1P02o`H0
0_l700;o0P02o`H00_l:00;o2@02o`@01?l200;o1P02o`L00_l<00?o0P03o`L00_l500;o1@02o`H0
0_l400?o0P03o`P00_l600;o0P02o`L00_l400Co0`03o`H00_l600;o0`02o`D00_l600;o1@02o`D0
0_l@00;o2002o`L00_lE00Co1`02o`L00_l400;o1`02o`@00_l500;o1@02o`H00_l600;o1P02oa00
000C00;o4@02o`d00_l:00;o5002o`T00_l00`3oo`0600;o1@02o`T00_l00`3oo`0600;o2P02o`T0
0_l300Go0P02o`H00_l700;o3@02o`800_l800;o1002o`H00_l600;o1@02o`800_l900;o1P02o`03
0?oo00T00_l300Co0P04o`H00_l600;o0`02o`@00_l700;o1002o`H00_l200;o3002o`P02olD00;o
0P02o`D00ol<00?o3@02o`@00_l600;o1`02o`D00_l600;o400001<00_lA00;o3@02o`X00_lD00;o
2@02o`030?oo00H00_l500;o2@02o`030?oo00H00_l:00;o2@02o`<00_l00`3oo`0200;o1P02o`L0
1ol900Co2@03o`800ol600;o1P02o`H01?l:00;o1P02o`030?oo00T00_l300;o00@0o`001?l600;o
1P02o`<00ol200?o1`03o`800ol600;o0P02o``00_l900Wo5@02o`800_l500;o3@02o`h00_l300?o
1P02o`L00_l500;o1P02oa00000C00;o4002o`d00_l;00;o5002o`T00_l900;o1@02o`T00_l900;o
2P02o`T00_l200?o00<0ool02P02o`L02Ol700Co2@07o`L00_l600;o1P04o`X00_l900;o2@02o`<0
0_l01P3o003o00;o1P02o`/01ol800Oo1`06o``00ol800;o1@02oa@00ol200?o1002o`d00_l>00Oo
1`02o`L00_l500;o600001<00_l=00Co2`04o``00_lD00;o2@02o`T00_l500;o2@02o`T00_l:00;o
2@02o`800_l200;o2P02o`L00_l500?o1P03o`X01Ol900;o1P02o`H00ol;00;o2@02o`T00_l300;o
00<0ool00_l00`3oo`0600;o2`05o`X01Ol900Ko2`04o`T00_l300;o5@02o`@00_l400;o3@02o`h0
2Ol500;o1`02o`D00_lH00005002o``00ol<00?o3002oaD00_l900;o2@02o`D00_l900;o2@02o`X0
0_l900;o00<0ool00`02o`X00_l700;o1P02o`H01?l900;o00@0oooo2002o`H00_l600Co2P02o`T0
0_l900;o0`02o`030?oo00;o00<0ool01P02o`/00_l0103oool900;o00@0oooo2002o`800_l:00Ko
2002o`<00_lE00;o1002o`@00_l=00;o3P02o`D00ol400;o1`02o`D00_lH00005002o`h00_l=00;o
2`02oaD00_l900;o2@02o`D00ol800;o2@02o`X00_l900Go0`02o`X00_l700;o1P02o`D01_l800;o
0P03o`L00_l600;o1@06o`T00_l900;o2@02o`800_l300;o0`02o`D00_l;00;o0P03o`P00_l200?o
1`02o`800_l200;o1P02o`800_l900;o00@0oooo5002o`H00_l300?o1`02o`<00ol700;o1002o`H0
0_l400;o1`02o`D00_lH00005003o`h00_l=00;o2P02oaH00_l700;o2P02o`H00_l700;o2P02o`X0
0_l900Co1002o`X00_l700;o1P02o`@00ol200?o1`02o`<00ol600;o1P02o`@00ol200?o2002o`X0
0_l700;o0`02o`<00_l300;o1@02o`/00_l300?o1`02o`<00ol600;o1P02o`D00ol300;o2002o`03
0?oo01D00_l600;o1002o`L00_l400;o1`02o`@00_l600;o1002o`H00_l600;o600001D00_l>00;o
3@02o`T00_lG00?o1@03o`X00_l700;o1@02o`/00_l:00;o2@04o`@00_l:00;o1`02o`D00ol400;o
1002o`L00_l400?o1@02o`H00_l400;o1002o`P00_l:00?o1@03o`<00_l800;o1@02o`/00_l400?o
1P02o`@00ol500;o1P02o`D00_l400;o2005oa@00ol600?o0`03o`D00ol400?o1@03o`@00_l500?o
1002o`@01?l600;o600001H00_l700;o0`03o`L00_l300?o2002oaT02Ol600[o1009o`H02_l300[o
1004o`801_l400[o0P0;o`<01Ol200Go0`05o`<01Ol200Co1004o`030?oo00?o0P05o`<02?l800Wo
0`06o`801_l00`3oo`06o`H01Ol300Go0P05o`<01Ol00`3oo`0:o`<01Ol200Go0`07oa@01_l200Ko
0`0:o`D02_l200_o100:o`@02?lE00005`000ol0000500Oo2007o`T000?o00006P05o`P02_l600Go
200:o`<02_l400?o0`06o`@02_l200Wo1@05o`801Ol300Go0`05o`801?l400Co00<0ool00ol200Go
0`08o`X01Ol500Ko0P06o`030?oo00Ko1P05o`<01Ol200Go0`05o`030?oo00[o0`05o`801Ol300Oo
5006o`801_l500Go00<0ool01`05o`030?oo00802Ol600So1P08oaD0000Q00Co2`04ool0aP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(34\\) OKQJINJPYKTYKPWLKJFYA WCBQDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1300;o1003obh0000E00;o
:002ocH02_oo04802_l]00005002obX00_lf00Go0P02ool0@`05o`800_l]00005002obX00_lf0003
o`000?l0B@000ol0000c00005002o`X01Ol<00Ko2@02oaT01Ol500Go1P02o`H01Ol700Ko200:o`@0
1_l300;o1006o`L02?l800So1@05o`H00_l300So1P08o`D01Ol600;o00<0ool01_l900;o1002o`@0
3Ol00`3oo`03o`H00_l400Ko1P07o`X02?l300Ko0`06oa400_l400;o2005o`H02_l800Go1P08o`H0
1Ol600;o400001<00_l900Wo2P06o`X00_lF00Wo0`05o`D00ol400Wo0`09o`L02_l400Ko0P03o`80
2Ol600So2008o`D01Ol500?o0`08o`H02?l500Go1@03o`030?oo00Ko2@02o`@00_l400go00<0ool0
0ol500?o0P09o`D01ol:00So0`06o`<01_lA00;o1002o`H02Ol400_o1@09o`@02_l400Go1@03oa00
000C00;o2@02o`D00_l<00;o3002oaD00ol500?o1002o`D00ol400?o1@03o`800ol400?o2P02o`T0
0_l400Co0P03o`@00ol700;o3`02o`X00_l500?o1`02o``00_l:00;o1@03o`@00_l<00?o1003o`H0
0_l600;o0`02o`D00ol300?o1003o`H00_l@00;o2002o`L00_lB00?o1003o`@00ol500?o1@02o`D0
0ol300?o1@03o`@00_l400Co1@02o`D00olA00004`02oa400_l;00;o3002oaD00_l700;o1002o`D0
0_l500;o1`02o`800_l600;o2P02o`T00_l400Co0P02o`H00_l700;o3`02o`X00_l500;o2002o``0
0_l:00;o1@02o`D00_l<00Co0`03o`H00_l600;o0`02o`D00_l400;o1P02o`H00_l@00;o2002o`L0
0_lB00Co0`03o`@00_l700;o1@02o`H00_l300;o1`02o`@00_l600;o1@02o`D00_lB00004`02oa40
0_l500[o2P02oa@00_l900;o0`02o`@00_l500;o2@02o`030?oo00H00_l:00;o2@02o`<01Ol200;o
1P02o`L00_l?00;o2P02o`@00_l900;o3002o`X00_l400;o1P02o``01?l200Co1P02o`H00_l300;o
1002o`D00_l600;o1P02o`800_l<00;o200;oa801?l200Co0`03o`h00_l600;o0P02o`T00_l300;o
1`02o`@00_l400;o4`0001<00_lA00;o1@0:o`X00_lD00;o2@02o`<00ol200?o1@02o`T00_l00`3o
o`0600;o2P02o`T00_l300;o00<0ool00P02o`H00_l700Oo2P02o`X00ol200?o2@02o``00_l:00?o
0P03o`H01ol700;o00@0o`001?l600;o1P02o`<00ol200?o1@02o`H00_l600;o0P02o``00_l900Wo
4`02o`040?l000Co0`02o`l00_l600;o0P02o`T00_l300;o1`02o`@00ol200?o4`0001<00_l@00;o
1P02o`@00_l<00;o5002o`T00_l300Oo1P02o`T00_l900;o2P02o`T00_l200?o00<0ool02P02o`L0
2Ol800?o2@07o`X00_l<00?o2@07o`L02Ol500;o00H0o`00o`02o`H00_l;00Oo3P02o`H01_l<00?o
2002o`D00_lC00;o00H0o`00o`02o`<00_l?00;o1@03o`800_l900;o0`02o`L00_l400Oo500001<0
0_l=00Co2002o`<00_l<00;o5002o`T00_l300Go2002o`T00_l900;o2P02o`T00_l200;o0P02o`X0
0_l700;o1@03o`H01?l900Go3002o`/01?l900Go2@02o`D00ol400;o00<0ool00_l00`3oo`0600;o
2`05oa000_l600Ko2`04o`T00_l300;o5002o`030?oo00;o00<0ool00`02o`l02Ol300;o2@02o`<0
0_l700;o1005oaH0000D00;o3003o`X000Co00000_l;00;o5@02o`T00_l300;o00@0oooo1`02o`T0
0_l900;o2P02o`T00_l00`3oo`0300;o2P02o`L00_l600;o1@06o`P00_l0103oool600;o0`02o`<0
0_l500Ko2002o`040?ooo`P00_l600;o1002o`030?oo00;o00<0ool01P02o`/00_l0103oool?00;o
1P02o`800_l:00Ko2002o`<00_lD00;o00<0ool00_l00`3oo`0300;o3`08o`@00_l900;o0`02o`L0
0_l400;o00@0oooo5@0001@00_l>00;o2@02o`800_l;00;o5@02o`T00_l300;o0P03o`H00ol800;o
2@02o`X00_l900Go0`02o`X00_l700;o1P02o`D00_l200;o2002o`800ol500;o0`02o`<00_l500;o
0P02o`P00_l200?o1`02o`H00_l300;o0`02o`<00_l500;o2`02o`800ol>00;o1P02o`800_l200;o
1P02o`800_l900;o00@0oooo4`02o`<00_l300;o0P03o`L00_l500;o1003o`<00ol800;o0`02o`L0
0_l400;o0P03oa@0000D00?o3P02o`T000?o00000_l;00;o5P02o`L00_l400;o0`03o`H00_l700;o
2P02o`X00_l900Co1002o`X00_l700;o1P02o`@00ol300;o1`02o`<00ol400;o0`02o`<00_l400?o
0`02o`L00_l300?o1P02o`H00_l300;o0`02o`<00_l500;o2`02o`<00ol=00;o1P02o`H00_l500?o
0`02o`P00_l00`3oo`0D00;o0`02o`<00_l300;o1`02o`D00_l500;o1002o`L00_l400;o1P02o`D0
0_l300?o4`0001D00_l>00;o2P001?l0ool:00;o5`03o`D00ol400;o1003o`H00_l500;o2`02o`X0
0_l900Co1002o`X00_l700;o1@03o`@00_l400;o1`02o`@00ol300;o0`02o`<00_l400;o1002o`L0
0_l400?o1@02o`D00ol300;o2002o`D00_l;00;o1003o``00_l600;o1P02o`D00_l400;o2005oa@0
0_l800;o0`03o`D00ol500;o1003o`D00_l500;o1@02o`@01?l500;o1003oa80000F00;o1`02o`<0
0ol:00Co2@02oaT02Ol300Go0`05o`@02Ol600[o0`0:o`@01?l200Ko100:o`802ol300Go0P05o`<0
1Ol300Go00<0ool02_l200Go0P05o`<01Ol300Go00<0ool02Ol300Ko0P06o`030?oo00Ko1P05o`<0
1Ol500[o00<0ool02_l300Go0P05o`<01olD00Ko0P06o`<02_l300[o1P09o`@02_l400Go0`05oa00
000G0003o`0000D01ol<00?o2@000ol0000J00Go1@05o`<01Ol600Go200:o`<02_l400?o0`06o`@0
2_l200Wo1@05o`801Ol300Go0`05o`030?oo00[o0P05o`801Ol300Go0`05o`030?oo00Oo1@06o`80
1_l00`3oo`06o`H01Ol300Go1@0:o`030?oo00[o0`05o`801Ol300Oo5006o`801_l500Go00<0ool0
0`09o`T01Ol600So1P05o`<01Ol@00008@04o`d00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(35\\) NKQJINKPYKTYKQWLJJFZA WDARDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oU@02o`@00ooK00005@02obP0
0_lf00[oU00:omX0000D00;o:P02ocH01Ol200;oU@05o`800_oJ00005002obX00_lf0003o`0009/0
00?o0000h00001@00_l:00Go2P05o``00_lF00Ko0`02o`801Ol600;o1P05o`L01_l800[o1006o`<0
0_l200Go1P02o`802?l800So1@05o`H00_l300So1P08o`D01Ol600;o1@05o`P00_l400;o100=o`<0
1_l900Ko1P07o`T02_l200Ko0`06oa400_l400;o1@08o`D01_l300_o1P03o`030?oo00Ko1P05o`H0
0_l@00004`02o`T02Ol600Wo2`02oaD01_l200?o0P05o`D00ol400Wo0`09o`L02_l400Ko0P03o`80
1Ol500?o0P08o`P02?l500Go1@03o`<02?l600So1@05o`D00ol300Wo1P02o`@00_l400go00<0ool0
1ol600Wo1@07o`T02_l200Ko0`06oa400_l400;o1@0:o`<01_l300_o1@04o`030?oo00So1005o`D0
0ol@00004`02o`T00_l500;o1P02o`D00_l;00;o5P02o`@01?l400;o1@03o`@00ol500?o0P03o`@0
0ol:00;o2@02o`@01?l400;o1@03o`D00_l?00;o2P02o`D00ol700;o3002o`X00_l500?o0`03o`D0
0ol400?o1003o`H00_l600;o00@0oooo1003o`D00ol400?o1P02o`d00_l500;o1002o`L00_lB00?o
1003o`D00_l400Co1002o`L00_l400;o1@03o`@00_l400Co1@02o`D00olA00004`02oa400_l=00;o
2P02oaH00_l400Co1002o`D00_l500;o1`02o`800_l600;o2P02o`T00_l400Co1002o`D00_l600;o
3`02o`X00_l500;o2002o``00_l:00;o1@02o`@00_l700;o1004o`<00ol600;o1P02o`030?oo00H0
0_l500;o1P02o`H00_l=00?o1002o`@00_l700;o4P04o`<00ol500;o1P02o`@00_l700;o1002o`D0
0_l500;o1P02o`D00_l500;o4P0001<00_lA00;o3@02o`X00_lF00;o0`05o`@00_l400;o1@02o`T0
0_l00`3oo`0600;o2P02o`T00_l300Go1002o`@00_l700;o3`02o`X00_l400;o2@02o``00_l:00;o
1002o`@00_l900;o0`04o`801?l600;o1P02o`030?oo00H00_l500;o1P02o`H00_l200;o2P03o`<0
0_l400_o4P04o`801?l500;o1`02o`<02ol400;o1002o`H00_l700;o1002o`@00_lC00004`02oa40
0_l=00;o2P02oaH00_l300;o00<0ool01003o`800ol500;o2@02o`030?oo00H00_l:00;o2@02o`<0
0_l00`3oo`0400?o0P03o`L01ol:00;o2P03o`800ol900;o3002o`X00ol200?o1002o`T00_l300;o
00@0o`001?l600;o1P02o`030?oo00H00_l500;o1P02o`H00_l200;o2`02o`<00_l500Wo4`02o`04
0?l000Co1@02o`L00_l400Wo1@02o`<00ol600;o1`02o`@00ol200?o4`0001<00_l@00;o3P02o`X0
0_lF00;o0P03o`030?oo00@01ol600;o2@02o`T00_l:00;o2@02o`800ol00`3oo`0400Oo2009o`P0
0ol900Oo2P02o``00ol900Oo1@02o`T00_l300;o00H0o`00o`02o`H00_lA00;o3@02o`H01_l;00?o
2@02o`D00_lC00;o00H0o`00o`02o`D00_l700;o1002o`D00_l500Oo1`02o`L00_l400Oo500001<0
0_l=00Co2002o`@00_l;00;o5P02o`800_l200;o1005o`P00_l900;o2@02o`X00_l900;o0P02o`80
0_l400Go2P02o`D00ol600Co2@05o``00_l;00Co2@05o`L00_l900;o0`02o`030?oo00;o00<0ool0
1P02oa400_l=00;o1P06o``00ol900;o0`02oa@00_l00`3oo`02o`030?oo00D00_l700;o1@02o`<0
0_l600Wo1@02o`L00_l400Go5P0001@00_l<00?o2@08o`X00_lG00;o00<0ool00`02o`@00_l0103o
ool700;o2@02o`T00_l:00;o2@02o`030?oo00<00_l400;o00@0oooo2@02o`H00_l500Ko2002o`04
0?ooo`H00_l300;o0`02o`D01_l800;o00@0oooo1P02o`T00_l300;o00<0ool00_l00`3oo`0600;o
4@02o`d00_l600;o0P02o`P00_l300;o2@02o`<00_lD00;o00<0ool00_l00`3oo`0500;o1`02o`D0
0_l300;o1P02o`D00ol400;o1`02o`@00_l0103ooolE00005002o`h00_l800Oo2`02oaL01Ol300;o
1002o`800ol600?o2002o`T00_l:00;o2@05o`<00_l400;o0P03o`P00_l600;o1@02o`800_l800;o
0P03o`D00_l300;o0`02o`D00_l200;o2002o`800ol500?o2002o`800_l300;o0`02o`D00_lA00;o
3@02o`H00_l200;o0P02o`@00_l300?o2@02o`040?oooa<00_l300;o0`02o`@00_l700;o1P02o`04
0?ooo`H00_l600;o1002o`L00_l400;o0P03oa@0000D00?o3P02o`L00_l@00;o5`04o`@00_l400;o
0`03o`H00_l700;o2P02o`X00_l900Co1002o`@00_l300?o1`02o`H00_l400?o0`02o`L00_l300?o
1002o`<00_l300;o1003o`<00_l700;o0`03o`D00_l700;o0`02o`<00_l300;o1@02oa400_l=00;o
1P02o`H00_l400;o1003o`P00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0700;o
1P02o`@00_l600;o1@02o`<00olC00005@02o`h00_l700;o3`02oaP01?l400;o1002o`@00ol600;o
1@02o`/00_l:00;o2@04o`@00_l400;o1003o`H00_l500?o1002o`@00_l700;o1003o`<00_l300;o
0`02o`@00_l400;o1`02o`@00ol500;o1@02o`@00_l800;o1@02oa400_l=00;o1P02o`H00_l400;o
1@02o`P01OlD00;o2002o`@00_l400Co1`05o`L00_l500?o1002o`@01?l500;o1003oa80000F00;o
1`02o`<00ol700;o3P02oaP01?l200Ko00<0ool00ol300Go1009o`H02_l300[o1004o`801_l00`3o
o`03o`<01Ol200_o0`05o`801Ol300Go0`05o`030?oo00[o0P05o`801Ol300Go0`05o`<02Ol300Ko
0P06o`030?oo00Ko2@0:o`D02_l00`3oo`0:o`@02_l400Oo5006o`801_l200[o1@07o`H02ol400[o
1005o`<01Ol@00005`000ol0000500Oo2008o`P000?o00005`03o`<01_l00`3oo`03o`<01Ol600Go
200:o`<02_l400?o0`06o`030?oo00?o0`05o`802Ol500Go0P05o`<01Ol300Go00<0ool02_l200Go
0P05o`<01Ol300Go1@05o`D01_l200Ko00<0ool01_l900[o1@0:o`030?oo00[o100:o`@01olD00Ko
0P06o`802?l700Oo1P09o`H02?l600Go0`05oa00000Q00Co2@08ool0a0000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(36\\) NKQIINKPZKSYKRXKJJFZA WDARDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2P05o`/0
1?l<00;o5P06o`<00_l200Go1P02o`H01Ol600[o1@0:o`@01_l300;o0P05o`H00_l200So1`0:o`@0
1Ol600;o0P02o`030?oo00?o1`08o`D01Ol600;o00<0ool00ol600?o00<0ool00ol200Go0P05o`H0
0_l300Ko2@06o`H01ol900[o0P06o`<01_lA00;o1002o`D02?l500Ko0`0;o`H00ol00`3oo`06o`H0
1Ol600;o400001<00_l900Wo2007o`/00_lE00Ko0P03o`801Ol500?o1009o`@02_l500[o1006o`80
0ol200Go1@03o`802?l700[o1005o`D00ol200[o1@08o`D01Ol500?o00<0ool00ol500Co00<0ool0
0ol200Go0P05o`D00ol00`3oo`07o`H02Ol500Oo2@0:o`801_l300Ko4@02o`@00_l500[o0`06o`<0
2ol500Co00<0ool02?l400Go1@03oa00000C00;o2@02o`D00_l700;o1002o`/00_lF00;o1004o`@0
0_l500?o1003o`D00ol700;o3@02o`T00_l400Co1002o`D00ol500;o3002o`D00_l600;o1@03o`<0
0ol500?o1`02o`X00_l500?o1002o`D00ol400?o1003o`D00_l500?o0P03o`@00ol500?o1003o`H0
0_l=00;o1@02o`@00_l700;o4P03o`@00ol500;o1004o`@00_l700;o1002o`D00ol400;o1004o`D0
0_l500?o4@0001<00_lA00;o1@02o`H00_l:00;o5P02o`@01?l400;o1@02o`D00_l700;o1`02o`d0
0_l900;o1004o`@00_l500;o1P02o``00ol400;o1P02o`D00_l400;o1`02o`L00_l:00;o1@02o`D0
0_l500;o1P03o`800ol600;o1@02o`<00_l600;o1@02o`H00_l600;o3@03o`@00_l400;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`@00_l500;o1@02o`H00_l500;o1@02oa80000C00;o4@02o`D0
0_l600;o2P02oaH00_l300Go1002o`@00_l500;o2@02o`H00_l=00;o2@02o`<01Ol400;o1002o`L0
0_l=00?o0`02o`H00_l400;o1@02o`L00_l700;o2P02o`@00_l600;o1002o`P00_l200;o1`02o`@0
0_l400;o1P02o`D00_l600;o1P02o`800_l:00?o0`02o`@02olB00Co0P04o`D00_l700;o0`0;o`@0
0_l400;o1P02o`L00_l400;o1002oa<0000C00;o4@02o`D00_l600;o2P02oaH00_l300;o00<0ool0
1003o`800ol500;o2@02o`H00_l=00;o2@02o`<00_l00`3oo`0400?o0P03o`L01ol900;o0`02o`H0
0ol200?o3@03o`L00_l:00?o0P03o`H00_l300?o2@04o`P00ol200?o1002o`H00_l500;o1P02o`H0
0_l200;o2`02o`<00_l500Wo4`02o`040?l000Co1@02o`L00_l400Wo1@02o`<00ol600;o1`02o`@0
0ol200?o4`0001<00_l@00;o1P02o`H00_l:00;o5P02o`800ol00`3oo`0400Oo1P02o`T00_l600;o
3@02o`T00_l200?o00<0ool01007o`P02Ol700?o2P07o`T01ol800?o2@07o`L01ol:00Co2007o`d0
0_l=00;o1P06o`/00ol900;o1@02oa<00_l01P3o003o00;o1@02o`L00_l400;o1@02o`D01ol700;o
1`02o`@01olD00004`02o`d01?l700?o1002o`/00_lF00;o0P02o`800_l400Go2002o`T00_l600;o
3@02o`T00_l200;o0P02o`@01Ol:00;o1@03o`L00ol900Go2@07o`T01?l900Go2@09o`P00ol900Go
3`02o`d00_l600Ko3003o`T00_l300;o5002o`030?oo00;o00<0ool01@02o`L00_l500;o0`02o`H0
2Ol500;o1`02o`@01OlF00005002o``00ol800Wo2P02oaL00_l00`3oo`0300;o1002o`040?ooo`L0
0_l900;o1P02o`d00_l900;o00<0ool00`02o`@00_l0103oool900;o1P02o`<00_l300;o2@02o`04
0?ooo`L00ol=00Ko2002o`040?ooo`P00_l500?o1`04o`P00_l0103oool>00;o3@02o`H00_l200;o
2002o`<00_l900;o0`02oa@00_l00`3oo`02o`030?oo00D00_l700;o1@02o`<00_l600;o1@03o`@0
0_l700;o1002o`040?oooaD0000D00;o3P02o`L00_l00`3oo`02o``00_lG00Go0`02o`@00_l200?o
1P03o`P00_l600;o3@02o`T01Ol300;o1002o`800ol800;o1P02o`<00_l300?o2002o`800ol600;o
1`000ol0000400;o0P02o`P00_l200?o1`02o`H00_l600Ko1`02o`800ol=00;o3@02o`H00_l200;o
0P02o`@00_l300?o2@02o`040?oooa<00_l300;o0`02o`@00_l700;o1P02o`040?ooo`H00_l600;o
1002o`L00_l400;o0P03oa@0000D00?o3P02o`L00_l@00;o5`04o`@00_l400;o0`03o`H00_l700;o
1`02o`d00_l900Co1002o`@00_l300?o1`02o`H00_l300;o1003o`L00_l300?o1@02o`H00_l500?o
0`02o`L00_l300?o1P02o`H00_l500?o0P03o`H00_l300?o3002o`d00_l600;o1P02o`@00_l400?o
2002o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00L00_l600;o1002o`H00_l500;o
0`03oa<0000E00;o3P02o`L00ol>00;o6004o`@00_l400;o1003o`H00_l500;o2002o`d00_l900Co
1002o`@00_l400?o1P02o`D00ol300;o1@02o`L00_l400?o1003o`@00ol500;o1002o`L00_l400?o
1@02o`D00ol500;o1002o`H00_l400?o2`02o`d00_l600;o1P02o`@00_l500;o2005oa@00_l800;o
1002o`@01?l700Go1`02o`D00ol400;o1004o`D00_l400?o4P0001H00_l700;o0`03o`P00ol<00;o
6004o`801_l00`3oo`03o`<01Ol400Wo100:o`D02_l400Co0P06o`030?oo00?o0`05o`802ol400[o
1005o`<01Ol300Wo0`05o`801Ol300Go0`05o`030?oo00Wo1005o`801Ol200Go0`05o`@02_l500[o
00<0ool02_l400[o1007oa@01_l200Ko0P0:o`D01ol600_o100:o`@01Ol300Go400001L000?o0000
1@07o`X01ol70003o`0001L00ol300Ko00<0ool00ol300Go1P05o`H02_l500[o1003o`<01_l00`3o
o`03o`<01Ol200Wo1P0:o`@01Ol300Go1@05o`030?l000801Ol200Go0`05o`<01Ol00`3oo`07o`H0
1Ol200Go0P05o`<01Ol400[o1@0:o`030?oo00[o100:o`@01olD00Ko0P06o`802?l700Oo1P09o`H0
2?l600Go0`05oa00000Q00Co3@05ool0``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(37\\) NJRJINKPZJRYJSXKIKEYB WDARDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`02o`h00_lF00Ko0`02o`@01_l700Go1P03o`80
1_l800[o1006o`<00_l200Go1P02o`802?l700[o1P06o`H01Ol600?o0P08o`L01_l700;o00<0ool0
0ol600Go0P05o`801Ol600;o0P0:o`@01Ol600;o00<0ool02_l500So100:oaD00_l400;o1@08o`D0
1_l300_o1P03o`030?oo00Ko1P05o`H00_l@00004`02o`T02Ol900;o3`02oaD01_l200?o0P09o`H0
1Ol500go1`0:o`@01_l200?o0P05o`D00ol200So1`0:o`@02Ol500Go1@04o`802?l500Wo1P0:o`@0
1Ol200Go0P05o`D00ol200[o1005o`D00ol00`3oo`0:o`D02?l400_o5002o`@00_l500[o0`06o`<0
2ol500Co00<0ool02?l400Go1@03oa00000C00;o2@02o`D00_l:00;o3P02oaH00_l400Co0P03o`@0
0ol700;o1@03o`800ol400?o2P02o`T00_l400Co1002o`D00ol500;o3002o`D00_l400?o1003o`H0
0_l500?o1`02o`P00ol400?o1@03o`D00ol400?o1003o`D00_l500?o1`02o`X00_l500?o1002o`H0
0_l800;o2@02o`D00olB00?o1003o`D00_l400Co1002o`L00_l400;o1@03o`@00_l400Co1@02o`D0
0olA00004`02oa400_l900;o3P02oaH00_l400Co0P02o`H00_l700;o1@02o`<00_l600;o2P02o`T0
0_l400Co1002o`D00_l600;o3003o`@00_l400;o1P02o`H00_l500;o2002o`P00_l600;o1@02o`L0
0_l500?o0P03o`H00_l500;o2002o`X00_l500;o1@02o`H00_l800;o2@02o`H00_lB00Co0`03o`D0
0_l600;o1002o`L00_l400;o1@02o`D00_l600;o1@02o`D00_lB00004`02oa400_l900;o3P02oaH0
0_l300Go0P02o`H00_l700;o1002o`@00_l600;o2P02o`T00_l300Go1002o`@00_l700;o3@03o`<0
0_l400;o1P02o`H00_l400;o2@02o`P00_l600;o1@02o`L00_l600;o0P02o`L00_l400;o2@02o`X0
0_l400;o1P02o`800_l200;o2002o`T00_l600;o4P04o`801?l500;o1`02o`<02ol400;o1002o`H0
0_l700;o1002o`@00_lC00004`02oa400_l:0003o`0000`00_lF00;o0`02o`030?oo00800_l600;o
1`02o`<00ol400;o1P02o`X00_l900;o0`02o`030?oo00@00ol200?o1`07o`T00_l300;o1002o`H0
0_l600;o0`03o`T00_l800;o1P02o`d00ol700Co2003o`800ol900;o2P03o`800ol600;o0P02o``0
0_l900;o1P02oa800_l0103o0004o`D00_l700;o1009o`D00_l300?o1P02o`L00_l400?o0P03oa<0
000C00;o4002o`/00_l=00;o5P02o`800ol00`3oo`0:00;o1`07o`d00_l:00;o2@02o`800ol00`3o
o`0400Oo2009o`L00ol@00;o1P07o`X00ol?00;o2007o`P01?l800Oo2P02o`X01ol700Ko3003o`P0
0_l500?o4P02o`060?l00?l00_l500;o1`02o`@00_l500;o1@07o`L00_l700;o1007oa@0000C00;o
3@04o``00_l=00;o5P02o`800_l200;o2P02o`L02Ol;00;o2P02o`T00_l200;o0P02o`@01Ol:00;o
1@03o`L00ol?00;o1P09o`L01?l?00;o1P07o`X00ol900Go3002o`X01Ol900Ko2`04o`P02OlC00;o
00<0ool00_l00`3oo`0500;o1`02o`D00_l300;o1P09o`D00_l700;o1005oaH0000D00;o3003o`h0
00?o00002P02oaL00_l00`3oo`0300;o2P02o`L00_l500?o2P02o`X00_l900;o00<0ool00`02o`@0
0_l0103oool900;o1P02o`<00_l300;o3`02o`H00_l500?o1@06o`h00_l500?o3`04o`P00_l0103o
ool;00;o2P02o`040?ooo`P00_l200;o2P06o`L02?lD00;o00<0ool00_l00`3oo`0500;o1`02o`D0
0_l300;o1P02o`D00ol400;o1`02o`@00_l0103ooolE00005002o`h00_l=00;o2`02oaL01Ol300;o
2P02o`L00_l600;o2P02o`X00_l900Go0`02o`@00_l200?o2002o`H00_l300;o0`03o`h00_l600;o
1P02o`D00_l200;o3P02o`D00_l70003o`0000D01_l700;o0P03o`X00_l:00;o0P03o`L00_l200;o
0P02o`H00_l200;o1`02o`@00olB00;o0`02o`<00_l400;o1`02o`H00_l0103oool600;o1P02o`@0
0_l700;o1002o`800olD00005003o`h00_l<00;o2`02oaL01?l400;o2P02o`L00_l600;o2P02o`X0
0_l900Co1002o`@00_l300?o1`02o`H00_l300;o1003o`d00_l600;o1P02o`@00ol300;o3@02o`D0
0_l600;o1P03o`800ol600;o0`03o`T00_l:00;o0`03o`H00_l600;o1@03o`<00_l600;o1@02oa80
0_l300;o0`02o`@00_l600;o1`02o`030?oo00L00_l600;o1002o`H00_l500;o0`03oa<0000E00;o
3P02o`d000?o00002002oaP01?l400;o2P02o`L00_l500?o2P02o`X00_l900Co1002o`@00_l400?o
1P02o`D00ol300;o1@02o`d00_l600;o1@03o`@00_l400;o3@02o`D00ol400?o1P02o`@00_l600;o
1003o`P00_l:00;o1003o`D00_l600;o1@02o`@00_l600;o1003oa800_l800;o1002o`@01?l700Go
1`02o`D00ol400;o1004o`D00_l400?o4P0001H00_l700;o0`03o`H00_l500;o2002oaP01?l200Ko
100:o`802ol600[o0`0:o`@01?l200Ko00<0ool00ol300Go0P0;o`@02_l700[o00<0ool02Ol300Go
0P05o`H02_l300Wo1005o`801Ol200Go0`05o`802_l400Go0`05o`030?oo00[o0`05o`801Ol200[o
4P06o`801_l200[o1@07o`H02ol400[o1005o`<01Ol@00005`000ol0000500Oo1`09o`P000?o0000
5`03o`<01_l400[o0P09o`P02_l300[o1003o`<01_l00`3oo`03o`<01Ol200Wo1P0:o`L02_l00`3o
o`07o`D01Ol200Go1P0:o`D01Ol00`3o000300Go0P05o`801Ol300Go0P0:o`@01Ol300Go00<0ool0
2_l300Go0P05o`802OlC00Ko0P06o`802?l700Oo1P09o`H02?l600Go0`05oa00000Q00Co2009ool0
a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(38\\) NIRJINKQ JRYJSXKJLEZB WDARDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o2P05o`/0
1?l<00;o5P06o`<00_l300[o1005o`H00ol200Ko200:o`@01_l300;o0P05o`H00_l600Go5P06o`H0
1Ol600?o0P08o`L01_l700;o00<0ool00ol600Go0P05o`801Ol600;o0`06o`L03Ol00`3oo`0:o`@0
2_l300[o5@02o`@00_l500So1@06o`<02ol600?o00<0ool01_l600Go1P02oa00000C00;o2@09o`L0
2?l;00;o5@06o`800ol300[o1005o`D03Ol700[o1006o`800ol200Go1@03o`@02OlB00Wo1@05o`D0
1?l200So1@09o`H02_l400Go0P05o`801Ol500?o00<0ool01ol600go00<0ool02_l400[o0`0;oa@0
0_l400;o1@0:o`<01_l300_o1@04o`030?oo00So1005o`D00ol@00004`02o`T00_l500;o1P03o`@0
0ol:00;o5P02o`@01?l700;o2P02o`D00ol200?o1003o`X00_l900;o1004o`@00_l500?o1003o`D0
0olA00?o1003o`H00_l500?o1`02o`P00ol400?o1@03o`D00ol400?o1003o`D00_l500?o0P03o`@0
0ol800;o1P02o`<00_l600;o1@02o`D00_l500;o1@03oa800ol400?o1@02o`@01?l400;o1`02o`@0
0_l500?o1002o`@01?l500;o1@03oa40000C00;o4@02o`D00_l600;o2P02oaH00_l400Co1`02o`X0
0_l500;o0`02o`H00_l:00;o2@02o`@01?l400;o1@02o`D00_l700;o4@02o`H00_l600;o1@02o`P0
0_l800;o1P02o`D00_l700;o1@03o`800ol600;o1@02o`<00_l600;o2002o`H00_l300;o1P02o`D0
0ol400;o1@02o`H00_lB00Co0`03o`D00_l600;o1002o`L00_l400;o1@02o`D00_l600;o1@02o`D0
0_lB00004`02oa400_l500;o1P02o`X00_lF00;o0`05o`L00_l:00;o1002o`@00_l600;o2P02o`T0
0_l300Go1002o`@00_l500;o2@02oa000_l600;o1P02o`@00_l900;o2002o`H00_l500;o1`02o`H0
0_l200;o1`02o`@00_l400;o1P02o`P00_l600;o0`02o`800_l200;o1P03o`<00_l500;o1P02oa80
1?l200Co1@02o`L00_l300_o1002o`@00_l600;o1`02o`@00_l400;o4`0001<00_lA00;o1@02o`H0
0_l:00;o5P02o`<00_l00`3oo`0700;o2P02o`<00ol400;o1P02o`X00_l900;o0`02o`030?oo00@0
0ol200?o1@02o`T00_l@00;o1P02o`H00_l300?o2@02o`P00_l600;o3@03o`L01?l800?o0P03o`@0
0_l600;o2002o`H00_l300;o0P02o`/00_l300;o1@02o`H00_lB00;o00@0o`001?l500;o1`02o`@0
2Ol500;o0`03o`H00_l700;o1003o`800olC00004`02oa000_l700;o1002o`/00_lF00;o0P03o`03
0?oo00L00_l:00Oo3@02o`X00_l900;o0P03o`030?oo00@01ol600;o2@02oaP00_l600Oo2P03o`l0
0_l800Oo2004o`P01ol=00;o2002o`/01_l;00?o2@02o`D00olB00;o00H0o`00o`02o`D00_l700;o
1002o`D00_l500Oo1`02o`L00_l400Oo500001<00_l=00Co2@07o`/00_lF00;o0P02o`800_l700;o
2P09o`/00_l:00;o2@02o`800_l200;o1005o`P00_l900;o6002o`H02Ol700Co3`02o`H01ol:00?o
2@05o`l00_l800;o2`06o``00ol800Wo4`02o`030?oo00;o00<0ool01@02o`L00_l500;o0`02o`H0
2Ol500;o1`02o`@01OlF00005002o``00ol:00Ko2`02oaL00_l00`3oo`0300;o1`02o`X00_l500?o
2P02o`X00_l900;o00<0ool00`02o`@00_l0103oool700;o2@02oaP00_l600;o1@03o`D01_l>00;o
1@03o`l01?l800;o00@0oooo3P02o`P00_l;00;o0P02o`P00_l300;o2008oa@00_l00`3oo`02o`03
0?oo00D00_l700;o1@02o`<00_l600;o1@03o`@00_l700;o1002o`040?oooaD0000D00;o3P02o`P0
0_l400;o2P02oaL01Ol300;o1`02o`X00_l600;o2P02o`X00_l900Go0`02o`@00_l200?o1P03o`P0
0_lH00;o1P02o`H00_l500;o0P02o`h00_l500;o1`000ol0000500Ko1`02o`800ol=00;o2002o`/0
0_l200;o0P02o`@00_l300?o1`02o`@00olB00;o0`02o`<00_l400;o1`02o`H00_l0103oool600;o
1P02o`@00_l700;o1002o`800olD00005003o`h00_l600;o1P02o`T00_lG00Co1002o`L00_l:00;o
1P02o`X00_l:00;o2@04o`@00_l400;o0`03o`H00_l700;o6@02o`H00_l600;o1003o`<00_l=00;o
1@02o`H00_l600?o0P03o`H00_l300?o3002o`P00_l;00;o1P02o`@00_l400?o1P02o`D00_lB00;o
0`02o`<00_l400;o1P02o`L00_l00`3oo`0700;o1P02o`@00_l600;o1@02o`<00olC00005@02o`h0
0_l600;o1P02o`P00_lH00Co1002o`L00_l:00;o1@03o`X00_l:00;o2@04o`@00_l400;o1003o`H0
0_l500;o6P02o`H00_l500?o1002o`@00_l=00;o1@03o`@00ol600;o1002o`H00_l400?o2`02o`P0
0_l;00;o1P02o`@00_l500;o1P02o`@00olB00;o2002o`@00_l400Co1`05o`L00_l500?o1002o`@0
1?l500;o1003oa80000F00;o1`02o`<00ol600?o1003o`L00_lH00Co0P06o`802_l400_o1P0:o`<0
2_l400Co0P06o`030?oo00?o0`05o`@02OlE00[o00<0ool02Ol300Go0P05o`H02_l300Wo1005o`80
1Ol200Go0`05o`@02_l200So1P0<o`@02_l300[o4P06o`801_l200[o1@07o`H02ol400[o1005o`<0
1Ol@00005`000ol0000500Oo2008o`P000?o00005`03o`<01_l200[o1009o`P02_l300[o1003o`<0
1_l00`3oo`03o`<01Ol600Go5`0:o`030?oo00Oo1@05o`801Ol600[o1@05o`030?l000<01Ol200Go
0P05o`<01Ol400[o0P08o`H03?l400[o0`09oa<01_l200Ko0P08o`L01ol600Wo1P08o`H01Ol300Go
400002401?l:00Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(39\\) NHSJINJQZJRZJSXKJLEYB WDASEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o2P05o`P0
1Ol>00;o5P06o`<00_l300Co0`04o`@00_l00`3oo`03o`L01_l800[o1006o`<00_l400Ko2`05o`H0
2_l600Ko1P05o`H00ol00`3oo`08o`H01_l700;o00<0ool00ol600Go0P05o`801Ol600;o0`06o`L0
3Ol00`3oo`0:o`D02?l400[o5@02o`@00_l500So1@06o`<01_l0103oo`05o`D03?l300Go1P02oa00
000C00;o2@09o`H01ol=00;o5@06o`800ol300Co0`04o`@02_l300Wo1`0:o`@01_l200?o0P09o`P0
2Ol400[o1009o`D01Ol500Co00<0ool02?l400Wo1P0:o`@01Ol200Go0P05o`D00ol00`3oo`07o`H0
3Ol00`3oo`0:o`D02?l400_o5002o`@00_l500[o0`06o`<01_l00`3oo`08o`<03?l300Go1@03oa00
000C00;o2@02o`D00_l;00?o3002oaH00_l400Co1002o`D00_l500?o1@03o`800ol400?o2P02o`T0
0_l400Co0P03o`@00ol600?o1@03o`@00_l500;o1003o`@00ol600;o1@03o`@00_l500;o1003o`@0
0ol500?o1@03o`@00ol400?o1@02o`D00ol200?o1003o`P00_l600;o0`02o`H00_l800;o2@02o`D0
0olB00?o1003o`D00_l400Co1002o`L00_l300?o1@03o`@00_l600;o1@02o`D00olA00004`02oa40
0_l;00?o2`02oaH00_l400Co1002o`D00_l500;o1`02o`800_l600;o2P02o`T00_l400Co0P02o`H0
0_l600;o1`02o`@00ol400;o1002o`H00_l600;o1@02o`D00ol400;o1002o`H00_l500;o1`02o`D0
0ol200?o1P02o`D00_l300;o1P02o`P00_l600;o0`02o`H00_l800;o2@02o`H00_lB00Co0`03o`D0
0_l600;o1002o`L00_l300;o1`02o`@00_l600;o1@02o`D00_lB00004`02oa400_l<00;o2`02oaH0
0_l300Go1002o`D00_l500;o1`02o`800_l600;o2P02o`T00_l300Go0P02o`H00_l500;o2@02o`@0
0ol300;o1002o`H00_l600;o1002o`L00ol300;o1002o`H00_l500;o1`02o`H00_l200;o1`02o`@0
0_l400;o1P02o`P00_l600;o0`02o`800_l200;o2002o`T00_l600;o4P04o`801?l500;o1`02o`<0
2ol300;o1`02o`@00_l200;o0P02o`D00_l400;o4`0001<00_lA00;o2004o`030?oo00X00_lF00;o
0`02o`030?oo00@00_l500;o3@03o`800_l600;o2P02o`T00_l300;o00<0ool00P02o`H00_l500;o
2@02o`D00_l300;o1002o`H00_l600;o0`03o`P00_l300;o1002o`H00_l=00?o1`04o`P00ol200?o
1002o`H00_l800;o1P02o`<00_l200;o3002o`T00_l600;o4P02o`040?l000Co1@02o`L00_l400Wo
3003o`@00_l200;o2@03o`800olC00004`02oa000_l700Wo2P02oaH00_l200?o00<0ool01002o`D0
0_l800Oo2`02o`X00_l900;o0P03o`030?oo00X00_l500;o2@02o`D00ol@00;o1P07o`T00ol@00;o
2007o`P01?l800Oo3@02o`P00_l;00Ko3003o`P00_l500?o4P02o`060?l00?l00_l500;o1`02o`@0
0_l500;o1`07o`D01_l900Oo500001<00_l=00Co2002o`@00ol:00;o5P02o`800_l200;o1009o`H0
1ol=00;o2P02o`T00_l200;o0P02o`X00_l500;o2@02o`H00ol?00;o1P09o`P00ol?00;o1P07o`X0
0ol900Go3`02o`P00_l;00Ko2`04o`P02OlC00;o00<0ool00_l00`3oo`0500;o1`02o`D00_l300;o
1P07o`L01_l900Go5P0001@00_l<00?o2002o`H00_l900;o5`02o`030?oo00<00_l400Wo1@03oa80
0_l:00;o2@02o`030?oo00<00_l:00;o1@02o`T00_l200;o0`02o`l00_l600;o1@03o`<00_l300;o
3`02o`D00ol?00Co2002o`040?ooo`h00_l800;o2`02o`800_l:00Ko1`08oa@00_l00`3oo`02o`03
0?oo00D00_l700;o1@02o`<00_l500?o3002o`800_l900;o00@0oooo5@0001@00_l>00;o1`02o`H0
0_l900;o5`05o`<00_l400;o1@02o`D00_l70003o`0000T00_l:00;o2@05o`<00_l:00;o1@03o`P0
0_l200;o0`03o`h00_l600;o1P02o`<00_l300?o3P02o`D00_l70003o`0000D01_l700;o0P03o`d0
0_l800;o2`02o`800_l200;o1P02o`800_l700;o1003oa800_l300;o0`02o`@00_l700;o1P02o`04
0?ooo`D00_l70003o`0000<00_l200;o0P02o`D00_l200?o500001@00ol>00;o1P02o`H00_l900;o
5`04o`@00_l400;o1@02o`D00_l600;o2`02o`X00_l900Co1002o`X00_l600;o1`02o`<00_l400?o
3@02o`H00_l600;o0`02o`@00ol=00;o1@02o`H00_l600?o0P03o`H00_l300?o3002o`P00_l;00;o
1P02o`D00ol300;o1P02o`D00_lB00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D0
0_l600;o1@02o`<00olC00005@02o`h00_l600;o1P000ol0000700;o6004o`@00_l400;o1@02o`D0
0ol400?o2`02o`X00_l900Co1002o`X00_l700;o1@02o`@00_l500;o3@02o`H00_l500?o0`02o`D0
0_l=00;o1@03o`@00ol600;o1002o`H00_l400?o2`02o`P00_l;00;o1P02o`D00_l400;o1P02o`@0
0olB00;o2002o`@00_l400Co1`05o`H00ol400?o1@02o`H00_l500;o1003oa80000F00;o1`02o`<0
0ol700;o1002o`P00_lH00Co0P06o`801?l300Co1@09o`H02_l300[o1004o`801_l400[o1009o`@0
2_l700[o00<0ool02Ol400[o1`0:o`<02Ol400Go0P05o`801Ol300Go100:o`802?l600co0`05o`80
1Ol200[o4P06o`801_l200[o1@07o`P02Ol300co0`05o`<01Ol@00005`000ol0000500Oo2007o`T0
00?o00005`03o`<01_l200Co0`04o`L01Ol00`3o000500[o0`0:o`@00ol300Ko100:o`H01Ol600[o
1`0:o`030?oo00Oo1P0:o`L02_l500Go00<0o`000`05o`801Ol200Go0`05o`@02_l200So1P0<o`<0
1Ol200Go0P09oa<01_l200Ko0P08o`L01ol:00Go00<0o`000P0<o`<01Ol300Go400002401?l;00Co
o`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(40\\) MHTJINIQZJRZJSYLJLEYB WDASEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o3006o`P0
1?l<00;o5@05o`<01Ol200Co0`04o`D02?l600Ko200:o`@01_l300;o0`0:o`P01Ol600[o1P06o`H0
1Ol600?o00<0ool02?l600Ko1`02o`030?oo00?o2008o`@03Ol300Ko1`0=o`030?oo00[o1@08o`@0
2_lE00;o1002o`D02?l500Ko0`06o`040?oo00Go1@0<o`<01Ol600;o400001<00_l=00Ko1`06o``0
0_lD00Go0`05o`801?l300Co1@08o`@02Ol700[o1006o`800ol300[o1P09o`@02_l400Wo1@05o`D0
1?l00`3oo`08o`@02Ol600[o1P08o`@03Ol00`3oo`07o`H03Ol00`3oo`0:o`D02?l400_o5002o`@0
0_l500[o0`06o`<01_l00`3oo`08o`<03?l300Go1@03oa00000C00;o3`02o`P00ol200?o2`02oaD0
0_l700;o1002o`D00_l900;o1`03o`@00ol:00;o2@02o`@01?l700;o2@03o`D00ol400;o1@02o`@0
0ol400?o1P02o`D00ol400;o1@02o`@00ol400?o1@03o`D00ol800;o2P02o`H00_l0103oool400?o
2002o`H00_l300;o1P02o`P00_l900;o1@03oa800ol400?o1@02o`@01?l400;o1`02o`<00ol500?o
1002o`H00_l500;o1@03oa40000C00;o3`02o`P00_l400;o2`02oaD00_l700;o1002o`D00_l900;o
1`02o`H00_l:00;o2@02o`@01?l700;o2@02o`L00_l400?o1002o`@00_l600;o1P02o`D00_l500?o
1002o`@00_l600;o1@02o`L00_l800;o2P02o`H00_l00`3oo`0600;o2002o`H00_l300;o1P02o`P0
0_l900;o1P02oa801?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l500;o1@02oa80
000C00;o2@0:o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l500;o2@02o`L00_l600;o2P02o`T0
0_l300Go1`02o`P00_l900;o1003o`<00_l400;o1P02o`H00_l400;o1`03o`<00_l400;o1P02o`D0
0_l700;o2002o`X00_l600;o00<0ool01P02o`P00_l600;o0`02o`800_l200;o2002o`T00_l600;o
4P04o`801?l500;o1`02o`<02ol300;o1`02o`@00_l200;o0P02o`D00_l400;o4`0001<00_l900[o
1@02o`H00_l:00;o5@02o`800ol200;o1002o`D00_l900;o1`02o`H00_l:00;o2@02o`<00_l00`3o
o`0700;o2002o`T00_l500;o0`02o`@00_l600;o1P02o`<00ol800;o0`02o`@00_l600;o3@03o`P0
0_l:00;o1P02o`030?oo00H00_l800;o1P02o`<00_l200;o3002o`T00_l600;o4P02o`040?l000Co
1@02o`L00_l400Wo3003o`@00_l200;o2@03o`800olC00004`02o`T00_l400;o1`02o`H00_l:00;o
5@02o`8000?o0?l00P02o`@00_l500;o2@02o`l00_l:00;o2@02o`800ol00`3oo`0700;o2002o`T0
0_l500?o4002o`H01ol900?o4002o`P01ol900?o2@02oa400_l800;o2`06o``00ol800;o1@03oa80
0_l01P3o003o00;o1@02o`L00_l400;o1@02o`L01ol500Ko2@07oa@0000C00;o2P02o`<00_l700;o
1P02o`X00_lE00;o00@0ool00_l00`3oo`0400Wo2@02o`l00_l:00;o2@02o`800_l200;o1`02o`P0
0_l900;o1P03o`l00_l600Wo2003o`l00_l600Oo2P04o`T00_lA00;o2002o`/01_l;00Co2009oa<0
0_l00`3oo`02o`030?oo00D00_l700;o1@02o`<00_l600Oo1`06o`T01OlF00005002o`X000Co0000
0_l700;o1P02o`T00_lF00;o00<0ool00P001?l0ool400Wo1002o`<00_l300;o2P02o`X00_l900;o
00<0ool00`02o`L00_l800;o2@02o`800_l300;o3`02o`H00_l500?o0`02o`<00_l?00;o1@03o`h0
1_l800;o4@02o`P00_l;00;o0P02o`X01_l700So5002o`030?oo00;o00<0ool01@02o`L00_l500;o
0`02o`D00ol<00;o0P02o`T00_l0103ooolE00005002o`X00_l200;o1`02o`H00_l900;o5P02o`03
0?l0008000Co0?oo1002o`D00_l400;o0`02o`<00_l:00;o2P02o`T01Ol300;o1`02o`P00ol800;o
0P02o`<00ol>00;o1P02o`H00_l300;o0`03o`h00_l500;o1`000ol0000500;o0P02o`P00_lA00;o
2002o`/00_l200;o0P02o`H00_l200;o1`02o`@00olB00;o0`02o`<00_l400;o1`02o`H00_l0103o
ool500;o1`000ol0000300;o0P02o`800_l500;o0P03oa@0000D00?o2P000ol00002o`L00_l600;o
2@02oaH01?l300Co1002o`D00_l400;o0`02o`<00_l:00;o2P02o`T01?l400;o1`02o`T00_l700;o
0`02o`@00ol=00;o1P02o`H00_l300;o1003o`d00_l500;o1P02o`H00ol300;o1`02oa400_l800;o
2`02o`H00_l500?o0`02o`H00_l500;o4P02o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H0
0_l500;o1P02o`D00_l300?o4`0001D00_l;0004o`3oo`P00_l400;o2@02oaL01?l400?o1002o`D0
0_l400;o0`02o`<00_l:00;o2P02o`T01?l400;o1`02o`X00_l500;o1002o`D00_l=00;o1P02o`D0
0ol300;o1@02o`d00_l500?o1003o`H00_l400;o1`02oa400_l800;o2`02o`H00_l500;o1002o`H0
0_l400?o4P02o`P00_l400;o1004o`L01Ol600?o1003o`D00_l600;o1@02o`@00olB00005P02o`X0
1?l800?o0P03o`P00_lG00Co1@04o`801?l300Co0`0<o`D02_l300[o1004o`801_l200[o1P09o`@0
2_l700[o00<0ool02Ol400[o1`0:o`<02Ol400Go0P05o`802?l900[o0P08o`H03?l300Go0P05o`80
2_lB00Ko0P06o`802_l500Oo2009o`<03?l300Go0`05oa00000G0003o`0000T00ol900Ko2@000ol0
000F00Co1@04o`801?l300Co0`0<o`D02_l300[o1003o`<01_l200[o2005o`H02_l700[o00<0ool0
1ol600[o1`0:o`D01Ol00`3o000300Go0P05o`802?l900[o0P08o`H03?l300Go0P05o`802OlC00Ko
0P06o`802?l700Oo2P05o`030?l000803?l300Go0`05oa00000S00?o2P04ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(41\\) MHTJINJQZJR JSZLJLFZB WDASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o3006o`H0
2Ol900;o5@05o`<01Ol200Co0`04o`D02?l600Ko200:o`@01_l300;o1006o`/01Ol600[o1P06o`H0
1Ol600?o4@06o`L00_l00`3oo`03o`L02_l300go0`06o`L03Ol00`3oo`05o`T02_l300[o5@02o`@0
0_l500So1@06o`<01_l0103oo`05o`D03?l300go400001<00_l=00Ko1P09o`X00_lD00Go0`05o`80
1?l300Co1@08o`@02Ol700[o1006o`800ol200Wo2009o`@02_l400Wo1@05o`D01?l?00Wo1P0:o`D0
2_l300go00<0ool01ol600go00<0ool01Ol900[o0`0;oa@00_l400;o1@0:o`<01_l300Ko00<0ool0
2?l300co0`0=oa00000C00;o3`02o``00_l=00;o5@02o`L00_l400;o1@02o`T00_l700?o1003o`X0
0_l900;o1004o`800ol400?o1P03o`D00ol400;o1@02o`@00ol400?o1P02o`D00olA00?o1003o`D0
0ol500?o1@02o`D00_l600;o1P02o`040?ooo`@00ol800;o1P02o`<00_l=00;o1@02o`D00_l500?o
4P03o`@00ol500;o1004o`@00_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l?00;o
3002o`d00_lE00;o1`02o`@00_l500;o2@02o`L00_l600;o2P02o`T00_l400Co0P02o`H00_l600;o
1`02o`@00ol400;o1002o`H00_l600;o1@02oa800_l600;o1@02o`L00_l500?o1002o`H00_l600;o
00<0ool01P02o`P00_l600;o0`02o`d00ol400;o1@02o`H00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T02_l:00;o3@02oaD00_l300;o0P02o`@0
0_l500;o2@02o`L00_l600;o2P02o`T00_l300Go0P02o`H00_l500;o2@02o`@00ol300;o1002o`H0
0_l600;o1002oa<00_l600;o1@02o`L00_l600?o0`02o`H00_l600;o00<0ool01P02o`P00_l600;o
0`02o`800_l:00?o0`02o`D00_l600;o4P04o`801?l500;o1`02o`<02ol300;o1`02o`@00_l200;o
0P02o`H00_l600;o400001<00_l900[o2P02o`d00_lE00;o0P03o`800_l400;o1@02o`T00_l700;o
1P02o`X00_l900;o0`02o`030?oo00800_l600;o1@02o`T00_l500;o0`02o`@00_l600;o1P02o`<0
0olC00;o1P02o`d00ol700;o0`02o`H00_l600;o00<0ool01P02o`P00_l600;o0`02o`800_l;00;o
0`02o`D00_l600;o4P02o`040?l000Co1@02o`L00_l400Wo3003o`@00_l200;o2P02o`H00_l@0000
4`02o`T00_l400;o3002o`d00_lE00;o0P000ol0o`0200;o1002o`D00_l900;o3`02o`X00_l900;o
0P03o`030?oo00X00_l500;o2@02o`D00ol@00;o1P07oa`00_l800Oo2003o`X00_lA00;o2002o`/0
1_l;00?o2@02o`D00olB00;o00H0o`00o`02o`D00_l700;o1002o`D00_l700Oo1@06o`X00_lH0000
4`02o`X00_l300;o3002o`d00_lE00;o00@0ool00_l00`3oo`0400Wo2@02o`l00_l:00;o2@02o`80
0_l200;o2P02o`D00_l900;o1P03o`l00_l600Wo6P02o`H01ol;00?o2@02oa400_l800;o2`06o``0
0ol800Wo4`02o`030?oo00;o00<0ool01@02o`L00_l500;o0`02o`H01ol700Ko2P02oaP0000D00;o
2P001?l00002o``00_l<00;o5P02o`030?oo008000Co0?oo1009o`@00_l300;o0`02o`X00_l:00;o
2@02o`030?oo00<00_l:00;o1@02o`T00_l200;o0`02o`l00_l600;o1@03oaT00_l500?o3002o`<0
0_l900;o4@02o`P00_l;00;o0P02o`P00_l300;o2008oa@00_l00`3oo`02o`030?oo00D00_l700;o
1@02o`<00_l500?o3002o`800_l:00;o600001@00_l:00;o0P02o``00_l<00;o5P02o`030?l00080
00Co0?oo1002o`D00_l400;o0`02o`<00_l:00;o2P02o`T01Ol300;o2P02o`D00ol800;o0P02o`<0
0ol>00;o1P02o`H00_lI00;o1@02o`L000?o00000`02o`<00ol800;o4@02o`P00_l;00;o0P02o`80
0_l400;o0`03o`L00_l400?o4P02o`<00_l300;o1002o`L00_l600;o00@0oooo1@02o`L000?o0000
0`02o`800_l200;o1P02oaP0000D00?o2P000ol00002o``00_l<00;o5P04o`<01?l400;o1@02o`@0
0_l300;o0`02o`X00_l:00;o2@04o`@00_l:00;o1P02o`L00_l300;o1003o`d00_l600;o1P02oaT0
0_l500;o1P02o`D00_l400?o1`02oa400_l800;o2`02o`H00_l400;o1003o`H00_l500;o4P02o`<0
0_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`/000Co0?oo
3002o`/00_lG00Co1003o`@00_l500;o1002o`<00_l300;o2P02o`X00_l900Co1002o`X00_l700;o
1@02o`@00_l500;o3@02o`H00_l500?o6@02o`D00ol400?o1@02o`D00_l700;o4@02o`P00_l;00;o
1P02o`@00_l500;o1P02o`@00olB00;o2002o`@00_l400Co1`05o`H00ol400?o1@02o`H00_l600;o
600001H00_l:00Co2003o`030?oo00X00_lG00Co1@04o`801?l300Co0`0<o`D02_l300[o1004o`80
1_l400[o1009o`@02_l700[o00<0ool02OlE00[o0`09o`D02_l300So2@0:o`802?l600co100:o`<0
2_lB00Ko0P06o`802_l500Oo2009o`<03?l300So5@0001L000?o00002@03o`P01_l:0003o`0001H0
1?l500Co0P04o`<01?l300co1@0:o`<02_l400?o0`06o`@02_l600Go1P0:o`L02_l00`3oo`07oaL0
2_l500Go00<0o`00100:o`<02?l900[o0P08o`H03?l400[o0`09oa<01_l200Ko0P08o`L01ol:00Go
00<0o`000P0<o`<02?lE00008`03o`/00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(42\\) MGUJINJP KS IS KILFZB WDBREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@0:o`T00_lE00Go0`05o`D01_l:00Co1`06o`P0
2_l400Ko0`02o`@01_l700So5@05o`H00_l200;o00<0ool00olE00[o1002o`030?oo00?o5005o`H0
0_l200[o100=o`030?oo00Go2@0:o`<02_lE00;o1002o`D02?l600[o1005o`H03ol300go400001<0
0_l=00Ko1@0:o`X00_lD00Go0`05o`<02_l600So0`09o`L02_l400Ko0P03o`802Ol600So5@05o`D0
0ol200[o4`0:o`@02_lB00Go1@03o`802_l400go00<0ool01Ol900[o0`0;oa@00_l400;o1@0:o`@0
2ol300Go1@0@o`<03Ol@00004`02o`l00_l800;o1@02o`X00_lE00;o1`02o`<01?l500;o1P02o`@0
0_l300?o1003o`X00_l900;o1004o`800ol400?o1`02oa/00_l500?o0`03o`D00olF00;o2003o`D0
0olC00;o1@03o`L00_l;00;o1P02o`<00_l=00;o1@02o`D00_l500?o4P03o`@00ol500;o1004o`D0
0_l500?o1002o`D00ol400;o1P02o`H00_l600;o400001<00_l?00;o2@03o`l00_lE00;o1`02o`<0
0_l700;o1@02o`H00_l200;o1P02o`X00_l900;o1004o`800_l600;o1`02oa/00_l500;o1002o`L0
0_lF00;o2002o`L00_lC00;o1@02o`P00_l;00;o1P02o`<00_l=00?o1002o`D00_l600;o4P04o`<0
0ol500;o1P02o`D00_l600;o1002o`D00_l500;o1P02o`H00_l600;o400001<00_l900[o2003o`h0
0_lE00;o0`02o`800_l200?o1`02o`D00_l600;o0P02o`H00_l:00;o2@02o`<01Ol200;o1P02o`L0
0_lK00;o1002o`D00_l700;o5P02o`P00_l700;o4`02o`@00_l900;o2`02o`H00_l300;o0P02o`X0
0ol300;o1@02o`H00_lB00Co0P04o`D00_l700;o1002o`H00_l400;o1002o`H00_l200;o0P02o`H0
0_l600;o400001<00_l900[o2@03o`d00_lE00;o0P03o`800_l200;o1007o`@00_l600;o0P02o`H0
0_l:00;o2@02o`<00_l00`3oo`0200;o1P02o`L01olF00?o0P03o`d00olF00;o4003oa<00ol200?o
2@02o`/00_l600;o0`02o`800_l;00;o0`02o`D00_l600;o4P02o`040?l000Co1@02o`L00_l400;o
1P02o`@00_l300?o1P02o`800_l:00;o1P02oa00000C00;o2@02o`@00_l<00?o3002oaD00_l20003
o`3o00800_l200;o1007o`@00_l600;o2P02o`X00_l900;o0P03o`030?oo00X00_l700Wo5007o`T0
1olG00;o2`07oa@01ol:00;o2`02o`/01_l;00?o2@02o`D00olB00;o00H0o`00o`02o`D00_l700;o
1002o`D00ol400Oo1`06o`X00_lH00004`02o`X00_l300;o3@03o`/00_lE00;o00@0ool00_l00`3o
o`0200;o3`02o`H00_l:00;o2P02o`T00_l200;o0P02o`X00_l700;o1@03oa<01Ol900Oo6@02o`T0
1olF00Go3002o`/00_l;00Ko3003o`P02OlC00;o00<0ool00_l00`3oo`0500;o1`02o`@02Ol500Wo
1@06o`X00_lH00005002o`X000Co00000_l>00;o2P02oaH00_l00`3oo`020004o`3oo`800_l?00;o
1P02o`X00_l:00;o2@02o`030?oo00<00_l:00;o1`02o`H00_lC00;o00@0oooo1`03oah00_l800?o
6`02o`040?ooo`/00_l;00;o2`02o`800_l800;o0`02o`P02?lD00;o00<0ool00_l00`3oo`0500;o
1`02o`@02?l600;o1@03o`@00_l200;o2P02oaP0000D00;o2P02o`800_l?00;o2@02oaH00_l00`3o
00020004o`3oo`800_l800;o1@02o`H00_l:00;o2P02o`T01Ol300;o2P02o`L00_l600;o4`02o`80
0ol600;o1`000ol0000E00;o2002o`L000?o00004P02o`800ol:00;o2`02o`/00_l200;o0P02o`@0
0_l300?o1`02o`@00olB00;o0`02o`<00_l400;o1`02o`@00_l400?o1@02o`H00_l400;o0P02o`80
0_l600;o600001@00ol:0003o`0000;o3`02o`T00_lF00Co0`04o`<00_l600?o1@02o`H00_l:00;o
2P02o`T01?l400;o2P02o`L00_l600;o4`02o`<00ol500;o1P02oaL00_l800;o1P02oa@00_l300?o
2@02o`/00_l;00;o1P02o`@00_l400?o1P02o`D00_lB00;o0`02o`<00_l400;o1P02o`D00_l500;o
1@02o`H00_l400;o1P02o`H00_lH00005@02o`/000Co0?oo2002o`D00_l800;o5`04o`@00ol300?o
1004o`D00_l600;o2P02o`X00_l900Co1002o`X00_l700;o1@03oa<00_l400?o1003o`@00olG00;o
2003o`@00olD00;o1003o`P00_l;00;o2`02o`H00_l400;o1@02o`H00_l400?o4P02o`P00_l400;o
1004o`D00_l400?o1@02o`D00ol400;o1P02o`H00_lH00005P02o`X01?l800?o0`03o`L00_lG00Co
1@04o`<02_l400Co1004o`@02_l300[o1004o`801_l400[o0P0;oa801Ol300Go0`09oa<02_l500Wo
4P05o`<01Ol200[o1008o`H03?l400[o0`0:oa801_l200Ko0P0:o`@02_l400_o0`0<o`<02?lE0000
5`000ol0000900?o2@07o`P000?o00005P04o`D01?l500Go00<0ool01004o`@01?l400[o0`0:o`@0
0ol300Ko100:o`802OlD00Go0`05o`D01Ol00`3o000B00[o1`05o`030?l001401Ol300Go0P0:o`@0
2?l600co100:o`<02OlC00Ko0P06o`802?l600Wo1@09o`D03?l300So5@0002<00ol:00Goo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(43\\) NFTJIMJP JS IS KILFZC XDAREK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1`05o``00_lF00Ko0`02o`801ol:00So1P06o`P0
2_l300Go0`05o`<01_l700So5`06o`L00_l00`3oo`03oaD02_l400;o00<0ool00olD00Go1P02o`80
2_l400go00<0ool01Ol900[o1`05oa@01Ol200Go0`08o`D01_l300_o1P0?o`<01Ol600;o400001<0
0_l=00Ko1@09o`/00_lE00Ko0P03o`801ol:00So1009o`L02_l300Go0`05o`030?oo00Oo1P08oaD0
2Ol600[o4`0:o`@02_lB00Go1@03o`802_l400go00<0ool01Ol900[o1@09oa801Ol200Go0`0:o`<0
1_l300_o1@0@o`<01Ol500?o400001<00_l?00;o1`02o`D00_l;00;o5P02o`@01?l400;o4002o`L0
0ol400?o2P02o`P00_l700;o0P03o`@00ol700;o6@03o`@00ol500?o1@03oaH00_l800?o1@03oa<0
0_l500?o1`02o`/00_l600;o0`02o`d00_l500;o1003o`D00olB00?o1003o`D00_l400Co1002o`L0
0_l400;o1@03o`@00_l600;o1@02o`D00olA00004`02o`l00_l?00;o2P02oaH00_l400Co1002oa00
0_l700;o1P02o`X00_l800;o1`02o`800_l600;o1`02oaT00_l600;o1@02o`L00_lF00;o2002o`L0
0_lC00;o1@02o`P00_l;00;o1P02o`<00_l=00?o1002o`@00_l700;o4`03o`800ol600;o1P02o`@0
0_l700;o1002o`D00_l500;o1P02o`D00_l500;o4P0001<00_l900[o3@02o`X00_lF00;o0`05o`@0
0_l200;o3002o`L00_l600;o2P02o`P00_l300;o0P02o`800_l600;o1`02oaT00_l600;o1@02o`L0
0_lF00;o2002o`L00_lC00;o1002o`T00_l;00;o1P02o`<00_l200;o2P03o`<00_l300?o7@02o`80
0_l700;o1`02o`<02ol400;o1002o`H00_l200;o0P02o`D00_l400;o4`0001<00_l900[o3@02o`X0
0_lF00;o0`02o`030?oo00@00_l200;o3002o`L00_l600;o2P02o`P00_l200?o0P02o`800_l600;o
1`07oa@00_l600;o3@03oaH00_l@00?o4`03o`800ol900;o2`02o`H00_l300;o0P02o`/00_l300;o
0`02oal01?l800;o1`02o`@02Ol500;o0`03o`H00_l200;o2@03o`800olC00004`02o`T00_l400;o
3P02o`/00_lF00;o0P03o`030?oo00@01_l<00;o3`02o`X00_l800;o0P000ol0o`0200;o2P02o`L0
2OlJ00;o2007oaL00_l;00Oo5007o`X00_l;00;o2`06o`/00ol700;o7`04o`P00_l700;o1002o`D0
0_l500Oo1`06o`T01olD00004`02o`X00_l300;o2`04o``00_lF00;o0P02o`800_l400Ko3002o`l0
0_l:00;o2002o`040?oo00;o00<0ool02P02o`L00_l500?o6@02o`H01olI00;o2@07oaH01Ol<00;o
2`02o`/01_l<00?o1P02oal00ol900;o1`02o`D00_l300;o1P09o`D01_l900Go5P0001@00_l:0004
o`0000;o2`03o``00_lG00;o00<0ool00`02o`@00_l200;o1`02o`<00_l300;o2P02o`X00_l800;o
00<0ool00P001?l0ool:00;o1`02o`H00_lI00;o1@03oah00_l800?o6`02o`040?ooo`/00_l;00;o
2`02o`800_l800;o0`02o`H00_lO00Co2002o`L00_l500;o0`02o`H00_l500?o1002o`800_l900;o
00@0oooo5@0001@00_l:00;o0P02o`d00_l;00;o5`05o`<00_l400;o0P02o`800_l300;o0`02o`<0
0_l:00;o2P02o`P00_l00`3o00020004o`3oo`X00_l700;o1P02oaT00_l500;o1`000ol0000E00;o
2002o`L000?o00004P02o`800ol:00;o2`02o`/00_l200;o0P02o`@00_l300?o1@03o`L00_lD00Ko
1`02o`L00_l600;o00@0oooo1P02o`H00_l400;o0P02o`800_l500;o0P03oa@0000D00?o2P000ol0
0002o`h00_l:00;o5`04o`@00_l400;o1P02o`<00_l300;o0`02o`X00_l:00;o2004o`<01?l:00;o
1`02o`H00_lI00;o1@02o`H00_lG00;o2002o`H00_lD00;o0`03o`T00_l;00;o2`02o`H00_l400;o
1003o`D00_l700;o4`03o`800ol600;o1P02o`L00_l00`3oo`0700;o1P02o`@00_l600;o1@02o`<0
0olC00005@02o`/000Co0?oo3P02o`T00_lH00Co1002o`@00_l600;o0`02o`<00_l300;o2P02o`X0
0_l800Co1003o`X00_l700;o1@03oaT00_l500?o1003oaL00_l800?o1003oa@00_l400?o2002o`/0
0_l;00;o1P02o`@00_l500;o1@03o`D00olC00;o1002o`H00_l400Co1`05o`L00_l500?o1002o`H0
0_l500;o1003oa80000F00;o2P04o`P00_l300?o2002oaP01?l200Ko00<0ool02_l300co1@0:o`<0
2_l300Co1@04o`@02_l200_o5@0:o`<02OlC00[o1@09oa801Ol300Go0P0:o`@02?l600co100:o`D0
2_lA00Go0P05o`<02_l500Oo1P0;o`<03?l300Go0`05oa00000G0003o`0000T00ol800Oo2@000ol0
000G00?o0`06o`030?oo00[o0`0<o`D02_l300[o0`04o`D01?l400[o0P09oaL02_l500Go00<0o`00
4P0:o`L01Ol00`3o000A00Go0`05o`802_l400So1P0<o`@02_l700Go00<0ool04@05o`801Ol300So
1`07o`H02Ol500co0`05o`<01Ol@00008`03o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(44\\) NFTIIMJP IS IR LILFZB XEASFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2@06o`T00_lF00Ko0`02o`801ol:00So1@0:o`D0
2_l300Go0`05o`<01_l700So5P0:o`@00_l00`3oo`03oaD02_l300Go1P03o`l03Ol200[o100=o`03
0?oo00Go2@0:o`<02_lC00Go0P05o`803?l200Ko0`06o`040?oo00Go1@07o`P01Ol600;o400001<0
0_l=00Ko2@06o`X00_lE00Ko0P03o`801ol:00So1@0:o`D02_l300Go0`05o`030?oo00Oo1P08oaH0
2_l400[o4`0:o`<01Ol500Co3`0=o`802_l400go00<0ool01Ol900[o0`0;oa801Ol200Go0P0<o`80
1_l300Ko00<0ool02?l300Oo2005o`D00ol@00004`02o`l00_l=00;o3002oaH00_l400Co1002oa00
0_l<00;o3@02o`P00_l700;o0P03o`@00ol700;o7P02o`P00ol500?o5P02o`T00_l500?o5002o`H0
0_l600;o2`02o`H00_l300;o3@02o`D00_l500;o1@03oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`d00_l500?o4@0001<00_l?00;o3@02o``00_lF00;o1004o`@00_l@00;o3002o`d0
0_l800;o1`02o`800_l600;o1`02oah00_l800;o1`02oaH00_l900;o1@02oaD00_l600;o1P02o`/0
0_l600;o0`02o`d00ol400;o1@02o`H00_lC00?o0P03o`H00_l600;o1002o`L00_l300;o1`02o`@0
0_l=00;o1@02oa80000C00;o2@0:o`D02_l:00;o5P02o`<01Ol400;o0P02o``00_l<00;o3@02o`P0
0_l300;o0P02o`800_l600;o1`02oah00_l800;o1`02oaH00_l900;o1002oaH00_l600;o1P02o`/0
0_l600;o0`02o`800_l:00?o0`02o`D00_l600;o5002o`800_l700;o0P02o`800_l400_o0`02o`L0
0_l400;o0P02o`T00_l400;o4`0001<00_l900[o1@0:o`X00_lF00;o0`02o`030?oo00@00_l200;o
3002o``00_l=00;o2002o`800ol200;o0P02o`H00_l700Oo6@02oa000olF00;o2@02o`<00olF00;o
1P02o`H00_l;00;o1P02o`<00_l200;o2`02o`<00_l500;o1P02oaD01?l800;o0P02o`T02Ol<00?o
1002o`800_l900?o0P03oa<0000C00;o2@02o`@00_l700;o1002o``00_lF00;o0P03o`030?oo00@0
1_l<00;o3002o`d00_l800;o0P000ol0o`0200;o2P02o`L02OlG00;o2`07oaL00_l900Oo5`02o`h0
0_l;00;o2`06o`/00ol900;o1@03oaD01?l800Ko2@02o`D00_l700Oo1@06o`T01olD00004`02o`X0
0_l300;o2002o`<00_l<00;o5P02o`800_l200;o1006o``00_l<00;o3@02o`P00_l0103oo`02o`03
0?oo00X00_l700;o1@03oaH00_l900Oo6@02o`T02OlE00;o3P02o`/00_l;00Ko3003o`P02OlF00?o
2@06o`X00_l300;o1P07o`L01_l900Go5P0001@00_l:0004o`0000;o2@001?l00002o`/00_lG00;o
00<0ool00`02o`@00_l200;o1`02o`<00_l300;o1`02o`d00_l800;o00<0ool00P001?l0ool:00;o
1`02o`H00_lF00;o2003oah00_l900;o1@03oa@00_l>00;o2`02o`/00_l200;o2002o`<00_l800So
5`04o`P00_l200;o2P02o`<00_l500?o3002o`800_l900;o00@0oooo5@0001@00_l:00;o0P02o`T0
0_l200;o2`02oaL01Ol300;o1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l800;o00<0o`00
0P001?l0ool:00;o1`02o`H00_lF00;o2002o`L000?o00005@02o`T00_l600;o5002o`h00_l;00;o
2`02o`800_l200;o1002o`<00ol700;o1003oaD01_l700;o0P02o`800_l700;o00@0oooo1@02o`L0
00?o00000`02o`800_l200;o1@02o`800olD00005003o`X000?o00000_l:0003o`0000;o2`02oaL0
1?l400;o1002o`H00_l300;o0`02o`<00_l700;o3@02o`P01?l300Co2P02o`L00_l600;o5P02o`P0
0_l600;o5`02o`T00_l600;o5002o`h00_l;00;o2`02o`H00_l400;o1003o`H00_l500;o5003o`80
0ol600;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1@02o`<00olC00005@02o`/000Co0?oo
2`001?l0ool:00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2004o`@00ol:00;o
1`02o`D00olF00;o2003o`@00olG00;o2@02o`D00olD00;o3P02o`/00_l;00;o1P02o`@00_l500;o
1P02o`@00olD00;o1002o`H00_l600;o1`05o`H00ol400?o1@02o`H00_l500;o1003oa80000F00;o
2P04o`/01?l900;o6004o`801_l00`3oo`0:o`<03?l300[o1@0:o`<01?l500Co100:o`802olC00[o
1@09oa<02_l300_o4P08o`L02_l400So1P0<o`@02_l300[o4`05o`801Ol200co1007o`P02Ol300co
0`05o`<01Ol@00005`000ol0000900?o3003o`T000?o00005`03o`<01_l00`3oo`0:o`<03?l300[o
1@0:o`<01?l500Co100:o`802OlE00[o1`05o`030?l001802_l300Wo5008o`L02_l400So1P0<o`@0
2_l300Wo5005o`801Ol200co1007o`X01Ol00`3o000200co0`05o`<01Ol@00008`03o``00ooo0<D0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(45\\) NFTHIMJQ IT IR LILFZA XEATFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o3006o`L0
1Ol<00;o5P06o`<00_l200Oo2P08o`D01?l300Co100:o`<01Ol300Go0`06o`/01OlE00[o1@08oa@0
2_l300Go1P03o`l03Ol200[o100=o`030?oo00Go2@0:o`801_l300Ko3`05o`801Ol200co0P06o`<0
1_l200So1007o`P01Ol600;o400001<00_l=00Ko1@09o`/00_lE00Ko0P03o`801ol:00So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`07o`P02OlC00[o1@08oa@02_l300Go1@04o`l03Ol200[o100=o`03
0?oo00Go2@0:o`801_l300Ko3`05o`801Ol200co0P06o`<01_l200So1007o`P01Ol500?o400001<0
0_l?00;o1`02o`D00_l;00;o5P02o`@01?l400;o4002o`T00_l500;o2@02o`P00_l700;o0P03o`@0
0ol600?o1@03oaH00_l<00;o6`02o`T00_l500?o5002o`H00_l600;o2`02o`H00_l300;o3@02o`D0
0_l400;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`L00_l900;o3@02o`D00olA00004`02o`l0
0_l?00;o2P02oaH00_l400Co1002oa000_l900;o1@02o`T00_l800;o1`02o`800_l600;o1P02o`L0
0_lF00;o3002oa/00_l900;o1@02oaD00_l600;o1P02o`/00_l600;o0`02o`d00ol400;o1002o`L0
0_lC00?o0P03o`H00_l600;o1002o`L00_l700;o2@02o`d00_l500;o4P0001<00_l900[o3@02o`X0
0_lF00;o0`05o`@00_l200;o3002o`T00_l500;o2@02o`P00_l300;o0P02o`800_l600;o1@02o`T0
0_lE00;o3002oa/00_l900;o1002oaH00_l600;o1P02o`/00_l600;o0`02o`800_l:00?o0`02o`@0
2olD00;o0P02o`L00_l200;o0P02o`@02ol700;o2@02o`800_l900;o1002oa<0000C00;o2@0:o`d0
0_l:00;o5P02o`<00_l00`3oo`0400;o0P02o``00_l900;o1@02o`T00_l800;o0P03o`800_l200;o
1P02o`D00_l900;o5@02o``00_lK00;o2@02o`<00olF00;o1P02o`H00_l;00;o1P02o`<00_l200;o
2`02o`<00_l500Wo5P04o`P00_l200;o2@09o`P00_l900;o0P02o`T00ol200?o4`0001<00_l900;o
1002o`l00_l:00;o5P02o`800ol00`3oo`0400Ko3002o`T00_l500;o2@02o`P00_l20003o`3o0080
0_l:00;o1@02o`T00_lE00;o3002oa/00_l900Oo5`02o`h00_l;00;o2`06o`/00ol900;o1@02oaH0
1?l800Ko2@02o`D00_l800;o2@06o`T01olD00004`02o`X00_l300;o2002o`@00_l;00;o5P02o`80
0_l200;o1006o``00_l900Wo2@02o`P00_l0103oo`02o`030?oo00X00_l500;o2@02oaD00_l<00;o
6`02o`T02OlE00;o3P02o`/00_l;00Ko3003o`T00_l300;o5`03o`T01_l:00;o0`02o`T00_l900Ko
2@05oaH0000D00;o2P001?l00002o`P02?l:00;o5`02o`030?oo00<00_l400;o0P02o`L00_l300;o
0`02o`@02Ol900;o2002o`030?oo008000Co0?oo2P02o`D00_l900;o5@02o`L00_l300;o0`02oaH0
0_l900;o1@03oa@00_l>00;o2`02o`/00_l200;o2002o`<00_l900;o0`02oaL01?l800;o0P02o`X0
0_l300;o1002o`<00_l300;o1002o`800_l900;o00@0oooo5@0001@00_l:00;o0P02o`P01ol;00;o
5`05o`<00_l400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l800;o00<0o`000P001?l0
ool:00;o1@03o`P00_lE00;o1`02o`<00_l300;o5P02o`T00_l600;o5002o`h00_l;00;o2`02o`80
0_l200;o1002o`<00ol900;o00@0oooo5P06o`L00_l200;o0P02o`L00_l0103oool400;o0`02o`<0
0_l400;o0P02o`800_l500;o0P03oa@0000D00?o2P000ol00002o`P00_l@00;o5`04o`@00_l400;o
1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l300Co2P02o`H00_l700;o5P02o`L00_l300;o
0`02oaH00_l900;o1P02oa@00_l>00;o2`02o`/00_l600;o1002o`@00ol800;o00<0ool05P03o`80
0ol600;o1P02o`L00_l00`3oo`0500;o0`02o`<00_l400;o1P02o`D00_l300?o4`0001D00_l;0004
o`3oo`P00_l?00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l400?o
2P02o`L00_l500;o5`02o`L00_l300;o0`02oaH00_l900;o1@03oa@00_l>00;o2`02o`/00_l600;o
1002o`D00_l800Go5P02o`@00_l600;o1P02o`L01Ol500;o0`02o`<00_l400;o1P02o`D00_l400?o
4P0001H00_l:00Co2002o`h00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co100:o`<01?l500Co
100:o`@02OlC00[o0`0<oa802_l300_o4P08o`L02_l400So1P0<o`@02_l400Oo5@05o`801Ol200co
1007o`H03?l200co0`05o`<01Ol@00005`000ol0000900?o2008o`P000?o00005`03o`<01_l00`3o
o`0:o`<03?l300Co0`04o`@02_l300Co1@04o`@02_l600Go5@0:o`<03?lB00[o0`09oa@02?l700[o
1008o`H03?l400[o1007oaD01Ol200Go0P0<o`@01ol600co0P0<o`<01Ol300Go400002<00ol800So
o`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(46\\) NFTHILKR IT IR MILFZA XEATFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lF00Ko0`02o`801ol:00So1@04o`<0
1?l400[o0`0=o`030?oo00?o1P02o`801Ol600?o400:o`D02?lD00[o0`05o`H00ol?00Go0`05o`80
2_l400go00<0ool01Ol900[o0P06o`<01_l?00Go0P05o`803?l200Ko0`06o`802?l400Oo200=oa00
000C00;o3@06o`L01ol;00;o5@06o`800ol200Oo2P08o`D01?l300Co100:o`<03Ol00`3oo`03o`D0
0ol200Go1@04oa002_l500So500:o`<01Ol500Co3`05o`<01Ol200[o100=o`030?oo00Go2@0:o`80
1_l300Ko3`05o`801Ol200co0P06o`<01_l200So1007o`P03Ol@00004`02o`l00_l800;o1002o`/0
0_lF00;o1004o`@00_l@00;o2@02o`D00_l900;o2P02o`H00_l300;o1@03o`D00_l500?o5P02o``0
0_lK00;o2@02o`D00olB00;o1`02o`L00_l;00;o1P02o`<00_l=00;o1@02o`@00_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o1`02o`T00_l>00;o1P02oa00000C00;o3`02o`L00_l600;o2P02oaH0
0_l400Co1002oa000_l900;o1@02o`T00_l:00;o1P02o`<00_l500;o1P02o`D00_lG00;o3002oa/0
0_l900;o1@02oa<00_l700;o1`02o`/00_l600;o0`02o`d00ol400;o1002o`L00_lC00?o0P03o`H0
0_l600;o1002o`L00_l700;o2@02o`h00_l600;o400001<00_l900[o1@02o`H00_l:00;o5P02o`<0
1Ol400;o0P02o``00_l900;o1@02o`T00_l:00;o1P02o`<00_l400;o1`02o`@00_lH00;o3002oa/0
0_l900;o1002oa@00_l300;o0P02o`L00_l;00;o1P02o`<00_l200;o2P03o`<00_l400_o5002o`80
0_l700;o0P02o`800_l400_o1`02o`T00_l200;o2P02o`H00_l@00004`02o`T02_l500;o1P02o`X0
0_lF00;o0`02o`030?oo00@00_l200;o3002o`T00_l500;o2@02o`X00_l600;o0`03o`800ol700;o
0`03oaP00_l<00;o6`02o`T00_l300?o5002o`800ol200;o1`02o`/00_l600;o0`02o`800_l;00;o
0`02o`D02OlF00Co2002o`800_l900Wo2002o`T00_l200;o2P02o`H00_l@00004`02o`T00_l400;o
1`02o`H00_l:00;o5P02o`800ol00`3oo`0400Ko3002o`T00_l500;o2@02o`X00_l;00Oo2007oaT0
0_l<00;o6`02o`T01olE00;o0P000ol0o`0200;o1`02o`/00_l;00Ko2`03o`T00_l500;o5P04o`P0
1_l900;o1@02o`P00_l900Ko2P02oaP0000C00;o2P02o`<00_l700?o1002o`/00_lF00;o0P02o`80
0_l400Ko3002o`T02Ol900;o2P02o`/01Ol:00Wo5`02o``00_lK00;o2@09oa<00_l0103oo`02o`03
0?oo00L00_l;00;o2`06o``00ol900;o0`02oaL00ol900Ko2P02o`<00_l900;o2@06o`X00_lH0000
5002o`X000Co00000_l700Wo2P02oaL00_l00`3oo`0300;o1002o`800_l700;o0`02o`<00_l400Wo
2@02o`X00_l;00;o00@0oooo2@02o`D00olF00;o1`02o`<00_l300;o5P02o`T00_l500?o4P02o`03
0?oo008000Co0?oo1`02o`/00_l;00;o0P02o`P00_l300;o2@02o`<00_lG00Co2002o`800_l:00;o
0`02o`@00_l300;o0`02o`@00_l200;o2P02oaP0000D00;o2P02o`800_l700;o00<0ool00_l<00;o
5`05o`<00_l400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l:00;o2`02o`800ol800;o
1P02oaH00_l700;o0`02o`<00_lF00;o2@02o`H00_lB00;o00<0o`000P001?l0ool700;o2`02o`/0
0_l200;o0P02o`@00_l300?o2@02o`040?oooaH01_l700;o0P02o`800_l700;o00@0oooo1002o`<0
0_l300;o1002o`800_l200;o1P02oaP0000D00?o2P000ol00002o`P00_l@00;o5`04o`@00_l400;o
1P02o`<00_l300;o0`02o`@00_l500;o2@02o`X00_l;00;o0`03o`L00_l600;o5P02o`L00_l300;o
0`02oaH00_l900;o1P02oa801?l300Co1`02o`/00_l;00;o1P02o`@00_l400?o2002o`030?oo01H0
0ol200?o1P02o`H00_l700;o00<0ool01@02o`<00_l300;o1002o`H00_l600;o600001D00_l;0004
o`3oo`P00ol>00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`X00_l;00;o
1003o`H00_l500?o5P02o`L00_l300;o0`02oaH00_l900;o1@03oa801?l400?o1`02o`/00_l;00;o
1P02o`@00_l500;o2005oaH00_l400;o1P02o`H00_l700Go1@02o`<00_l300;o1002o`H00_l600;o
600001H00_l:00Co2@03o``00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co100:o`<02?l600Go
0`05o`802olC00[o0`0<oa802_l300_o4P04o`D01?l200[o1008o`H03?l400[o1007oaD01Ol200Go
0P0<o`@01ol600co0P0<o`<02?lE00005`000ol0000900?o2P07o`L000?o00005`03o`<01_l00`3o
o`0:o`<03?l300Co0`04o`@02_l300So1P05o`<01Ol200Wo5@0:o`<03?lB00[o0`09oa@01?l500Co
0P0:o`@02?l600co100:o`@01olE00Go0P05o`803?l400Oo1P0<o`803?l300So5@0002<00ol<00Go
o`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(47\\) MGTHIMLR IT IR LILF A XEBTFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2002o`h00_lE00Go0`05o`D01_l700So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`0;o`801Ol600?o400:o`D02?lD00[o0`05o`H00ol?00go0P0:o`@0
3Ol00`3oo`05oaD01_l300Ko3`05o`801Ol200co0`0:o`H02?l400Oo200=oa00000C00;o3@06o`P0
0_l?00;o5005o`<01Ol300[o1@08o`D01?l300Co100:o`<01Ol300Go00<0ool02ol200Go1@04oa00
2_l500So500:o`<01Ol500Co3`0=o`802_l400go00<0ool01OlE00Ko0`06o`l01Ol200Go0P0<o`<0
2ol500So1007o`P03Ol@00004`02o`l00_l;00;o3P02oaD00_l700;o0`04o`D00_l800;o2@02o`D0
0_l900;o2002o`L00_l500;o1P02o`@00_l500?o5P02o``00_lK00;o2@02o`D00olD00;o1P02o`H0
0_l;00;o1P02o`<00_lJ00;o1`02oa800ol400?o1@02o`H00_l500;o1@03o`L00_l900;o3P02o`H0
0_l@00004`02o`l00_l;00;o3P02oaD00_l700;o0`02o`L00_l800;o2@02o`D00_l900;o2002o`L0
0_l500;o1P02o`@00_l500;o5`02o``00_lK00;o2@02o`D00_lE00;o1P02o`H00_l;00;o1P02o`<0
0_lJ00;o1`02oa<00ol200?o1P02o`H00_l500;o1P02o`L00_l900;o3P02o`H00_l@00004`02o`T0
2_l900;o3P02oaD00_l300;o0P02o`800ol700;o2002o`T00_l500;o2@02o`P00_l300;o0P02o`D0
0_l600;o1002o`@00_lH00;o3002oa/00_l900;o1002oaH00_l600;o1P02o`/00_l600;o0`02o`80
0_lF00_o5002o`800_l700;o0P02o`800_l500;o1P02o`L00_l900;o0P02o`X00_l600;o400001<0
0_l900[o2P000ol0000<00;o5@02o`800ol200;o0P02o`@01ol700;o2@02o`D00_l900;o2002o`80
0ol200;o1@02o`H00_l400;o0`03oaP00_l<00;o6`02o`T00_l300?o5P02o`H00_l600;o2`02o`H0
0_l300;o0P02oaL02OlF00Co2002o`800_l900;o1P02o`L00_l900;o0P02o`X00_l600;o400001<0
0_l900;o1002o``00_l=00;o5@02o`8000?o0?l00P02o`800_l400Oo1`02o`T00_l500;o2@02o`P0
0_l20003o`3o00800_l500;o3007oaT00_l<00;o6`02o`T01olG00;o3P02o`/00_l;00Ko5`02o`D0
0_lF00Co2006o`T00_l500?o1`02o`T01_l:00;o600001<00_l:00;o0`02o``00_l=00;o5@02o`04
0?oo00;o00<0ool00P02oa800_l900Wo2@02o`P00_l0103oo`02o`030?oo00D00_l<00Wo5`02o``0
0_lK00;o2@09oaD00_l>00;o2`02o`/01_lH00;o0`02oaL00ol900Ko2@09o`P00_l900Ko2P02oaP0
000D00;o2P001?l00002o`d000?o00002P02oaH00_l00`3oo`020004o`3oo`800_l=00;o0`02o`<0
0_l400Wo2@02o`P00_l00`3oo`020004o`3oo`D00_l<00;o1@03oaH00_l700;o0`02o`<00_lF00;o
2@02o`D00olD00;o3P02o`/00_l;00;o0P02oaP00_l300;o5`04o`P00_l200;o2@08o`@00_l300;o
0`02o`@00_l200;o2P02oaP0000D00;o2P02o`800_l=00;o2`02oaH00_l00`3o00020004o`3oo`80
0_l800;o0`02o`<00_l300;o1002o`D00_l900;o2002o`030?l0008000Co0?oo1@02o``00_l600;o
5P02o`L00_l300;o0`02oaH00_l900;o1P02oa@00_l>00;o2`02o`/00_l200;o0P02oaD00_l0103o
oolF00Ko1`02o`800_l200;o1@02o`@00ol300;o0`02o`<00_l400;o0P02o`800_l600;o600001@0
0ol:0003o`0000;o3@02o`/00_lF00Co0`04o`<00_l600?o0`02o`<00_l300;o1002o`D00_l900;o
2004o`<01?l500;o3002o`H00_lF00;o1`02o`<00_l300;o5P02o`T00_l600;o5002o`h00_l;00;o
2`02o`H00_lE00;o00<0ool05P03o`800ol600;o1P02o`D00_l500;o0`02o`<00_l300;o1002o`H0
0_l600;o600001D00_l;0004o`3oo`h000?o00002002oaL01?l400?o0`03o`@01?l300;o0`02o`<0
0_l400;o1@02o`T00_l800Co1003o`D00_l<00;o1@03oaH00_l700;o0`02o`<00_lF00;o2@02o`D0
0olD00;o3P02o`/00_l;00;o1P02oaD01OlF00;o1002o`H00_l600;o1@02o`@00ol300;o0`02o`<0
0_l400;o1P02o`H00_lH00005P02o`X01?l700;o1@02o`P00_lG00Co1@04o`<02_l300co0`04o`<0
1?l400[o0`04o`D01?l00`3oo`06o`L02olC00[o0`0<oa802_l300_o4P08o`L02_l400So1P0<oa80
1olE00Go0P05o`803?l300[o100<o`803?l300So5@0001L000?o00002@03o`L02Ol80003o`0001H0
1?l500Co1@05o`030?oo00<03?l300Co0`04o`@02_l300Co1@04o`030?oo00Ko1`09oaD02_l300co
4P0:o`<02OlD00So1`0:o`@02?l600co4P07oaD01Ol200Go0P0<o`<02Ol500co0P0<o`<02?lE0000
8`03o`L02Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(48\\) MFUHIMLS IT IR MIKF A XEBSFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lE00Go0`05o`030?oo00Go3@04o`H0
1?l300Co100:o`<01Ol300Go00<0ool02ol300;o00<0ool00olE00[o1@08oa@02_l300Go1P03o`l0
1Ol300Go0P0:o`@01Ol600;o00<0ool01OlE00Ko0`06o`l01Ol200Go0P0<o`<02_l500;o00<0ool0
0ol500Oo200=oa00000C00;o3@06o`H02?l;00;o5005o`<01Ol00`3oo`05o`/02?l400Co0`04o`@0
2_l300Go0`05o`030?oo00_o0`0:oa<02_l500So500:o`<01Ol500Co3`05o`<01Ol200[o1005o`D0
0ol00`3oo`05oaD01_l300Ko3`05o`801Ol200co0`0;o`@02_l300Oo200=oa00000C00;o3`02o`L0
0ol400?o2P02oaD00_l700;o1002o`h00_l400;o1@02o`D00_l900;o2002o`L00_l500;o1P02o`<0
0ol500?o5P02o``00_lK00;o2@02o`D00olB00;o1`02o`L00_l:00;o1@03o`@00_lJ00;o1`02oa80
0ol400?o1@02o`H00_l500;o1@03o`<00ol500?o1002o`h00_l600;o400001<00_l?00;o1`02o`H0
0_l:00;o5@02o`L00_l400;o3@02o`H00_l400;o1@02o`T00_l800;o1`02o`D00_l600;o0`02o`L0
0_lF00;o3002oa/00_l900;o1@02oa<00_l700;o1`02o`X00_l500;o1@02oaX00_l700;o4`03o`80
0ol600;o1P02o`D00_l600;o0`02o`L00_l400;o3P02o`H00_l@00004`02o`T02_l500;o1P02o`X0
0_lE00;o0`02o`800_l400;o0P02o`T00_l600;o1002o`D00_l900;o2002o`<00_l200;o1@02o`H0
0_l300;o1`02oaH00_l<00;o6`02o`T00_l400;o5002o`<00_l200;o1`02o`X00_l400;o1P02o`80
0_lF00_o5002o`800_l700;o0P02o`800_l500;o1P02o`<00_l700;o1002o`800_l:00;o1P02oa00
000C00;o2@0:o`D00_l600;o2P02oaD00_l200?o0P02o`@00_l200;o2@02o`H00_l400;o1@02o`T0
0_l800;o0P03o`800_l500;o1P02o`/00olF00;o3002oa/00_l900;o0`03oa@00_l200?o0P02o`L0
0_l:00?o0P03o`H00_l200;o5`09oaH01?l800;o0P02o`T00_l600;o2`03o`@00_l200;o2P02o`H0
0_l@00004`02o`T00_l400;o2002o`@00_l;00;o5@02o`8000?o0?l00P02o`@01_l900;o1P02o`@0
0_l500;o2@02o`P00_l20003o`3o00800_l500;o3P07oaL00_l<00;o6`02o`T01olE00;o0P000ol0
o`0200;o1`02o`X01ol700Ko5`02o`D00_lF00Co2006o`T00_l500?o1P07o`D01_l:00;o600001<0
0_l:00;o0`02o`T01ol;00;o5@02o`040?oo00;o00<0ool01006o`T00_l600;o1009o`T00_l800;o
00@0ool00_l00`3oo`0500;o3007oaT00_l<00;o6`02o`T02OlC00;o00@0ool00_l00`3oo`0700;o
2P05o`T01_lH00;o0`02oaL00ol900Ko2@09o`D01ol700Ko2P02oaP0000D00;o2P001?l00002o`T0
1_l;00;o5P02o`030?oo008000Co0?oo1002o`800_l900;o1P02o`@02Ol900;o2002o`030?oo0080
00Co0?oo1@02o`/00olN00;o1`02o`<00_l300;o5P02o`T00_l500?o4P02o`030?oo008000Co0?oo
1`02o`X00_l0103oool800;o0P02oaP00_l300;o5`04o`P00_l200;o2@08o`D00ol<00;o0P02o`X0
0_lH00005002o`X00_l200;o2002o`@00_l:00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o
1@02o`H00_l400;o1@02o`T00_l800;o00<0o`000P001?l0ool500;o2`02o`L000?o00005@02o`L0
0_l300;o0`02oaH00_l900;o1P02oa800_l00`3o00020004o`3oo`L00_l:00;o0P03o`L00_l200;o
0P02oaD00_l0103ooolF00Ko1`02o`800_l200;o1@02o`@00ol400;o1`000ol0000300;o0P02o`80
0_l600;o600001@00ol:0003o`0000;o1`02o`H00_l900;o5P04o`<01?l400;o1P02o`D00_l600;o
1002o`D00_l900;o2004o`<01?l500;o2`02o`H00_lG00;o1`02o`<00_l300;o5P02o`T00_l600;o
4P04o`<01?l700;o2P02o`<00ol600;o1P02oaD00_l00`3oo`0F00?o0P03o`H00_l600;o1@02o`D0
0_l400;o1P02o`D00_l600;o1P02oaP0000E00;o2`001?l0ool700;o1P02o`P00_lG00Co1003o`@0
0_l600;o1@02o`H00_l400;o1@02o`T00_l800Co1003o`D00_l;00?o1003oaL00_l700;o0`02o`<0
0_lF00;o2@02o`D00olB00Co1003o`L00_l:00;o1003o`D00_l600;o5@05oaH00_l400;o1P02o`H0
0_l500;o1003o`@00ol400?o1@02o`H00_l600;o600001H00_l:00Co1`03o`@00ol700;o5`04o`D0
1?l00`3oo`0:o`@01?l400Co0P04o`<01?l400[o0`04o`D01?l00`3oo`06o`T02OlC00[o0`0<oa80
2_l300_o4P04o`D01?l200[o1005o`<01Ol00`3oo`0:oa801olE00Go0P05o`803?l300[o1P09o`<0
3?l300So5@0001L000?o00002@03o`P02?l80003o`0001H01?l500Co00<0ool02_l400Co1004o`80
1?l300Co100:o`<01?l500Co00<0ool01_l;00Go00<0o`004P0:o`<03?lB00[o0`09oa@01?l500Co
0P0:o`@01Ol300Go00<0ool02_lB00Oo5@05o`801Ol200co0`09o`T01Ol00`3o000200co0`08oaD0
000S00?o2@06ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(49\\) MFUHIMLT IT JR LIKF A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@05o`h00_lE00Go0`05o`030?oo00Go3@04o`H0
1?l300Co100:o`<01Ol300Go00<0ool02ol400So500:o`D02?lE00Ko1P05o`H00ol?00go0P0:o`@0
1Ol600;o00<0ool01OlE00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500Oo200=oa00
000C00;o3@06o`D01ol=00;o5005o`<01Ol00`3oo`05o`/02?l400Co0`04o`@02_l300Go0`05o`03
0?oo00_o1008oa@02_l500So4`09o`D01Ol500Co3`0=o`802_l400Go1@03o`030?oo00Go5@06o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`07o`P03Ol@00004`02o`l00_l<00?o3002oaD0
0_l700;o1002o`h00_l400;o1@02o`D00_l900;o2002o`L00_l500;o1P02o`L00_lK00;o3002oaH0
0ol400?o1P02o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_lJ00;o1`02oa800ol400?o1@02o`H0
0_l400;o1`02o`<00ol500?o1002o`h00_l600;o400001<00_l?00;o3@03o`/00_lE00;o1`02o`@0
0_l=00;o1P02o`@00_l500;o2@02o`P00_l700;o1@02o`H00_l700;o6`02o``00_lF00;o1P02o`H0
0_l500;o5@02o`H00_l600;o2P02o`D00_l500;o6P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l>00;o1P02oa00000C00;o2@0:o``00_l;00;o5@02o`<00_l200;o1002o`80
0_l900;o1P02o`@00_l500;o2@02o`P00_l300;o0P02o`D00_l600;o1`02oa/00_l<00;o5P02o`H0
0_l600;o1002oaH00_l600;o1P02o`X00_l400;o1P02o`800_lF00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`X00_l600;o400001<00_l900[o2004o`030?oo00X00_lE00;o
0P03o`800_l400;o0P02o`T00_l600;o1002o`D00_l900;o2002o`800ol200;o1@02o`H00_l700;o
6`02o``00_lF00;o1P02o`H00_l300?o5P02o`H00_l600;o2P03o`800ol600;o0P02oaL02OlC00;o
00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`@00_l800Wo
2P02oaD00_l20003o`3o00800_l400Ko2@02o`H00_l400;o1@02o`T00_l800;o0P000ol0o`0200;o
1@02o`l00_lK00;o3002oah00_l600Oo5`02o`h00_l:00Oo1`06oaL00_l500;o4`02o`060?l00?l0
0_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`X00_l300;o2002o`@00ol:00;o5@02o`04
0?oo00;o00<0ool01006o`T00_l600;o1009o`T00_l800;o00@0ool00_l00`3oo`0500;o3`02oa/0
0_l<00;o7P02o`H02OlE00;o3P02o`X01Ol900Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko
2P02o`<00_l600Oo1`06o`X00_lH00005002o`X000Co00000_l700;o1P02o`T00_lF00;o00<0ool0
0P001?l0ool400;o0P02o`T00_l600;o1009o`T00_l800;o00<0ool00P001?l0ool500;o2P02o`<0
0_l300;o5P02o`L00_l300;o0`02oaT00_l600;o1@03oa@00_l>00;o2P02o`040?ooo`P00_l200;o
6002o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0
000D00;o2P02o`800_l700;o1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l500;o
1P02o`@00_l500;o2@02o`P00_l00`3o00020004o`3oo`D00_l:00;o0`02o`<00_lF00;o1`02o`<0
0_l300;o6@02o`H00_l600;o5002o`h00_l:00;o0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o2P000ol00002o`L00_l600;o2@02oaH01?l300Co1002o`H00_l500;o1P02o`@00_l500;o
2@02o`P01?l300Co1@02o`X00_l300;o0`02oaH00_l700;o0`02o`<00_lI00;o1P02o`H00_lD00;o
3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool0
1P02o`H00_l500;o1P02o`H00_lH00005@02o`/000Co0?oo1`02o`H000?o00001`02oaL01?l400?o
1002o`H00_l500;o1P02o`@00_l500;o2@02o`P01?l400?o1@02o`X00_l300;o0`02oaH00_l700;o
0`02o`<00_lI00;o1P02o`D00olD00;o3P02o`X00_l400?o1@02o`H00_lE00Go5002o`P00_l400;o
1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o2P04o`P00_l400;o2002oaL01?l500Co
00<0ool02_l400Co1004o`801?l300Co100:o`<01?l500Co00<0ool01_l700co4P0:o`<03?lD00[o
00<0ool02OlB00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol800Wo
0`0<o`<02?lE00005`000ol0000900?o2007o`T000?o00005P04o`D01?l00`3oo`0:o`@01?l400Co
0P04o`<01?l400[o0`04o`D01?l00`3oo`06o`L03?lB00[o0`0<oa@02_l00`3oo`07oa@02?l700[o
1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0
000S00?o2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(50\\) MFUHINMT IU IR LIKE A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00Go3@04o`H0
1?l300Co100:o`@01_l300;o0P05o`<01Ol400So500:o`P01?lE00[o0`05o`H00ol?00go0P0:o`@0
1Ol600;o00<0ool02_l@00Ko0`06oa400_l400;o100<o`801_l300Ko00@0ool01Ol500Oo200=oa00
000C00;o2@09o`P01_l<00;o5005o`<01Ol00`3oo`05o`/02?l400Co0`04o`@02_l400Ko0P03o`80
1Ol300Go1008oa@02_l600So4`0:o`<01Ol500Co3`0=o`802_l400Go1@03o`030?oo00[o4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`07o`P03Ol@00004`02o`T00_l500;o1`03o`80
0ol;00;o5@02o`L00_l400;o3P02o`@00_l500;o1@02o`T00_l900;o1004o`<00_l700;o2002oa/0
0_l:00;o1002oaL00_l900;o1@03oa@00_l600;o1P02o`X00_l500?o1002o`H00_lB00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`h00_l600;o400001<00_lA00;o1P02o`@0
0_l;00;o5@02o`L00_l400;o3@02o`H00_l400;o1@02o`T00_l900;o1004o`<00_l700;o2002oa/0
0_l900;o1P02oaH00_l900;o1@02oaD00_l600;o1P02o`X00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`h00_l600;o400001<00_lA00;o1@02o`H0
0_l:00;o5@02o`<00_l200;o1002o`800_l900;o1P02o`@00_l500;o2@02o`T00_l300Go0`02o`<0
0_l200;o2002oa/00_l900;o1P02oaH00_l900;o1002oaH00_l600;o1P02o`X00_l400;o1P02o`80
0_l200;o4P0;oa801?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l:00;o1P02oa00
000C00;o4@02o`D00_l600;o2P02oaD00_l200?o0P02o`@00_l200;o2@02o`H00_l400;o1@02o`T0
0_l900;o0`02o`030?oo00<00_l200?o0P02o`P00_lK00;o2@02o`H00_lF00;o2@02o`<00olF00;o
1P02o`H00_l:00?o0P03o`H00_l200;o5`09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o
0P02o`X00_l600;o400001<00_lA00;o1@02o`H00_l:00;o5@02o`8000?o0?l00P02o`@01_l900;o
1P02o`@00_l500;o2@02o`T00_l200?o00<0ool00`02o`8000?o0?l00P02o`P00_lK00;o2@02o`H0
0_lF00;o2@07oaL00_l>00;o2P07o`L01_lG00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o
1`07o`D01_l:00;o600001<00_l:00;o1002o`H00_l600;o2P02oaD00_l0103oo`02o`030?oo00@0
1_l900;o1P02o`@02Ol900;o2@02o`800_l200;o0`02o`040?oo00;o00<0ool02002oa/00_l900;o
1P02oaH00_l900Wo5@02o`h00_l:00Go2@06oaP00_l300;o5002o`030?oo00;o00<0ool01@06o`X0
0_l300;o1P07o`L01_l:00;o600001@00_l900So1P02o`H00_l900;o5P02o`030?oo008000Co0?oo
1002o`800_l900;o1P02o`@02Ol900;o2@02o`030?oo00<00_l300;o00<0ool00P001?l0ool300;o
0`02o`<00_lF00;o2@02o`H00_lF00;o2@02o`D00olD00;o3P02o`X00_l0103oool800;o0P02oaP0
0_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH0000
5002o`T01ol700;o1P02o`T00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l500;o1P02o`@0
0_l500;o2@02o`T01Ol300;o0`02o`030?l0008000Co0?oo0`02o`<00_l300;o5P02o`T00_l600;o
5P02o`T00_l600;o5002o`h00_l:00;o0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o
2002o``00_l600;o2@02oaH01?l300Co1002o`H00_l500;o1P02o`@00_l500;o2@02o`T01?l400;o
0`04o`<01?l300;o0`02o`<00_lF00;o2@02o`H00_lF00;o2@02o`H00_lD00;o3P02o`X00_l300?o
1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o
1P02o`H00_lH00005@02o`P00_l=00;o1002o`T00_lG00Co1003o`@00_l600;o1@02o`H00_l400;o
1@02o`T00_l900Co1002o`<01?l400?o0`02o`<00_l300;o5P02o`T00_l600;o5P02o`T00_l500?o
5002o`h00_l:00;o1003o`D00_l600;o5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o
1P02o`H00_lH00005P02o`L00_l=00?o0P03o`P00_lG00Co1@04o`030?oo00[o1004o`@01?l200Co
0`04o`@02_l400Co0P06o`030?oo00;o1@04o`803?lB00[o1004o`@01?lA00[o0`0;oa802?l700[o
1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003
o`0000D02?l800Ko2@000ol0000F00Co1@04o`030?oo00[o1004o`@01?l200Co0`04o`@02_l400?o
0`06o`030?oo00;o1@04o`803?lB00[o1004o`@01?lA00[o0`09oa@02?l700[o1005o`<01Ol00`3o
o`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So2@04ool0
aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(51\\) METGJNMT IT IR LHJD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2@09o`T00_lE00Go0`05o`030?oo00[o1@08o`P0
1_l700Ko1`06o`<00_l200Go0`05o`@02?lD00[o1@08oa@02_l300Go1P03o`l03Ol200Co0`04o`D0
1_l700So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<03Ol@00004`02o`T0
2Ol700Wo2P02oa@01Ol300Go00<0ool02_l500So1P0:o`<02Ol600Ko0P03o`801Ol300Go1008oa@0
2_l500So500:o`<01Ol500Co3`0=o`801?l300Co0`09o`H02_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@02o`D00_l;00;o3@02oaD00_l700;o1002o`H0
0_l800;o2004o`D00_l300?o1003o`H00_l400Co0`02o`L00_l800;o6`02o``00_lK00;o2@02o`D0
0olD00;o1P02o`<00_l500;o1003o`@00ol600;o1004oa800_l700;o4P03o`@00ol500;o1P02o`@0
0_l700;o0`03o`D00ol400;o1P02o`H00_l600;o400001<00_lA00;o2P02o`d00_lE00;o1`02o`@0
0_l600;o2002o`P00_l700;o0`02o`H00_l600;o1004o`<00_l700;o2002oa/00_l<00;o6`02o`T0
0_l500;o5@02o`H00_l300;o1@02o`@00_l600;o1P02o`H00_lB00;o1`02oa801?l300?o1@02o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4@02o`X00_l=00;o5@02o`<0
0_l200;o1002o`800_l200;o2002o`L00ol700;o0`02o`H00_l600;o0`05o`<00_l300;o0P02o`P0
0_lK00;o3002oa/00_l900;o1002oaH00_l600;o0`02o`D00_l400;o1P02o`H00_l700;o4@0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02oa40
0_l:00;o3@02oaD00_l200?o0P02o`@00_l200;o3002o`L00_l400Oo0P02o`H00_l600;o0`02o`03
0?oo00<00_l200?o0P02o`P00_lK00;o3002oa/00_l900;o0`03oaH00_l600;o0`02o`D00_l400;o
1P02o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o
400001<00_lA00;o2P02o`d00_lE00;o0P000ol0o`0200;o1006o``00_l700;o1007o`X00_l600;o
0P03o`030?oo00<00_l20003o`3o00800_l800;o6`02o``00_lK00;o2@07oaL00_l;00;o1@02o``0
0_l600;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH0000
4`02o`X00_l400;o2`02o`d00_lE00;o00@0ool00_l00`3oo`0400Ko3002o`L00_lE00;o1P02o`80
0_l200;o0`02o`040?oo00;o00<0ool02002oa/00_l<00;o6`02o`T02OlE00;o2`09o``00_l600;o
1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@0
0_l900So2`02o``00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`800_lE00;o
1P02o`030?oo00<00_l300;o00<0ool00P001?l0ool300;o0`02o`<00_lF00;o1`02o`<00_l300;o
5P02o`T00_l500?o5002o`/02Ol<00;o1P02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D0
0_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l900Oo3002o``00_lF00;o00<0o`00
0P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l200;o2002o`/00_l600Go0`02o`<00_l00`3o
00020004o`3oo`<00_l300;o0`02oaH00_l700;o0`02o`<00_lF00;o2@02o`H00_lD00;o2`02o`D0
0_l<00;o1P02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D0
0_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`P00_lA00;o3002oaH01?l300Co1002o`H0
0_l300;o0`02o`<00_l300;o1P03o`/00_l600Co1002o`<01?l300Co0`02o`<00_l300;o5P02o`L0
0_l300;o0`02oaH00_l900;o1P02oa@00_l;00;o1@02o``00_l600;o1P02oaD00_l00`3oo`0D00;o
0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2002oa40
0_l;00;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`<00ol400Co2`02o`H01?l400;o0`04o`@0
0ol300;o0`02o`<00_lF00;o1`02o`<00_l300;o5P02o`T00_l500?o5002o`/00_l500;o3002o`H0
0_l400Co5@05oa@00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`L0
0_l=00?o00<0ool02P02oaL01?l500Co00<0ool02_l300co100:o`H02_l200Co0P06o`030?oo00;o
1@04o`803?lB00[o0`0<oa802_l300_o4P08o`L01?l300Co1P0:o`802_lC00Oo5006o`801_l00`3o
o`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0000500So1`06o`X000?o00005P04o`D01?l00`3o
o`0:o`<03?l600Go00<0ool01P0:o`800ol300Ko00<0ool00_l500Co0P0<oa802_l300co4P0:o`<0
2OlD00So1`04o`<01?l600[o0P08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co
0`08oaD0000O00So2P03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(52\\) MFUGKMLS IU IS LIKE A WEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go200:o`T00_lE00Go0`05o`030?oo00Go3@04o`T0
1_l500Go1P02o`030?oo00?o0`05o`030?oo00_o0`02o`030?oo00?o5@0:o`P01?lE00[o1002o`03
0?oo00?o500=o`802_l400Go1P02o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`04
0?oo00Go1@07o`P03Ol@00004`02o`T02Ol600[o2P02oa@01Ol300Go00<0ool01Ol;00So1@0:o`<0
1Ol500?o00<0ool00ol300Go00<0ool02ol300[o4`0:o`H02?lC00[o100:oa803Ol200[o1005o`D0
0ol00`3oo`0:oa001_l300Ko4@02o`@00_l400co0P06o`<01_l00`3oo`08o`<01ol800go400001<0
0_l900;o1@02o`L00_l500;o2P02oaD00_l700;o1002o`h00_l400;o1004o`D00_l500;o1@03o`<0
0_l700;o1@02o`H00_l300?o1@03oaH00_l:00;o1002oaL00_l800?o1@03oa@00_l600;o1P02o`X0
0_l500?o1002o`H00_lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`h0
0_l600;o400001<00_lA00;o1`03o`l00_lE00;o1`02o`@00_l=00;o1P02o`<00_l700;o1@02o`D0
0_l400;o1`02o`D00_l600;o0`02o`L00_lF00;o2@02o`H00_lF00;o2002o`L00_lD00;o1P02o`H0
0_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@0
0_l>00;o1P02oa00000C00;o4@02o`P00ol>00;o5@02o`<00_l200;o1002o`800_l900;o1P02o`80
0ol700;o1@02o`@00_l500;o0`02o`800_l500;o1P02o`<00_l700;o5P02o`T00_l600;o5P02o`P0
0_l700;o5002o`H00_l600;o2P02o`@00_l600;o0P02o`800_lB00_o4P04o`801?l500;o0P02o`80
0_l400_o0`02o`L00_l400;o0P02o`X00_l600;o400001<00_lA00;o2@03o`d00_lE00;o0P03o`80
0_l400;o0P02o`T00_l600;o0P02o`@01ol400?o0P03o`D00_l200?o0P02o`D00_l600;o2`03oaH0
0_l900;o1P02oaH00_l@00?o5002o`H00_l600;o2P03o`800ol600;o0P02oaL02OlC00;o00@0o`00
1?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o4@02o`X00ol<00;o5@02o`80
00?o0?l00P02o`@01_l900;o1P02o`800_l400Oo1007o`H00_l20003o`3o00800_l500;o3P07oaL0
0_l900;o1P02oaH00_l;00Oo5@02o`h00_l:00Oo1`06oaL00_l500;o4`02o`060?l00?l00_l500Ko
2@02o`D00_l700Oo1@06o`X00_lH00004`02o`X00_l400;o3003o`/00_lE00;o00@0ool00_l00`3o
o`0400Ko2@02o`H00_l200;o3`05o`P00_l0103oo`02o`030?oo00D00_l<00Oo6@02o`T00_l600;o
5P02o`T01olG00;o3P02o`X01Ol900Ko6002o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<0
0_l600Oo1`06o`X00_lH00005002o`T02?l=00;o2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o
2@02o`H00_l200;o3`02o`040?ooo`L00_l00`3oo`020004o`3oo`D00_l;00?o7P02o`T00_l600;o
5P02o`P00olL00;o3P02o`X00_l0103oool800;o0P02oaP00_l300;o5002o`030?oo00;o00<0ool0
1@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T01ol?00;o2@02oaH00_l00`3o
00020004o`3oo`@00_l200;o0P02o`D00_l600;o0P02o`P00_l500;o0P03o`H00_l00`3o00020004
o`3oo`D00_l;00;o1`000ol0000E00;o2@02o`H00_lF00;o2002o`L000?o00004`02o`h00_l:00;o
0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1@02o`L000?o00000`02o`800_l200;o1P02oaP0000D00?o2002oa@00_l900;o5P04o`<01?l400;o
1P02o`D00_l600;o0`02o`H00ol500;o0`03o`D01?l300Co1@02o`/00_l600;o5`02o`T00_l600;o
5P02o`P00_l600;o5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@0
0_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800;o3@02o`D00_l800;o
5`04o`@00ol400;o1P02o`D00_l600;o0`03o`@01?l500;o1003o`@01?l400?o1@02o`/00ol400?o
5`02o`T00_l600;o5P02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l600;o5@05oa@00_l800;o
1002o`H00_l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`L00_l=00?o0`03o`L00_lG00Co
1@04o`030?oo00[o1004o`@01?l300[o0`05o`<01Ol00`3oo`02o`D01?l00`3oo`06o`T02OlC00[o
1004o`@01?lA00[o1@09oa802?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o
1007o`P02Ol300co0`08oaD0000G0003o`0000D02?l800Oo20000ol0000F00Co1@04o`030?oo00[o
1004o`@01?l500Go00<0ool00`05o`<01Ol00`3oo`02o`D01?l00`3oo`06o`/01Ol00`3o000B00[o
1004o`@01?lA00[o1`05o`030?l001402?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`03
0?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So2@05ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(53\\) MFUGKMKS IU IS LIKE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00Go0`05o`030?oo00Go3@04o`T0
1_l500Go1P02o`030?oo00?o0`05o`030?oo00?o1P02o`<00_l00`3oo`03oaD02_l800Co5@0:o`@0
0_l00`3oo`03oa@03Ol200[o1005o`H00_l00`3oo`0:oa001_l300Ko4@02o`@00_l400co0P06o`<0
1_l0103oo`05o`D03?l300go400001<00_l900Wo1P09o`/00_lD00Go0`05o`030?oo00Go2`08o`D0
2_l300Go1@03o`030?oo00?o0`05o`030?oo00?o1@03o`<02_lC00[o1P08oa<02_l400[o4P0=o`80
2_l400Go1@03o`030?oo00[o4006o`<01_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<0
3Ol@00004`02o`T00_l500;o1P02o`D00_l;00;o5@02o`L00_l400;o3P02o`@00_l400Co1@02o`D0
0_l500?o0`02o`L00_l400;o1@03o`@00ol500?o5P02o`X00_l400;o5`02o`P00ol500?o5002o`H0
0_l600;o2P02o`D00ol400;o1P02oa800_l700;o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D0
0ol400;o1P02o`H00_l600;o400001<00_lA00;o3@02o`X00_lE00;o1`02o`@00_l=00;o1P02o`<0
0_l700;o1@02o`D00_l400;o1`02o`@00_l500;o1@02o`L00_lF00;o2@02o`H00_lF00;o2002o`L0
0_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02oa400_l=00;o2P02oaD00_l300;o0P02o`@0
0_l200;o2@02o`H00_l200?o1`02o`D00_l400;o1@02o`<00_l200;o1002o`@00_l600;o1`02oaH0
0_l900;o1P02oaH00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4P0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02oa40
0_l=00;o2P02oaD00_l200?o0P02o`@00_l200;o2@02o`H00_l200;o1007o`@00ol200?o1@02o`80
0ol200;o1003o`800ol>00?o5P02o`T00_l600;o5P02oa000olD00;o1P02o`H00_l:00?o0P03o`H0
0_l200;o5`09oa<00_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<0
0_lA00;o3002o`/00_lE00;o0P000ol0o`0200;o1006o`T00_l600;o0P02o`@01ol400Oo1P02o`80
00?o0?l00P02o`@01ol:00Oo5`02o`T00_l600;o5P02o`/01olE00;o3P02o`X01ol700Ko5`02o`D0
0_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`@00_l:00Co
3002oaD00_l0103oo`02o`030?oo00@01_l900;o1P02o`800_l?00Go2002o`040?oo00;o00<0ool0
1005o`X01olI00;o2@02o`H00_lF00;o2@07oaL00_l>00;o2P05o`T01_lH00;o0`02oa@00_l00`3o
o`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2@08o`X00ol<00;o5P02o`03
0?oo008000Co0?oo1002o`800_l900;o1P02o`800_l?00;o00@0oooo1`02o`030?oo008000Co0?oo
1002o`040?ooo`P00olN00;o2@02o`H00_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l200;o
6002o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0
000D00;o2@07o`d00_l;00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o1@02o`H00_l200;o
2002o`D00_l200?o1P02o`030?l0008000Co0?oo1002o`800ol700;o1`000ol0000E00;o2@02o`H0
0_lF00;o2002o`L000?o00004`02o`h00_l:00;o0P03o`L00_l200;o0P02oaD00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o2002oa<00_l:00;o5P04o`<01?l400;o1P02o`D00_l600;o0`02o`H00ol500;o0`03o`D0
1?l300Co1002o`<00ol600;o1P02oaL00_l900;o1P02oaH00_l800;o1P02oaD00_l>00;o2P02o`<0
0ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D0
0_l600;o1P02oaP0000E00;o2002oa<00_l900;o5`04o`@00ol400;o1P02o`D00_l600;o0`03o`@0
1?l500;o1003o`@01?l400?o1002o`@00ol500?o1003oaL00_l900;o1P02oaH00_l800?o1003oaD0
0_l>00;o2P02o`@00ol500;o1P02oaD01OlD00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H0
0_l600;o600001H00_l700;o3@02o`<00ol800;o5`04o`D01?l00`3oo`0:o`@01?l400Co0`0:o`<0
1Ol300Go00<0ool00_l500Co00<0ool00ol300Go1009oa<02_l400Co1004oa402_l500Wo4P08o`L0
2_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L0
00?o00001@08o`L01ol90003o`0001H01?l500Co00<0ool02_l400Co1004o`D01Ol00`3oo`0300Go
0`05o`030?oo00;o1@04o`030?oo00?o0`05o`H01Ol00`3o000B00[o1004o`@01?lA00[o1`05o`03
0?l001402?l700[o1005o`<01Ol00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o
000200co0`08oaD0000O00So2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(54\\) MFTHKMKS IU IS LIKF A VEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go3006o`T00_lE00Go0`05o`030?oo00Go2P08o`D0
1?l300Co0`05o`H00_l00`3oo`03o`<01Ol00`3oo`03o`H00_l300;o00<0ool00olE00[o2004oaD0
2_l400;o00<0ool00olD00go0P0:o`@01Ol600;o00<0ool01OlE00Ko0`06oa@00_l700co0P06o`<0
1_l0103oo`05o`D03?l300go400001<00_l900Wo2P06o`X00_lD00Go0`05o`030?oo00Go2P08o`D0
1?l300Co0`05o`D00ol00`3oo`03o`<01Ol00`3oo`03o`D00ol300[o4`0:o`H02?lC00[o100:oa80
3Ol200[o1005o`D00ol00`3oo`05oaD01_l300Ko4`04o`H03?l200Ko0`06o`030?oo00So0`0<o`<0
3Ol@00004`02o`T00_l500;o3002o``00_lE00;o1`02o`@00_l@00;o2@02o`D00_l600;o1@03o`<0
0_l700;o1002o`D00ol400?o1@03oaH00_l:00;o1002oaL00_l800?o1@03oa@00_l600;o1P02o`X0
0_l500?o1002oaX00_l700;o5@04o`P00_l600;o1002o`L00_l300?o1@03o`@00_l600;o1P02o`H0
0_l@00004`02oa400_l;00;o3002oaD00_l700;o1002oa000_l900;o1@02o`H00_l500;o1002o`L0
0_l400;o1@02o`D00_l700;o5P02o`T00_l600;o5P02o`P00_l700;o5002o`H00_l600;o2P02o`D0
0_l500;o6P02o`L00_lE00Co2002o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00
000C00;o4@02o`D02_l:00;o5@02o`<00_l200;o1002o`800_l<00;o2@02o`D00_l600;o1002o`D0
0_l300;o0P02o`@00_l400;o1P02o`L00_lF00;o2@02o`H00_lF00;o2002o`L00_lD00;o1P02o`H0
0_l:00;o1002o`H00_l200;o5P0;oa@00_l200;o1`02o`800_l200;o100;o`<00_l700;o1002o`80
0_l200;o1P02o`H00_l@00004`02oa400_l500[o2P02oaD00_l200?o0P02o`@00_l200;o3002o`T0
0_l500;o1P03o`800ol500;o0P03o`800_l400?o0P03o`h00olF00;o2@02o`H00_lF00;o4003oa@0
0_l600;o1P02o`X00ol200?o1P02o`800_lG00Wo5@02o`800_l700;o0P02o`T02Ol<00?o1002o`80
0_l:00;o1P02oa00000C00;o4@02o`D00_l400;o3002oaD00_l20003o`3o00800_l400Ko3002o`T0
0_l500;o1P07o`H00_l20003o`3o00800_l400Oo2P07oaL00_l900;o1P02oaH00_l;00Oo5@02o`h0
0_l:00Oo1`06oaL00_l500;o5003o`800ol600Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`X0
0_l400;o1`02o`<00_l<00;o5@02o`040?oo00;o00<0ool01006o``00_l900Wo1P05o`P00_l0103o
o`02o`030?oo00@01Ol:00Oo6@02o`T00_l600;o5P02o`T01olG00;o3P02o`X01Ol900Ko6002o`<0
0_lE00;o1002o`H01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2@08o`P000Co00000_l;00;o
5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l400Wo1P02o`040?ooo`L00_l00`3o
o`020004o`3oo`@00_l0103oool800?o7P02o`T00_l600;o5P02o`P00olL00;o3P02o`X00_l0103o
ool800;o0P02oaP00_l300;o5@02o`@00_l600;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0
000D00;o2@07o`T00_l200;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`@00_l500;o1P02o`800ol600;o00<0o`000P001?l0ool400;o0P03o`L00_l70003o`0001D0
0_l900;o1P02oaH00_l800;o1`000ol0000C00;o3P02o`X00_l200?o1`02o`800_l200;o5@02o`04
0?oooa@00_l600;o1@02o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`P00_l?0003o`0000;o2`02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o
1@02o`H00_l300?o1@04o`<01?l400;o0`03o`H00_l600;o5`02o`T00_l600;o5P02o`P00_l600;o
5@02o`h00_l:00;o0`03o`H00_l600;o5@02o`030?oo01D00_l600;o1@02o`H00_l700;o00<0ool0
1P02o`H00_l500;o1P02o`H00_lH00005@02o`P00_l@0004o`3oo`X00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1002o`D00_l600;o1003o`@01?l400?o1002o`@00ol500?o1003oaL00_l900;o
1P02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o1P02oaD01OlD00?o1P03o`@00_l600;o
1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l700;o4004o`T00_lG00Co1@04o`030?oo00[o
0`0<o`<01?l300Co0`05o`<01Ol00`3oo`02o`D01?l00`3oo`03o`<01Ol400Wo4`0:o`@01?l400Co
4@0:o`D02OlB00So1`0:o`@01Ol300Go00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol800Wo
0`0<o`<02?lE00005`000ol0000500So2`03o`T000?o00005P04o`D01?l00`3oo`0:o`<03?l300Co
0`04o`<01Ol300Go00<0ool00_l500Co00<0ool00ol300Go1P05o`030?l001802_l400Co1004oa40
2_l700Go00<0o`004@08o`L02_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo
2P05o`030?l000803?l300So5@0001l02?l;00?oo`350000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(55\\) NFTGJMKS IU IS LIJF A VEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lF00Ko0`02o`801ol:00So2006o`L0
1_l600Go0`05o`030?oo00?o1P02o`<00_l00`3oo`03oaD02_l800Co5@0:o`@00_l00`3oo`03oa@0
3Ol200[o1P06o`H01olE00Ko0`06oa@00_l700co0P06o`<01_l0103oo`05o`D03?l300go400001<0
0_l900Wo1P09o`/00_lE00Ko0P03o`801ol:00So1P0:o`<02Ol500Go0`05o`030?oo00?o1@03o`<0
2_lC00[o1P08oa<02_l400[o4P0=o`802_l400Wo1@07oaD01_l300Ko4`04o`H03?l200Ko0`06o`03
0?oo00So0`0<o`<03Ol@00004`02o`T00_l500;o1P02o`D00_l;00;o5P02o`@01?l400;o4002o`P0
1?l500;o0`03o`@00ol500;o1`02o`@00_l500?o1003o`D00olF00;o2P02o`@00_lG00;o2003o`D0
0olD00;o1P02o`H00_l800?o1003o`H00_lJ00;o1`02oaD01?l800;o1P02o`@00_l700;o0`03o`D0
0ol400;o1P02o`H00_l600;o400001<00_lA00;o3@02o`X00_lF00;o1004o`@00_l@00;o2002o`L0
0_l300;o1P02o`D00_l700;o1002o`D00_l500;o1`02oaH00_l900;o1P02oaH00_l800;o1`02oa@0
0_l600;o1P02o`P00_l600;o1P02oaX00_l700;o5@04o`P00_l600;o1002o`L00_l300;o1`02o`@0
0_l600;o1P02o`H00_l@00004`02oa400_l=00;o2P02oaH00_l300Go1002o`800_l<00;o1`03o`L0
0_l300;o1P02o`D00_l300;o0P02o`@00_l400;o1P02o`L00_lF00;o2@02o`H00_lF00;o2002o`L0
0_lD00;o1P02o`H00_l800;o1P02o`H00_l200;o5P0;oa@00_l200;o1`02o`800_l200;o100;o`<0
0_l700;o1002o`800_l200;o1P02o`H00_l@00004`02oa400_l=00;o2P02oaH00_l300;o00<0ool0
1002o`800_l<00;o1`02o`@01ol200;o1P02o`D00_l200?o0P02o`@00ol200?o3P03oaH00_l900;o
1P02oaH00_l@00?o5002o`H00_l600;o2002o`H00_l600;o0P02oaL02OlE00;o0P02o`L00_l200;o
2@09o``00ol400;o0P02o`X00_l600;o400001<00_lA00;o3@02o`X00_lF00;o0P03o`030?oo00@0
1_l<00;o1`02o`@01ol:00;o1@02o`8000?o0?l00P02o`@01ol:00Oo5`02o`T00_l600;o5P02o`/0
1olE00;o3P02oa000_l600Ko5`02o`D00_lD00?o0P03o`H01_l900;o1@02o`L01ol500Ko2P02oaP0
000C00;o2P02o`@00_l700;o1002o`/00_lF00;o0P02o`800_l400Ko3002o`L00_lE00;o1@02o`04
0?oo00;o00<0ool01005o`X01olI00;o2@02o`H00_lF00;o2@07oaL00_l>00;o4002o`H01_lH00;o
0`02oaD00_l400;o1P06o`X00_l300;o1P07o`L01_l:00;o600001@00_l900So1`08o`X00_lG00;o
00<0ool00`02o`@00_l200;o1`02o`<00_l300;o0P02oaD00_l500;o00<0ool00P001?l0ool400;o
00@0oooo2003oah00_l900;o1P02oaH00_l800?o7002o`h00_l@00;o1P02o`800_lH00;o0`02oaD0
0_l400;o1P02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T01ol800Oo2`02oaL0
1Ol300;o1002o`800_l200;o0`02o`<00_l300;o0P02o`P00_l;00;o1@02o`030?l0008000Co0?oo
1002o`800ol700;o1`000ol0000E00;o2@02o`H00_lF00;o2002o`L000?o00004`02o`h00_l@00;o
1P02o`800_l200;o5@02o`040?oooa@00_l600;o1@02o`800_l200;o1`02o`040?ooo`D00_l70003
o`0000<00_l200;o0P02o`H00_lH00005003o`P00_l=00;o4002oaL01?l400;o1002o`H00_l300;o
0`02o`<00_l300;o1P03o`/00_l500Co0`04o`@00_l300?o1P02o`H00_lG00;o2@02o`H00_lF00;o
2002o`H00_lE00;o3P02oa000_l600;o1P02oaD00_l00`3oo`0E00;o1P02o`D00_l600;o1`02o`03
0?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800;o3@02o`l00_lH00Co1002o`@00_l600;o
0`02o`<00_l300;o0`03o`@01?l;00;o1@04o`@00ol400;o1003o`D00ol400?o5`02o`T00_l600;o
5P02o`P00ol400?o5@02o`h00_l@00;o1P02o`H00_lE00Go5003o`H00ol400;o1P02o`L01Ol600?o
1003o`D00_l600;o1P02oaP0000F00;o1`02o`d00_l>00;o6004o`801_l00`3oo`0:o`<03?l400[o
1P0:o`030?oo00;o1@04o`030?oo00?o0`05o`@02OlC00[o1004o`@01?lA00[o1@09oa802?l700[o
1`0:o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o0000
1@08o`L02?l80003o`0001L00ol300Ko00<0ool02_l300co1P05o`030?oo00H02_l00`3oo`02o`D0
1?l00`3oo`03o`<01Ol600Go00<0o`004P0:o`@01?l400Co4@0:o`L01Ol00`3o000A00So1`0:o`L0
2_l00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So
1`08ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(56\\) NFTHIMKT IU ISZLIJF A VEASEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lF00Ko0`02o`801ol:00So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`03o`H00_l400So500:o`P01?lE00[o1002o`030?oo00?o1`0:o`<0
3Ol200[o1P06o`H01olE00Ko0`06oa@00_l700co0P06o`<01_l0103oo`05o`D03?l300Go0`05oa00
000C00;o2@09o`P01ol;00;o5@06o`800ol200Oo2P08o`D01?l300Co100:o`<01Ol300Go00<0ool0
0ol500?o1008oa@02_l600So4`0:o`@02_l500[o0`0=o`802_l400Wo1@07oaD01_l300Ko4`04o`H0
3?l200Ko0`06o`030?oo00So0`0<o`<01Ol300Go400001<00_l900;o1@02o`L00_l400;o2`02oaH0
0_l400Co1002oa000_l900;o1@02o`T00_l800;o1`02o`@00_l500?o2002oa/00_l:00;o1002oaL0
0_l800?o1@03o`D00_l500;o1P02o`H00_l600;o2003o`@00ol600;o6P02o`L00_lE00Co2002o`H0
0_l400;o1`02o`<00ol500?o1002o`H00_l400;o1`02oa40000C00;o4@02o`D00_l600;o2P02oaH0
0_l400Co1002oa000_l900;o1@02o`T00_l800;o1`02o`@00_l500;o2@02oa/00_l900;o1P02oaH0
0_l800;o1`02o`D00ol400;o1P02o`H00_l600;o2002o`H00_l600;o6P02o`L00_lE00Co2002o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l400;o1`02oa40000C00;o4@02o`D00_l600;o2P02oaH0
0_l300Go1002o`800_l<00;o2@02o`D00_l900;o2002o`<00_l200;o1002o`@00_l:00;o6`02o`T0
0_l600;o5P02o`P00_l700;o1P03o`<00_l600;o1P02o`H00_l800;o1P02o`H00_l200;o5P0;oa@0
0_l200;o1`02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1002o`<00_l200;o4@0001<0
0_lA00;o1@02o`H00_l:00;o5P02o`<00_l00`3oo`0400;o0P02o``00_l900;o1@02o`T00_l800;o
0P03o`800_l400?o0P03o`X00_lK00;o2@02o`H00_lF00;o4003o`L00_l300;o1P02o`H00_l600;o
2002o`H00_l600;o0P02oaL02OlE00;o0P02o`L00_l200;o2@09o``00ol400;o0P02o`P00_l200?o
0P02oa40000C00;o4@02o`D00_l600;o2P02oaH00_l200?o00<0ool01006o``00_l900;o1@02o`T0
0_l800;o0P000ol0o`0200;o1007o`/00_lK00;o2@02o`H00_lF00;o2`07o`P00ol:00;o3P02oa00
0_l600Ko5`02o`D00_lD00?o0P03o`H01_l900;o1@02o`L01ol500Ko2002o`8000?o0?l00P02oa40
000C00;o2P02o`@00_l600?o1002o`/00_lF00;o0P02o`800_l400Ko3002o`T02Ol900;o2002o`04
0?oo00;o00<0ool01005o`d00_lK00;o2@02o`H00_lF00;o2@07o`/00ol900;o3P02oa000_l600Ko
6002o`<00_lE00;o1002o`H01_l:00;o0`02o`H01ol700Ko2002o`040?oo00;o00<0ool04@0001@0
0_l900So1P09o`X00_lG00;o00<0ool00`02o`@00_l200;o1`02o`<00_l300;o1009o`T00_l800;o
00<0ool00P001?l0ool400;o00@0oooo1`02o`<00_l300;o5P02o`T00_l600;o5P02o`P00ol<00;o
0`02o`T00_l>00;o4002o`H00_l200;o6002o`<00_lE00;o1002o`H00_l200;o2P02o`<00_l500?o
3002o`800_l800;o00<0ool00P001?l0oolA00005002o`T01ol700;o00<0ool00_l<00;o5`05o`<0
0_l400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T00_l800;o00<0o`000P001?l0ool400;o
0P03o`H00_l300;o0`02oaH00_l900;o1P02oaH00_l800;o1`000ol0000300;o0`03o`P00_l>00;o
4002o`H00_l200;o0P02oaD00_l0103ooolD00;o1P02o`D00_l200;o0P02o`L00_l0103oool500;o
1`000ol0000300;o0P02o`800_l400;o00<0o`000P001?l0oolA00005003o`P00_l=00;o4002oaL0
1?l400;o1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l800Co0`04o`@00_l300?o1@02o`<0
0_l300;o5P02o`T00_l600;o5P02o`P00_l600;o1@02o`@00ol700;o3P02oa000_l600;o1P02oaD0
0_l00`3oo`0E00;o1P02o`D00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l400Co0`04oa40
000E00;o2002o`d00ol>00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P0
1?l400?o1002o`@00ol400;o0`02o`<00_lF00;o2@02o`H00_lF00;o2003o`@00ol500;o1@02o`L0
0_l>00;o4002o`H00_l600;o5@05oa@00ol600?o1002o`H00_l700Go1P03o`@00ol500;o1P02o`@0
1?l400?o4@0001H00_l700;o3P03o``00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co100:o`<0
1?l500Co00<0ool00ol300Go0P0<oa802_l400Co1004oa402_l500Wo1@0:o`<02?l700[o1`0:o`03
0?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300Co1@04oa00000G0003o`0000D0
2?l900Oo1`000ol0000G00?o0`06o`030?oo00[o0`0<o`<01?l300Co100:o`<01?l500Co00<0ool0
0ol300Go0P0<oa802_l400Co1004oa402_l700Go00<0o`00100:o`<02?l700[o1`0:o`030?oo00[o
4P07oa@01_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300Co1@04oa00000O00So2`05ool0
``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(57\\) NFTHINKS IU IS LIKF AZWEASFM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`02o`h00_lF00Ko0`02o`801ol:00So1@04o`<0
1?l400[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l800Co5@0:o`@00_l00`3oo`03oa@0
3Ol200[o1005o`H00_l00`3oo`05oaD01_l300Ko00<0ool02?l600;o1002o`@03?l200Ko0`06o`04
0?oo00Go1@07o`P01Ol300Go400001<00_l900Wo2@02o`l00_lE00Ko0P03o`801ol:00So1@04o`<0
1?l400[o1006o`800ol200Go1@03o`<02_lC00[o1P08oa<02_l400[o4P0=o`802_l400Go1@03o`03
0?oo00Go5@06o`<01_l00`3oo`08o`H00_l400;o100<o`801_l300Ko00<0ool02?l300Oo2005o`<0
1Ol@00004`02o`T00_l500;o2P02o`h00_lF00;o1004o`@00_l@00;o2@02o`D00_l900;o2@02o`@0
1?l400;o1@03o`@00ol500?o5P02o`X00_l400;o5`02o`P00ol500?o5002o`H00_l600;o2P02o`D0
0ol400;o6P02o`L00_l400;o1@02o`D00ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o``0
0_l700;o4@0001<00_lA00;o2@02o`h00_lF00;o1004o`@00_l@00;o2@02o`D00_l900;o2@02o`@0
1?l400;o1@02o`D00_l700;o5P02o`T00_l600;o5P02o`P00_l700;o5002o`H00_l600;o2P02o`D0
0_l500;o6P02o`L00_l400?o1002o`D01?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o``0
0_l700;o4@0001<00_lA00;o2@02o`h00_lF00;o0`05o`@00_l200;o3002o`T00_l500;o2@02o`T0
0_l300Go1002o`@00_l600;o1`02oaH00_l900;o1P02oaH00_l800;o1`02oa@00_l600;o1P02o`X0
0_l400;o1P02o`800_lF00_o1@03o`<00_l500Co0P04o`D00_l200;o0P02o`@02ol300;o1`02o`@0
0_l200;o2002o`<00_l200;o4@0001<00_lA00;o2P000ol0000<00;o5P02o`<00_l00`3oo`0400;o
0P02o``00_l900;o1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oaH00_l900;o1P02oaH0
0_l@00?o5002o`H00_l600;o2P03o`800ol600;o0P02oaL02Ol700;o0`02o`D00_l0103o0004o`D0
0_l200;o2@09o``00ol400;o0P02o`P00_l200?o0P02oa40000C00;o4@02o`X00_l=00;o5P02o`80
0ol00`3oo`0400Ko3002o`T00_l500;o2@02o`T00_l200?o00<0ool01007o`X01olG00;o2@02o`H0
0_lF00;o2`07oaD00_l>00;o2P07o`L01_lG00;o1@02o`L00ol900;o00H0o`00o`02o`D01_l900;o
1@02o`L01ol500Ko2002o`8000?o0?l00P02oa40000C00;o2P02o`@00_l;00;o3@02oaH00_l200;o
0P02o`@01_l<00;o2@09o`T00_l900;o0P02o`800_l400Go2P07oaT00_l900;o1P02oaH00_l900Oo
5`02o`h00_l:00Go2@06oaP00_l300;o2@03o`P00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H0
1ol700Ko2002o`040?oo00;o00<0ool04@0001@00_l900So30000ol0000:00;o5`02o`030?oo00<0
0_l400;o0P02o`L00_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o00@0oooo2003oah0
0_l900;o1P02oaH00_l800?o7002o`h00_l:00;o00@0oooo2002o`800_lH00;o0`02o`D00_l300;o
2002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`P00_l00`3oo`020004
o`3ooa40000D00;o2@07o`d00_l;00;o5`05o`<00_l400;o0P02o`800_l300;o0`02o`<00_l400;o
1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00005@02o`T00_l600;o5P02o`P00_l70003
o`0001<00_l>00;o2P02o`800ol700;o0P02o`800_lE00;o00@0oooo1@02o`<00ol600;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1002o`030?l00080
00Co0?oo4@0001@00ol800;o4P02o`/00_lG00Co1002o`@00_l600;o0`02o`<00_l300;o1002o`D0
0_l900;o2@04o`@00_l400;o0`03o`H00_l600;o5`02o`T00_l600;o5P02o`P00_l600;o5@02o`h0
0_l:00;o0`03o`H00_l600;o5@02o`030?oo00H00_l400?o1@02o`<00_l300;o1002o`H00_l700;o
00<0ool01P02o`H00_l500;o1P02o`@01?l300Co4@0001D00_l800;o4`000ol0000800;o6004o`@0
0_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o1003oaL0
0_l900;o1P02oaH00_l800?o1003oaD00_l>00;o2P02o`@00ol500;o1P02oaD01Ol600;o1@02o`D0
0_l800;o1002o`H00_l700Go1P03o`@00ol500;o1P02o`@01?l400?o4@0001H00_l700;o3002o`D0
0_l800;o6004o`801_l00`3oo`0:o`<03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@0
2OlC00[o1004o`@01?lA00[o1@09oa802?l700[o1005o`<01Ol00`3oo`0:oa801ol700[o0`06o`80
1_l00`3oo`0:o`@01ol800Wo0`0<o`<01?l500Co400001L000?o00001@08o`H02Ol80003o`0001L0
0ol300Ko00<0ool02_l300co0`04o`<01?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`00
4P0:o`@01?l400Co4@0:o`L01Ol00`3o000A00So1`0:o`@01Ol300Go00<0ool02_lB00Oo1`0:o`<0
1_l200Ko00<0ool02_l400Oo2P05o`030?l000803?l300Co1@04oa00000O00So1P09ool0a0000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(58\\) MEUHHOKR JT IS KIKE AZWEASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lE00Go0`05o`030?oo00[o2004o`H0
1?l300Co1004o`<01?l600Go1@05o`H00_l200Go1P03oa401_l800So500:o`@00_l00`3oo`03oa@0
1Ol600;o0P0:o`@01Ol600;o00<0ool02_l@00Ko0`06o`030?oo00So1P02o`@00_l400co0P06o`<0
1_l0103oo`05o`D01ol800go400001<00_l900Wo1`08o`/00_lD00Go0`05o`030?oo00[o1P08o`@0
1?l300Co1004o`<01?l400Wo0`05o`D00ol200Go1@04o`l02Ol700So500:o`@02_lB00Go1@03o`80
2_l400Go1@03o`030?oo00[o4006o`<01_l00`3oo`08o`H00_l400;o100<o`801_l300Ko00<0ool0
2?l300Oo200=oa00000C00;o2@02o`D00_l600?o1003o`X00_lE00;o1`02o`@00_l600;o1P02o`@0
0_l500;o1@02o`H00_l500;o1003o`D00ol400;o1@03o`D00_l500?o4@03o`@00ol900;o6`02o`P0
0ol500?o4`02o`D00ol700;o2P02o`D00ol400;o1P02oa800_l700;o1002o`D00_l500?o1003o`D0
0_l600;o1002o`L00_l300?o1@03o`@00_l>00;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaD0
0_l700;o1002o`H00_l500;o1P02o`@00_l500;o1P02o`D00_l400;o1`02o`@00_l500;o1P02o`D0
0_lB00;o1P02o`T00_lK00;o2002o`L00_lC00;o1@02o`P00_l:00;o1@02o`D00_l600;o4P02o`L0
0_l400?o1002o`D01?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`h00_l600;o400001<0
0_lA00;o1@02o`H00_l:00;o5@02o`<00_l200;o1002o`800_l200;o1@02o`H00_l400;o1@02o`H0
0_l500;o0`02o`T00_l300;o1002o`L00_l400;o4`02o`H00_l900;o6`02o`P00_l700;o4`02o`@0
0_l900;o2P02o`@00_l600;o0P02o`800_lB00_o1@03o`<00_l500Co0P04o`D00_l200;o0P02o`@0
2ol300;o1`02o`@00_l200;o2P02o`H00_l@00004`02oa400_l500;o1P02o`X00_lE00;o0P03o`80
0_l400;o0P02o`T00_l600;o1002o`D00_l600;o1@02o`<00_l900;o0`03o`800ol700;o0`03oa<0
0_l600;o2@02oa/00_l@00?o4`03o`800ol900;o2P03o`800ol600;o0P02oaL02Ol700;o0`02o`D0
0_l0103o0004o`D00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<00_lA00;o1P02o`@0
0_l;00;o5@02o`8000?o0?l00P02o`@01_l900;o1P02o`@00_l500;o1P02o`D00_l300;o2@02o`<0
1ol800Oo7002o`T00_lK00;o2`07oa@01ol:00;o2P07o`L01_lG00;o1@02o`L00ol900;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o2P02o`@00_l800Oo2`02oaD00_l0103o
o`02o`030?oo00@01_l900;o1P02o`@02Ol600Wo0`02o`T00_l300Go2P09oaX00_l900;o6`02o`T0
1olF00Go3002o`X01Ol900Ko6002o`<00_l900?o2002o`030?oo00;o00<0ool01@06o`X00_l300;o
1P07o`L01_l:00;o600001@00_l900So2006o`/00_lF00;o00<0ool00P001?l0ool400;o0P02o`T0
0_l600;o1009o`H02Ol300;o2@02o`<00_l0103oool900;o1@03oaT00_l400;o0`02o`<00_lF00;o
2003oa/00_l0103oool;00;o2P02o`040?ooo`P00_l200;o6002o`<00_l500;o0`02o`P00_l00`3o
o`02o`030?oo00D00_l200;o2P02o`<00_l500?o3002o`800_l:00;o600001@00_l900Oo2002o`@0
0_l:00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o1@02o`H00_l400;o1@02o`H00_l500;o
0`02o`T00_l300;o0P03o`P00_l600;o6@02o`@00_l300;o0`02oaH00_l800;o1`000ol0000B00;o
0P03o`X00_l:00;o0P03o`L00_l200;o0P02oaD00_l0103oool500;o0`03o`H00_l300;o0`02o`@0
0_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol800;o
3002o`H00_l900;o5P04o`<01?l400;o1P02o`D00_l600;o1002o`D00_l600;o1@02o`@00_l700;o
1002o`<00ol700;o1P02oaT00_l400;o0`02o`<00_lF00;o2002o`H00_lD00;o0`03o`T00_l:00;o
0`03o`H00_l600;o5@02o`030?oo00H00_l400?o1@02o`<00_l300;o1002o`H00_l700;o00<0ool0
1P02o`H00_l500;o1P02o`H00_lH00005@02o`P00_l<00;o1P02o`P00_lG00Co1003o`@00_l600;o
1@02o`H00_l400;o1@02o`H00_l500;o1003o`D00ol400;o1003o`H00_l500?o6@02o`@00_l300;o
0`02oaH00_l800?o1003oa@00_l400?o2002o`X00_l400?o1@02o`H00_lE00Go1P02o`D00_l500;o
2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l700;o3003o`@00ol700;o
5`04o`D01?l00`3oo`0:o`@01?l400Co0P04o`<01?l400Co0`04o`@02Ol300Go0`05o`802olE00[o
00<0ool02_lB00[o1@09oa801Ol300Go0P0:o`@01Ol300Go00<0ool02_lB00Oo1`0:o`<01_l200Ko
00<0ool02_l400Oo2009o`<03?l300So5@0001L000?o00001@08o`L02?l80003o`0001H01?l500Co
00<0ool02_l400Co1004o`801?l300Co1004o`<01?l600Go1@05o`<01Ol200Wo5`0:o`030?oo00[o
4P0:o`L01Ol00`3o000A00Go0`05o`802_l400Go0`05o`030?oo00[o4P07o`L02_l300Ko0P06o`03
0?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000O00So2006ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(59\\) LEUHHOKS IT IS KIKE A WDASFM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2005o`h00_lE00go00<0ool02_l800Co1P04o`<0
1?l400Co0`04o`H01Ol500Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`@00_l00`3oo`03oa@0
1Ol600;o0P0:o`@01Ol600;o00<0ool02_l@00Ko0`06oa400_l400;o1@08o`D01_l300Ko00@0ool0
1Ol500Oo2005o`<01Ol@00004`02o`T02Ol600Oo3@02oa@03Ol00`3oo`0:o`H02?l400Co0`04o`@0
1?l300Co1009o`<01Ol500?o0`0:oa<02_l500So500:o`@02_lB00Go1@03o`802_l400Go1@03o`03
0?oo00[o4006o`<01_lA00;o1002o`D02_l300Ko0`06o`030?oo00So0`07o`P01Ol300Go400001<0
0_l900;o1@02o`/00ol<00;o5`02o`H00_l300;o1P02o`H00_l400;o1@02o`D00_l600;o1@02o`@0
0ol500?o1002o`D00ol400?o1@03oaH00_l<00;o6`02o`P00ol500?o4`02o`D00ol700;o2P02o`D0
0ol400;o1P02oa800_l700;o4P03o`@00ol500;o1004o`@00_l700;o0`03o`D00ol400;o3002o`L0
0_lA00004`02oa400_l;00?o2`02oaL00_l600;o0`02o`H00_l500;o1P02o`@00_l500;o1P02o`D0
0_l400;o1`02o`@00_l500;o1@02o`L00_lF00;o3002oa/00_l800;o1`02oa<00_l500;o2002o`X0
0_l500;o1@02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o``0
0_l700;o4@0001<00_lA00;o3002o`/00_lG00;o1P02o`<00_l200;o0P02o`D00_l600;o1002o`D0
0_l600;o1@02o`<00_l900;o0`02o`@00_l600;o1`02oaH00_l<00;o6`02o`P00_l700;o4`02o`@0
0_l900;o2P02o`@00_l600;o0P02o`800_lB00_o4P04o`801?l500;o1`02o`<02ol300;o1`02o`@0
0_l200;o2002o`<00_l200;o4@0001<00_lA00;o2004o`030?oo00X00_lG00;o1P02o`<00_l200;o
2@02o`H00_l400;o1@02o`H00_l500;o0`02o`T00_l300?o0P03o`h00olF00;o3002oa/00_l@00?o
4`03o`800ol900;o2P03o`800ol600;o0P02oaL02OlC00;o00@0o`001?l500;o1`02o`@02Ol<00?o
1002o`800_l800;o0P03o`800_lA00004`02oa400_l600Wo2P02oaL00_l;00Ko2@02o`H00_l400;o
1@02o`H00_l500;o0`02o`T00_l300Oo2P07oaL00_l<00;o6`02o`/01olD00Oo2P02o`X01ol700Ko
5`02o`D00_lC00;o00H0o`00o`02o`D00_l700;o1002o`D00_l700Oo1@06o`P00_l20003o`3o0080
0_lA00004`02o`X00_l400;o1`02o`@00ol:00;o5`02o`/01_l900;o1P02o`@02Ol600Wo0`02o`T0
0_l300Go2P07oaT00_l<00;o6`02o`T01olF00Go3002o`X01Ol900Ko6002o`<00_lD00;o00<0ool0
0_l00`3oo`0500;o1`02o`D00_l300;o1P07o`L01_l800;o00@0ool00_l00`3oo`0A00005002o`T0
2?l600;o1P02o`T00_lH00;o2`02o`800_l900;o1P02o`@02Ol600Wo0`02o`T00_l300;o00@0oooo
2003oah00_l700;o0`02o`<00_lF00;o2003oa/00_l0103oool;00;o2P02o`040?ooo`P00_l200;o
6002o`<00_lD00;o00<0ool00_l00`3oo`0500;o1`02o`D00_l300;o1@03o``00_l200;o2002o`03
0?oo008000Co0?oo4@0001@00_l900Oo1`02o`H00_l900;o6002o`/00_l200;o0P02o`D00_l600;o
1002o`D00_l600;o1@02o`<00_l900;o0`02o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`P00_l70003o`0001800_l200?o2P02o`X00_l200?o1`02o`800_l200;o5@02o`040?oooa<0
0_l300;o0`02o`@00_l700;o1P02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`@00_l00`3o
00020004o`3ooa40000D00?o2002o``00_l600;o2@02oaP00_l;00;o1P02o`D00_l600;o1002o`D0
0_l600;o1@02o`@00_l700;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H0
0_lD00;o0`03o`T00_l:00;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o
1`02o`030?oo00H00_l600;o1@02o`H00_l400Co0`04oa40000E00;o2002o``00_l60003o`0000L0
0_lI00;o2`02o`H00_l500;o1P02o`@00_l500;o1P02o`D00_l400?o1@03o`@00_l400?o1@03o`@0
0olG00;o1`02o`<00_l300;o5P02o`P00ol400?o5002o`@00ol800;o2P02o`@00ol500;o1P02oaD0
1OlD00;o2002o`@00_l400Co1`05o`H00ol400?o1@02o`H00_l400Co1003oa40000F00;o1`02o`d0
0_l400;o2002oaL02?l600co1004o`@01?l200Co0`04o`@01?l300Co1009o`<01Ol300Go1009oa<0
2_l300co4P0:o`D02OlB00Go0`05o`802_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko0P0:o`D0
1ol800Wo0`0<o`<01?l500Co400001L000?o00001@08o`L01ol90003o`0001H02?l600co1004o`@0
1?l200Co0`04o`@01?l300Co1P05o`D01Ol300Go1P05o`030?l001802_l300co4P0:o`L01Ol00`3o
000A00Go0`05o`802_l400Go0`05o`030?oo00[o4P07oa@01_l200Ko0P08o`L01ol:00Go00<0o`00
0P0<o`<01?l500Co400001l02?l900Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(60\\) LDTHHOKS IT IS LIKEZB WDASFM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00go0P08o`P02?l500Co0`04o`@0
1?l300Co1P05o`D01Ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o1002o`030?oo00?o500=o`80
2_l400Go1P02o`030?oo00[o100:o`<02_lE00;o1002o`D02?l500Ko0`06o`040?oo00Go1@07o`P0
1Ol300Go400001<00_l;00Oo2006o``00_lD00go0P0:o`H02?l500Co0`04o`@01?l300Co1009o`<0
1Ol500?o0`0:oa<02_l500So500:o`@02_lB00go0P0:o`@01Ol500?o00<0ool02_l400[o0`0;oa@0
0_l400;o1@0:o`<01_l300Ko00<0ool02?l300Oo2005o`<01Ol@00004`02o`X00_l400;o1`03o`80
0ol;00;o5`02o`H00_l300;o1004o`P00_l900;o1@02o`H00_l500;o1003o`D00ol400;o1@03o`@0
0ol500?o5P02o``00_lK00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o1@02o`D0
0_l500;o1@03oa800ol400?o1@02o`@01?l400;o1`02o`<00ol500?o1002o``00_l700;o4@0001<0
0_l900;o1P02o`H00_l400;o2`02oaL00_l600;o0`02o`H00_l800;o2@02o`D00_l600;o1@02o`@0
0_l700;o1002o`D00_l500;o1`02oaH00_l<00;o6`02o`P00_l700;o5002o`H00_l600;o2P02o`D0
0_l500;o1P02o`D00ol400;o1@02o`H00_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@0
0_l<00;o1`02oa40000C00;o2@02o`H00_l500;o1P02o`X00_lG00;o1P02o`<00_l700;o1`02o`T0
0_l500;o1P02o`D00_l300;o2@02o`<00_l400;o1P02o`L00_lF00;o3002oa/00_l800;o1`02oa@0
0_l600;o1P02o`X00_l400;o1P02o`800_l200;o1P03o`<00_l500;o1P02oa801?l200Co1@02o`L0
0_l300_o0`02o`L00_l400;o0P02o`P00_l300;o0P02oa40000C00;o2@02o`H00_l500;o1P02o`X0
0_lG00;o1P02o`<00_l700;o1`02o`T00_l500;o1P02o`D00_l300;o2@02o`<00ol200?o3P03oaH0
0_l<00;o6`02oa000olD00;o1P02o`H00_l:00?o0P03o`H00_l200;o2`02o`<00_l500;o1P02oa80
0_l0103o0004o`D00_l700;o1009o``00ol400;o0P02o`P00_l200?o0P02oa40000C00;o2@02o`H0
0_l500;o1P02o`X00_lG00;o2`02o`L00_l700;o2@02o`D00_l600;o1@02o`<00_l900;o0`07o`X0
1olG00;o3002oa/00_l;00Oo5@02o`h00_l:00Oo1`06o`/00ol900;o1@03oa800_l01P3o003o00;o
1@02o`L00_l400;o1@02o`L01ol500Ko2002o`8000?o0?l00P02oa40000C00;o2@03o`@00_l600;o
1P02o`X00_lG00;o2`02o`L00_l700;o2@09o`H02Ol300;o2@02o`<01Ol:00Oo6@02o``00_lK00;o
2@07oaL00_l>00;o2P05o`T01_l<00?o2009oa<00_l00`3oo`02o`030?oo00D00_l700;o1@02o`<0
0_l600Oo1`06o`P00_l0103oo`02o`030?oo0140000D00;o2009o`H00_l600;o2@02oaP00_l;00;o
1`02o`800_l300;o0`02o`@02Ol600Wo0`02o`T00_l300;o00@0oooo2003oah00_l700;o0`02o`<0
0_lF00;o2003oa`00_l>00;o2P02o`040?ooo`P00_l200;o2002o`<00_l800So5002o`030?oo00;o
00<0ool01@02o`L00_l500;o0`02o`D00ol<00;o0P02o`P00_l00`3oo`020004o`3ooa40000D00;o
2002o`030?oo00;o2002o`H00_l900;o6002o`/00_l700;o0P02o`<00_l300;o1002o`D00_l600;o
1@02o`<00_l900;o0`02o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`P00_l70003
o`0001<00_l>00;o2P02o`800ol700;o0P02o`800_l400;o0`03o`L00_l400?o4P02o`<00_l300;o
1002o`L00_l600;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1002o`030?l0008000Co0?oo
4@0001@00ol800;o3002o`H00_l900;o6002o`/00_l600;o0`02o`<00_l300;o1002o`D00_l600;o
1@02o`@00_l700;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lF00;o2002o`H00_lE00;o
3P02o`X00_l300?o1P02o`H00_l400;o1003o`H00_l500;o4P02o`<00_l300;o1002o`H00_l700;o
00<0ool01P02o`H00_l500;o1P02o`@01?l300Co4@0001D00_l800?o3002o`@00_l900;o6@02o`/0
0_l400Co0`02o`<00_l300;o1002o`D00_l600;o1@02o`@00ol500?o1002o`@00ol500?o1003oaL0
0_l700;o0`02o`<00_lF00;o2003o`@00olE00;o3P02o`X00_l400?o1@02o`H00_l400;o1@02o`H0
0_l400?o4P02o`P00_l400;o1004o`L01Ol600?o1003o`D00_l600;o1004o`@00olA00005P02o`P0
0ol;00?o0P03o`P00_lG00So1`0:o`@03?l300Co0`04o`@01?l300Co1009o`<01Ol300Go1009oa<0
2_l300co4P0:o`D02OlB00So1`0:o`@01Ol300Go00<0ool02_l400[o0`0:oa801_l200Ko0P0:o`D0
1ol800Wo0`0<o`<01?l500Co400001L000?o00001`07o`L01_l90003o`0001H02?l700So1P0<o`<0
1?l300Co1004o`<01?l600Go1@05o`<01Ol600Go00<0o`004P0:o`<03?lB00[o1`05o`030?l00140
2?l700[o1005o`<01Ol00`3oo`0:o`@02_l300Wo4`06o`801_l200So1`07o`X01Ol00`3o000200co
0`04o`D01?l@00008`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(61\\) MDTGHOKS IT IR LILD A WDASFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00Go0`05o`802?l800So2006o`H0
1?l300Co1P05o`D01Ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o0`05o`H00ol?00go0P0:o`@0
3Ol200So4`06o`<01_lA00;o1002o`D02?l500Ko0`06o`040?oo00Go1@07o`P03Ol@00004`02o`/0
1ol700Wo2P02oa@01Ol300Go0P0:o`H02?l600[o1004o`<01?l400Wo0`05o`D00ol300[o4`0:o`D0
2?lD00[o0`05o`D01?l?00go0P0:o`@03Ol200[o4@06o`<01_lA00;o1002o`D02_l300Ko0`06o`03
0?oo00So0`07o`P03Ol@00004`02o`X00_l400;o2`02o`d00_lE00;o1`02o`@00_l400Co2002o`P0
1?l500;o1@02o`D00_l400?o1@03o`@00_l500?o1003o`D00olF00;o3002oa/00_l900;o1@03oa@0
0_l600;o1P02o`/00_l600;o0`02o`@01?lB00;o1`02oa800ol400?o1@02o`@01?l400;o1`02o`<0
0ol500?o1002o`h00_l600;o400001<00_l900;o1P02o`X00_l=00;o5@02o`L00_l400;o1P02o`P0
0_l800;o1`02o`D00_l500;o1002o`L00_l400;o1@02o`D00_l700;o5P02o``00_lK00;o2@02o`D0
0_lE00;o1P02o`H00_l;00;o1P02o`<00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l>00;o1P02oa00000C00;o2@02o`H00_l:00;o3@02oaD00_l300;o0P02o`@0
0_l700;o1`02o`L00ol700;o1@02o`D00_l300;o2@02o`<00_l400;o1P02o`L00_lF00;o3002oa/0
0_l900;o1002oaH00_l600;o1P02o`/00_l600;o0`02o`L00_lA00_o4P04o`801?l500;o1`02o`<0
2ol300;o1`02o`@00_l200;o2P02o`H00_l@00004`02o`T00_l600;o2P02o`d00_lE00;o0P03o`80
0_l400;o1`02o`L00_l700;o1007o`@00_l500;o0`02o`T00_l300?o0P03o`h00olF00;o3002oa/0
0_l900;o0`03oaH00_l600;o1P02o`/00_l600;o0`02o`L00_lB00Wo4`02o`040?l000Co1@02o`L0
0_l400Wo3003o`@00_l200;o2P02o`H00_l@00004`02o`T00_l600;o2P02o`d00_lE00;o0P000ol0
o`0200;o1002o`L00_l700;o1`02o`@01ol400;o1@02o`<00_l900;o0`07o`X01olG00;o3002oa/0
0_l900Oo5`02o`h00_l;00;o2`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@02o`L00_l400;o
1@02o`L01ol500Ko2P02oaP0000C00;o2@03o`@00_l;00;o3@02oaD00_l0103oo`02o`030?oo00@0
0_l700;o1`02o`L00_l?00Wo0`02o`T00_l300Go2P07oaT00_l<00;o6`02o`T02OlE00;o3P02o`/0
0_l;00;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`L00_l500;o0`02o`H01ol700Ko
2P02oaP0000D00;o2009o`/00_l<00;o5P02o`030?oo008000Co0?oo1002o`L00_l200;o0`02o`<0
0_l200;o3`09o`<00_l900;o0`02o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`T00_l500?o
5002o`h00_l;00;o2`02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l700;o1@02o`<0
0_l500?o3002o`800_l:00;o600001@00_l800;o00<0ool00_l=00;o3002oaH00_l00`3o00020004
o`3oo`@00_l700;o0P02o`<00_l300;o0P02o`P00_l500;o1@02o`<00_l900;o0`02o`800ol700;o
1`000ol0000E00;o1`02o`<00_l300;o5P02o`T00_l600;o5002o`h00_l;00;o2`02o`L00_lD00;o
00@0oooo4`02o`<00_l300;o1002o`L00_l600;o00@0oooo1@02o`L000?o00000`02o`800_l200;o
1P02oaP0000D00?o2002oa400_l<00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`<00_l600?o
1@02o`D00_l400;o1`02o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`T00_l600;o
5002o`h00_l;00;o2`02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool0
1P02o`H00_l500;o1P02o`H00_lH00005@02o`P00ol@00;o2`02oaL01?l400?o1002o`@01?l300;o
0`02o`<00_l300?o1004o`D00_l500;o1003o`D00ol400;o1003o`D00ol400?o5`02o`L00_l300;o
0`02oaH00_l900;o1@03oa@00_l>00;o2`02o`/00_l400Co5@05oa@00_l800;o1002o`@01?l700Go
1P03o`@00ol500;o1P02o`H00_lH00005P02o`P00ol;00?o00<0ool02P02oaL01?l500Co0P0:o`@0
3?l400[o1004o`<01?l400Wo0`05o`<01Ol400Wo4`0:o`<03?lB00[o0`0;oa802?l700[o1008o`L0
2_lC00Oo5006o`801_l200[o1@07o`P02Ol300co0`08oaD0000G0003o`0000L01ol600Ko2P000ol0
000F00Co1@04o`802?l600co1P05o`030?oo00@01?l300Co1P05o`D01Ol300Go1P05o`030?l00180
2_l300co4P0:o`<02OlD00So1`0:o`@02?l700So5@07oa@01_l200Ko0P08o`L01ol:00Go00<0o`00
0P0<o`<02?lE00008`05o`T00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(62\\) METGHOKR HT IR LJKD A WDASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00Go0`05o`030?oo00[o1@08o`P0
1_l600Co0`04o`H01Ol500Go1P02o`801Ol600?o4004o`<01?l400So500:o`<01Ol600?o3`0=o`<0
1_l700Go1P02o`802?lC00Ko0`06oa400_l400;o1@08o`D01_l300Ko00@0ool01Ol500co0`0=oa00
000C00;o2`07o`H02_l:00;o5005o`<01Ol00`3oo`0:o`D02?l600[o1004o`<01?l400Wo0`05o`D0
0ol200Go1@04oa001?l300Co1008oa@02_l300Go1@04o`l03Ol00`3oo`07o`H01Ol500?o0P0:oa40
1_l300Ko4@02o`@00_l500[o0`06o`<01_l00`3oo`08o`<03?l300go400001<00_l:00;o1002o`L0
0_l500;o2P02oaD00_l700;o1002o`H00_l800;o2004o`D00_l500;o1@02o`@00ol500?o1002o`D0
0ol500;o1@03oa<00_l500;o2002oa/00_l900;o1@03oa@00_l600;o00@0oooo1003o`L00_l500?o
1002o`@01?lB00;o1`02oa800ol400?o1@02o`@01?l400;o1`02o`<00ol500?o1002o`H00_l600;o
1P02oa00000C00;o2@02o`H00_l700?o3`02oaD00_l700;o1002o`H00_l800;o2002o`L00_l500;o
1@02o`@00_l700;o1002o`D00_l600;o1@02oa@00_l500;o2002oa/00_l900;o1@02oaD00_l600;o
00<0ool01P02o`L00_l500;o1@02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`<0
0_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l800?o3P02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l700?o1`02o`D00_l500;o0`02o`T00_l300;o1002o`L00_l400;o5@02o`D0
0_l800;o6`02o`T00_l400;o5P02o`H00_l00`3oo`0600;o1`02o`@00_l600;o1`02oa402olB00Co
0P04o`D00_l700;o0`0;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T00_l600;o
2@03o`d00_lE00;o0P03o`800_l400;o0P02o``00_l700;o1007o`@00_l500;o0`02o`T00_l300?o
0P03o`L00_l300?o5@02o`D00_l800;o6`02o`T00_l300?o5P02o`H00_l00`3oo`0600;o1`03o`80
0ol600;o1`02oa802OlC00;o00@0o`001?l500;o1`02o`@02Ol<00?o1002o`800_l:00;o1P02oa00
000C00;o2@02o`H00_l:00?o3002oaD00_l20003o`3o00800_l400Ko3002o`L00_l400Oo1002o`D0
0_l300;o2@02o`<01ol800Oo5P02o`D00_l800;o6`02o`T01olG00;o4@02o`L01ol700;o1`02oa80
0_l500;o4`02o`060?l00?l00_l500;o1`02o`@00_l500;o1`07o`D01_l:00;o600001<00_l900?o
1002o``00ol;00;o5@02o`040?oo00;o00<0ool01006o``00_l700;o3`09o`<00_l900;o0`05o`X0
2OlD00Wo2002oa/00_l900Wo5@02oa400_l700Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`03
0?oo00D00_l700;o1@02o`<00_l600Oo1`06o`X00_lH00005002o`P02Ol=00;o2P02oaH00_l00`3o
o`020004o`3oo`@00_l200;o1`02o`<00_l300;o0P02o`l02Ol300;o2@02o`<00_l0103oool900;o
1@03oa<02Ol300;o0`02o`<00_lF00;o2@02o`D00olD00;o4@02o`L00_l0103oool800;o1`02oa<0
0_l300;o5002o`030?oo00;o00<0ool01@02o`L00_l500;o0`02o`D00ol<00;o0P02o`X00_lH0000
5002o`P00_l00`3oo`02oa000_l900;o5P02o`030?l0008000Co0?oo1002o`800_l200;o0`02o`<0
0_l300;o0P02o`P00_l500;o1@02o`<00_l900;o0`02o`800ol800;o1P02oa<00_l500;o0`02o`<0
0_l300;o5P02o`T00_l600;o5002oa400_l700;o0P03o`L00_l700;o5002o`040?oooa<00_l300;o
0`02o`@00_l700;o1P02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`P0
0_lD00;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l300;o1P03o`D00_l500;o1002o`L0
0_l400;o0`03o`L00_l600;o4`02o`D00_l300;o0`02o`<00_lF00;o2@02o`H00_lD00;o4@02o`L0
0_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H0
0_l500;o1P02o`H00_lH00005@02o`P00ol<00;o1@02o`P00_lG00Co1003o`@00_l600;o0`02o`<0
0_l300;o0`03o`@01?l500;o1@02o`@00ol500?o1002o`@00ol600;o1@03oa<00_l500;o0`02o`<0
0_l300;o5P02o`T00_l500?o5002oa400_l700;o1003o`D00_l400Co5@05oa@00_l800;o1002o`@0
1?l700Go1P03o`@00ol500;o1P02o`H00_lH00005P02o`P00ol;00?o0`03o`L00_lG00Co1@04o`03
0?oo00[o0`0<o`@02_l400Co0`04o`@02Ol300Go0`05o`802olC00Co0`04o`803?lB00[o0`0;oa80
2?l900[o0P05o`<01Ol200[o4`07oa@01_l200Ko0P0:o`D01ol800Wo0`0<o`<02?lE00005`000ol0
000700Oo1`07o`P000?o00005P04o`D01?l00`3oo`0:o`<03?l600Go00<0ool01004o`<01?l600Go
1@05o`<01Ol200Wo5@04o`<01?l200co4P0:o`<02OlD00So2@0:o`801Ol300Go0P08oaD01olD00Ko
0P06o`802?l700Oo2P05o`030?l000803?l300So5@0002<01Ol800Goo`350000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(63\\) MESHHNKR IT JS LJKD A WDASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00[o1002o`03
0?oo00?o1P04o`<01?l400Co0`04o`<01_l300;o0P05o`H00_l200Go1P03oa002_l500So5@06o`L0
0_l00`3oo`03oa@03Ol300Ko1`05o`H00_l200So4`06o`<01_lA00;o1002o`D02?l500Ko0`06o`04
0?oo00Go1@0<o`<03Ol@00004`02o`/01ol600Wo2`02oa@01Ol300Go00<0ool02_l400[o1004o`<0
1?l400Co0`04o`<01_l200?o0P05o`D00ol200Go1@04oa002_l500So4`09o`H02_lB00go00<0ool0
1ol600Go1@03o`802_lA00Ko0`06oa400_l400;o1@0:o`<01_l300Ko00<0ool02?l300co0`0=oa00
000C00;o2P02o`@00_l600;o1@02o`/00_lE00;o1`02o`@00_l600;o1003o`D00ol400;o1@02o`H0
0_l500;o1@02o`@01?l400;o1@03o`D00_l500?o5P02o``00_lF00?o1003o`D00ol500?o5002o`H0
0_l0103oool400?o1`02o`D00ol400;o1004oa800_l700;o4P03o`@00ol500;o1004o`@00_l700;o
0`03o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`d00_l:00;o5@02o`L00_l400;o
1P02o`@00_l700;o1002o`D00_l600;o1@02o`D00_l400Co1002o`D00_l600;o1@02oaL00_l<00;o
5P02o`H00_l500;o1`02oa@00_l600;o00<0ool01P02o`L00_l500;o1@02o`H00_lB00;o1`02oa80
1?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H0
0_l=00;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`@00_l700;o1002o`D00_l600;o1@02o`D0
0_l300Go1002o`@00_l700;o1002oaP00_l<00;o5P02o`H00_l500;o1`02oa@00_l600;o00<0ool0
1P02o`L00_l400;o1P02o`L00_lA00_o4P04o`801?l500;o1`02o`<02ol300;o1`02o`@00_l200;o
0P02o`H00_l600;o400001<00_l900;o1P02o`d00_l:00;o5@02o`800ol200;o1002o`800_l@00?o
1002o`D00_l600;o1@02o`D00_l300;o00<0ool01003o`800ol700;o0`03oaP00_l<00;o5P02o`H0
0_l=00?o5002o`H00_l00`3oo`0600;o1`03o`800ol600;o1`02oa802OlC00;o00@0o`001?l500;o
1`02o`@02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2@02o`H00_l<00;o2`02oaD00_l20003
o`3o00800_l400Ko2`07o`D00_l500;o1P02o`D00_l500;o0P03o`030?oo00@01ol800Oo6@02o``0
0_lN00;o2007oaD00_lA00;o1`07o`L00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D00_l700;o
1002o`D00_l700Oo1@06o`X00_lH00004`02o`T00ol400;o2P04o``00_lE00;o00@0ool00_l00`3o
o`0400Ko2@07o`L02Ol600Wo1@02o`800_l200;o1005o`X02OlG00;o3002oah00_l600Oo5`02oa40
0_l700Go2@02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l700;o1@02o`<00_l600Oo
1`06o`X00_lH00005002o`P02Ol:00?o3002oaH00_l00`3oo`020004o`3oo`@00_l200;o2003o``0
2Ol600Wo1@02o`030?oo00<00_l400;o00@0oooo2@02o`D00olF00;o1`02o`<00_l300;o6@02o`D0
0olL00;o4@02o`L00_l0103oool800;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`L0
0_l500;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`P00_l00`3oo`02o`h00_l;00;o5P02o`03
0?l0008000Co0?oo1002o`800_l200;o1002o`L000?o00000`02o`D00_l600;o1@02o`D01Ol300;o
1002o`800ol800;o1P02oaH00_l700;o0`02o`<00_lI00;o1@02o`L000?o00004`02oa400_l700;o
0P03o`L00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l700;o1P02o`040?ooo`D00_l70003
o`0000<00_l200;o0P02o`H00_lH00005003o`P00_lC00;o2P02oaH01?l300Co1002o`H00_l400;o
1P02o`D00_l500;o1P02o`D00_l500Co1002o`@00_l300?o1`02o`H00_lF00;o1`02o`<00_l300;o
6@02o`D00_l600;o5@02oa400_l700;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@0
0_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D00_l800?o4P02o`T00_lG00Co
1003o`@00_l600;o1003o`@00ol500;o1@02o`H00_l500;o1@04o`@00_l400;o1003o`H00_l500?o
5P02o`L00_l300;o0`02oaT00_l500?o1003oaD00_lA00;o1`02o`@00ol500;o1004oaD01OlD00;o
2002o`@00_l400Co1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l800?o2`02o`<00ol800;o
5`04o`D01?l00`3oo`0:o`D02Ol400Co0`04o`@01?l300Co0`04o`801_l00`3oo`03o`<01Ol200_o
4`0:o`<03?lD00[o0`09oa802?l900[o0P05o`<01Ol200[o4`07oa@01_l200Ko0P0:o`D01ol800Wo
0`0<o`<02?lE00005`000ol0000700Oo1P07o`T000?o00005P04o`D01?l00`3oo`0:o`L01Ol00`3o
000300Co0`04o`@01?l300Co0`03o`<01_l00`3oo`03o`<01Ol200Wo5@0:o`<03?lD00[o1@05o`03
0?l001402?l900[o0P05o`<01Ol200So5@07oa@01_l200Ko0P08o`L01ol:00Go00<0o`000P0<o`<0
2?lE00008`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(64\\) NETHHOKR IT IS LJKD AZWEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co3006o`T00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400Co0`04o`H01Ol500Go1P02o`801Ol600?o400:o`D02?lD00[o1002o`030?oo00?o500=o`<0
1_l700Go1P02o`802?lC00Ko0`06o`030?oo00So1P02o`@00_l400co0P06o`<01_l0103oo`05o`H0
2?l600go400001<00_l;00Oo2P06o`X00_lE00Ko0P03o`803?l500So1@04o`<01?l400Co0`04o`@0
2Ol300Go1@03o`801Ol500Co400:o`D02?lD00[o100:oa803Ol00`3oo`07o`H01Ol500?o0P0:oa40
1_l300Ko00<0ool02?l600;o1002o`@03?l200Ko0`06o`030?oo00So100:o`@03Ol@00004`02o`X0
0_l400;o3002o``00_lF00;o1004o`@00_l600;o2002o`T00_l500;o1P02o`D00_l400?o1@03o`@0
0_l500?o1@02o`D00olF00;o3002oa/00_l800?o1@03oa@00_l600;o00@0oooo1003o`L00_l500?o
1002o`@01?lB00;o1`02o`@00_l500;o1@03o`@00ol500;o1P02o`@00_l700;o0`03o`D00ol400;o
1004o`H00_l600;o400001<00_l900;o1P02o`/00_l<00;o5P02o`@01?l400;o1P02o`P00_l900;o
1@02o`H00_l500;o1002o`L00_l400;o1@02o`H00_l500;o5`02o``00_lK00;o2002o`L00_lD00;o
1P02o`030?oo00H00_l700;o1@02o`D00_l600;o4P02o`L00_l400?o1002o`D01?l300?o1@02o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l500[o2P02oaH0
0_l300Go1002o`800_l200;o2002o`T00_l500;o1P02o`D00_l300;o2@02o`<00_l400;o1`02o`@0
0_lH00;o3002oa/00_l800;o1`02oa@00_l600;o00<0ool01P02o`L00_l400;o1P02o`L00_lA00_o
1@03o`<00_l500Co0P04o`D00_l200;o0P02o`@02ol300;o1`02o`@00_l700;o1@02o`H00_l@0000
4`02o`T00_l600;o1@0:o`X00_lF00;o0`02o`030?oo00@00_l200;o3002o`T00_l500;o1P02o`D0
0_l300;o2@02o`<00ol200?o1`02o`<00olH00;o3002oa/00_l@00?o5002o`H00_l00`3oo`0600;o
1`03o`800ol600;o1`02oa802Ol700;o0`02o`D00_l0103o0004o`D00_l200;o2@09o``00ol400;o
1`02o`D00_l600;o400001<00_l900;o1P02o`D00_l400;o3002oaH00_l200?o00<0ool01006o``0
0_l900;o1@02o`H00_l500;o0`02o`T00_l300Oo2007oaT00_l<00;o6`02o`/01olE00;o4@02o`L0
1ol700;o1`02oa800_l500;o1`03o`T00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D00_l700;o
1@02oaP0000C00;o2@03o`@00_l700;o0`02o``00_lF00;o0P02o`800_l400Ko3002o`T02Ol600Wo
0`02o`T00_l300Go2P09oaL00_l<00;o6`02o`T01olG00;o4@02o`L01Ol900;o1`02oa<00_l300;o
2@03o`P00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700;o1`02o`D00_lH00005002o`P0
2Ol80004o`0000;o2`02oaL00_l00`3oo`0300;o1002o`800_l700;o0`02o`<00_l400Wo1P09o`<0
0_l900;o0`02o`040?ooo`T00_l500?o5P02o`L00_l300;o0`02oaH00_l800?o7002oa400_l700;o
00@0oooo2002o`L00_lC00;o0`02o`D00_l300;o2002o`030?oo00;o00<0ool01@02o`800_l:00;o
0`02o`D00ol<00;o1`02o`D00_lH00005002o`P00_l00`3oo`02o`X00_l200;o2`02oaL01Ol300;o
1002o`800_l200;o0`02o`<00_l300;o1002o`D00_l600;o1@02o`<00_l900;o0`02o`800ol800;o
1P02oaH00_l700;o0`02o`<00_lF00;o2002o`L000?o00004`02oa400_l700;o0P03o`L00_l700;o
5002o`040?ooo`D00_l300?o1P02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003
o`0000<00_l700;o1@02oaP0000D00?o2002o`l000?o00000_l;00;o5`04o`@00_l400;o1P02o`<0
0_l300;o0`02o`@00_l500;o1P02o`D00_l400;o1`02o`@00_l300?o1`02o`H00_lF00;o1`02o`<0
0_l300;o5P02o`P00_l600;o5@02oa400_l700;o0`03o`H00_l600;o5@02o`030?oo00H00_l400?o
1@02o`<00_l300;o1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`P0
0ol?0004o`3oo`X00_lH00Co1002o`@00_l600;o0`02o`<00_l300;o1002o`D00_l600;o1@02o`@0
0ol500?o1002o`@00ol600;o1@03oaH00_l700;o0`02o`<00_lF00;o2003o`@00olE00;o4@02o`L0
0_l400?o1@02o`@01?lE00Go1P02o`D00_l500;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`@0
1?l600;o600001H00_l800?o3P04o`T00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co1004o`<0
1?l400Wo0`05o`<01Ol200_o4`0:o`<03?lB00[o1@09oa802?l900[o0P05o`<01Ol200[o4`07o`L0
2_l300Ko0P06o`030?oo00[o1007o`P02Ol400[o1008oaD0000G0003o`0000L01ol:00?o2@000ol0
000G00?o0`06o`030?oo00[o0`0<o`<01?l300Co1004o`<01?l600Go1@05o`<01Ol200Wo5@0:o`<0
3?lB00[o1`05o`030?l001402?l900[o0P05o`<01Ol200So5@07o`L02_l300Ko0P06o`030?oo00[o
1007o`X01Ol00`3o000300So1P08oaD0000S00Go2P03ool0a@000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(65\\) NETHIOKS IT IT KIKD AZWEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400[o1`05o`D01Ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o1@08oa<01Ol600;o0P0:o`@0
1Ol600;o0P08oa<01_l300Ko00<0ool02?l600;o1002o`@03?l200Ko0`06o`040?oo00Go1P08o`H0
3Ol@00004`02o`/01ol600Wo2`02oaD01_l200?o0P0<o`D02?l500Co0`04o`@02_l500Wo0`05o`D0
0ol300[o4`0:o`D02?lD00[o1@08oa<01Ol500?o0P0:o`@01Ol500?o0P0:oa401_l300Ko00<0ool0
2?l600;o1002o`@03?l200Ko0`06o`030?oo00So100:o`@03Ol@00004`02o`X00_l400;o1P02o`D0
0_l;00;o5P02o`@01?l400;o1P02o`P00_l900;o1@02o`T00_l800?o1@03o`@00_l500?o1003o`D0
0olF00;o3002oa/00_l<00;o6002o`D00ol700;o2P02o`D00ol400;o1004oa800_l700;o1002o`D0
0_l500?o1003o`D00_l600;o1002o`L00_l300?o1@03o`@00_l400Co1P02o`H00_l@00004`02o`T0
0_l600;o3@02o`X00_lF00;o1004o`@00_l600;o2002o`T00_l500;o2@02o`P00_l700;o1002o`D0
0_l500;o1`02oaH00_l<00;o6`02o``00_lH00;o1@02o`P00_l:00;o1@02o`D00_l600;o4P02o`L0
0_l400?o1002o`D01?l300?o1@02o`H00_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00
000C00;o2@02o`H00_l=00;o2P02oaH00_l300Go1002o`800_l200;o2002o`T00_l500;o2@02o`L0
0_l900;o0`02o`@00_l600;o1`02oaH00_l<00;o6`02o``00_lH00;o1002o`T00_l:00;o1002o`H0
0_l700;o4@0;o`D00ol300;o1@04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o1`02o`D0
0_l600;o400001<00_l900;o1P02o`d00_l:00;o5P02o`<00_l00`3oo`0400;o0P02o``00_l900;o
1@02o`T00_l700;o2@02o`<00ol200?o3P03oaH00_l<00;o6`02o``00_lH00?o0P03o`T00_l:00?o
0P03o`H00_l700;o4P09o`L00_l300;o1@02o`040?l000Co1@02o`800_l900Wo3003o`@00_l700;o
1@02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lF00;o0P03o`030?oo00@01_l<00;o2@02o`D0
0_l900;o1`02o`T00_l300Oo2P07oaL00_l<00;o6`02o``00_lH00Oo2P02o`X01ol700;o1`02oa80
0_l500;o1`03o`T00_l01P3o003o00;o1@06o`T00_l500;o1`07o`D00_l700;o1@02oaP0000C00;o
2@03o`@00_l700;o1002o`/00_lF00;o0P02o`800_l400Ko3002o`T02Ol900;o1`02o`T00_l300Go
2P07oaT00_l<00;o6`02o``00_lH00Go3002o`X01Ol900;o1`02oa<00_l300;o2@03o`P00_l00`3o
o`02o`030?oo00D01_l:00;o0`02o`H01ol700;o1`02o`D00_lH00005002o`P02Ol700So2P02oaL0
0_l00`3oo`0300;o1002o`800_l700;o0`02o`<00_l400Wo2@02o`L00_l900;o0`02o`040?ooo`P0
0olN00;o1`02o`<00_l300;o5P02o`L00_l300;o0`02oa<00_l0103oool;00;o2P02o`040?ooo`P0
0_l700;o4`02o`<00_l500;o0`02o`P00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l500?o
3002o`L00_l500;o600001@00_l800;o00<0ool00_l900Oo2`02oaL01Ol300;o1002o`800_l200;o
0`02o`<00_l300;o1002o`D00_l900;o1`02o`T00_l300;o0P03o`L00_l70003o`0001D00_l700;o
0`02o`<00_lF00;o1`02o`<00_l300;o4`02o`800ol:00;o2P02o`800ol700;o1`02oa@00_l0103o
ool500;o0`03o`H00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o
1`02o`D00_lH00005003o`P00_l=00;o4002oaL01?l400;o1002o`H00_l300;o0`02o`<00_l400;o
1@02o`T00_l800;o1`02o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`L00_l300;o
0`02oa<00_l300?o2@02o`X00_l300?o1P02o`H00_lE00;o00<0ool01P02o`@00ol500;o0`02o`<0
0_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2003o``00_l?00;o
6004o`@00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P00ol500?o1002o`@00ol500?o
1003oaL00_l700;o0`02o`<00_lF00;o1`02o`<00_l300;o4`02o`@00ol800;o2P02o`@00ol500;o
1004oaD01Ol600;o1@02o`D00_l800;o1002o`H00_l700Go1P03o`@00ol500;o1004o`H00_lH0000
5P02o`P00ol;00;o3P02oaP01?l200Ko00<0ool02_l300co0`04o`<01?l400[o1@09o`<01Ol300Go
1009oa<02_l300co4P0:o`<03?lA00Go0`05o`802_l400Go0`05o`802_lC00Oo1`0:o`<01_l200Ko
00<0ool02_l400Oo2009o`@02_l400So5@0001L000?o00001`07o`H02?l80003o`0001L00ol300Ko
00<0ool02_l300co0`04o`<01?l400[o1`05o`D01Ol300Go1P05o`030?l001802_l300co4P0:o`<0
3?lA00Go0`05o`802_l400Go0`05o`802?lE00Oo1`0:o`<01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000<02?l600So5@0002<01Ol600Soo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(66\\) METHIOKS IT IT KIJD A WEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`L01Ol500Go1P02o`<00_l00`3oo`03oaD02_l500So500:o`D02?lC00Go1P02o`80
2_l600Ko1`08oa<01_l300Ko4@02o`@00_l400co0P06o`<01_l0103oo`05o`H02?l600go400001<0
0_l;00Oo2007o`/00_lD00Go0`05o`030?oo00[o1@08o`D01?l300Co100:o`D02Ol300Go1@03o`<0
2_lC00[o1@08oa@02_l500So4`05o`D00ol200[o1009o`H02_lA00Ko0`06oa400_l400;o100<o`80
1_l300Ko00<0ool02?l400[o100=oa00000C00;o2P02o`@00_l700;o1002o`/00_lE00;o1`02o`@0
0_l600;o2002o`T00_l500;o2@02o`P00ol500?o1002o`D00ol400?o1@03oaH00_l<00;o6`02o``0
0_lH00;o1@03o`L00_l800?o1003o`H00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l400Co1P02o`H00_l@00004`02o`T00_l600;o1@02o`H00_l:00;o5@02o`L0
0_l400;o1P02o`P00_l900;o1@02o`T00_l800;o1`02o`@00_l500;o1@02o`L00_lF00;o3002oa/0
0_l<00;o6002o`D00_l800;o2002o`H00_l600;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@0
0_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l700;o2@02o`<00_l400;o1P02o`L0
0_lF00;o3002oa/00_l<00;o6002o`@00_l900;o2002o`H00_l600;o1`02oa402olB00Co0P04o`D0
0_l200;o0P02o`@02ol300;o1`02o`@00_l700;o1@02o`H00_l@00004`02o`T00_l600;o1@02o`H0
0_l:00;o5@02o`800ol200;o1002o`800_l<00;o2@02o`D00_l900;o1`02o`T00_l300?o0P03o`h0
0olF00;o3002oa/00_l<00;o6003o`800ol900;o2002o`H00_l600;o1`02oa802OlC00;o00@0o`00
1?l500;o0P02o`T02Ol<00?o1002o`L00_l500;o1P02oa00000C00;o2@02o`H00_l500;o1P02o`X0
0_lE00;o0P000ol0o`0200;o1006o``00_l900;o1@02o`T00_l700;o2@02o`<01ol:00Oo5`02o``0
0_lK00;o3002oaP01ol:00;o4002o`H00_l700;o4P02o`D00_lC00;o00H0o`00o`02o`D01_l900;o
1@02o`L01ol500;o1`02o`D00_lH00004`02o`T00ol400;o1P03o`@00_l;00;o5@02o`040?oo00;o
00<0ool01006o``00_l900Wo2@02o`L00_l900;o0`05o`X01olI00;o3002oa/00_l<00;o6005o``0
0_l@00;o1P02o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700;o
1`02o`D00_lH00005002o`P02Ol600Wo2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1009o`T00_l700;o2@02o`<00_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l700;o
0`02o`<00_lC00;o00@0oooo2`02oa000_l600;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@02o`800_l:00;o0`02o`D00ol<00;o1`02o`D00_lH00005002o`P00_l00`3oo`02o`P00_l00`3o
o`02o``00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`T0
0_l700;o2@02o`<00_l200?o1`02o`L000?o00005@02o`L00_l300;o0`02oaH00_l700;o0`02o`<0
0_lC00;o0P03o`X00_l@00;o1P02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1`02o`040?ooo`D00_l70003o`0000<00_l700;o1@02oaP0000D00?o2002o`d00_l@00;o5P04o`<0
1?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P00_l700;o1002o`<00ol600;o1P02oaL0
0_l700;o0`02o`<00_lF00;o1`02o`<00_l300;o4`02o`<00ol900;o4002o`H00_l600;o5@02o`03
0?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D0
0_l800?o3003o`h00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2003o`D0
0ol400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o1003o`P0
0_l@00;o1P02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l400Co1P02oaP0
000F00;o2003o``00ol<00;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@02_l500Wo0`05o`<0
1Ol400Wo4`0:o`<03?lB00[o0`0<oa401Ol300Go0P0:o`L02_l200[o4`07oa@01_l200Ko00<0ool0
2_l400Oo2009o`@02_l400So5@0001L000?o00001`07o`P01ol70003o`0001H01?l500Co00<0ool0
2_l300co0`04o`<01?l400[o1`05o`D01Ol300Go1P05o`030?l001802_l300co4P0:o`<03?lA00Go
0`05o`802_l700[o0P08oaD01olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000300So1P08oaD0
000S00Go2P05ool0``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(67\\) MDTHIOKS IT IT KIJD A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`02o`h00_lE00Go0`05o`802?l800So1@04o`<0
1?l400[o1`05o`D01Ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o1@08oa<01Ol600;o0P0:o`H0
1_l700So4`06o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<03Ol@00004`02o`/0
1ol900;o3`02oa@01Ol300Go0P0:o`H02?l500Co0`04o`@02_l500Wo0`05o`D00ol300[o4`0:o`D0
2?lD00[o1@08oa<01Ol500?o0P0:o`@02Ol600[o4@06o`<01_lA00;o1002o`@03?l200Ko0`06o`03
0?oo00So0`0<o`<03Ol@00004`02o`X00_l400;o2P02o`h00_lE00;o1`02o`@00_l400Co2002o`T0
0_l500;o2@02o`P00ol500?o1002o`D00ol400?o1@03oaH00_l<00;o6`02o``00_lH00;o1@03o`L0
0_l800?o1003o`H00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L00_l300?o1@03o`@0
0_l600;o1P02o`H00_l@00004`02o`T00_l600;o2@02o`h00_lE00;o1`02o`@00_l600;o2002o`T0
0_l500;o2@02o`P00_l700;o1002o`D00_l500;o1`02oaH00_l<00;o6`02o``00_lH00;o1@02o`P0
0_l800;o1P02o`H00_l600;o4P02o`L00_lB00Co0`03o`D00_l600;o1002o`L00_l300;o1`02o`@0
0_l600;o1P02o`H00_l@00004`02o`T00_l600;o2@02o`h00_lE00;o0`02o`800_l400;o1`02o`L0
0_l900;o1@02o`T00_l700;o2@02o`<00_l400;o1P02o`L00_lF00;o3002oa/00_l<00;o6002o`@0
0_l900;o2002o`H00_l600;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@02ol300;o1`02o`@0
0_l200;o0P02o`H00_l600;o400001<00_l900;o1P02o`X000?o00003002oaD00_l200?o0P02o`@0
0_l700;o1`02o`T00_l500;o2@02o`L00_l900;o0`03o`800ol>00?o5P02o``00_lK00;o3002oaP0
0ol200?o2@02o`P00_l600;o1P02o`L00_lB00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@0
0_l200;o2P02o`H00_l@00004`02o`T00_l600;o2P02o`d00_lE00;o0P000ol0o`0200;o1002o`L0
0_l700;o2@02o`D00_l900;o1`02o`T00_l300Oo2P07oaL00_l<00;o6`02o``00_lH00Oo2P02oa00
0_l600;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH0000
4`02o`T00ol400;o2`02o`d00_lE00;o00@0ool00_l00`3oo`0400;o1`02o`L00_l900Wo2@02o`L0
0_l900;o0`05o`X01olI00;o3002oa/00_l<00;o6005o``00_l@00;o1P02o`L00_lC00;o0`02oa@0
0_l00`3oo`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2009o``000?o0000
2P02oaH00_l00`3oo`020004o`3oo`@00_l700;o0P02o`<00_l300;o1009o`T00_l700;o2@02o`<0
0_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o00@0oooo2`02oa00
0_l600;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o
0P02o`X00_lH00005002o`P00_l00`3oo`02o`h00_l;00;o5P02o`030?l0008000Co0?oo1002o`L0
0_l200;o0`02o`<00_l400;o1@02o`T00_l700;o2@02o`<00_l200?o1`02o`L000?o00005@02o`L0
0_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o0P03o`X00_l@00;o1P02o`L00_lD00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`P00_lB00;o2`02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T0
0_l800;o1`02o`@00_l300?o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`L00_l300;o0`02oa<0
0_l300?o2@02oa000_l600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3o
o`0600;o1P02o`D00_l600;o1P02oaP0000E00;o2003oa8000?o00002002oaL01?l400?o1002o`@0
1?l300;o0`02o`<00_l400;o1@02o`T00_l800?o1@03o`@00_l400?o1@03o`@00olG00;o1`02o`<0
0_l300;o5P02o`L00_l300;o0`02oa<00_l400?o2002oa000_l600;o1004oaD01OlD00;o2002o`@0
0_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l800?o2P02o`D00_l800;o5`04o`D0
1?l200[o100<o`<01?l300Co100:o`D02Ol300Go0`05o`@02OlC00[o0`0<oa802_l300co4@05o`<0
1Ol200[o1`0:o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol800Wo0`0<o`<02?lE00005`000ol0
000700Oo1@09o`P000?o00005P04o`D01?l200So1P0<o`<01?l300Co100:o`L01Ol500Go0`05o`H0
1Ol00`3o000B00[o0`0<oa802_l300co4@05o`<01Ol200[o1`0:o`802?lE00Oo5006o`801_l00`3o
o`0:o`@01ol:00Go00<0o`000P0<o`<02?lE00008`05o`D02Ooo0<@0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(68\\) NDTHHNKS IT IT KHKD A WEAREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lF00Ko0`02o`<02?l800So1@04o`<0
1?l400Co0`04o`<01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1@08oa@02_l500So4`05o`H0
0_l200Co0`04o`<01Ol600;o0P08oa<01_l300Ko4@02o`@00_l400co0P06o`<02ol600oo0`0=oa00
000C00;o2`07o`L02?l;00;o5@06o`800ol300[o1P08o`D01?l300Co1004o`<01?l300Ko0P03o`80
1Ol500?o0`0:oa<02_l500So500:o`D02?lC00Go1@03o`801?l300Co0`05o`D00ol200[o4@06o`<0
1_lA00;o1002o`@03?l200Ko0`0;o`D04?l300go400001<00_l:00;o1002o`H00ol400?o2P02oaH0
0_l400Co1002o`@01?l800;o2@02o`D00_l600;o1@02o`D00_l400Co1002o`D00ol400?o1@03oaH0
0_l<00;o6`02o``00_lH00;o1@03o`@00_l500;o1P02o`D00ol400;o1004oa800_l700;o4P03o`@0
0ol500;o1P02o`@00_l700;o1002o`D00ol400;o1P02o`H00_l600;o400001<00_l900;o1P02o`D0
0_l600;o2P02oaH00_l400Co1002o`H00_l800;o2@02o`D00_l600;o1@02o`D00_l400Co1002o`D0
0_l500;o1`02oaH00_l<00;o6`02o``00_lH00;o1@02o`D00_l500;o1P02o`D00_l500;o1P02oa80
0_l700;o4P04o`<00ol500;o1P02o`@00_l700;o1002o`D00_l500;o1P02o`H00_l600;o400001<0
0_l900;o1P02o`D00_l600;o2P02oaH00_l300Go1002o`L00_l700;o2@02o`D00_l600;o1@02o`D0
0_l300Go1002o`@00_l600;o1`02oaH00_l<00;o6`02o``00_lH00;o1002o`H00_l500;o1P02o`@0
0_l600;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@02ol400;o1002o`H00_l200;o0P02o`H0
0_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaH00_l300;o00<0ool01002o`L00_l700;o
2@02o`D00_l600;o1@02o`D00_l300;o00<0ool01003o`800ol>00?o5P02o``00_lK00;o3002oaP0
0ol200?o1P02o`D00_l600?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o2@09o`D0
0_l300?o1P02o`800_l:00;o1P02oa00000C00;o2@02o`H00_l600;o1002o`/00_lF00;o0P03o`03
0?oo00@00_l700;o1`02o`T00_l500;o1P02o`D00_l500;o0P03o`030?oo00@01ol:00Oo5`02o``0
0_lK00;o3002oaP01ol700;o1@02o`H01ol700;o1`02oa800_l500;o4`02o`060?l00?l00_l500Ko
2@02o`D00_l500Oo1`06o`X00_lH00004`02o`T00ol400;o2007o`/00_lF00;o0P02o`800_l400;o
1`02o`L00_l900Wo1P09o`D00_l200;o0P02o`@01Ol:00Oo6@02o``00_lK00;o3002oaP01Ol900Wo
1P05o`T00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Wo1@06o`X0
0_lH00005002o`P02Ol800Ko2`02oaL00_l00`3oo`0300;o1002o`L00_l200;o0`02o`<00_l400Wo
1P09o`D00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<00_l300;o5P02o`L00_l300;o
0`02oa<00_l0103oool800Wo1P02o`040?ooo`P00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3o
o`0500;o0P02o`X00_l300;o1P02o`D00ol400;o0P02o`X00_lH00005002o`P00_l00`3oo`02o`T0
0_l400;o2P02oaL01Ol300;o1002o`L00_l200;o0`02o`<00_l400;o1@02o`H00_l500;o1@05o`<0
0_l400;o0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o1`02o`<00_l300;o4`02o`80
0ol700;o1@02o`H00_l200?o1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`800_l200;o
1`02o`040?ooo`H00_l600;o1002o`800_l200;o1P02oaP0000D00?o2002o``00_l600;o2@02oaL0
1?l400;o1002o`H00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l400;o0`03o`H0
0_l600;o5`02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o0`03o`H00_l500;o1P02o`<0
0ol600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0700;o1P02o`@0
0_l600;o1P02oaP0000E00;o2003o`/00_l600;o2002oaP01?l400;o1002o`@01?l300;o0`02o`<0
0_l400;o1@02o`H00_l500;o1@04o`@00_l400;o1003o`D00ol400?o5`02o`L00_l300;o0`02oaH0
0_l700;o0`02o`<00_lC00;o1003o`D00_l500;o1P02o`@00ol500;o1004oaD01OlD00;o2002o`@0
0_l600;o1`05o`L00_l500?o1002o`H00_l600;o600001H00_l800?o2P03o`@00ol700;o6004o`80
1_l200[o100<o`<01?l300Co1004o`<01?l300Co0P06o`030?oo00?o0`05o`@02OlC00[o0`0<oa80
2_l300co4@05o`<01Ol200Co0`04o`<01Ol300Go0P0:oa<01olD00Ko0P06o`030?oo00[o1007o`H0
2ol300co0`08oaD0000G0003o`0000L01ol600So20000ol0000G00?o0`06o`802?l600co0`04o`<0
1?l400Co0`04o`<00ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`<03?lA00Go
0`05o`801?l300Co0`05o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo1P09o`D03?l300So
5@0002<01Ol700Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(69\\) MDTHHMKS IT IT KILD A XEAREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lE00Go0`05o`802?l800So1@04o`<0
1?l400Co0`04o`801Ol300Go00<0ool00ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o1@08oa<0
1Ol600;o0P0:o`@03Ol200So4`06o`<01_l?00Go0P05o`803?l200Ko0`0;o`H03ol300go400001<0
0_l;00Oo1P07o`d00_lD00Go0`05o`802_l600So1@04o`<01?l400Co0`04o`801Ol300Go00<0ool0
0ol500?o0`0:oa<02_l500So500:o`D02?lC00Go1@03o`802_l400go0P0:oa401_l300Ko3`05o`80
1Ol200co0P06o`<02ol5013o0`0=oa00000C00;o2P02o`@00_l;00?o3002oaD00_l700;o1002o`@0
1?l800;o2@02o`D00_l600;o1@02o`@00_l700;o1002o`D00ol400?o1@03oaH00_l<00;o6`02o``0
0_lH00;o1@03o`L00_l;00;o1P02o`<00_l400Co4P02o`L00_lB00?o1003o`D00_l600;o1002o`L0
0_l400;o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o2`03o`/00_lE00;o1`02o`@0
0_l600;o2002o`T00_l500;o1P02o`D00_l400;o1`02o`@00_l500;o1@02o`L00_lF00;o3002oa/0
0_l<00;o6002o`D00_l800;o2`02o`H00_l300;o1P02oa800_l700;o4`03o`800ol600;o1P02o`@0
0_l700;o1002o`D00_l500;o1P02o`H00_l600;o400001<00_l900;o1P02o``00_l;00;o5@02o`<0
0_l200;o1002o`L00_l700;o2@02o`D00_l600;o1@02o`@00_l300;o0P02o`@00_l400;o1P02o`L0
0_lF00;o3002oa/00_l<00;o6002o`@00_l900;o2`02o`H00_l300;o1`02oa402olD00;o0P02o`L0
0_l200;o0P02o`@02ol400;o1002o`H00_l200;o0P02o`H00_l600;o400001<00_l900;o1P02o`P0
1?l00`3oo`0:00;o5@02o`800ol200;o1002o`L00_l700;o2@02o`D00_l600;o1@02o`@00_l200?o
0P02o`@00ol200?o3P03oaH00_l<00;o6`02o``00_lH00?o0P03o`T00_l;00;o1P02o`<00_l700;o
4P09oaH01?l800;o0P02o`T02Ol500;o0`03o`H00_l200;o2P02o`H00_l@00004`02o`T00_l600;o
1P09o`X00_lE00;o0P000ol0o`0200;o1002o`L00_l700;o2@02o`D00_l600;o1@02o`@00_l20003
o`3o00800_l400Oo2P07oaL00_l<00;o6`02o``00_lH00Oo2P02o`/00_l;00;o1`02oa800_l500;o
5P04o`P01_l900;o1@02o`D01ol700Ko2P02oaP0000C00;o2@03o`@00_l700;o1003o`X00_lE00;o
00@0ool00_l00`3oo`0400;o1`02o`L00_l900Wo1P09o`@00_l0103oo`02o`030?oo00@01Ol:00Oo
6@02o``00_lK00;o3002oaP01Ol<00;o2`02o`/00_l700;o4`02o`<00_lG00?o2@06o`X00_l300;o
1P09o`D01_l:00;o600001@00_l800Wo1P02o`H00_l900;o5P02o`030?oo008000Co0?oo1002o`L0
0_l200;o0`02o`<00_l400Wo1P09o`@00_l00`3oo`020004o`3oo`@00_l0103oool800?o7P02o`L0
0_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o00@0oooo2`02o`/00_l;00;o1`02oa<00_l300;o
5`04o`P00_l200;o2P02o`<00_l600;o1@03o`@00_l200;o2P02oaP0000D00;o2002o`030?oo00;o
2002o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`L00_l200;o0`02o`<00_l400;o1@02o`H0
0_l500;o1002o`030?l0008000Co0?oo1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o
5P02o`L00_l300;o0`02oa<00_l200?o2P02o`/00_l;00;o1`02oa@00_l0103ooolF00Ko1`02o`80
0_l200;o1`02o`040?ooo`H00_l600;o1002o`800_l200;o1P02oaP0000D00?o2002o``00_l600;o
2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1004o`<01?l400;o
0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lC00;o0`03o`T00_l;00;o
2`02o`H00_lE00;o00<0ool05P03o`800ol600;o1P02o`L00_l00`3oo`0700;o1P02o`@00_l600;o
1P02oaP0000E00;o2003o`/00_l60003o`0000L00_lG00Co1003o`@00_l400Co0`02o`<00_l300;o
1002o`D00_l600;o1@02o`@01?l400?o1002o`@00ol500?o1003oaL00_l700;o0`02o`<00_lF00;o
1`02o`<00_l300;o4`02o`@00ol800;o2`02o`/00_l400Co5@05oaH00_l400;o1P02o`H00_l700Go
1`02o`D00ol400;o1P02o`H00_lH00005P02o`P00ol;00;o1002o`P00_lG00Co1@04o`802_l400co
0`04o`<01?l400Co0`04o`801?l500Co00<0ool00ol300Go1009oa<02_l300co4P0:o`<03?lA00Go
0`05o`802_l400So1`0:oa<01olE00Go0P05o`803?l400Oo1P0;o`<03?l300So5@0001L000?o0000
1`07o`H01ol90003o`0001H01?l500Co0P08o`H03?l300Co0`04o`@01?l300Co0P04o`D01?l00`3o
o`03o`<01Ol600Go00<0o`004P0:o`<03?lB00[o0`0<oa401Ol300Go0P0:o`@02?l700So5@07oaD0
1Ol200Go0P0<o`@01ol600Wo1@0<o`<02?lE00008`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(70\\) MDTHIMKSZIT IT LHLD A WEARDM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`802?l800So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`03o`H00_l300;o00<0ool00ol600[o1@0:o`D02?lD00[o1@08oa<0
3Ol200Co0`04o`<03Ol200So4`06o`<01_lA00;o1002o`@03?l200Ko0`0;o`H00ol00`3oo`06o`H0
1Ol300Go400001<00_l<00;o3006o``00_lD00Go0`05o`802_l600So1@04o`<01?l400[o0`05o`<0
1Ol00`3oo`03o`D00ol300[o100:o`D02_l500So500:o`D02?lC00go0P04o`<01?l300go0P0:oa40
1_l300Ko4@02o`@00_l400co0P06o`<02ol500Co00<0ool02?l400Go0`05oa00000C00;o3@02o`X0
0ol200?o2`02oaD00_l700;o1002o`@01?l800;o2@02o`D00_l900;o2002o`L00_l400;o1@03o`@0
0ol500?o1002o`D00_l900;o3002oa/00_l<00;o6@02o`H00_l300;o1@02o`L00_l600;o0`02o`@0
1?lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`@00_l500?o1002o`@01?l400;o1`02oa40
000C00;o3@02o`X00_l400;o2`02oaD00_l700;o1002o`H00_l800;o2@02o`D00_l900;o2002o`L0
0_l400;o1@02o`D00_l700;o1003o`@00_l900;o3002oa/00_l<00;o6@02o`H00_l300;o1@02o`L0
0_l600;o0`02o`H00_lB00;o1`02oa801?l300?o1@02o`H00_l400;o1`02o`@00_l500;o1@02o`H0
0_l400;o1`02oa40000C00;o3@02o`T00_l600;o2P02oaD00_l300;o0P02o`@00_l700;o1`02o`T0
0_l500;o2@02o`P00_l300;o0P02o`@00_l400;o1P02o`L00_l500?o0`02o`T00_l<00;o6`02o``0
0_lI00;o1P02o`<00_l500;o1`02o`H00_l300;o1`02oa402olB00Co0P04o`D00_l200;o0P02o`@0
2ol400;o1002o`H00_l700;o0`02o`<00_l200;o4@0001<00_l>0003o`0000L00_l600;o2P02oaD0
0_l200?o0P02o`@00_l700;o1`02o`T00_l500;o2@02o`P00_l200?o0P02o`@00ol200?o3P03o`H0
0_l300;o2@02o``00_lK00;o3002oaT00_l600;o0`02o`D00_l700;o1P02o`<00_l700;o4P09oa<0
0_l0103o0004o`D00_l200;o2@09o`D00_l300?o1P02o`L00_l300;o0P03o`800_lA00004`02o`h0
0_l800;o1P02o`X00_lE00;o0P000ol0o`0200;o1002o`L00_l700;o2@02o`D00_l900;o2002o`80
00?o0?l00P02o`@01ol:00Oo1`03o`d00_l<00;o6`02o``00_lI00;o2`02o`D00_l700;o2`02o`L0
0_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500;o1@07o`L00_l700;o0`02o`8000?o0?l0
0P02oa40000C00;o3P02o`P00_l600;o2P02oaD00_l0103oo`02o`030?oo00@00_l700;o1`02o`T0
2Ol900;o2002o`040?oo00;o00<0ool01005o`X01ol:00?o3002o``00_lK00;o3002oaT00_l;00Wo
1`02o`/00_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Wo1@02o`L0
0_l300;o00@0ool00_l00`3oo`0A00005002o`h000?o00001P02o`H00_l900;o5P02o`030?oo0080
00Co0?oo1002o`L00_l200;o0`02o`<00_l400Wo2@02o`P00_l00`3oo`020004o`3oo`@00_l0103o
ool800?o2`02o`<00_l<00;o1`02o`<00_l300;o5P02o`L00_l300;o0`02oa@00_l;00Wo1`02o`/0
0_l700;o4`02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1P02o`D00ol400;o
1`02o`<00_l00`3oo`020004o`3ooa40000D00;o3P02o`L00_l600;o2@02oaH00_l00`3o00020004
o`3oo`@00_l700;o0P02o`<00_l300;o1002o`D00_l900;o2002o`030?l0008000Co0?oo1002o`80
0ol700;o1`000ol0000200;o0`03o`/00_l700;o0`02o`<00_lF00;o1`02o`<00_l300;o5002o`/0
0_l500;o1`02o`/00_l700;o5002o`040?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103o
ool600;o1P02o`@00_l700;o0`02o`030?l0008000Co0?oo4@0001@00ol=00;o1`02o`H00_l900;o
5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l300Co1002o`<00ol600;o
1P02o`@00_l400?o2P02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lD00;o2`02o`D00_l700;o
2`02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01`02o`H00_l400;o
1P02o`@01?l300Co4@0001D00_l>0003o`0000H00_l400;o2@02oaL01?l400?o1002o`@01?l300;o
0`02o`<00_l400;o1@02o`T00_l800Co1003o`@00_l400?o1@03o`@00ol400;o1@02o`X00_l700;o
0`02o`<00_lF00;o1`02o`<00_l300;o5002o`/00_l500;o1`02o`/00_l400Co5@05oa@00_l800;o
1002o`H00_l700Go1`02o`D00ol400;o1004o`@01?l400?o4@0001H00_l600;o1@02o`L00ol200?o
2002oaL01?l500Co0P0:o`@03?l300Co0`04o`@02_l300Co1@04o`030?oo00?o0`05o`@02Ol400[o
1@0:o`<03?lB00[o0`0<oa402?l700Co0`04o`<02?l700[o4`07oa@01_l200Ko00<0ool02_l400Oo
1P0;o`@02_l400Co1@04oa00000G0003o`0000@02Ol800Ko2@000ol0000F00Co1@04o`802?l600co
0`04o`<01?l400[o0`04o`D01?l00`3oo`03o`<01Ol600Go00<0o`000`0:o`D02_l300co4P0:o`<0
3?lA00So1`04o`<01?l300So1`08oaD01olD00Ko0P06o`030?oo00[o1007o`H02Ol600So1P04o`D0
1?l@00007P09o`T01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(71\\) METIIMKS IT IT LILD B VEARDM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2`09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o0`05o`<01Ol00`3oo`03o`H00_l300;o00<0ool00olE00[o1@08oa@02_l500So4`0=o`80
2_l400go0P08oa@02_lH00;o1`0<o`801_l300_o1P03o`030?oo00Ko1P05o`<01Ol@00004`02o``0
0_l;00Wo2P02oa@01Ol300Go00<0ool02_l500So1@0:o`D02_l300Go0`05o`030?oo00?o1@03o`<0
2_lC00[o1@08oa@02_l500So4`0=o`802_l400go0P0:oa802olF00Co1P0<o`801_l300_o1@04o`03
0?oo00So1005o`<01Ol@00004`02o`d00_l>00;o3@02oaD00_l700;o1002o`H00_l800;o3002o`d0
0_l800;o1`02o`@00_l500?o1003o`D00olF00;o3002oa/00_l<00;o6@02o`H00_l600;o2`02o`H0
0_l300;o1004oa<00_l500?o5@04o`P00_l600;o1002o`L00_l400;o1@03o`@00_l400Co1002o`L0
0_lA00004`02o`d00_l>00;o3@02oaD00_l700;o1002o`H00_l800;o3002o`d00_l800;o1`02o`@0
0_l500;o1@02o`L00_lF00;o3002oa/00_l<00;o6@02o`H00_l600;o2`02o`H00_l300;o1P02oa<0
0_l600;o5@04o`P00_l600;o1002o`L00_l400;o1@02o`D00_l600;o1002o`L00_lA00004`02o`d0
0_l>00;o3@02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o3@02o`P00_l300;o0P02o`@0
0_l400;o1P02o`L00_lF00;o3002oa/00_l<00;o6@02o`H00_l600;o2`02o`H00_l300;o1`02oa80
0_l600;o5002o`800_l700;o0P02o`800_l400_o1002o`@00_l600;o1`02o`<00_l300;o0P02oa40
000C00;o3P000ol0000<00;o3@02oaD00_l200?o0P02o`@00_l200;o3002o``00_l=00;o2002o`80
0ol200;o1003o`800ol>00?o5P02o``00_lK00;o3002oaT00_l600;o1P02o`/00_l600;o0`02o`L0
0_lB00;o1P02oa@00_l200;o1`02o`800_l900Wo1@02o`<00ol600;o1`02o`<00_l200?o0P02oa40
000C00;o3P02o`d00_l=00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002o`d00_l800;o0P000ol0
o`0200;o1007o`X01olG00;o3002oa/00_l<00;o6@02o`h00_l;00;o2`02o`L00_lB00;o1@03oa<0
0ol200?o1P06o`T00_l500;o1@07o`L00_l700;o0`02o`8000?o0?l00P02oa40000C00;o3P02o`d0
0_l=00;o5@02o`040?oo00;o00<0ool01006o``00_l<00;o3@02o`P00_l0103oo`02o`030?oo00@0
1Ol:00Oo6@02o``00_lK00;o3002oaT00_l>00;o2`02o`/00_l700;o4P09oa@00_l400;o1P06o`X0
0_l300;o1P09o`D00_l700;o0`02o`040?oo00;o00<0ool04@0001@00_l>0003o`0000/00_l<00;o
5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`P00_l00`3oo`020004
o`3oo`@00_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lD00;o3P02o`/0
0_l;00;o1`02oa802?lE00;o1002o`H00_l200;o2P02o`<00_l600;o1@03o`@00_l700;o0`02o`03
0?oo008000Co0?oo4@0001@00_l>00;o3002o``00_lF00;o00<0o`000P001?l0ool400;o0P02o`80
0_l300;o0`02o`<00_l700;o3@02o`P00_l00`3o00020004o`3oo`@00_l200?o1`02o`L000?o0000
5@02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lD00;o3P02o`/00_l;00;o1`02oa800_l400?o
4`02o`H00_l500;o0P02o`800_l700;o00@0oooo1P02o`H00_l400;o1`02o`<00_l00`3o00020004
o`3ooa40000D00?o3@02o``00_l<00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o
2004o`<01?l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l700;o0`02o`<00_lD00;o
3P02o`/00_l;00;o1P02oa<00_l500;o4`02o`H00_l500;o1P02o`L00_l00`3oo`0700;o1P02o`@0
0_l600;o1004o`<01?lA00005@02o`h000?o00002P02o`/00_lG00Co1003o`@00_l600;o0`02o`<0
0_l300;o1`02o`d00_l800Co1003o`@00_l400?o1@03o`@00olG00;o1`02o`<00_l300;o5P02o`L0
0_l300;o0`02oa@00_l>00;o2`02o`/00_l400Co4`02o`@00olB00?o1P03o`@00_l600;o1`05o`L0
0_l500?o1002o`@01?l400Co1003oa40000F00;o1P02o`D00_l700?o00<0ool02P02oaL01?l500Co
00<0ool02_l300co0`0:o`D02_l300Co1@04o`030?oo00?o0`05o`@02OlC00[o0`0<oa802_l300co
4@08o`L02_l400So1`0:oa802_lB00Ko0P06o`030?oo00[o1007o`H02ol400[o1004o`D01?l@0000
5`000ol0000400Wo1`06o`X000?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`<01?l500Co
00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`<03?lA00So1`0:o`@02?l700So5009oa<0
1_l200Ko00<0ool02_l400Oo1P09o`H02?l600Co1@04oa00000N00Wo2P03ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(72\\) METIIMKS HS IT LIKD A VEARDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P0:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o0`05o`<01Ol00`3oo`03o`H00_l300;o00<0ool00olE00Co0`04o`<00_l00`3oo`03oaD0
2_l500So4`0=o`802_l400Go1P02o`802?lC00Ko0`06oa@00_l700co0P06o`<02ol600?o00<0ool0
1_l600go400001<00_l<00;o2P0:o`X00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o0`05o`<0
1Ol00`3oo`03o`D00ol300[o4`04o`<01?l300[o4`0:o`D02?lC00go0P0:o`@01Ol500?o0P0:oa40
1_l300Ko4`04o`H03?l200Ko0`0;o`D01?l00`3oo`08o`@03Ol@00004`02o`d00_l:00;o1@02o`X0
0_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2002o`L00_l400;o1@03o`@00ol500?o4`02o`D0
0_l400?o1@03oaH00_l<00;o6@02o`H00_l600;o2P02o`D00ol400;o1004oa800_l700;o5@04o`P0
0_l600;o1002o`L00_l400;o1@03o`@00_l400Co1P02o`H00_l@00004`02o`d00_l;00?o3`02oaD0
0_l700;o1002o`H00_l800;o3002o`d00_l800;o1`02o`@00_l500;o1@02o`L00_lC00;o1@02o`@0
0_l700;o5P02o``00_lI00;o1P02o`H00_l:00;o1@02o`D00_l600;o4P02o`L00_lE00Co2002o`H0
0_l400;o1`02o`@00_l500;o1@02o`H00_l600;o1P02oa00000C00;o3@02o``00ol>00;o5@02o`<0
0_l200;o1002o`800_l200;o2002o``00_l=00;o2002o`<00_l200;o1002o`@00_l600;o1`02oa<0
0_l500;o1002o`L00_lF00;o3002oaT00_l600;o1P02o`X00_l400;o1P02o`L00_lA00_o5002o`80
0_l700;o0P02o`800_l400_o1002o`@00_l600;o1`02o`D00_l600;o400001<00_l>0003o`0000/0
0ol=00;o5@02o`800ol200;o1002o`800_l<00;o3002o`d00_l800;o0P03o`800_l400?o0P03o`h0
0olC00;o1@02o``00olF00;o3002oaT00_l600;o1P02o`X00ol200?o1P02o`L00_lB00Wo5@02o`80
0_l700;o0P02o`T02Ol500;o0`03o`H00_l700;o1@02o`H00_l@00004`02o`h00_l=00?o3002oaD0
0_l20003o`3o00800_l400Ko3002o``00_l=00;o2002o`8000?o0?l00P02o`@01ol:00Oo5002o`D0
0_l700Oo5`02o``00_lI00;o3P02o`X01ol700;o1`02oa800_l500;o5003o`800ol600Ko2@02o`D0
0_l500Oo1`02o`L00_l500;o600001<00_l>00;o3P03o`/00_lE00;o00@0ool00_l00`3oo`0400Ko
3002o``00_l=00;o2002o`040?oo00;o00<0ool01005o`X01olF00Wo1@07oaT00_l<00;o6@02o`h0
0_l:00Go2@02o`L00_lC00;o0`02oaD00_l400;o1P06o`X00_l300;o1P09o`D00_l700;o1@02oaP0
000D00;o3P000ol0000=00;o2P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o
1`02o`d00_l800;o00<0ool00P001?l0ool400;o00@0oooo2003oa/02Ol400?o7P02o`L00_l300;o
0`02oa@00_l>00;o2P02o`040?ooo`P00_l700;o4`02o`<00_lE00;o1002o`H00_l200;o2P02o`<0
0_l600;o1@03o`@00_l700;o1@02oaP0000D00;o3P02o`l00_l900;o5P02o`030?l0008000Co0?oo
1002o`800_l200;o0`02o`<00_l300;o1`02o`d00_l800;o00<0o`000P001?l0ool400;o0P03o`L0
0_l70003o`0001800_l500;o1002o`L000?o00005@02o`L00_l300;o0`02oa@00_l>00;o2P02o`80
0ol700;o1`02oa@00_l0103ooolD00;o1P02o`D00_l200;o0P02o`L00_l0103oool600;o1P02o`@0
0_l700;o1@02oaP0000D00?o3@02o`l00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L0
0_l=00;o2004o`<01?l400;o0`03o`H00_l600;o5002o`D00_l400;o1P02oaL00_l700;o0`02o`<0
0_lD00;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05@02o`H00_l500;o1P02o`L00_l00`3o
o`0700;o1P02o`@00_l600;o1P02oaP0000E00;o3P000ol0000600;o1@02o`P00_lG00Co1003o`@0
0_l600;o0`02o`<00_l300;o1`02o`d00_l800Co1003o`@00_l400?o1@03o`@00olD00;o1@02o`@0
0ol400?o5`02o`L00_l300;o0`02oa@00_l>00;o2P02o`@00ol500;o1004oaD01OlD00?o1P03o`@0
0_l600;o1`05o`L00_l500?o1002o`@01?l600;o600001H00_l600;o1@02o`L00ol300?o1`02oaL0
1?l500Co00<0ool02_l300co0`0:o`D02_l300Co1@04o`030?oo00?o0`05o`@02OlC00Co0`04o`@0
2OlC00[o0`0<oa402?l700[o1005o`<01Ol200[o4`07oa@01_l200Ko00<0ool02_l400Oo1P0;o`@0
2_l400So5@0001L000?o00001009o`P01ol80003o`0001H01?l500Co00<0ool02_l300co0`0:o`D0
2_l300Co1@04o`030?oo00?o0`05o`H01Ol00`3o000B00Co0`04o`H01Ol00`3o000B00[o0`0<oa40
2?l700[o1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo1P09o`H02?l600So5@0001h0
2Ol900Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(73\\) NETIHNKS HS IS MHJD A VEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lF00Ko0`02o`803?l500So1@0:o`D0
1?l300Co0`06o`<00_l200Go1P02o`<00_l00`3oo`03oaD01?l300Co0`02o`030?oo00?o5@0:o`@0
0_l00`3oo`03oa@01Ol300Go0P04o`<01?l500Ko1`08oa<01_l300Ko5002o`L03?l200Ko0`06o`04
0?oo00Go1P08o`H03Ol@00004`02o``00_l:00Wo2`02oaD01_l200?o0P0<o`D02?l500[o1@04o`<0
1?l300Ko0P03o`801Ol500?o0`0:oa<01?l300Co0`0:oa<02_l400[o4P05o`<01Ol200Co0`04o`<0
2Ol600[o4@06o`<01_lC00Co1P0<o`801_l300Ko00<0ool02?l400[o100=oa00000C00;o3@02o`T0
0_l500;o2`02oaH00_l400Co1002o`H00_l800;o3002o`X00_l500;o1@02o`@01?l400;o1@03o`@0
0ol500?o4`02o`D00_l400?o1@03oaH00_l800?o1@03oa800_l700;o1002o`D00_l400?o1003o`H0
0_l400Co4P02o`L00_lE00Co2002o`H00_l400;o1`02o`<00ol500?o1002o`@01?l600;o1P02oa00
000C00;o3@02oa400_l:00;o5P02o`@01?l400;o1P02o`P00_l<00;o2P02o`D00_l500;o1004o`@0
0_l500;o1@02o`L00_lC00;o1@02o`@00_l700;o5P02o`P00_l700;o4P02o`L00_l400;o1@02o`@0
0_l600;o1P02o`H00_lB00;o1`02oaD01?l800;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H0
0_l600;o400001<00_l=00;o4@02o`X00_lF00;o0`05o`@00_l200;o0P02o`P00_l<00;o2P02o`D0
0_l500;o0`05o`@00_l400;o1P02o`L00_lC00;o1@02o`@00_l700;o5P02o`P00_l700;o4P02o`<0
0_l200;o1002o`D00_l400;o1P02o`H00_l700;o4@0;oa@00_l200;o1`02o`800_l200;o100;o`<0
0_l700;o1002o`L00_l500;o1P02oa00000C00;o3P000ol0000?00;o2P02oaH00_l300;o00<0ool0
1002o`800_l<00;o3002o`X00_l500;o1@02o`<00_l00`3oo`0400?o0P03o`h00olC00;o1@02o``0
0olF00;o4003oa800_l200?o0P02o`@00_l500;o1002o`H00_l600;o1`02oa802OlE00;o0P02o`L0
0_l200;o2@09o``00ol400;o1`02o`D00_l600;o400001<00_l>00;o3`02o`/00_lF00;o0P03o`03
0?oo00@01_l<00;o3002o`X00_l500;o1@02o`800ol00`3oo`0400Oo2P07oa@00_l500;o1`07oaL0
0_l;00Oo4`02o`8000?o0?l00P02o`@00_l500;o3002o`H00_l700;o4P02o`D00_lD00?o0P03o`H0
1_l900;o1@02o`L01ol500;o1`02o`D00_lH00004`02o`h00_l<00Co3002oaH00_l200;o0P02o`@0
1_l<00;o3002o`X02Ol500;o0P02o`800_l400Go2P07oaH02Ol500Oo6@02o`T01olE00;o00@0ool0
0_l00`3oo`0400Wo3002o`H00_l700;o4`02o`<00_lE00;o1002o`H01_l:00;o0`02o`H01ol700;o
1`02o`D00_lH00005002o`h000?o00002P03o``00_lG00;o00<0ool00`02o`@00_l200;o1`02o`<0
0_l300;o1`02o`X02Ol500;o00<0ool00`02o`@00_l0103oool800?o6`09o`@00olN00;o2003oaX0
0_l00`3oo`020004o`3oo`@02Ol<00;o1P02o`L00_lC00;o0`02oaD00_l400;o1P02o`800_l:00;o
0`02o`D00ol<00;o1`02o`D00_lH00005002o`h00_l=00;o2`02oaL01Ol300;o1002o`800_l200;o
0`02o`<00_l300;o1`02o`X00_l500;o1@05o`<00_l400;o0P03o`L00_l70003o`0001800_l500;o
1002o`L000?o00005@02o`P00_l70003o`0001400_l00`3o00020004o`3oo`@00_l500;o3002o`H0
0_l700;o5002o`040?oooa@00_l600;o1@02o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<0
0_l700;o1@02oaP0000D00?o3@02o`h00_l:00;o5`04o`@00_l400;o1P02o`<00_l300;o0`02o`L0
0_l:00;o1@02o`D01?l400;o1002o`<00ol600;o1P02oa@00_l500;o1002o`H00_lG00;o2002o`H0
0_lC00Co0`04o`@00_l500;o3002o`H00_l600;o5@02o`030?oo01D00_l600;o1@02o`H00_l700;o
00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`h000?o00003002o`T00_lH00Co1002o`@0
0_l600;o0`02o`<00_l300;o1`02o`X00_l500;o1@04o`@00_l400;o1003o`D00ol400?o5002o`D0
0_l400?o1003oaL00_l800?o1003oa<01?l400?o1002o`D00_l<00;o1P02o`@01?lE00Go5003o`H0
0ol400;o1P02o`L01Ol600?o1003o`D00_l400Co1P02oaP0000F00;o1P02o`D00_l700;o0`03o`P0
0_lH00Co0P06o`030?oo00[o0`0<o`<02_l500Co0`04o`<01?l200Ko00<0ool00ol300Go1009oa<0
1?l300Co1009oa<02_l500Wo4P04o`D01?l200Co0`04o`H02_l200[o4`07oa@01_l200Ko00<0ool0
2_l400Oo2009o`@02_l400So5@0001L000?o00001009o`L01ol90003o`0001L00ol300Ko00<0ool0
2_l300co0`0:o`D01?l300Co0`03o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P04o`<01?l600Go
00<0o`004P0:o`L01Ol00`3o000A00Co1@04o`801?l300Co1P0:o`802?lE00Oo5006o`801_l00`3o
o`0:o`@01ol:00Go00<0o`000`08o`H02?lE00007P09o`T01?oo0<H0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(74\\) MDTHIMLS HS IS MIKD AZWEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3P06o`T00_lE00Go0`05o`802?l800So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`0;o`<00_l00`3oo`03oaD01?l300Co0`02o`030?oo00?o5@0:o`@0
0_l00`3oo`03oa@01Ol300Go0P0:o`@01Ol600;o0P08oa<01_l300Ko00<0ool02?l600;o1002o`@0
3?l200Ko0`06o`040?oo00Go1P08o`H03Ol@00004`02o``00_l>00Ko2P02oa@01Ol300Go0P0:o`H0
2?l500Co0`04o`@02_l300Go0`05o`030?oo00_o0`0:oa<01?l300Co0`0:oa<02_l400[o4P05o`<0
1Ol200[o1005o`D00ol200[o4@06o`<01_l00`3oo`08o`H00_l400;o100<o`801_l300Ko00<0ool0
2?l400[o100=oa00000C00;o3@02o`l00_l<00;o5@02o`L00_l400;o1004o`P00_l900;o1@02o`T0
0_l800;o1`02o`D00_l600;o0`03o`D00olC00;o1@02o`@00ol500?o5P02o`P00ol500?o4P02o`L0
0_l700;o2P02o`D00ol400;o1004oa800_l700;o1002o`D00_l500?o1003o`D00_l600;o1002o`L0
0_l300?o1@03o`@00_l400Co1P02o`H00_l@00004`02o`d00_l?00;o3002oaD00_l700;o1002o`H0
0_l800;o2@02o`D00_l900;o2002o`L00_l500;o1P02o`<00_l700;o4`02o`D00_l400;o1`02oaH0
0_l800;o1`02oa800_l700;o1`02o`X00_l500;o1@02o`H00_lB00;o1`02o`@00ol400;o1@04o`<0
0ol500;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l=00;o2@0:o`X0
0_lE00;o0`02o`800_l400;o1`02o`L00_l900;o1@02o`T00_l800;o0`02o`800_l500;o1P02o`<0
0_l700;o4`02o`D00_l400;o1`02oaH00_l800;o1`02oa800_l300;o0P02o`L00_l:00;o1002o`H0
0_l700;o4@0;o`D00ol300;o1@04o`801?l500;o0P02o`800_l400_o0`02o`L00_l400;o1`02o`D0
0_l600;o400001<00_l>0003o`0000L02_l:00;o5@02o`800ol200;o1002o`L00_l700;o2@02o`D0
0_l900;o2002o`800ol200;o1@02o`H00_l;00?o4`02o`D00_l<00?o5P02oa000olB00;o0P03o`80
0_l700;o2P03o`800ol600;o1`02oa802Ol700;o0`02o`D00_l0103o0004o`D00_l200;o2@09o``0
0ol400;o1`02o`D00_l600;o400001<00_l>00;o2002o`@00_l<00;o5@02o`8000?o0?l00P02o`@0
0_l700;o1`02o`T00_l500;o2@02o`P00_l20003o`3o00800_l500;o3P07oa@00_l500;o1`07oaL0
0_l;00Oo4`02o`8000?o0?l00P02o`L00_l:00Oo1`02o`L00_lB00;o1@02o`L00ol900;o00H0o`00
o`02o`D01_l900;o1@02o`L01ol500;o1`02o`D00_lH00004`02o`h00_l900;o0`02o``00_lE00;o
00@0ool00_l00`3oo`0400;o1`02o`L00_l900Wo2@02o`P00_l0103oo`02o`030?oo00D00_l<00Oo
5P09o`D01olI00;o2@07oaD00_l0103oo`02o`030?oo00L00_l:00Go2@02o`L00_lC00;o0`02o`T0
0ol800;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`02o`L00_l500;o600001@00_l>0003
o`0000P000Co00000_l;00;o5P02o`030?oo008000Co0?oo1002o`L00_l200;o0`02o`<00_l400Wo
2@02o`P00_l00`3oo`020004o`3oo`D00_l;00?o6`09o`@00olN00;o2003oaX00_l00`3oo`020004
o`3oo`L00_l:00;o00@0oooo2002o`L00_lC00;o0`02o`D00_l300;o2002o`030?oo00;o00<0ool0
1@02o`800_l:00;o0`02o`D00ol<00;o1`02o`D00_lH00005002o`h00_l900;o0P02o`/00_lF00;o
00<0o`000P001?l0ool400;o1`02o`800_l300;o0`02o`@00_l500;o2@02o`P00_l00`3o00020004
o`3oo`D00_l;00;o1`000ol0000B00;o1@02o`@00_l70003o`0001D00_l800;o1`000ol0000A00;o
00<0o`000P001?l0ool700;o2P02o`800ol700;o1`02oa@00_l0103oool500;o0`03o`H00_l300;o
0`02o`@00_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o1`02o`D00_lH00005003o`d0
0_l:0003o`0000;o2`02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l800Co
0`04o`D00_l;00;o1P02oa@00_l500;o1002o`H00_lG00;o2002o`H00_lC00Co0`04o`L00_l:00;o
0`03o`H00_l600;o5@02o`030?oo00H00_l400?o1@02o`<00_l300;o1002o`H00_l700;o00<0ool0
1P02o`H00_l500;o1P02o`H00_lH00005@02o`h000?o00002@001?l0ool:00;o5`04o`@00ol400;o
1004o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l400?o1@02o`/00ol400?o5002o`D00_l400?o
1003oaL00_l800?o1003oa<01?l400?o1`02o`X00_l400?o1@02o`@01?lE00Go1P02o`D00_l500;o
2002o`@00_l600;o1`05o`H00ol400?o1@02o`@01?l600;o600001H00_l600;o1@02o`X01?l900;o
5`04o`D01?l200[o100<o`<01?l300Co100:o`<01?l500Co00<0ool01_l900Wo4`04o`<01?l400Wo
4`0:o`D02OlB00Co1@04o`802_l400Go0`05o`802_lC00Oo1`0:o`<01_l200Ko00<0ool02_l400Oo
2009o`@02_l400So5@0001L000?o00001009o`/00ol90003o`0001H01?l500Co0P08o`H03?l300Co
0`04o`@02_l300Co1@04o`030?oo00Ko2`05o`030?l001801?l300Co1P05o`030?l001802_l700Go
00<0o`004@04o`D01?l200[o1005o`<01Ol200So5@07o`L02_l300Ko0P06o`030?oo00[o1007o`X0
1Ol00`3o000300So1P08oaD0000N00Wo2`03ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(75\\) MDTHJNLT HS IS MIKEZA WEATEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lE00Go0`05o`802?l800So1@04o`<0
1?l500Ko1`06o`<00_l200go1008oa@01?l300Co0`02o`030?oo00?o5@0:o`@00_l00`3oo`03oa@0
1Ol300Go0P0:o`@01Ol600;o00<0ool02_l400[o0P06o`<01_lA00;o1002o`@03?l200Ko0`06o`80
2?l400co0`0=oa00000C00;o3002o`X02Ol;00;o5005o`<01Ol200[o1P08o`D01?l300Co0`09o`H0
1_l200?o0P0=o`@02?lD00Co0`04o`<02_lC00[o100:oa801Ol300Go0P0:o`@01Ol500?o00<0ool0
2_l400[o0P06o`<01_lA00;o1002o`@03?l200Ko0`06o`802?l400co0`0=oa00000C00;o3@02o`T0
0_l500;o2`02oaD00_l700;o1002o`@01?l800;o2@02o`D00_l400?o1003o`H00_l400Co1@02o`H0
0_l700;o6002o`D00_l400?o1@03oaH00_l800?o1@03oa800_l700;o1`02o`X00_l500?o1002o`H0
0_l500;o1@02o`@00_l700;o4P03o`@00ol500;o1P02o`@00_l700;o1`02o`T00_l600;o1P02o`H0
0_l@00004`02o`d00_lA00;o2P02oaD00_l700;o1002o`H00_l800;o2@02o`D00_l400;o1P02o`H0
0_l400Co1@02o`H00_l700;o6002o`D00_l400;o1`02oaH00_l800;o1`02oa800_l700;o1`02o`X0
0_l500;o1@02o`H00_l500?o1002o`@00_l700;o4P04o`<00ol500;o1P02o`@00_l700;o1`02o`T0
0_l600;o1P02o`H00_l@00004`02o`d00_lA00;o2P02oaD00_l300;o0P02o`@00_l700;o1`02o`T0
0_l500;o1002o`H00_l600;o0`05o`D00_l600;o1`02oaP00_l500;o1002o`L00_lF00;o2002o`L0
0_lB00;o0`02o`800_l700;o2P02o`@00_l600;o0P02o`800_l600?o0`02o`@02olB00Co0P04o`D0
0_l200;o0P02o`@02ol700;o2@02o`800_l200;o1P02o`H00_l@00004`02o`h000?o00003`02o`X0
0_lE00;o0P03o`800_l400;o1`02o`L00_l900;o1@02o`@00_l600;o1P02o`<00_l00`3oo`0500;o
1P02o`L00_lH00;o1@02o``00olF00;o4003oa800_l200?o0P02o`L00_l:00?o0P03o`H00_l200;o
2`02o`<00_l500Wo4`02o`040?l000Co1@02o`800_l900Wo2002o`T00_l200;o2P02o`H00_l@0000
4`02o`h00_l@00;o2P02oaD00_l20003o`3o00800_l400;o1`02o`L00_l900;o1@02o``00_l600;o
0P03o`030?oo00D00_l?00;o6002o`D00_l700Oo5`02o`/01olC00;o0P000ol0o`0200;o1`02o`X0
1ol700Ko2`03o`T00_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l800;o2@06o`X00_lH0000
4`02o`h00_l900;o1002o`/00_lE00;o00@0ool00_l00`3oo`0400;o1`02o`L00_l900Wo3002o`H0
0_l200;o0P02o`D00_l?00;o6009o`D01olI00;o2@07oaD00_l0103oo`02o`030?oo00L00_l:00Go
2@06o``00ol900;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o0`02o`T00_l900Ko2P02oaP0
000D00;o3P000ol0000700So2P02oaH00_l00`3oo`020004o`3oo`@00_l700;o0P02o`<00_l300;o
1009o``00_l600;o00<0ool00`02o`D00_l:00;o0`02o`<00_lC00Wo1003oah00_l800?o6P02o`03
0?oo008000Co0?oo1`02o`X00_l0103oool800;o0P02o`P00_l300;o2@02o`<00_lD00;o00<0ool0
0_l00`3oo`0500;o0P02o`X00_l300;o1002o`<00_l300;o1002o`800_l:00;o600001@00_l>00;o
2007o`/00_lF00;o00<0o`000P001?l0ool400;o1`02o`800_l300;o0`02o`@00_l500;o3002o`H0
1Ol300;o1@02o`X00_l300;o0`02oa<00_l500;o1002o`L000?o00005@02o`P00_l70003o`000140
0_l00`3o00020004o`3oo`L00_l:00;o0P03o`L00_l200;o0P02o`@00_l300?o2@02o`040?oooa<0
0_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool400;o0`02o`<00_l400;o0P02o`800_l600;o
600001@00ol=00;o2002oa000_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D00_l<00;o
1P04o`@00_l500;o2P02o`<00_l300;o4`02o`D00_l400;o1P02oaL00_l800;o1P02oa<01?l300Co
1`02o`X00_l300?o1P02o`H00_l400;o1003o`P00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L0
0_l00`3oo`0500;o0`02o`<00_l400;o1P02o`H00_lH00005@02o`h000?o00001P02o`l00_lG00Co
1003o`@00_l400Co0`02o`<00_l300;o1002o`D00_l<00;o1P04o`@00_l500;o2P02o`<00_l300;o
4`02o`D00_l400?o1003oaL00_l800?o1003oa<01?l400?o1`02o`X00_l400?o1@02o`H00_l400;o
1@02o`P01OlD00;o2002o`@00_l600;o1`05o`D00_l300;o0`02o`@00_l600;o1P02oaP0000F00;o
1P02o`D00_l700;o3P02oaL01?l500Co0P0:o`@03?l300Co0`04o`H02_l200Co0P06o`030?oo00Ko
1`0<oa801?l300Co1009oa<02_l500Wo4P04o`D01?l200[o1005o`<01Ol00`3oo`0:o`@02_l400Oo
5006o`801_l00`3oo`0:o`@01ol600co0P0<o`<02?lE00005`000ol0000400Wo1`08o`P000?o0000
5P04o`D01?l200So1P0<o`<01?l300Co1P0:o`800ol300Ko00<0ool01_l700co4P04o`<01?l600Go
00<0o`004P0:o`L01Ol00`3o000A00Co1@04o`802_l400Go0`05o`030?oo00[o100:o`@01olD00Ko
0P06o`030?oo00[o1007o`H03?l200co0`08oaD0000N00Wo1`08ool0a0000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(76\\) METIJNKS IT HS MIKEZA WEBTEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l600Ko1`06o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l500So5004o`<01?l300;o00<0ool0
0olD00Go0`05o`802_l400Go1P02o`030?oo00[o100:o`801_l300Ko4@02o`@00_l400co0`0:o`H0
2?l400co0`0=oa00000C00;o3002o``01ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1009o`H0
1_l200?o0P05o`D00ol300[o4`0:o`D02?lD00Co0`04o`<02_lB00Go0`05o`802_l400Go1@03o`03
0?oo00[o100:o`801_l300Ko4@02o`@00_l400co0`0;o`D02?l400co0`0=oa00000C00;o3@02o`X0
0_l400;o2`02oaD00_l700;o1002o`H00_l800;o3002o`P00ol400?o1P02o`@01?l400;o1@03o`@0
0ol500?o5P02o``00_lH00;o1@02o`@00ol500?o4P02o`L00_l700;o2P02o`D00ol400;o1P02o`D0
0_l500;o1002o`L00_lB00?o1003o`D00_l600;o1@02o`D00ol700;o2@02o`H00_l600;o1P02oa00
000C00;o3@02o`T00_l600;o2P02oaD00_l700;o1002o`H00_l800;o3002o`P00_l600;o1P02o`@0
1?l400;o1@02o`D00_l700;o5P02o``00_lH00;o1@02o`@00_l700;o4P02o`L00_l700;o2P02o`D0
0_l500;o1P02o`D00ol400;o1002o`L00_lB00Co0`03o`D00_l600;o1@02o`H00_l700;o2@02o`H0
0_l600;o1P02oa00000C00;o3@02o`T00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`P0
0_l<00;o2002o`H00_l600;o0`05o`@00_l400;o1P02o`L00_lF00;o3002oaP00_l500;o1002o`L0
0_lB00;o0`02o`800_l700;o2P02o`@00_l600;o0P02o`800_l600?o0`02o`@02olB00Co0P04o`D0
0_l200;o0P02o`D00_l600;o1`02o`T00_l200;o0P02o`H00_l600;o400001<00_l>0003o`0000L0
0_l600;o2P02oaD00_l200?o0P02o`@00_l200;o3002o``00_l800;o1P02o`H00_l300;o00<0ool0
1003o`800ol>00?o5P02o``00_lH00;o1@02o``00olB00;o0P03o`800_l700;o2P03o`800ol600;o
0P02o`/00_l300;o1@09oa<00_l0103o0004o`D00_l200;o2@02o`H00_l700;o2@02o`800_l:00;o
1P02oa00000C00;o3P02o`P00_l600;o2P02oaD00_l20003o`3o00800_l400Ko3002o``00_l@00;o
1P02o`800ol00`3oo`0400Oo2P07oaL00_l<00;o6002o`D00_l700Oo4`02o`8000?o0?l00P02o`L0
0_l:00Oo1`06o`/00ol900;o1@02oa<00_l01P3o003o00;o1@06o`T00_l500?o1`02o`T01_l:00;o
600001<00_l>00;o2003o`@00_l;00;o5@02o`040?oo00;o00<0ool01006o``00_l<00;o4002o`H0
0_l200;o0P02o`@01Ol:00Oo6@02o``00_lH00Wo1@07oaD00_l0103oo`02o`030?oo00L00_l:00Go
2@06o``00ol900;o0`02oa@00_l00`3oo`02o`030?oo00D01_l900Wo2002o`T01_l:00;o600001@0
0_l>0003o`0000H02Ol:00;o5P02o`030?oo008000Co0?oo1002o`800_l700;o0`02o`<00_l700;o
4002o`H00_l00`3oo`0300;o1002o`040?ooo`P00olN00;o1`02o`<00_l300;o4`09o`@00olJ00;o
00<0ool00P001?l0ool700;o2P02o`040?ooo`P00_l200;o2002o`<00_l900;o0`02oa@00_l00`3o
o`02o`030?oo00D00_l200;o2@08o`@00_l300;o0`02o`@00_l200;o2P02oaP0000D00;o3P02o`L0
0_l00`3oo`02o``00_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l700;o
4002o`H01Ol300;o1002o`800ol700;o1`000ol0000E00;o1`02o`<00_l300;o4`02o`D00_l400;o
1`000ol0000A00;o00<0o`000P001?l0ool700;o2P02o`800ol700;o0P02o`800_l400;o0`03o`T0
0_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o1003o`<00_l300;o0`02o`@00_l200;o
0P02o`H00_lH00005003o`d00_l800;o4002oaH01?l300Co1002o`H00_l300;o0`02o`<00_l700;o
4002o`H01?l400;o1002o`<00ol600;o1P02oaL00_l700;o0`02o`<00_lC00;o1@02o`@00_l600;o
4`04o`<01?l700;o2P02o`<00ol600;o1P02o`@00_l400?o2002o`030?oo01@00_l300;o0`02o`@0
0_l600;o1@02o`D00_l300;o0`02o`<00_l400;o1P02o`H00_lH00005@02o`h000?o00001P03o`h0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`@00_l400?o1@03o`@0
0olG00;o1`02o`<00_l300;o4`02o`D00_l400?o1003oa<01?l400?o1`02o`X00_l400?o1@02o`H0
0_l400;o1@02o`P01OlD00;o2002o`@00_l600;o1@02o`@00ol300;o0`02o`<00_l400;o1P02o`H0
0_lH00005P02o`H00_l500;o2003o``00_lG00Co1@04o`030?oo00[o0`0<o`<02_l700[o0P04o`80
1_l00`3oo`03o`<01Ol400Wo4`0:o`<03?lB00Co0`04o`@02OlB00Co1@04o`802_l400Go0`05o`03
0?oo00[o100:o`@01olD00Ko0P06o`030?oo00[o0`0:o`@03?l200co0`08oaD0000G0003o`0000@0
2Ol900Oo1`000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l700[o0P03o`<01_l00`3oo`03o`<0
1Ol600Go00<0o`004P0:o`<03?lB00Co0`04o`H01Ol00`3o000A00Co1@04o`802_l400Go0`05o`03
0?oo00[o100:o`@01olD00Ko0P06o`030?oo00[o0`09o`D03?l200co0`08oaD0000N00Wo2`05ool0
``000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(77\\) METIJNKS IUZHS MIKEZA WEBSDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@02o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l600Ko1`06o`<00_l200Go1P02o`<00_l00`3oo`03oaD02_l800Co1P0:o`D01?l300Co0`02o`03
0?oo00?o5005o`<01Ol200[o1005o`H00_l00`3oo`0:o`@02_l200Ko0`06oa400_l400;o100<o`<0
2_l500;o00<0ool00ol600So1P0=oa00000C00;o3002o`d00_l?00;o5005o`<01Ol00`3oo`0:o`D0
2?l500[o1009o`H01_l200?o0P05o`D00ol300[o4`0:o`H02?l400[o1@04o`<01?l300[o4P05o`<0
1Ol200[o1005o`D00ol00`3oo`0:o`@02_l200Ko0`06oa400_l400;o100<o`<02ol400[o100:o`@0
3Ol@00004`02o`d00_l=00;o3P02oaD00_l700;o1002o`H00_l800;o3002o`P00ol400?o1P02o`@0
1?l400;o1@03o`@00ol500?o5P02o`X00_l400;o1@02o`D00_l600;o1@02o`@00ol500?o4P02o`L0
0_l700;o2P02o`D00ol400;o1P02o`D00_l500;o1002o`L00_lB00?o1003o`D00_l600;o1@02o`D0
0ol300?o1@03o`@00_l400Co1P02o`H00_l@00004`02o`d00_l=00;o3P02oaD00_l700;o1002o`H0
0_l800;o3002o`P00_l600;o1P02o`@01?l400;o1@02o`D00_l700;o5P02o`T00_l600;o1003o`@0
0_l600;o1@02o`@00_l700;o4P02o`L00_l700;o2P02o`D00_l500;o1P02o`D00ol400;o1002o`L0
0_lB00Co0`03o`D00_l600;o1@02o`H00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d0
0_l=00;o3P02oaD00_l300;o0P02o`@00_l200;o0P02o`P00_l<00;o2002o`H00_l600;o0`05o`@0
0_l400;o1P02o`L00_lF00;o2@02o`H00_l500?o0`02o`H00_l500;o1002o`L00_lB00;o0`02o`80
0_l700;o2P02o`@00_l600;o0P02o`800_l600?o0`02o`@02olB00Co0P04o`D00_l200;o0P02o`D0
0_l600;o0`02o`L00_l400;o1`02o`D00_l600;o400001<00_l>0003o`0000`000?o00003002oaD0
0_l200?o0P02o`@00_l200;o3002o``00_l800;o1P02o`H00_l300;o00<0ool01003o`800ol>00?o
5P02o`T00_l600;o1P02o`<00_l600;o1@02o``00olB00;o0P03o`800_l700;o2P03o`800ol600;o
0P02o`/00_l300;o1@09oa<00_l0103o0004o`D00_l200;o2@02o`H00_l;00?o1002o`L00_l500;o
1P02oa00000C00;o3P02o`d00_l=00;o5@02o`8000?o0?l00P02o`@01_l<00;o3002oa000_l600;o
0P03o`030?oo00@01ol:00Oo5`02o`T00_l600;o1P03o`X00_l500;o1`07oa<00_l20003o`3o0080
0_l700;o2P07o`L01_l;00?o2@02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@03o`H01ol500;o
1`02o`D00_lH00004`02o`h00_l=00;o3@02oaD00_l0103oo`02o`030?oo00@01_l<00;o3002oa00
0_l600;o0P02o`800_l400Go2P07oaT00_l900;o1P02o`L00ol900Wo1@07oaD00_l0103oo`02o`03
0?oo00L00_l:00Go2@06o``00ol900;o0`02oa@00_l00`3oo`02o`030?oo00D01_l900Wo1@07o`L0
0_l700;o1@02oaP0000D00;o3P000ol0000<0003o`0000X00_lF00;o00<0ool00P001?l0ool400;o
0P02o`L00_l300;o0`02o`L00_l@00;o1P02o`030?oo00<00_l400;o00@0oooo2003oah00_l900;o
1P02o`<00_l300;o2@09o`@00olJ00;o00<0ool00P001?l0ool700;o2P02o`040?ooo`P00_l200;o
2002o`<00_l900;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2@08o`D00ol<00;o1`02o`D0
0_lH00005002o`h00_l=00;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o
0`02o`L00_l@00;o1P05o`<00_l400;o0P03o`L00_l70003o`0001D00_l900;o1P02o`<00_l300?o
2002o`D00_l400;o1`000ol0000A00;o00<0o`000P001?l0ool700;o2P02o`800ol700;o0P02o`80
0_l400;o0`03o`T00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l500;o1003o`@00_l70003
o`0000<00_l700;o1@02oaP0000D00?o3@02o`d00_l;00;o5P04o`<01?l400;o1P02o`<00_l300;o
0`02o`L00_l@00;o1P04o`@00_l400;o0`03o`H00_l600;o5`02o`T00_l600;o0`02o`@00ol700;o
1@02o`@00_l600;o4`04o`<01?l700;o2P02o`<00ol600;o1P02o`@00_l400?o2002o`030?oo01@0
0_l300;o0`02o`@00_l600;o1@02o`D00_l400;o1P02o`D00_l600;o1P02oaP0000E00;o3P000ol0
000<0003o`0000P00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`@0
0_l400?o1@03o`@00olG00;o2@02o`H00_l300;o1@02o`L00_l500;o1003o`@00olC00Co1003o`L0
0_l:00;o1003o`D00_l600;o1002o`D00_l800Go5002o`P00_l400;o1P02o`D00_l400?o1003o`@0
0ol500;o1004o`H00_lH00005P02o`H00_l500;o1P02o`D00_l800;o5`04o`D01?l00`3oo`0:o`<0
3?l300[o1`0:o`801?l200Ko00<0ool00ol300Go1009oa<02_l400Co1004o`802_l500Co0`04o`@0
2OlB00Co1@04o`802_l400Go0`05o`030?oo00[o100:o`@01olD00Ko0P06o`030?oo00[o0`0:o`H0
2Ol400[o1008oaD0000G0003o`0000@02Ol600Wo20000ol0000F00Co1@04o`030?oo00[o0`0<o`<0
2_l700[o0P03o`<01_l00`3oo`03o`<01Ol600Go00<0o`004P0:o`@01?l400Co0P0:o`D01?l300Co
1P05o`030?l001401?l500Co0P0:o`@01Ol300Go00<0ool02_l400[o1007oa@01_l200Ko00<0ool0
2_l300Wo2@05o`030?l000<02?l600So5@0001h02Ol600Woo`340000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(78\\) MEUHINKSZIUZHS MIKEZA XEBSEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lE00Go0`05o`030?oo00[o2004o`H0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00ol600[o1@0:o`P01?l600[o1@04o`<0
1?l300;o00<0ool00olD00Go0`05o`802_l400Go1P02o`030?oo00[o100:o`801_l300Ko3`05o`80
1Ol200co0`0:o`D00_l00`3oo`03o`D03?l300go400001<00_l<00;o2`08o`/00_lD00Go0`05o`03
0?oo00[o1P08o`@01?l300Co100:o`@01_l200?o0P05o`D00ol300[o100:o`D02_l600So100:o`D0
1?l300Co0`0:oa801Ol300Go0P0:o`@01Ol500?o00<0ool02_l400[o0P06o`<01_l?00Go0P05o`80
3?l300_o100:o`<03?l300go400001<00_l=00;o2@03o`@00ol:00;o5@02o`L00_l400;o1P02o`H0
0_l400;o1@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o1002o`D00_l900;o2P02o`@0
0_l500;o1@02o`H00_l500;o1003o`D00olB00;o1`02o`L00_l:00;o1@03o`@00_l600;o1@02o`D0
0_l400;o1`02oa800ol400?o1@02o`H00_l500;o1@03o`<00ol500?o1002o`H00_l600;o1P02oa00
000C00;o3@02o`T00_l600;o2P02oaD00_l700;o1002o`H00_l500;o1P02o`@00_l500;o2@02o`T0
0_l400Co1002o`D00_l500;o1`02o`@00ol400;o2@02o`T00_l600;o1003o`@00_l600;o1@02o`@0
0_l700;o4P02o`L00_l700;o2P02o`D00_l500;o1P02o`D00ol400;o1002o`L00_lC00?o0P03o`H0
0_l600;o1@02o`H00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`d00_l900;o1P02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l500;o1P02o`@00_l500;o2@02o`T00_l300Go1002o`@0
0_l600;o1`02o`D00ol300;o2@02o`T00_l600;o1@03o`<00_l600;o1@02o`@00_l700;o4P02o`<0
0_l200;o1`02o`X00_l400;o1P02o`800_l200;o1P03o`<00_l400_o5002o`800_l700;o0P02o`80
0_l500;o1P02o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`h000?o00001`02o`H0
0_l:00;o5@02o`800ol200;o1002o`800_l900;o1P02o`@00_l500;o2@02o`T00_l300;o00<0ool0
1003o`800ol>00?o1P02o`<00_l900;o2@02o`H00_l600;o0`02o`H00_l500;o3003oa800_l200?o
0P02o`L00_l:00?o0P03o`H00_l200;o2`02o`<00_l500Wo5P04o`P00_l200;o2@02o`H00_l;00?o
1002o`800_l:00;o1P02oa00000C00;o3P02o`T00_l400;o2`02oaD00_l20003o`3o00800_l400Ko
2@02o`H00_l400;o1@02o`T00_l900;o0P03o`030?oo00@01ol:00Oo1`03o`d00_l900;o1P02o`H0
0ol:00;o1@02o`L01olC00;o0P000ol0o`0200;o1`02o`X01ol700Ko2`03o`T00_l500;o5P04o`P0
1_l900;o1@03o`H01ol500Ko2P02oaP0000C00;o3P02o`X01ol;00;o5@02o`040?oo00;o00<0ool0
1006o`T00_l600;o1009o`T00_l900;o0P02o`800_l400Go2P07o`X00ol<00;o2@02o`H00_l700?o
2@09o`D01olE00;o00@0ool00_l00`3oo`0700;o2P05o`T01_l<00?o2@02o`<00_lG00?o2@06o`T0
2Ol500Oo1`06o`X00_lH00005002o`h000?o00002006o`/00_lF00;o00<0ool00P001?l0ool400;o
0P02o`T00_l600;o1009o`T00_l900;o00<0ool00`02o`@00_l0103oool800?o2`02o`<00_l<00;o
2@02o`H00_l300;o0`02o`T02Ol400?o6P02o`030?oo008000Co0?oo1`02o`X00_l0103oool800;o
0P02o`P00_l300;o2@02o`<00_lG00Co2002o`800_l900So1@03o``00_l200;o2P02oaP0000D00;o
3P02o`P00_l400;o2P02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`D00_l600;o1002o`D0
0_l900;o2@05o`<00_l400;o0P03o`L00_l70003o`0000800_l300?o2`02o`T00_l600;o0`02o`<0
0ol800;o1@02o`@00_l70003o`0001400_l00`3o00020004o`3oo`L00_l:00;o0P03o`L00_l200;o
0P02o`@00_l300?o2@02o`040?oooaH01_l700;o0P02o`800_l500;o1003o`@00_l70003o`0000<0
0_l200;o0P02o`H00_lH00005003o`d00_l700;o1P02o`T00_lF00Co0`04o`@00_l600;o1@02o`H0
0_l400;o1@02o`T00_l900Co1002o`@00_l300?o1P02o`H00_l400;o1003o`X00_l900;o1P02o`<0
0_l400?o1`02o`D00_l400;o1P02oa<01?l300Co1`02o`X00_l300?o1P02o`H00_l400;o1003o`P0
0_l00`3oo`0F00?o0P03o`H00_l600;o1@02o`D00_l400;o1P02o`D00_l600;o1P02oaP0000E00;o
3P000ol0000500;o1P02o`P00_lG00Co1003o`@00_l600;o1@02o`H00_l400;o1@02o`T00_l900Co
1002o`@00_l400?o1@03o`@00ol400;o1@02o`X00_l900;o1P02o`<00_l500;o1`02o`D00_l400?o
1003oa<01?l400?o1`02o`X00_l400?o1@02o`H00_l400;o1@02o`P01OlF00;o1002o`H00_l600;o
1@02o`@00ol400?o1003o`D00_l600;o1P02oaP0000F00;o1P02o`D00_l600?o1003o`L00_lG00Co
1@04o`030?oo00[o1004o`@01?l200Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@02Ol400[o
1@0:o`@01?l400Co0P0:o`D01?l300Co1009oa801?l500Co0P0:o`@01Ol300Go00<0ool02_l400[o
1007oaD01Ol200Go0P0<o`<02_l600Wo0`0<o`<02?lE00005`000ol0000400Wo1`08o`P000?o0000
5P04o`D01?l00`3oo`0:o`@01?l400Co0P04o`<01?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go
00<0o`000`0:o`D02_l400Co1004o`802_l500Co0`04o`H01Ol00`3o000A00Co1@04o`802_l400Go
0`05o`030?oo00[o100:o`@01olE00Go0P05o`803?l300Wo2@05o`030?l000803?l300So5@0001h0
2Ol800Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(79\\) MDTIIMJSZITZIS MJKEZA XEBSEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2P05o`h00_lE00Go0`05o`802?l800So1@0:o`D0
2_l300Go0`05o`<01_l800;o00<0ool00ol600[o1@0:o`D02?l500[o1@0:o`@00_l00`3oo`03oa@0
1Ol300Go0`06o`L01Ol600;o00<0ool02_l400[o0P06o`<01_l?00Go0P05o`803?l300[o1@02o`03
0?oo00?o1@0<o`<03Ol@00004`02o``00_l:00Oo3@02oa@01Ol300Go0P0:o`H02?l500[o1@0:o`<0
1Ol300Go00<0ool01ol700[o100:o`D02_l500So1@0:o`D02_l400[o4P05o`<01Ol00`3oo`07o`H0
1Ol500?o00<0ool02_l400[o0P06o`<01_l?00Go0P05o`803?l300_o100:o`<03?l300go400001<0
0_l=00;o3P03o``00_lE00;o1`02o`@00_l400Co2002o``00_l=00;o2002o`L00_l200?o1003o`H0
0ol500?o1002o`D00_l900;o3002o`T00_l500;o2@02o`P00ol500?o4P02o`L00_l200?o1003o`L0
0_l500?o1002o`H00_l500;o1@02o`@00_l700;o4P03o`@00ol500;o1P02o`D00_l500?o0`03o`D0
0ol400;o1P02o`H00_l600;o400001<00_l=00;o3`03o`/00_lE00;o1`02o`@00_l600;o2002o``0
0_l=00;o2002o`L00_l200;o1P02o`H00_l700;o1003o`@00_l900;o3002o`T00ol400;o2@02o`P0
0_l700;o4P02o`L00_l200;o1P02o`L00_l500;o1@02o`H00_l500?o1002o`@00_l700;o4`03o`80
0ol600;o1P02o`D00_l600;o0`02o`L00_l400;o1P02o`H00_l600;o400001<00_l=00;o4002o`/0
0_lE00;o0`02o`800_l400;o1`02o`L00_l<00;o3@02o`P00_l300;o0P02o`800_l600;o1P02o`L0
0_l500?o0`02o`T00_l<00;o2P03o`<00_l900;o2002o`L00_lB00;o0`02o`800_l200;o1P02o`L0
0_l400;o1P02o`800_l200;o1P03o`<00_l400_o5002o`800_l700;o0P02o`800_l500;o1P02o`<0
0_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`h000?o00002P04o`030?oo00X00_lE00;o
0P03o`800_l400;o1`02o`L00_l<00;o3@02o`P00_l200?o0P02o`800_l600;o3P03o`H00_l300;o
2@02o``00_l;00;o0`02o`T00_l@00?o4P02o`800ol200;o0P02o`H00_l700?o0P03o`H00_l200;o
2`02o`<00_l500Wo5P04o`P00_l200;o2@02o`H00_l;00?o1002o`800_l:00;o1P02oa00000C00;o
3P02o`T02Ol:00;o5@02o`8000?o0?l00P02o`@00_l700;o1`02o``00_l=00;o2002o`8000?o0?l0
0P02o`X00_l900Oo1`03o`d00_l<00;o2`03o`d00_l;00Oo4`02o`8000?o0?l00P02o`X00_l700Oo
1`06o`/00ol900;o1@02oaH01?l800Ko2@02o`D00ol600Oo1@06o`X00_lH00004`02o`h00_l900;o
1003o`X00_lE00;o00@0ool00_l00`3oo`0400;o1`02o`L00_l<00;o3@02o`P00_l0103oo`02o`03
0?oo00X00_l700Oo2P03o``00_l<00;o3003o``00_l900Oo5@02o`040?oo00;o00<0ool02P02o`L0
1Ol900Ko3003o`T00_l300;o5`03o`T01_l900Wo1@07o`L01_l:00;o600001@00_l>0003o`0000H0
0_l600;o2@02oaH00_l00`3oo`020004o`3oo`@00_l700;o0P02o`<00_l300;o1`02o`d00_l800;o
00<0ool00P001?l0ool:00;o1P03o`/00_l300;o3002o`L00_l300;o0`02o`<00_l300;o3002o`P0
0olJ00;o00<0ool00P001?l0ool:00;o1`02o`040?ooo`P00_l200;o2002o`<00_l900;o0`02oaL0
1?l800;o0P02o`T02?l500?o3002o`800_l:00;o600001@00_l>00;o1`02o`H00_l900;o5P02o`03
0?l0008000Co0?oo1002o`L00_l200;o0`02o`<00_l700;o3@02o`P00_l00`3o00020004o`3oo`X0
0_l600;o1`000ol0000200;o0`03o`/00_l700;o0`02o`<00_l300;o0`03o`/00_l800;o1`000ol0
000A00;o00<0o`000P001?l0ool:00;o1`02o`800ol700;o0P02o`800_l400;o0`03o`T00_l0103o
oolF00Ko1`02o`800_l200;o1@02o`@00ol400;o1`000ol0000300;o0P02o`800_l600;o600001@0
0ol=00;o1`02o`H00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2004o`<0
1?l:00;o1P02o`H00_l400;o1003o`X00_l700;o0`02o`<00_l300;o1003o`X00_l800;o1P02oa<0
1?l300Co2P02o`L00_l300?o1P02o`H00_l400;o1003o`P00_l00`3oo`0F00?o0P03o`H00_l600;o
1@02o`D00_l400;o1P02o`D00_l600;o1P02oaP0000E00;o3P000ol0000500;o1P000ol0000700;o
5`04o`@00ol400;o1004o`<00_l300;o0`02o`L00_l=00;o2004o`@00ol:00;o1P03o`@00ol400;o
1@02o`X00_l700;o0`02o`<00_l300;o1@02o`X00_l800?o1003oa<01?l400?o2P02o`L00_l400?o
1@02o`H00_l400;o1@02o`P01OlF00;o1002o`H00_l600;o1@02o`@00ol400?o1003o`D00_l600;o
1P02oaP0000F00;o1P02o`D00_l700;o1002o`P00_lG00Co1@04o`802_l400co0`0:o`D02_l300Co
1@04o`@02_l400Wo100:o`D02_l300co0`0:o`D02_l500Wo4P04o`D01?l400[o0P05o`<01Ol00`3o
o`0:o`@02_l400Oo5@05o`801Ol200co0`0:o`H02Ol300co0`08oaD0000G0003o`0000@02Ol700Oo
2@000ol0000F00Co1@04o`802?l600co0`0:o`D02_l300Co1@04o`@02_l600Go00<0o`000`0:o`D0
2_l300co0`0:o`D02_l700Go00<0o`004@04o`D01?l400[o0P05o`<01Ol00`3oo`0:o`@02_l400Oo
5@05o`801Ol200co0`09o`T01Ol00`3o000200co0`08oaD0000N00Wo2@04ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(80\\) METIIMJSZHT IS MJJEZA XEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o0`05o`<01Ol300Ko2002o`030?oo00?o1P0:o`D01?l300Co1008oa@02_l400;o00<0ool0
0olD00Go0`05o`<01_l900Ko1P0<o`@02_l200Ko0`06o`l01Ol200Go0P0<o`801_l300Ko00@0ool0
1Ol500co0`0=oa00000C00;o2P08o`P01_l<00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`<0
1Ol300Go00<0ool01ol700[o100:o`D01?l300Co1008oa@02_l400[o4P05o`<01Ol00`3oo`07o`H0
2Ol500co100:o`801_l300Ko3`05o`801Ol200co0P06o`<01_l00`3oo`08o`<03?l300go400001<0
0_l900?o1003o`H00ol200?o2`02oaD00_l700;o1002o`H00_l800;o3002o`d00_l800;o1`02o`80
0ol400?o1P03o`D00ol400;o1@02o`H00_l500;o2002oa/00_l800?o1@03oa800_l700;o0P03o`@0
0ol500?o1003o`H00_l600;o1@02o`D00_l400;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol500?o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l600;o1002o`/00_lE00;o1`02o`@0
0_l600;o2002o``00_l=00;o2002o`L00_l200;o1P02o`H00_l700;o1003o`@00_l600;o1@02o`P0
0_lK00;o2002o`L00_lB00;o1`02o`800_l600;o1@02o`H00_l600;o1P02o`D00ol400;o1002o`L0
0_lC00?o0P03o`H00_l600;o1002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T0
0_l600;o1@02o`H00_l:00;o5@02o`<00_l200;o1002o`800_l200;o2002o``00_l=00;o2002o`<0
0_l200;o0P02o`H00_l600;o1`02o`D00ol300;o1P02o`D00_l800;o6`02o`P00_l700;o4P02o`<0
0_l200;o0P02o`H00_l500;o1P02o`H00_l200;o0P02o`H00ol300;o100;oa@00_l200;o1`02o`80
0_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T00_l600;o1@02o`H0
0_l:00;o5@02o`800ol200;o1002o`800_l<00;o3002o`d00_l800;o0P03o`800_l200;o1P02o`h0
0ol600;o0`02o`H00_l500;o2002oa/00_l@00?o4P02o`800ol200;o0P02o`H00_l500;o1P02o`H0
0_l200;o2`02o`<00_l500Wo5P04o`P00_l200;o2@09o``00ol400;o0P02o`X00_l600;o400001<0
0_l:00;o1002o`H00_l600;o2P02oaD00_l20003o`3o00800_l400Ko3002o``00_l=00;o2002o`80
00?o0?l00P02o`X00_l900Oo1`03o`X00_l500;o2002oa/00_l;00Oo4`02o`8000?o0?l00P02o`X0
0_l=00;o1P06o`/00ol900;o1@02oaH01?l800Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/0
1ol600;o1P02o`X00_lE00;o00@0ool00_l00`3oo`0400Ko3002o``00_l=00;o2002o`040?oo00;o
00<0ool02P02o`L01ol:00?o2@09o`P00_lK00;o2@07oaD00_l0103oo`02o`030?oo00X00_l=00;o
1P06o``00ol900;o0`02oaL00ol900Ko2P02o`<00_l600Oo1`06o`X00_lH00005002o`X01_l700;o
1P02o`T00_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l=00;o2002o`03
0?oo008000Co0?oo2P02o`H00ol;00;o0`02o`T02Ol300;o0`02o`<00_lF00;o2003oaX00_l00`3o
o`020004o`3oo`X00_l=00;o1P02o`800_l800;o0`02o`T00_l300;o5`04o`P00_l200;o2P02o`<0
0_l500?o3002o`800_l:00;o600001@00_l900;o1002o`H00_l600;o2@02oaH00_l00`3o00020004
o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o2002o`030?l0008000Co0?oo2P02o`H0
0_l70003o`0000800_l300?o2002o`D00_l300;o0`02o`<00_lF00;o2002o`L000?o00004@02o`03
0?l0008000Co0?oo2P02o`d00_l600;o0P02o`800_l400;o0`03o`T00_l0103ooolF00Ko1`02o`80
0_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H00_lH00005003o`L00_l600;o
1@02o`H00_l900;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2004o`<01?l:00;o
1P02o`H00_l400;o1003o`L00_l500;o0`02o`<00_l300;o5P02o`P00_l600;o4`04o`<01?l:00;o
3@02o`H00_l600;o1002o`@00ol800;o00<0ool05P03o`800ol600;o1P02o`L00_l00`3oo`0600;o
1P02o`D00_l600;o1P02oaP0000E00;o1`02o`H00_l600;o1002o`T00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1`02o`d00_l800Co1003o`X00_l600?o1003o`@00_l500;o1`02o`D00_l300;o
0`02o`<00_lF00;o2003o`@00olC00Co1003o`X00_l=00;o1P02o`H00_l400;o1@02o`P01OlF00;o
1002o`H00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600?o1003o`H00ol200?o
2002oaL01?l500Co00<0ool02_l300co0`0:o`D02_l300Co1@04o`@02_l400Wo100:o`D01?l300Co
0P0<oa802_l500Wo4P04o`D01?l400[o1@0:o`030?oo00[o100:o`@01olE00Go0P05o`803?l400Oo
2009o`<03?l300So5@0001L000?o00001@08o`P01_l90003o`0001H01?l500Co00<0ool02_l300co
0`0:o`D02_l300Co1@04o`@02_l600Go00<0o`000`0:o`D01?l300Co0P0<oa802_l700Go00<0o`00
4@04o`D01?l400[o1@0:o`030?oo00[o100:o`@01olE00Go0P05o`803?l400Oo2P05o`030?l00080
3?l300So5@0002001_l:00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(81\\) MDTHIMKSZHS IS LIKEZAZWFAREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00Go0`05o`802?l800So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`03o`H00_l300;o00<0ool00ol600[o1@04o`<01?l300;o00<0ool0
0olE00[o1002o`030?oo00?o500=o`802_l400Go1P02o`030?oo00[o100:o`801_l300Ko00<0ool0
2?l600;o1002o`@01ol700Ko0`0;o`H03ol300go400001<00_l:00So1`09o`X00_lD00Go0`05o`80
2_l600So1@04o`<01?l400[o0`05o`<01Ol00`3oo`03o`D00ol300[o100:o`D01?l300Co0`0:oa<0
2_l400[o4P0=o`802_l400Go1@03o`030?oo00[o100:o`801_l300Ko00<0ool02?l600;o1002o`@0
1ol700Ko0`0;o`D04?l300go400001<00_l900?o1003o`X00_l=00;o5@02o`L00_l400;o1004o`P0
0_l900;o1@02o`T00_l800;o1`02o`@00_l500?o1003o`D00ol400;o1@02o`H00_l500;o1003o`D0
0olF00;o2003o`D00olD00;o1P02o`H00_l:00;o1@03o`@00_l600;o1@02o`D00_l400;o1`02o`@0
0_l500;o1@03o`@00ol500;o3002o`L00_l400;o1@03o`@00_l600;o1P02o`H00_l@00004`02o`T0
0_l600;o2P02o`d00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o2@02o`P00_l700;o1002o`D0
0_l500;o1`02o`@00ol400;o1P02o`D00_l400;o1`02oaH00_l800;o1`02oa@00_l600;o1P02o`X0
0_l500;o1@02o`H00_l500?o1002o`@00_l700;o1003o`@00_l500Co0`03o`D00_l<00;o1`02o`@0
0_l500;o1@02o`H00_l600;o1P02oa00000C00;o2@02o`H00_l:00;o3@02oaD00_l300;o0P02o`@0
0_l700;o1`02o`T00_l500;o2@02o`P00_l300;o0P02o`@00_l400;o1P02o`L00_l500?o0`02o`H0
0_l500;o1002o`L00_lF00;o2002o`L00_lD00;o1P02o`H00_l:00;o1002o`H00_l200;o0P02o`H0
0ol300;o100;o`D00ol300;o1@04o`801?l500;o0P02o`P02ol400;o1002o`H00_l200;o0P02o`H0
0_l600;o400001<00_l900;o1P02o`X00_l=00;o5@02o`800ol200;o1002o`L00_l700;o2@02o`D0
0_l900;o2002o`800ol200;o1003o`800ol>00?o1P02o`<00_l600;o1@02o``00olF00;o4003oa@0
0_l600;o1P02o`X00ol200?o1P02o`800_l;00;o0`02o`D02Ol700;o0`02o`D00_l0103o0004o`D0
0_l200;o2@09o`D00_l300?o1P02o`800_l:00;o1P02oa00000C00;o2P02o`@00_l;00;o3@02oaD0
0_l20003o`3o00800_l400;o1`02o`L00_l900;o1@02o`T00_l800;o0P000ol0o`0200;o1007o`X0
1ol700?o2P02o`D00_l700Oo5`02o`/01olE00;o3P02o`X01ol700Ko2`03o`T00_l500;o1`03o`T0
0_l01P3o003o00;o1@06o`T00_l500;o1@07o`L01_l:00;o600001<00_l;00Oo2`02o`d00_lE00;o
00@0ool00_l00`3oo`0400;o1`02o`L00_l900Wo2@02o`P00_l0103oo`02o`030?oo00@01Ol:00Oo
2P03o`T02Ol500Oo6@02o`T01olG00;o3P02o`X01Ol900Ko3003o`T00_l300;o2@03o`P00_l00`3o
o`02o`030?oo00D01_l:00;o0`02o`H02Ol500Ko2P02oaP0000D00;o2P06o``00_l<00;o5P02o`03
0?oo008000Co0?oo1002o`L00_l200;o0`02o`<00_l400Wo2@02o`P00_l00`3oo`020004o`3oo`@0
0_l0103oool800?o2`02o`<00_l900Wo1003oah00_l800?o7002o`h00_l:00;o00@0oooo2002o`80
0_l800;o0`02o`T00_l300;o1@02o`<00_l800;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o
1P02o`D00ol400;o0P02o`X00_lH00005002o`T00_l400;o2`02o``00_lF00;o00<0o`000P001?l0
ool400;o1`02o`800_l300;o0`02o`@00_l500;o2@02o`P00_l00`3o00020004o`3oo`@00_l200?o
1`02o`L000?o00000P02o`<00ol800;o1@02o`@00_l70003o`0001D00_l800;o1`000ol0000C00;o
3P02o`X00_l200?o1`02o`800_l200;o1002o`<00ol900;o00@0oooo1@02o`<00ol600;o0`02o`<0
0_l400;o0P02o`800_l700;o00@0oooo1P02o`H00_l400;o0P02o`800_l600;o600001@00ol700;o
1P02o`X00_l<00;o5P04o`<01?l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l300Co
1002o`<00ol600;o1P02o`@00_l400?o1`02o`D00_l400;o1P02oaL00_l800;o1P02oaD00_l>00;o
2P02o`<00ol600;o1P02o`@00_l400?o2002o`030?oo00H00_l400?o1@02o`<00_l300;o1002o`H0
0_l700;o00<0ool01`02o`H00_l400;o1P02o`H00_lH00005@02o`L00_l600;o2P02o`/00_lG00Co
1003o`@00_l400Co0`02o`<00_l300;o1002o`D00_l900;o2004o`@00ol400;o1003o`D00ol400?o
1002o`D00_l700;o1@02o`@00ol400?o5`02o`P00ol400?o5@02o`h00_l:00;o1003o`D00_l600;o
1002o`D00_l800Go1P02o`D00_l500;o2002o`@00_l600;o1`05o`L00_l500?o1002o`H00_l600;o
600001H00_l600?o1003o`H00ol00`3oo`0:00;o5`04o`D01?l200[o100<o`<01?l300Co100:o`<0
1?l500Co00<0ool00ol300Go1009o`@02_l500Co0`04o`@02OlC00[o1@09oa802?l700[o1005o`<0
1Ol00`3oo`0:o`@02_l400Oo1`0:o`<01_l200Ko00<0ool02_l400Oo1P0;o`<03?l300So5@0001L0
00?o00001@08o`L01_l:0003o`0001H01?l500Co0P08o`H03?l300Co0`04o`@02_l300Co1@04o`03
0?oo00?o0`05o`H01Ol00`3o000300[o1@04o`<01?l600Go00<0o`004P0:o`L01Ol00`3o000A00So
1`0:o`@01Ol300Go00<0ool02_l400[o1007o`L02_l300Ko0P06o`030?oo00[o1007o`H02Ol500co
0`08oaD0000P00Ko2`03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(82\\) MDTGIMKSZHT ISZKIKE AZXFASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00Go0`05o`802?l800So2006o`H0
2_l300Go0`05o`030?oo00?o1P02o`<00_l00`3oo`03o`H02_l500Co0`04o`@02?lD00[o1002o`03
0?oo00?o1`0:o`<01Ol600;o0P0:o`@01Ol600;o00<0ool02_l@00Ko0`06o`030?oo00So1005o`80
1Ol200Oo1`06o`<01_l0103oo`05o`D03?l300go400001<00_l:00So1P0:o`X00_lD00Go0`05o`80
2_l600So1P0:o`@02_l300Go0`05o`030?oo00?o1@03o`<02_l400[o1@04o`<01?l400So500:o`@0
2_l500[o0`05o`D00ol200[o1005o`D00ol00`3oo`0:oa001_l300Ko00<0ool02?l400Go0P05o`80
1ol700Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o1P02o`D00_l:00;o5@02o`L0
0_l400;o1004o`P00_l800Co1@02o`P00_l800;o1`02o`@00_l500?o1003o`D00ol400;o1@02o`H0
0_l500;o2002oa/00_l800?o1@03o`D00_l500;o1@02o`D00ol700;o2P02o`D00ol400;o1P02oa80
0_l700;o1002o`D00_l500?o1003o`D00_l<00;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00
000C00;o2@02o`H00_l700?o3`02oaD00_l700;o1002o`H00_l800;o2002o`L00_l800;o2002o`L0
0_l400;o1@02o`D00_l700;o1003o`@00_l600;o1@02o`P00_lK00;o2002o`L00_l500?o1002o`D0
0_l500;o2002o`X00_l500;o1@02o`H00_lB00;o1`02o`@00ol400;o1P03o`800ol600;o3002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o2003o`h00_lE00;o0`02o`80
0_l400;o1`02o`L00_l700?o1`02o`P00_l800;o0`02o`800_l400;o1002o`H00_l700;o1@03o`<0
0_l600;o1@02o`P00_lK00;o2002o`L00_l600?o0`02o`D00_l400;o2@02o`X00_l400;o1P02o`80
0_l200;o4P0;o`D00ol300;o1`02o`800_l700;o0P02o`P02ol300;o1`02o`@00_l200;o0P02o`H0
0_l600;o400001<00_l900;o1P02o`T00ol=00;o5@02o`800ol200;o1002o`L00_l700;o1`02o`@0
1ol700;o2002o`800ol200;o1003o`800ol>00?o1P02o`<00_l600;o1@02o`P00_lK00;o4003o`L0
0_l300;o1@03o`800ol900;o2P03o`800ol600;o0P02oaL02Ol700;o0`02o`P01?l800;o0P02o`T0
2Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2P02o`@00_l;00?o3002oaD00_l20003o`3o0080
0_l400;o1`02o`L00_l700;o1007o`L00_l800;o0P000ol0o`0200;o1007o`X01ol700?o2P02o`D0
0_l800;o6`02o`/01ol800?o2@07o`X00_l:00Oo1`06oaL00_l500;o1`03o``01?l800Ko2@02o`D0
0_l700Oo1@06o`X00_lH00004`02o`/01ol<00?o2`02oaD00_l0103oo`02o`030?oo00@00_l700;o
1`02o`L00_lB00;o2002o`040?oo00;o00<0ool01005o`X01ol:00?o2@09o`P00_lK00;o2@07o`/0
0ol800Go3002o`X01Ol900Ko6002o`<00_l900?o2`03o`T01_l:00;o0`02o`H01ol700Ko2P02oaP0
000D00;o2P06o`h00_l:00;o5P02o`030?oo008000Co0?oo1002o`L00_l200;o0`02o`<00_l200;o
4P02o`P00_l00`3oo`020004o`3oo`@00_l0103oool800?o2`02o`<00_l900Wo0`02o`<00_l300;o
5P02o`P00ol<00;o0`02o`P00_l0103oool;00;o2P02o`040?ooo`P00_l200;o6002o`<00_l500;o
0`02o`/01?l800;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o2@02o`@00_l>00;o
2@02oaH00_l00`3o00020004o`3oo`@00_l700;o0P02o`<00_l300;o0P02o`P00_l800;o2002o`03
0?l0008000Co0?oo1002o`800ol700;o1`000ol0000200;o0`03o`P00_l500;o0`02o`<00_l300;o
5P02o`P00_l70003o`0000<00_l300?o1`02o`800ol:00;o2P02o`800ol700;o0P02o`800_lE00;o
00@0oooo1@02o`<00ol900Ko1`02o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o
0P02o`H00_lH00005003o`L00_l600;o3@02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o
0`02o`H00ol800;o2004o`<01?l400;o0`03o`H00_l600;o1002o`@00ol700;o1@02o`<00_l300;o
0`02oaH00_l800;o1P02o`D00_l400?o1P02o`<00ol900;o2P02o`<00ol600;o1P02oaD00_l00`3o
o`0600;o1003o`L00ol200?o1P02o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH0000
5@02o`L00_l600;o1P02o`D00_l800;o5`04o`@00ol400;o1004o`<00_l300;o0`02o`<00ol400Co
2002o`P01?l400?o1002o`@00ol500?o1003o`@00_l500;o1`02o`D00_l300;o0`02o`<00_lF00;o
2003o`@00ol500;o1@02o`H00_l400?o2002o`X00_l400?o1@02o`H00_lE00Go1P02o`D00_l700;o
1002o`H00_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600?o1003o`H00ol300?o
1`02oaL01?l500Co0P0:o`@03?l400[o100:o`<01?l500Co00<0ool00ol300Go1009o`@02_l500Co
0`04o`803?lB00[o1@09o`D02_l300Go0`05o`802_l400Go0`05o`030?oo00[o4P07o`L02_l400Go
0P05o`803?l400Oo2009o`<03?l300So5@0001L000?o00001@08o`P01ol80003o`0001H01?l500Co
0P08o`H03?l600Go00<0ool0100:o`<01?l500Co00<0ool00ol300Go1P05o`030?l000<02_l500Co
0`04o`803?lB00[o1`05o`030?l000@02_l300Go0`05o`802_l400Go0`05o`030?oo00[o4P07o`L0
2_l400Go0P05o`803?l400Oo2P05o`030?l000803?l300So5@0002001_l:00Goo`350000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(83\\) METGHNKSZIT JRZLIJE A WFASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00Go0`05o`030?oo00[o1@08o`P0
1_l600Co0`04o`<01_l300;o0P05o`H00_l300;o00<0ool00ol600[o1@0:o`D02?lE00Ko1P05o`H0
0ol200[o0`0=o`802_l600Ko1P0<oa001_l300Ko4@02o`@00_l400Oo1`06o`<01_l0103oo`05o`D0
3?l300go400001<00_l:00So1P09o`/00_lD00Go0`05o`030?oo00[o1@08o`H02_l400Co0`04o`<0
1_l200?o0P05o`D00ol300[o100:o`D02_l500So4`09o`D01Ol500Co0P0:o`<03Ol200[o1009o`D0
3?l@00Ko0`06oa400_l400;o1007o`L01_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@03o`@0
0ol500;o1@02o`/00_lE00;o1`02o`@00_l600;o2002o`P01?l500;o1@02o`D00_l500;o1004o`@0
0_l500?o1003o`D00ol400;o1@02o`T00_l<00;o5P03o`@00ol600;o1@03o`D00_l500;o1P02o`H0
0_l600;o2003o`@00ol600;o1P02oa800_l700;o4P03o`@00ol500;o3002o`L00_l300?o1@03o`@0
0_l600;o1P02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lE00;o1`02o`@00_l600;o2002o`P0
0_l700;o1@02o`D00_l500;o1004o`@00_l500;o1@02o`L00_l400?o1002o`T00_l<00;o5P02o`H0
0_l600;o1@02o`H00ol400;o1P02o`H00_l600;o2002o`H00_l600;o1P02oa800_l700;o4P04o`<0
0ol500;o3002o`L00_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o3@02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o1`03o`L00_l500;o1@02o`D00_l300Go1002o`@0
0_l600;o1`02o`D00ol300;o2@02o``00_lF00;o1P02o`H00_l400;o2003o`<00_l600;o1P02o`H0
0_l800;o1P02o`H00_l200;o0P02oa802olB00Co0P04o`D00_l200;o200;o`<00_l700;o1002o`80
0_l200;o1P02o`H00_l@00004`02o`T00_l600;o3@02o`X00_lE00;o0P03o`800_l400;o0P02o``0
0_l700;o1007o`@00_l500;o1@02o`<00_l00`3oo`0400?o0P03o`h00ol600;o0`02o`T00_l<00;o
5P02o`H00_l600;o0`03o`T00_l300;o1P02o`H00_l600;o2002o`H00_l600;o0P02oaL02OlC00;o
00@0o`001?l500;o0P02o`T02Ol<00?o1002o`800_l:00;o1P02oa00000C00;o2P02o`@00_l=00;o
2`02oaD00_l20003o`3o00800_l400Ko3002o`L00_l400Oo1002o`D00_l500;o0P03o`030?oo00@0
1ol:00Oo1`03o`d00_l<00;o7P02o`H01ol:00?o2P02o`h00_l@00;o1P06oaL00_l500;o4`02o`06
0?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH00004`02o`/01ol:00Co3002oaD00_l0103o
o`02o`030?oo00@01_l<00;o1`02o`l02Ol500;o0P02o`800_l400Go2P07o`X00ol<00;o3002oah0
0_l600Wo2@03o`T00_l>00;o4002o`H01_lH00;o0`02oa@00_l00`3oo`02o`030?oo00D01_l:00;o
0`02o`H01ol700Ko2P02oaP0000D00;o2P06o`/00ol<00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l200;o3`09o`D00_l00`3oo`0300;o1002o`040?ooo`P00ol;00;o0`02o``0
0_l700;o0`02o`<00_lI00;o1P02o`D00ol400;o0`02o`T00_l>00;o4002o`H00_l200;o6002o`<0
0_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0000D00;o
2@02o`@00_l<00;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`80
0_l800;o1@02o`D00_l500Go0`02o`@00_l200?o1`02o`L000?o00000P02o`<00ol;00;o1`02o`<0
0_l300;o6@02o`H00_l600;o1002o`<00ol800;o3P02oa000_l600;o0P02o`800_lE00;o00@0oooo
4`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`H0
0_lH00005003o`L00_l600;o3002o`X00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o0`02o`H0
0ol500;o1@02o`D01?l400;o1002o`<00ol600;o1P02o`@00_l400?o2P02o`L00_l300;o0`02oaT0
0_l600;o1P02o`@00_l400?o1`02o`h00_l@00;o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o
1002o`H00_l700;o00<0ool01P02o`H00_l500;o1P02o`H00_lH00005@02o`L00_l600;o3002o`T0
0_lG00Co1003o`@00_l600;o0`02o`<00_l300;o0`03o`@01?l500;o1@02o`D01?l400;o1002o`@0
0ol500?o1003o`@00_l500;o2P02o`L00_l300;o0`02oaT00_l600;o1@03o`@00_l500;o1`02o`h0
0_l@00;o1P02o`H00_lE00Go5002o`P00_l400;o1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0
000F00;o1P03o`@00ol600;o0`03o`P00_lG00Co1@04o`030?oo00[o0`0<o`@02_l400Co0`04o`<0
1?l200Ko00<0ool00ol300Go1009o`@02_l500[o0`0<oa@02_l00`3oo`09o`D02_l300So1`0:o`L0
2_l00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`08oaD0000G0003o`0000D0
2?l700Oo2@000ol0000F00Co1@04o`030?oo00[o0`0<o`H01Ol00`3oo`0400Co0`04o`<00ol300Ko
00<0ool00ol300Go1P05o`030?l000<02_l500[o0`0<oa@02_l00`3oo`07o`L02_l300So1`0:o`L0
2_l00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`08oaD0000P00Ko
2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(84\\) METGHOKSYIT IRZLIJE A WEASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co3006o`T00_lE00Go0`05o`030?oo00[o1@08o`P0
1_l600Co0`04o`H01Ol500Go1P02o`<00_l00`3oo`03o`L02?l600[o1@08oa@02_l300Go1P03o`80
2_l300go0P0:o`H01_l600co4006o`<01_lA00;o1002o`@03?l200Ko0`06o`040?oo00Go1@0<o`<0
3Ol@00004`02o`X02?l:00Ko2P02oa@01Ol300Go00<0ool02_l500So1P0:o`@01?l300Co1009o`<0
1Ol500?o0`0:o`D02?l600[o1@08oa@02_l300Go1@04o`802_l300go0P0:o`@02Ol500co4006o`<0
1_lA00;o1002o`@03?l200Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o2`02o``0
0_lE00;o1`02o`@00_l600;o2002o`P01?l500;o1@02o`D00_l400?o1@03o`@00_l500?o1003o`D0
0ol700;o3@02o``00_lK00;o2@02o`D00ol500;o1@02o`H00_l600;o1P02o`P00ol400?o1P02o`H0
0_lB00;o1`02oa800ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`H00_l600;o1P02oa00
000C00;o2@02o`H00_l;00;o3002oaD00_l700;o1002o`H00_l800;o2002o`L00_l500;o1@02o`@0
0_l700;o1002o`D00_l500;o1`02o`L00_l=00;o3002oa/00_l900;o1@02o`H00ol400;o1P02o`H0
0_l600;o2002o`H00_l600;o1P02oa800_l700;o4P04o`<00ol500;o1P02o`@00_l700;o0`02o`L0
0_l400;o1P02o`H00_l600;o400001<00_l900;o1P02o`D02_l:00;o5@02o`<00_l200;o1002o`80
0_l200;o2002o`L00ol700;o1@02o`D00_l300;o2@02o`<00_l400;o1P02o`L00_l700;o3@02o``0
0_lK00;o2@02o`@00_l800?o0`02o`H00_l600;o1P02o`P00_l600;o1P02o`800_l200;o4P0;oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T0
0_l600;o1@0:o`X00_lE00;o0P03o`800_l400;o0P02o``00_l700;o1007o`@00_l500;o0`02o`T0
0_l300?o0P03o`h00ol700;o3@02o``00_lK00;o2@02o`<00ol900;o0`02o`H00_l600;o1P02o`P0
0_l600;o1P02o`800_lG00Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@00_l200;o2P02o`H0
0_l@00004`02o`X00_l400;o1P02o`@00_l<00;o5@02o`8000?o0?l00P02o`@01_l<00;o1`02o`@0
1ol400;o1@02o`<00_l900;o0`07o`X01ol800?o3002o``00_lK00;o2@07o`X00ol:00;o3P02oa00
0_l600Ko5`02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko2P02oaP0000C00;o
2`07o`L00_l300;o3002oaD00_l0103oo`02o`030?oo00@01_l<00;o1`02o`l02Ol300;o2@02o`<0
1Ol:00Oo2@04o``00_l<00;o6`02o`T02Ol900?o2@02o`h00_l@00;o1P06oaP00_l300;o5002o`03
0?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:00Ko2@001?l00002o`/0
0_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`800_l?00Wo0`02o`T00_l300;o
00@0oooo2003o`d01_l;00;o1`02o`<00_l300;o5P02o`T00_l500?o1002o`<00_l900;o3P02oa00
0_l600;o0P02oaP00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o
0P02o`X00_lH00005002o`T00_l400;o2002o`800_l;00;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o0`02o`<00_l300;o0P02o`P00_l500;o1@02o`<00_l900;o0`02o`800ol700;o1`000ol0
000400;o0P02o`/00_l700;o0`02o`<00_lF00;o2@02o`H00_l400;o0`03o`P00_l>00;o4002o`H0
0_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L0
00?o00000`02o`800_l200;o1P02oaP0000D00?o1`02o`H00_l80003o`0000;o2`02oaH01?l300Co
1002o`H00_l300;o0`02o`<00_l300;o1P03o`D00_l500;o1002o`L00_l400;o0`03o`H00_l600;o
1@03o`<00_l:00;o1`02o`<00_l300;o5P02o`T00_l600;o1002o`@00ol700;o3P02oa000_l600;o
1P02oaD00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o
1P02oaP0000E00;o1`02o`H00_l90004o`3oo`X00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
0`03o`@01?l500;o1@02o`@00ol500?o1002o`@00ol500?o1003o`D00_l400;o2P02o`L00_l300;o
0`02oaH00_l900;o1@03o`@00_l500;o1`02o`h00_l@00;o1P02o`H00_lE00Go5002o`P00_l400;o
1P02o`L01Ol600?o1003o`D00_l600;o1P02oaP0000F00;o1P03o`@00ol900Co2@02oaL01?l500Co
00<0ool02_l300co100:o`@01?l300Co1009o`<01Ol300Go1009o`<01Ol200Go100:o`<03?lB00[o
0`0;o`D02_l300So1`0:o`L02_l00`3oo`0:oa801olD00Ko0P06o`030?oo00[o1007o`P02Ol300co
0`08oaD0000G0003o`0000D02?l;00?o2@000ol0000F00Co1@04o`030?oo00[o0`0<o`H01Ol00`3o
o`0400Co0`04o`H01Ol500Go0`05o`H01Ol00`3o000200Go0P05o`@02_l300co4P0:o`<02Ol700[o
0`08o`L02_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<0
2?lE00008006o``00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(85\\) NETGHNKSZIS JR LIJE A WFASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lF00Ko0`02o`803?l500So2006o`H0
1?l300Co0`06o`<00_l200Go1P02o`<00_l00`3oo`03o`H02_l500[o1002o`030?oo00?o5P06o`H0
1Ol600?o3`0=o`802_l600Ko1P0<oa001_l300Ko4@02o`@00_l400Oo1`06o`<01_l0103oo`05o`D0
3?l300go400001<00_l:00So1P09o`/00_lE00Ko0P03o`803?l500So1P0:o`@01?l300Co0`06o`80
0ol200Go1@03o`<02_l400[o1@0:o`@02_lB00Wo1@05o`D01?l?00go0P0:o`@02Ol500co4006o`<0
1_lA00;o1002o`@01ol700Ko0`06o`030?oo00So0`0<o`<03Ol@00004`02o`T00ol400?o1@02o`D0
0_l;00;o5P02o`@01?l400;o1P02o`P00_l800Co1@02o`D00_l500;o1@02o`@01?l400;o1@03o`@0
0ol500?o1002o`D00_l900;o2003o`D00olA00?o1003o`H00_l500?o5002o`H00_l600;o2003o`@0
0ol600;o1P02oa800_l700;o4P03o`@00ol500;o3002o`L00_l300?o1@03o`@00_l600;o1P02o`H0
0_l@00004`02o`T00_l600;o3@02o`X00_lF00;o1004o`@00_l600;o2002o`P00_l700;o1@02o`D0
0_l500;o1004o`@00_l500;o1@02o`L00_l400?o1002o`T00_l800;o1`02oa400_l600;o1P02o`D0
0_lE00;o1P02o`H00_l800;o1P02o`H00_l600;o4P02o`L00_lB00Co0`03o`D00_l<00;o1`02o`<0
0_l700;o1002o`H00_l600;o1P02oa00000C00;o2@02o`H00_l=00;o2P02oaH00_l300Go1002o`80
0_l200;o2002o`L00ol700;o1@02o`D00_l500;o0`05o`@00_l400;o1P02o`L00_l500?o0`02o`T0
0_l800;o1`02oa400_l600;o1P02o`@00_lF00;o1P02o`H00_l800;o1P02o`H00_l200;o0P02oa80
2olB00Co0P04o`D00_l200;o200;o`<00_l700;o1002o`800_l200;o1P02o`H00_l@00004`02o`T0
0_l600;o3@02o`X00_lF00;o0`02o`030?oo00@00_l200;o3002o`L00_l400Oo1002o`D00_l500;o
0`02o`030?oo00@00ol200?o3P03o`H00_l300;o2@02oa000olA00;o1P02o`H00_l300?o5P02o`H0
0_l600;o2002o`H00_l600;o0P02oaL02OlC00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`80
0_l:00;o1P02oa00000C00;o2P02o`@00_l>00;o2P02oaH00_l200?o00<0ool01006o``00_l700;o
1007o`@00_l500;o1@02o`800ol00`3oo`0400Oo2P07o`L00ol=00;o2`07oaX00_l600Oo5`02o`h0
0_l@00;o1P06oaL00_l500;o4`02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`X00_lH0000
4`02o`/01ol700;o1002o`/00_lF00;o0P02o`800_l400Ko3002o`L00_l?00Wo1@02o`800_l200;o
1005o`X01ol:00?o3002o`T01olL00;o1P09oaD00_l>00;o4002o`H01_lH00;o0`02oa@00_l00`3o
o`02o`030?oo00D01_l:00;o0`02o`H01ol700Ko2P02oaP0000D00;o2P06o`P02?l:00;o5`02o`03
0?oo00<00_l400;o0P02o`L00_l300;o0`02o`800_l?00Wo1@02o`030?oo00<00_l400;o00@0oooo
2003o`/00_l300;o3002o`P00olQ00;o1P02o`D00olD00;o3P02oa000_l600;o0P02oaP00_l300;o
5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`D00ol<00;o0P02o`X00_lH00005002o`T0
0_l400;o1`07o`/00_lG00Go0`02o`@00_l200;o0P02o`<00_l300;o0`02o`800_l800;o1@02o`D0
0_l500Go0`02o`@00_l200?o1`02o`L000?o00000P02o`<00ol;00;o2002o`L000?o00006002o`H0
0_l600;o5002o`h00_l@00;o1P02o`800_l200;o5@02o`040?oooa<00_l300;o0`02o`@00_l200;o
0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l600;o600001@00ol700;o1P02o`H0
0_l@00;o5`04o`@00_l400;o1P02o`<00_l300;o0`02o`<00_l600?o1@02o`D00_l500Co1002o`@0
0_l300?o1P02o`H00_l400;o1003o`X00_l800;o1P02oaX00_l600;o1P02oa@00_l>00;o4002o`H0
0_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o1`02o`030?oo00H00_l600;o1@02o`H0
0_l600;o600001D00_l700;o1P02o`H00_l?00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`<0
0ol400Co1@02o`D00_l500Co1002o`@00_l400?o1@03o`@00ol400;o1@02o`X00_l800?o1003oaX0
0_l600;o1@03oa@00_l>00;o4002o`H00_l600;o5@05oa@00_l800;o1002o`H00_l700Go1P03o`@0
0ol500;o1P02o`H00_lH00005P02o`H00ol400?o1P02o`h00_lH00Co0P06o`030?oo00[o0`0<o`@0
2_l400Co0`04o`<01?l200Ko00<0ool00ol300Go1009o`@02_l500[o1@09oaD02_l00`3oo`09oa80
2?l700[o1`0:o`030?oo00[o4P07oa@01_l200Ko00<0ool02_l400Oo2009o`<03?l300So5@0001L0
00?o00001@08o`L02?l80003o`0001L00ol300Ko00<0ool02_l300co1P05o`030?oo00@01?l300Co
0`03o`<01_l00`3oo`03o`<01Ol600Go00<0o`000`0:o`D02_l700Go00<0o`00500:o`030?oo00Oo
5008o`L02_l700[o00<0ool02_lB00Oo5006o`801_l00`3oo`0:o`@01ol:00Go00<0o`000P0<o`<0
2?lE00008006o`P02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(86\\) NETHHNKS IS IR LIJEZA WFASEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400Co0`04o`<01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1002o`030?oo00?o5@0:o`<0
1Ol600?o3`0=o`802_l600Ko1P0<o`@02_l200Ko0`06oa400_l400;o1007o`L01_l300Ko00@0ool0
1Ol500co0`0=oa00000C00;o2P08o`P01ol;00;o5@06o`800ol200co1@08o`D01?l300Co1004o`<0
1?l300Ko0P03o`801Ol500?o0`0:oa<02_l400[o4`0:o`<01Ol500Co3`0=o`802_l400Wo1@0<o`@0
2_l200Ko0`06oa400_l400;o1007o`L01_l300Ko00<0ool02?l300co0`0=oa00000C00;o2@03o`@0
0ol600;o1002o`/00_lF00;o1004o`@00_l600;o2002o`T00_l500;o1P02o`D00_l500;o1004o`@0
0_l500?o1003o`D00olF00;o2003o`D00olF00;o2@02o`D00olD00;o1P02o`H00_l800?o1003o`H0
0_l600;o1@02o`D00_l400;o1`02oa800ol400?o1@02o``00_l700;o0`03o`D00ol400;o1P02o`H0
0_l600;o400001<00_l900;o1P02o`D00_l600;o2P02oaH00_l400Co1002o`H00_l800;o2@02o`D0
0_l600;o1@02o`D00_l400Co1002o`D00_l500;o1`02oaH00_l800;o1`02oaH00_l900;o1@02oaD0
0_l600;o1P02o`P00_l600;o1P02o`H00_l500?o1002o`@00_l700;o4P04o`<00ol500;o3002o`L0
0_l300;o1`02o`@00_l600;o1P02o`H00_l@00004`02o`T00_l600;o1@02o`H00_l:00;o5P02o`<0
1Ol400;o0P02o`800_l800;o2@02o`D00_l600;o1@02o`D00_l300Go1002o`@00_l600;o1`02oaH0
0_l800;o1`02oaH00_l900;o1002oaH00_l600;o1P02o`P00_l600;o1P02o`800_l200;o1P03o`<0
0_l400_o4P04o`801?l500;o0P02o`P02ol300;o1`02o`@00_l200;o0P02o`H00_l600;o400001<0
0_l900;o1P02o`D00_l600;o2P02oaH00_l300;o00<0ool01002o`800_l<00;o2@02o`D00_l600;o
1@02o`D00_l300;o00<0ool01003o`800ol>00?o5P02oa000olF00;o2@02o`<00olF00;o1P02o`H0
0_l800;o1P02o`H00_l200;o2`02o`<00_l500Wo4`02o`040?l000Co1@02o`800_l900Wo3003o`@0
0_l200;o2P02o`H00_l@00004`02o`X00_l400;o1P02o`H00_l:00;o5P02o`800ol00`3oo`0400Ko
3002o`T00_l500;o1P02o`D00_l500;o0P03o`030?oo00@01ol:00Oo5`02o`/01olG00;o2@07oaL0
0_l>00;o4002o`H01_l;00?o2@02o`D00_lC00;o00H0o`00o`02o`D01_l900;o1@02o`L01ol500Ko
2P02oaP0000C00;o2`07o`H00ol400;o2`02oaH00_l200;o0P02o`@01_l<00;o2@09o`H02Ol500;o
0P02o`800_l400Go2P07oaT00_l900Oo6@02o`T02OlE00;o3P02oa000_l600Ko3003o`T00_l300;o
5002o`030?oo00;o00<0ool01@06o`X00_l300;o1P07o`L01_l:00;o600001@00_l:00Ko1`09o`X0
0_lG00;o00<0ool00`02o`@00_l200;o1`02o`<00_l300;o1009o`H02Ol500;o00<0ool00`02o`@0
0_l0103oool800?o7P02o`P00olN00;o2@02o`D00olD00;o3P02oa000_l600;o0P02o`P00_l300;o
2@02o`<00_lD00;o00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1@03o``00_l200;o2P02oaP0
000D00;o2@02o`@00_l600;o00<0ool00_l<00;o5`05o`<00_l400;o0P02o`800_l300;o0`02o`<0
0_l400;o1@02o`H00_l500;o1@05o`<00_l400;o0P03o`L00_l70003o`0001D00_l800;o1`000ol0
000E00;o2@02o`H00_lD00;o3P02oa000_l600;o0P02o`800_l400;o0`03o`T00_l0103ooolC00;o
0`02o`<00_l400;o0P02o`800_l700;o00@0oooo1@02o`L000?o00000`02o`800_l200;o1P02oaP0
000D00?o1`02o`H00_l600;o4002oaL01?l400;o1002o`H00_l300;o0`02o`<00_l400;o1@02o`H0
0_l500;o1@04o`@00_l400;o0`03o`H00_l600;o5`02o`P00_l600;o5`02o`T00_l600;o5002o`h0
0_l@00;o1P02o`H00_l400;o1003o`P00_l00`3oo`0D00;o0`02o`<00_l400;o1P02o`L00_l00`3o
o`0600;o1P02o`D00_l600;o1P02oaP0000E00;o1`02o`H00_l600?o3P02oaP01?l400;o1002o`H0
0_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l400;o1003o`D00ol400?o5`02o`P0
0ol400?o5`02o`T00_l500?o5002o`h00_l@00;o1P02o`H00_l400;o1@02o`P01OlD00;o2002o`@0
0_l600;o1`05o`H00ol400?o1@02o`H00_l600;o600001H00_l600?o1003o`L00ol<00;o6004o`80
1_l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`04o`801_l00`3oo`03o`<01Ol400Wo4`0:o`D0
2OlC00[o0`0;oa802?l700[o1`0:o`030?oo00[o100:o`@01olD00Ko0P06o`030?oo00[o1007o`P0
2Ol300co0`08oaD0000G0003o`0000D02?l900Oo1`000ol0000G00?o0`06o`030?oo00[o0`0<o`<0
1?l300Co1004o`<01?l300?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o1`05o`030?l00180
2_l300Wo5008o`L02_l700[o00<0ool02_l400[o1007oa@01_l200Ko00<0ool02_l400Oo2P05o`03
0?l000803?l300So5@0002001_l<00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(87\\) NETHHNKS IS IR LIKDZA WFATEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`02o`h00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400Co0`04o`<01_l300;o0P05o`H00_l300;o00<0ool00olE00[o1002o`030?oo00?o5@0:o`<0
1Ol600?o3`0=o`802_l400Go1P02o`802?l700[o0P06o`<01_lA00;o1002o`@01ol700Ko0`06o`80
2?l400co0`0=oa00000C00;o2P08o`T00_l?00;o5@06o`800ol200co1@08o`D01?l300Co1004o`<0
1?l300Ko0P03o`801Ol500?o0`0:oa<02_l400[o4`0:o`<01Ol500Co3`0=o`802_l400Go1@03o`80
2_l500[o0P06o`<01_lA00;o1002o`@01ol700Ko0`06o`802?l400co0`0=oa00000C00;o2@03o`@0
0ol900;o3P02oaH00_l400Co1002o`H00_l800;o2@02o`D00_l600;o1@02o`D00_l400Co1002o`D0
0ol400?o1@03oaH00_l800?o1@03oaH00_l900;o1@03oa@00_l600;o1P02o`X00_l500?o1002o`@0
1?l500;o1@02o`@00_l700;o4P03o`@00ol500;o3002o`L00_l700;o2@02o`H00_l600;o1P02oa00
000C00;o2@02o`H00_l900;o3P02oaH00_l400Co1002o`H00_l800;o2@02o`D00_l600;o1@02o`D0
0_l400Co1002o`D00_l500;o1`02oaH00_l800;o1`02oaH00_l900;o1@02oaD00_l600;o1P02o`X0
0_l500;o1@02o`H00_l500?o1002o`@00_l700;o4P04o`<00ol500;o3002o`L00_l700;o2@02o`H0
0_l600;o1P02oa00000C00;o2@02o`H00_l900;o3P02oaH00_l300Go1002o`800_l200;o2002o`T0
0_l500;o1P02o`D00_l500;o0`05o`@00_l400;o1P02o`L00_lF00;o2002o`L00_lF00;o2@02o`@0
0_lF00;o1P02o`H00_l:00;o1002o`H00_l700;o1@03o`<00_l400_o4P04o`801?l500;o0P02o`P0
2ol700;o2@02o`800_l200;o1P02o`H00_l@00004`02o`T00_l600;o2P000ol0000<00;o5P02o`<0
0_l00`3oo`0400;o0P02o``00_l900;o1@02o`H00_l500;o1@02o`<00_l00`3oo`0400?o0P03o`h0
0olF00;o4003oaH00_l900;o0`03oaH00_l600;o1P02o`X00ol200?o1P02o`L00_l600;o0`02o`D0
2OlC00;o00@0o`001?l500;o0P02o`T02Ol800;o2@02o`800_l:00;o1P02oa00000C00;o2P02o`@0
0_l;00;o3@02oaH00_l200?o00<0ool01006o``00_l900;o1@02o`H00_l500;o1@02o`800ol00`3o
o`0400Oo2P07oaL00_l;00Oo5`02o`T01olG00;o3P02o`X01ol700;o1`02o`H00ol900;o1@02oa<0
0_l01P3o003o00;o1@06o`T00_l500;o2002o`T01_l:00;o600001<00_l;00Oo2`02o`d00_lF00;o
0P02o`800_l400Ko3002o`T02Ol600Wo1@02o`800_l200;o1005o`X01olI00;o2@07oaT00_l900Wo
5@02o`h00_l:00Go2@02o`L00_l700?o2@02o`<00_lD00;o00<0ool00_l00`3oo`0500Ko2P02o`<0
0_l900;o2@06o`X00_lH00005002o`X01_l=0003o`0000X00_lG00;o00<0ool00`02o`@00_l200;o
1`02o`<00_l300;o1009o`H02Ol500;o00<0ool00`02o`@00_l0103oool800?o7P02o`P00olN00;o
2@02o`D00olD00;o3P02o`X00_l0103oool800;o1`02o`<00_l300;o2@02o`<00_lD00;o00<0ool0
0_l00`3oo`0500;o0P02o`X00_l300;o1002o`<00_l300;o1002o`800_l:00;o600001@00_l900;o
1002o``00_l;00;o5`05o`<00_l400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`H00_l500;o
1@05o`<00_l400;o0P03o`L00_l70003o`0001D00_l800;o1`000ol0000E00;o2@02o`H00_lD00;o
3P02o`X00_l200?o1`02o`L00_l300;o0`03o`T00_l0103ooolC00;o0`02o`<00_l400;o0P02o`80
0_l700;o00@0oooo1002o`<00_l300;o1002o`800_l200;o1P02oaP0000D00?o1`02o`H00_l;00;o
2`02oaL01?l400;o1002o`H00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l400;o
0`03o`H00_l600;o5`02o`P00_l600;o5`02o`T00_l600;o5002o`h00_l:00;o0`03o`H00_l600;o
1002o`@00ol800;o00<0ool05002o`<00_l300;o1002o`H00_l700;o00<0ool01@02o`<00_l300;o
1002o`H00_l600;o600001D00_l700;o1P02o``000?o00002002oaP01?l400;o1002o`H00_l300;o
0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l400;o1003o`D00ol400?o5`02o`P00ol400?o
5`02o`T00_l500?o5002o`h00_l:00;o1003o`D00_l400Co1002o`D00_l800Go5002o`P00_l400;o
1P02o`L01Ol500;o0`02o`<00_l400;o1P02o`H00_lH00005P02o`H00ol400?o1@02o`D00_l800;o
6004o`801_l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`04o`801_l00`3oo`03o`<01Ol400Wo
4`0:o`D02OlC00[o0`0;oa802?l700[o1005o`<01Ol200[o1@0:o`@01olD00Ko0P06o`030?oo00[o
1007o`H03?l200co0`08oaD0000G0003o`0000D02?l600Wo20000ol0000G00?o0`06o`030?oo00[o
0`0<o`<01?l300Co1004o`<01?l300?o0`06o`030?oo00?o0`05o`H01Ol00`3o000B00[o1`05o`03
0?l001802_l300Wo5008o`L02_l400Go0`05o`802?l700[o1007oa@01_l200Ko00<0ool02_l400Oo
1P0<o`803?l300So5@0002001_l700Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(88\\) METHHNKS IT IRZLJKD A WFATEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co1004o`<01?l300Ko0`02o`801Ol600;o0`02o`030?oo00?o5@0:o`D02?lD00[o0`05o`H0
0ol200[o0`0=o`<01_l700Go1P02o`802?lC00Ko0`06oa400_l400;o1007o`L01_l300Ko0P08o`@0
3?l300Go0`05oa00000C00;o2P08o`L02?l;00;o5005o`<01Ol00`3oo`0:o`D02?l500Co0`04o`@0
1?l300Co0`06o`800ol200Go1@03o`<02_lC00[o1@08oa@02_l300Go1@04o`802_l300go00<0ool0
1ol600Go1@03o`802_lA00Ko0`06oa400_l400;o1007o`L01_l300Ko0P08o`@03?l300Go0`05oa00
000C00;o2@03o`@00ol500?o1003o`X00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o1P02o`D0
0_l500;o1004o`@00_l500?o1003o`D00olF00;o3002oa/00_l900;o1@03o`D00_l500;o1P02o`H0
0_l0103oool400?o1`02o`D00ol400;o1004oa800_l700;o4P03o`@00ol500;o3002o`L00_l700;o
2@02o`H00_l400;o1`02oa40000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o1`02o`@00_l600;o
2002o`T00_l500;o1P02o`D00_l500;o1004o`@00_l500;o1@02o`L00_lF00;o3002oa/00_l900;o
1@02o`H00ol400;o1P02o`H00_l00`3oo`0600;o1`02o`D00_l500;o1P02oa800_l700;o4P04o`<0
0ol500;o3002o`L00_l700;o2@02o`H00_l400;o1`02oa40000C00;o2@02o`H00_l500;o1P02o`X0
0_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D00_l600;o1@02o`D00_l300Go1002o`@0
0_l600;o1`02oaH00_l<00;o6`02o`T00_l400;o2003o`<00_l600;o1P02o`030?oo00H00_l700;o
1002o`H00_l700;o4@0;oa801?l200Co1@02o`800_l800_o1`02o`T00_l200;o0P02o`@00_l300;o
0P02oa40000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o0P03o`800_l400;o0P02o``00_l900;o
1@02o`H00_l500;o1@02o`<00_l00`3oo`0400?o0P03o`h00olF00;o3002oa/00_l900;o0`03o`T0
0_l300;o1P02o`H00_l00`3oo`0600;o1`03o`800ol600;o1`02oa802OlC00;o00@0o`001?l500;o
0P02o`T02Ol800;o2@02o`800_l800;o0P03o`800_lA00004`02o`X00_l400;o1`02o`@00_l;00;o
5@02o`8000?o0?l00P02o`@01_l<00;o2@02o`D00_l600;o1@02o`D00_l200?o00<0ool01007o`X0
1olG00;o3002oa/00_l900Oo2P03o`X00_lA00;o1`07o`L00_l700;o4P02o`D00_lC00;o00H0o`00
o`02o`D01_l900;o1@02o`P00_l900Ko2002o`8000?o0?l00P02oa40000C00;o2`07o`P01ol;00;o
5@02o`040?oo00;o00<0ool01006o``00_l900Wo1P09o`D00_l200;o0P02o`@01Ol:00Oo6@02o``0
0_lK00;o2@09o`T00ol900;o4@02o`L01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@06o`X00_l300;o2@02o`T01_l800;o00@0ool00_l00`3oo`0A00005002o`X01_l900Ko2`02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`H02Ol500;o00<0ool00`02o`@0
0_l0103oool800?o7P02o`L00_l300;o0`02oaH00_l900;o1@03o`@00_l300;o2@02oa400_l700;o
00@0oooo2002o`L00_lC00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l400;o
0`02o`<00_l400;o0P02o`P00_l00`3oo`020004o`3ooa40000D00;o2@02o`@00_l700;o1002o`X0
0_lF00;o00<0o`000P001?l0ool400;o0P02o`800_l300;o0`02o`<00_l400;o1@02o`H00_l500;o
1@05o`<00_l400;o0P03o`L00_l70003o`0001D00_l700;o0`02o`<00_lF00;o2@02o`H00_l400;o
0`03o`P00_lA00;o1`02o`800ol700;o1`02oa@00_l0103ooolC00;o0`02o`<00_l400;o0P02o`80
0_l700;o00@0oooo1002o`<00_l300;o1002o`800_l200;o1002o`030?l0008000Co0?oo4@0001@0
0ol700;o1P02o`D00_l600;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`H0
0_l500;o1@04o`@00_l400;o0`03o`H00_l600;o5`02o`L00_l300;o0`02oaH00_l900;o1P02o`@0
0_l400?o1`02oa400_l700;o0`03o`H00_l600;o5@02o`030?oo01@00_l300;o0`02o`@00_l600;o
1`02o`030?oo00D00_l300;o0`02o`@00_l600;o1004o`<01?lA00005@02o`L00_l600;o1@02o`H0
0_l800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@00_l500;o1P02o`D00_l500Co1002o`@0
0_l400?o1@03o`@00olG00;o1`02o`<00_l300;o5P02o`T00_l500?o1002o`D00_l700;o4@02o`L0
0_l400?o1@02o`@01?lE00Go5002o`P00_l400;o1P02o`L01Ol500;o0`02o`<00_l400;o1P02o`@0
1?l400?o4@0001H00_l600?o1003o`D00ol400?o1`02oaL01?l500Co00<0ool02_l300co0`04o`<0
1?l400Co0`04o`<01?l200Ko00<0ool00ol300Go1009oa<02_l300co4P0:o`<02ol500[o0`08o`T0
2_l200Go0`05o`802_lC00Oo5006o`801_l00`3oo`0:o`@01ol600co0P0<o`<01?l500Co400001L0
00?o00001@08o`L02?l80003o`0001H01?l500Co00<0ool02_l300co0`04o`<01?l400Co0`04o`<0
0ol300Ko00<0ool00ol300Go1P05o`030?l001802_l300co4P0:o`<02Ol700[o0`08o`T02_l200Go
0`05o`802?lE00Oo5006o`801_l00`3oo`0:o`@01ol600co0P0<o`<01?l500Co400002001_l900Ko
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(89\\) METIHMJS IT IRZLIKD A WFATEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500Co0`04o`801Ol300Go0`06o`P00_l00`3oo`03oaD02_l500So500:o`<01Ol600?o0P0:o`<0
3Ol200[o1005o`H00_l200So4`06o`<01_lA00;o1002o`@01ol700Ko0`06o`802?l400co0`05o`<0
1Ol@00004`02o`X02?l600Oo3@02oa@01Ol300Go00<0ool02_l500So1@0:o`D01?l300Co0P05o`<0
1Ol00`3oo`07o`L02_lC00[o1@08oa@02_l300Go1@04o`802_l300go0P0:o`@01Ol500?o0P0:oa40
1_l300Ko4@02o`@00_l400Oo1`06o`<01_l200So100<o`<01Ol300Go400001<00_l900?o1003o`X0
0ol<00;o5@02o`L00_l400;o1P02o`P00_l<00;o2P02o`D00_l400;o1`02o`800ol400?o1P03o`D0
0olF00;o3002oa/00_l900;o1@03o`D00_l500;o1P02o`H00_l600;o2P02o`D00ol400;o1004oa80
0_l700;o4P03o`@00ol500;o3002o`L00_l700;o2@02o`H00_l400;o1`02oa40000C00;o2@02o`H0
0_l;00?o2`02oaD00_l700;o1002o`H00_l800;o3002o`X00_l500;o1002o`L00_l200;o1P02o`H0
0_l700;o5P02o``00_lK00;o2@02o`D00_l600?o1002o`H00_l600;o1P02o`X00_l500;o1@02o`H0
0_lB00;o1`02oa801?l300?o1@02o``00_l700;o1`02o`T00_l600;o1002o`L00_lA00004`02o`T0
0_l600;o3002o`/00_lE00;o0`02o`800_l400;o0P02o`800_l800;o3002o`X00_l500;o1002o`<0
0_l200;o0P02o`H00_l600;o1`02oaH00_l<00;o6`02o`T00_l400;o2003o`<00_l600;o1P02o`H0
0_l:00;o1002o`H00_l700;o4@0;oa801?l200Co1@02o`800_l800_o1`02o`T00_l200;o0P02o`@0
0_l300;o0P02oa40000C00;o2@02o`H00_l800Co00<0ool02P02oaD00_l200?o0P02o`@00_l200;o
3002o``00_l:00;o1@02o`@00_l200?o0P02o`800_l600;o3P03oaH00_l<00;o6`02o`T00_l300?o
2@02o`<00_l600;o1P02o`H00_l:00?o0P03o`H00_l700;o4P09oa<00_l0103o0004o`D00_l200;o
2@09o`P00_l900;o0P02o`P00_l200?o0P02oa40000C00;o2P02o`@00_l700Wo2P02oaD00_l20003
o`3o00800_l400Ko3002o``00_l:00;o1@02o`@00_l20003o`3o00800_l:00;o2@07oaL00_l<00;o
6`02o`T01ol:00?o2P02o`h00_l:00Oo1`02o`L00_lB00;o1@02oa<00_l01P3o003o00;o1@06o`T0
0_l500;o2002o`T01_l800;o0P000ol0o`0200;o4@0001<00_l;00Oo1`02o`@00ol:00;o5@02o`04
0?oo00;o00<0ool01006o``00_l<00;o2P09o`@00_l0103oo`02o`030?oo00X00_l700Oo6@02o``0
0_lK00;o2@09o`T00ol900;o3P02o`X01Ol900;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool0
1@06o`X00_l300;o2@02o`T01_l800;o00@0ool00_l00`3oo`0A00005002o`X01_l700;o1P02o`T0
0_lF00;o00<0ool00P001?l0ool400;o0P02o`L00_l300;o0`02o`L00_l:00Wo1002o`030?oo0080
00Co0?oo2P02o`H00olN00;o1`02o`<00_l300;o5P02o`T00_l500?o1002o`<00_l900;o3P02o`X0
0_l0103oool800;o1`02oa<00_l300;o5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`@0
0_l300;o0`02o`@00_l200;o2002o`030?oo008000Co0?oo4@0001@00_l900;o1002o`H00_l600;o
2@02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l:00;o1@02o`@0
0_l00`3o00020004o`3oo`X00_l600;o1`000ol0000E00;o1`02o`<00_l300;o5P02o`T00_l600;o
1002o`<00ol800;o3P02o`X00_l200?o1`02o`L00_lD00;o00@0oooo4`02o`<00_l300;o1002o`80
0_l200;o1`02o`040?ooo`@00_l300;o0`02o`@00_l200;o0P02o`@00_l00`3o00020004o`3ooa40
000D00?o1`02o`H00_l500;o1P02o`T00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`X0
0_l500;o1004o`<01?l:00;o1P02o`H00_lG00;o1`02o`<00_l300;o5P02o`T00_l600;o1002o`@0
0ol700;o3P02o`X00_l300?o1P02o`H00_lE00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o
00<0ool01@02o`<00_l300;o1002o`H00_l400Co0`04oa40000E00;o1`02o`H00_l500;o1P000ol0
000700;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`L00_l:00;o1@02o`@01?l400?o2P02o`H0
0ol400?o5`02o`L00_l300;o0`02oaH00_l900;o1@03o`@00_l500;o1`02o`h00_l:00;o1003o`D0
0_l400Co5@05oa@00_l800;o1002o`H00_l700Go1@02o`<00_l300;o1002o`H00_l400Co1003oa40
000F00;o1P03o`@00ol600;o1002o`P00_lG00Co1@04o`030?oo00[o0`0<o`<02_l500Co0`04o`80
1?l500Co100:o`@02OlC00[o0`0<oa802_l300_o1@0:o`<02?l700[o1005o`<01Ol200[o4`07oa@0
1_l200Ko00<0ool02_l400Oo1P0<o`803?l300Co1@04oa00000G0003o`0000D02?l700Oo2@000ol0
000F00Co1@04o`030?oo00[o0`0<o`<02_l500Co0`04o`801?l500Co100:o`H01Ol00`3o000B00[o
0`0<oa802_l300Wo1`0:o`<02?l700[o1005o`<01Ol200So5@07oa@01_l200Ko00<0ool02_l400Oo
1P0<o`803?l300Co1@04oa00000P00Ko2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(90\\) METHHNJS IS ISZKIKE B WFATEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co1004o`<01?l300Ko0`02o`@01_l800;o00<0ool00olE00[o1002o`030?oo00?o5@0:o`@0
0_l00`3oo`03o`L02_l300Go1P02o`802_l400Go1P02o`030?oo00[o4@0:oaD00_l400;o1007o`L0
1_l300Ko0P08o`@03?l300Go0`05oa00000C00;o2@07o`X01_l<00;o5005o`<01Ol00`3oo`0:o`D0
2?l500Co0`04o`@01?l300Co0`06o`800ol200Wo1`0:oa<02_l400[o4`0:o`@02_l500[o0`05o`D0
0ol200[o1005o`D00ol00`3oo`0:oa402olD00;o1002o`@01ol700Ko0`06o`802?l400co0`05o`<0
1Ol@00004`02o`h00ol800?o0P03o`/00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o1P02o`D0
0_l500;o1004o`800ol400?o1P03o`D00olF00;o2003o`D00olF00;o2003o`D00ol500;o1@02o`D0
0_l500?o1`02o`X00_l500?o1002o`H00_lC00;o1@03oa800ol400?o1@02o``00_l700;o1`02o`T0
0_l600;o1002o`L00_lA00004`02o`l00ol700;o1002o`/00_lE00;o1`02o`@00_l600;o2002o`T0
0_l500;o1P02o`D00_l500;o1004o`800_l600;o1P02o`L00_lF00;o2002o`L00_lF00;o2002o`L0
0_l500?o1002o`D00_l500;o2002o`X00_l500;o1@02o`H00_lC00;o1P02oa801?l300?o1@02o``0
0_l700;o1`02o`T00_l600;o1002o`L00_lA00004`02oa000_l600;o1P02o`X00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o2@02o`D00_l600;o1@02o`D00_l300Go0P02o`H00_l600;o1`02oaH0
0_l800;o1`02oaH00_l800;o1`02o`H00ol300;o1@02o`@00_l900;o2P02o`@00_l600;o0P02o`80
0_lC00;o1P02oa801?l200Co1@02o`800_l800_o1`02o`T00_l200;o0P02o`@00_l300;o0P02oa40
000C00;o3004o`030?oo00D00_l600;o2P02oaD00_l200?o0P02o`@00_l200;o3002o`T00_l500;o
1P02o`D00_l500;o0`02o`030?oo00800_l600;o3P03oaH00_l@00?o5P02oa000ol700;o0`02o`D0
0ol200?o2@02o`X00ol200?o1P02o`800_lG00;o1P02oa800_l0103o0004o`D00_l200;o2@09o`P0
0_l900;o0P02o`P00_l200?o0P02oa40000C00;o2P09o`D00_l600;o2P02oaD00_l20003o`3o0080
0_l400Ko3002o`T00_l500;o1P02o`D00_l500;o0P03o`030?oo00X00_l900Oo5`02o`/01olG00;o
2`07o`P00ol900Oo2P02o`X01ol700Ko5`02o`D00olB00;o00H0o`00o`02o`D01_l900;o1@02o`P0
0_l900Ko2002o`8000?o0?l00P02oa40000C00;o2P02o`@00ol500;o1P02o`X00_lE00;o00@0ool0
0_l00`3oo`0400Ko3002o`T02Ol600Wo1@02o`800_l200;o2P02o`L01olI00;o2@07oaT00_l900Oo
2`03o`P01Ol<00;o2P05o`T01_lG00Wo4`02o`030?oo00;o00<0ool01@06o`X00_l300;o2@02o`T0
1_l800;o00@0ool00_l00`3oo`0A00005002o`P00_l600;o1@02o`H00_l900;o5P02o`030?oo0080
00Co0?oo1002o`800_l700;o0`02o`<00_l400Wo1P09o`D00_l00`3oo`0300;o2P02o`H00olN00;o
2003oah00_l800?o3002o`<00_l800;o00@0oooo2`02o`X00_l0103oool800;o0P02oaL02?lD00;o
00<0ool00_l00`3oo`0500;o0P02o`X00_l300;o1002o`<00_l300;o1002o`800_l800;o00<0ool0
0P001?l0oolA00005002o`P00_l600;o1@02o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o0`02o`<00_l300;o1002o`D00_l600;o1@02o`D01Ol300;o2P02o`H00_l70003o`0001D0
0_l800;o1`000ol0000E00;o2002o`L000?o00000`02o`<00ol700;o0P03o`X00_l:00;o0P03o`L0
0_l200;o0P02oa<00_l400?o4P02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`@00_l300;o
0`02o`@00_l200;o0P02o`@00_l00`3o00020004o`3ooa40000D00?o1`02o`H00_l500;o1P02o`T0
0_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D00_l600;o1@02o`D01?l400;o2P02o`H0
0_l600;o5`02o`P00_l600;o5`02o`P00_l600;o1@02o`@00ol600;o0`03o`T00_l:00;o0`03o`H0
0_l600;o4`02o`D00_lB00;o0`02o`<00_l400;o1P02o`L00_l00`3oo`0500;o0`02o`<00_l400;o
1P02o`@01?l300Co4@0001D00_l700;o1P000ol0000500;o1002o`T00_lG00Co1003o`@00_l600;o
0`02o`<00_l300;o1002o`D00_l600;o1@02o`D01?l400;o2P02o`H00ol400?o5`02o`P00ol400?o
5`02o`P00ol400?o1@02o`D00_l600;o1003o`P00_l:00;o1003o`D00_l600;o4`02o`@00olB00;o
2002o`@00_l600;o1`05o`D00_l300;o0`02o`@00_l600;o1004o`@00olA00005P02o`L00_l400;o
1`03o`800ol800;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`04o`801_l400[o
1009oa<02_l500Wo4`0:o`D02Ol500[o0`05o`<01Ol200[o1005o`<01Ol00`3oo`0:oa402_lB00Ko
0P06o`030?oo00[o1007o`H03?l200co0`04o`D01?l@00005`000ol0000500Oo2@06o`T000?o0000
5P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`03o`<01_l400[o1P05o`030?l00180
2_l700Go00<0o`004P0:o`L01Ol00`3o000400[o0`05o`<01Ol200[o1005o`<01Ol00`3oo`0:oa40
2OlC00Ko0P06o`030?oo00[o1007o`H03?l200co0`04o`D01?l@00008@04o`/01?oo0<H0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(91\\) METHHNJS IS HT KHKF B WEASEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2`09o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co1004o`<01?l300Ko0`02o`@01_l800;o00<0ool00olE00[o1002o`030?oo00?o5@04o`<0
1?l400So4`05o`H00_l200Co0`04o`<01Ol600;o00<0ool01OlF00[o5@02o`@00_l400co0P06o`<0
1_l0103oo`05o`D03?l300Go0`05oa00000C00;o2@07o`T02Ol:00;o5005o`<01Ol00`3oo`0:o`D0
2?l500Co0`04o`@01?l300Co0`06o`800ol200Wo1`0:oa<02_l400[o4`04o`<01?l400So4`05o`D0
0ol200Co0`04o`<01Ol500?o00<0ool01OlF00_o5002o`@00_l400co0P06o`<01_l00`3oo`08o`<0
3?l300Go0`05oa00000C00;o3P03o``00_l=00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`H0
0_l500;o1@02o`@01?l200?o1003o`H00ol500?o5P02o`P00ol500?o4`02o`D00_l800;o6002o`D0
0ol400;o1@02o`H00_l500?o1002oa/00_l500?o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D0
0ol400;o1P02o`@00_l700;o4@0001<00_l?00?o2`02o`d00_lE00;o1`02o`@00_l600;o2002o`T0
0_l500;o1P02o`D00_l500;o1004o`800_l600;o1P02o`L00_lF00;o2002o`L00_lC00;o1@02o`P0
0_lH00;o1@02o`D00_l500;o1P02o`D00_l500;o6`02o`H00_lB00Co0`03o`D00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o1002o`L00_lA00004`02oa000_l;00;o3@02oaD00_l300;o0P02o`@0
0_l200;o0P02o`P00_l900;o1@02o`H00_l500;o1@02o`<01Ol200;o1P02o`H00_l700;o5P02o`P0
0_l700;o4`02o`D00_l800;o6002o`@00_l600;o1@02o`H00_l400;o1P02o`800_lG00;o1P02oa80
1?l200Co1@02o`800_l200;o100;o`<00_l700;o1002o`800_l200;o1002o`<00_l200;o4@0001<0
0_l<00Co00<0ool02P02o`d00_lE00;o0P03o`800_l400;o0P02o``00_l900;o1@02o`H00_l500;o
1@02o`<00_l00`3oo`0200;o1P02o`h00olF00;o4003oa<00_l500;o2002oaP00ol200?o1P02o`D0
0_l600?o0P03o`H00_l200;o5`02o`H00_lB00;o00@0o`001?l500;o0P02o`T02Ol<00?o1002o`80
0_l800;o0P03o`800_lA00004`02o`X02Ol:00;o3@02oaD00_l20003o`3o00800_l400Ko3002o`T0
0_l500;o1P02o`D00_l500;o0P03o`030?oo00X00_l900Oo5`02o`/01olD00;o1@02o`P00_lH00Oo
1`02o`D00_l600Oo1`06oaL00_l500?o4P02o`060?l00?l00_l500Ko2@02o`D00_l700Oo1@06o`P0
0_l20003o`3o00800_lA00004`02o`X00_l400?o2P02o`d00_lE00;o00@0ool00_l00`3oo`0400Ko
3002o`T02Ol600Wo1@02o`800_l200;o2P02o`L01olI00;o2@07oaH02Ol800;o6005o`T02Ol600Go
2@06oaL02OlC00;o00<0ool00_l00`3oo`0500Ko2P02o`<00_l600Oo1`06o`P00_l0103oo`02o`03
0?oo0140000D00;o2002o`H00_l:00;o3002oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<0
0_l300;o1009o`H02Ol500;o00<0ool00`02o`X00_l600?o7P02o`P00olK00Wo0`02o`<00_l300;o
4`02o`040?ooo`P02Ol600;o00@0oooo2002o`800_lG00So5002o`030?oo00;o00<0ool01@02o`80
0_l:00;o0`02o`D00ol<00;o0P02o`P00_l00`3oo`020004o`3ooa40000D00;o2002o`H00_l:00;o
3002oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o1P02o`D0
0_l500Go0`02o`X00_l600;o1`000ol0000E00;o2002o`L000?o00004P02o`D00_l300;o0`02o`<0
0_lC00;o0P03o`L00_l500;o1P02o`800ol700;o0P02o`800_lC00;o1003oa800_l300;o0`02o`@0
0_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o0P02o`800_l400;o00<0o`000P001?l0
oolA00005003o`L00_l600;o2P02o``00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1002o`D0
0_l600;o1@02o`D01?l400;o2P02o`H00_l600;o5`02o`P00_l600;o5002o`D00_l300;o0`02o`<0
0_lC00;o0`03o`H00_l500;o1P02o`<00ol600;o1P02oa<00_l500;o4P02o`<00_l300;o1002o`H0
0_l700;o00<0ool01P02o`H00_l500;o1P02o`@01?l300Co4@0001D00_l700;o1P000ol0000900;o
2`02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l:00;o
1P03o`@00olG00;o2003o`@00olD00;o1@02o`<00_l300;o0`02oa<00_l400?o1@02o`D00_l600;o
1003o`D00_l600;o4`02o`@00olB00;o2002o`@00_l600;o1`05o`H00ol400?o1@02o`H00_l400Co
1003oa40000F00;o1`02o`@00_l700?o00<0ool02P02oaL01?l500Co00<0ool02_l300co0`04o`<0
1?l400Co0`04o`<01?l200Ko100:o`@02OlC00[o1@09oa<01?l300Co0P0<oa401Ol300Go0P04o`<0
1?l300Go0`05o`030?oo00[o4@0:oa801_l200Ko00<0ool02_l400Oo2009o`<03?l300Co1@04oa00
000G0003o`0000D01ol800Ko2P000ol0000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co1004o`<0
1?l300?o0`06o`@02_l600Go00<0o`004P0:o`L01Ol00`3o000B00Co0`04o`803?lA00Go0`05o`80
1?l300Co0`05o`<01Ol00`3oo`0:oa402OlC00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co
0`04o`D01?l@00008@04o``00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(92\\) METHHNKS JS HT KILF A VFASEM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2P0:o`T00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co1004o`<01?l300Ko0`02o`801Ol600;o0`02o`030?oo00?o5P06o`L00_l00`3oo`03oaD0
1?l300Co1008oa<01Ol600;o0P0:o`@03Ol00`3oo`05oaD01_l300Ko5002o`L01ol700Ko0`06o`04
0?oo00Go1@0<o`<01Ol300Go400001<00_l900Oo200:o`X00_lD00Go0`05o`030?oo00[o1@08o`D0
1?l300Co1004o`<01?l300Ko0P03o`801Ol500?o0`0:oa802Ol600[o4`04o`<01?l400So4`05o`D0
0ol200[o100=o`030?oo00Go5@06o`<01_lC00Co1P07o`L01_l300Ko00<0ool02?l300co0`05o`<0
1Ol@00004`02o`h00ol800;o1@02o`X00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o1P02o`D0
0_l500;o1004o`@00_l500?o1003o`D00olA00?o1003o`D00ol500?o4`02o`D00_l800;o6002o`D0
0ol700;o2`02o`H00_l300;o6P02o`L00_lE00Co2002o``00_l700;o0`03o`D00ol400;o1P02o`@0
0_l700;o4@0001<00_l?00?o2003o`l00_lE00;o1`02o`@00_l600;o2002o`T00_l500;o1P02o`D0
0_l500;o1004o`@00_l500;o1@02o`L00_lA00;o1P02o`D00_l700;o4`02o`D00_l800;o6002o`D0
0_l800;o2`02o`H00_l300;o6P02o`L00_lE00Co2002o``00_l700;o0`02o`L00_l400;o1P02o`@0
0_l700;o4@0001<00_l@00;o2@03o`h00_lE00;o0`02o`800_l400;o0P02o`800_l800;o2@02o`D0
0_l600;o1@02o`D00_l300Go1002o`@00_l600;o1`02oa400_l600;o1@02o`L00_lC00;o1@02o`P0
0_lH00;o1002o`T00_l;00;o1P02o`<00_l200;o5P0;oa@00_l200;o1`02o`800_l800_o0`02o`L0
0_l400;o0P02o`800_l400;o0`02o`800_lA00004`02o``01?l00`3oo`0900?o3@02oaD00_l200?o
0P02o`@00_l200;o3002o`T00_l500;o1P02o`D00_l500;o0`02o`030?oo00@00ol200?o3P03oa40
0_l600;o3@03oa<00_l500;o2002oaP00ol200?o2@02o`/00_l600;o0`02o`800_lG00Wo5@02o`80
0_l700;o0P02o`T02Ol<00?o1002o`800_l800;o0P03o`800_lA00004`02o`X02Ol:00?o3002oaD0
0_l20003o`3o00800_l400Ko3002o`T00_l500;o1P02o`D00_l500;o0P03o`030?oo00@01ol:00Oo
6P02o`P01olD00;o1@02o`P00_lH00Oo2P02o`/00_l;00Ko5`02o`D00_lD00?o0P03o`H01_l900;o
1@02o`L01ol500Ko2002o`8000?o0?l00P02oa40000C00;o2P02o`@00ol;00?o2`02oaD00_l0103o
o`02o`030?oo00@01_l<00;o2@09o`H02Ol500;o0P02o`800_l400Go2P07oa`00_l600Oo5P09o`P0
0_lH00Go3002o`/00_l;00Ko6002o`<00_lE00;o1002o`H01_l:00;o0`02o`H01ol700Ko2002o`04
0?oo00;o00<0ool04@0001@00_l800;o1P02o``00_l:00;o5P02o`030?oo008000Co0?oo1002o`80
0_l700;o0`02o`<00_l400Wo1P09o`D00_l00`3oo`0300;o1002o`040?ooo`P00olQ00;o1@03oa/0
2Ol300;o0`02o`<00_lC00;o00@0oooo2`02o`/00_l;00;o0P02oaP00_l300;o5@02o`@00_l600;o
0P02o`X00_l300;o1@03o``00_l200;o2002o`030?oo008000Co0?oo4@0001@00_l800;o1P02o`d0
0_l900;o5P02o`030?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o1002o`D00_l600;o
1@02o`D01Ol300;o1002o`800ol700;o1`000ol0000H00;o1@02o`L000?o00004P02o`D00_l300;o
0`02o`<00_lC00;o0P03o`X00_l;00;o2`02o`800_l200;o5@02o`040?oooa@00_l600;o1@02o`80
0_l200;o1`02o`040?ooo`D00_l70003o`0000<00_l200;o0P02o`@00_l00`3o00020004o`3ooa40
000D00?o1`02o`H00_l=00;o2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`H0
0_l500;o1@04o`@00_l400;o0`03o`H00_l600;o6P02o`D00_l600;o5002o`D00_l300;o0`02o`<0
0_lC00;o0`03o`T00_l;00;o2`02o`H00_lE00;o00<0ool05@02o`H00_l500;o1P02o`L00_l00`3o
o`0600;o1P02o`D00_l600;o1004o`<01?lA00005@02o`L00_l60003o`0000D00_l500;o2002oaL0
1?l400?o1002o`H00_l300;o0`02o`<00_l400;o1@02o`H00_l500;o1@04o`@00_l400;o1003o`D0
0ol400?o6P02o`D00ol400?o5002o`D00_l300;o0`02o`<00_lC00;o1003o`P00_l;00;o2`02o`H0
0_lE00Go5003o`H00ol400;o1P02o`L01Ol600?o1003o`D00_l600;o1004o`@00olA00005P02o`L0
0_l400;o1`03o`<00ol700;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`04o`80
1_l00`3oo`03o`<01Ol400Wo5@0:o`<02OlC00Co0`04o`803?lA00Go0`05o`802_l400So1P0<oa80
1olD00Ko0P06o`030?oo00[o1007o`P02Ol300co0`04o`D01?l@00005`000ol0000500Oo2@07o`P0
00?o00005P04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@01?l300Co0`03o`<01_l00`3oo`03o`<0
1Ol600Go00<0o`00500:o`D01Ol00`3o000B00Co0`04o`803?lA00Go0`05o`802_l400So1P0<oa80
1olD00Ko0P06o`030?oo00[o1007o`X01Ol00`3o000200co0`04o`D01?l@00008@04o`/01Ooo0<D0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(93\\) MDTHINKS JS IT JILF A VEATEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3005o``00_lE00Go0`05o`802?l800So1@04o`<0
1?l400[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l700;o00<0ool00olE00[o1@08oaD0
1_l700[o100=o`030?oo00Go5@06o`<01_lD00;o1`0<o`801_l300Ko0P08o`@03?l300go400001<0
0_l900Oo2009o`/00_lD00Go0`05o`802_l600So1@04o`<01?l400[o1006o`800ol200Go1@03o`<0
2_lB00Wo1P0:oa<02_l500So4`09o`H02_l400go00<0ool01OlE00Ko0`06oa<01?l600co0P06o`<0
1_l200So100<o`<03Ol@00004`02o`h00ol700;o1@02o`/00_lE00;o1`02o`@00_l400Co2002o`T0
0_l500;o2@02o`T00_l400Co1002o`D00ol400?o1@03oa400ol400?o1@03o`D00olF00;o3002oaH0
0ol400?o2@02o`/00_l600;o0`02oaX00_l700;o5@04o`P00_l600;o1002o`L00_l700;o2@02o`H0
0_l600;o1P02oa00000C00;o3`03o`h00_l:00;o5@02o`L00_l400;o1P02o`P00_l900;o1@02o`T0
0_l900;o1004o`@00_l500;o1@02o`L00_lA00;o1P02o`D00_l700;o5P02o``00_lF00;o1P02o`T0
0_l;00;o1P02o`<00_lJ00;o1`02oaD01?l800;o1P02o`@00_l700;o1`02o`T00_l600;o1P02o`H0
0_l@00004`02oa000_l>00;o2P02oaD00_l300;o0P02o`@00_l700;o1`02o`T00_l500;o2@02o`T0
0_l300Go1002o`@00_l600;o1`02oa400_l600;o1@02o`L00_lF00;o3002oaH00_l600;o2@02o`/0
0_l600;o0`02o`800_lF00_o5002o`800_l700;o0P02o`800_l400_o1`02o`T00_l200;o0P02o`H0
0_l600;o400001<00_l<00Co00<0ool03@02o`X00_lE00;o0P03o`800_l400;o1`02o`L00_l900;o
1@02o`T00_l900;o0`02o`030?oo00@00ol200?o3P03oa400_l600;o3@03oaH00_l<00;o5P02o`H0
0_l900;o2`02o`H00_l300;o0P02oaL02OlE00;o0P02o`L00_l200;o2@09o`P00_l900;o0P02o`X0
0_l600;o400001<00_l:00Wo3002o`/00_lE00;o0P000ol0o`0200;o1002o`L00_l700;o2@02o`D0
0_l900;o2@02o`800ol00`3oo`0400Oo2P07oaX00_l800Oo5`02o``00_lN00;o2@02o`/00_l;00Ko
5`02o`D00_lD00?o0P03o`H01_l900;o1@02o`P00_l900Ko2P02oaP0000C00;o2P02o`@00ol900Co
3002oaD00_l0103oo`02o`030?oo00@00_l700;o1`02o`T02Ol900;o2@02o`800_l200;o1005o`X0
1olL00;o1P07oaT00_l<00;o7P02o`T00_l;00;o2`06oaP00_l300;o5@02o`@00_l600Ko2P02o`<0
0_l900;o2@06o`X00_lH00005002o`P00_l600;o2@03o``00_lF00;o00<0ool00P001?l0ool400;o
1`02o`800_l300;o0`02o`@02Ol900;o2@02o`030?oo00<00_l400;o00@0oooo2003ob400_l500?o
7P02o`L00_l300;o0`02oaT00_l900;o2`02o`/00_l200;o6002o`<00_lE00;o1002o`H00_l200;o
2P02o`<00_l400;o0`02o`<00_l400;o0P02o`X00_lH00005002o`P00_l600;o2`02o`/00_lF00;o
00<0o`000P001?l0ool400;o1`02o`800_l300;o0`02o`@00_l500;o2@02o`T01Ol300;o1002o`80
0ol700;o1`000ol0000H00;o1@02o`L000?o00005@02o`L00_l300;o0`02oaT00_l900;o2`02o`/0
0_l200;o0P02oaD00_l0103ooolD00;o1P02o`D00_l200;o0P02o`L00_l0103oool400;o0`02o`<0
0_l400;o0P02o`800_l600;o600001@00ol700;o1P02o``00_l:00;o5P04o`<01?l400;o1P02o`<0
0_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`<00ol600;o1P02oaX00_l500;o1P02oaL0
0_l700;o0`02o`<00_lI00;o2@02o`/00_l;00;o1P02oaD00_l00`3oo`0E00;o1P02o`D00_l600;o
1`02o`030?oo00D00_l300;o0`02o`@00_l600;o1P02oaP0000E00;o1`02o`H000?o00002`02o`T0
0_lG00Co1003o`@00_l400Co0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o1003o`D0
0ol400?o6P02o`D00ol400?o5`02o`L00_l300;o0`02oaT00_l900;o2`02o`/00_l600;o5@05oa@0
0ol600?o1002o`H00_l700Go1@02o`<00_l300;o1002o`H00_l600;o600001H00_l700;o1002o`L0
0_l300?o2002oaL01?l500Co0P0:o`@03?l300Co0`04o`@02_l400Co0P06o`030?oo00?o0`05o`@0
2OlE00[o0`09oa<02_l300co500:o`802_l400So1P0<oa801olD00Ko0P06o`030?oo00[o1007o`H0
3?l200co0`08oaD0000G0003o`0000D01ol800Oo2@000ol0000F00Co1@04o`802?l600co0`04o`<0
1?l400[o1003o`<01_l00`3oo`03o`<01Ol600Go00<0o`00500:o`D01Ol00`3o000B00[o0`0<oa@0
2_l200[o1008o`H03?lB00Oo5006o`801_l00`3oo`0:o`@01ol600co0P0<o`<02?lE00008@04o`/0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(94\\) NETHINKS JSZIS KIKF A VEBTDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3P06o`T00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l700;o00<0ool00ol600[o1@0:o`@0
0_l00`3oo`03oa@01Ol600;o0P0:o`@01Ol600;o00<0ool01OlE00Ko0`06oa@00_l700co0`0:o`H0
2?l500So1P0=oa00000C00;o2@07o``01_l:00;o5@06o`800ol200co1@08o`D01?l300Co100:o`@0
1_l200?o0P05o`D00ol300[o4P09o`H02_l400[o1@0:o`@02_lB00Go1@03o`802_l400Go1@03o`03
0?oo00Go5@06o`<01_lC00Co1P0<o`<02ol500So1@0:o`@03Ol@00004`02o`h00ol=00;o3002oaH0
0_l400Co1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@00ol500?o4@03o`@0
0ol500?o1@03o`@00_l500;o2@02o`P00ol500?o4`02o`D00ol700;o2P02o`D00ol400;o6P02o`L0
0_lE00Co2002o`H00_l500;o1@03o`L00_l900;o1004o`H00_l600;o400001<00_l?00?o3002o``0
0_lF00;o1004o`@00_l600;o2002o`T00_l500;o2@02o`T00_l400Co1002o`D00_l500;o1`02oa40
0_l600;o1@02o`L00_l400?o1002o`T00_l800;o1`02oa<00_l500;o2002o`X00_l500;o1@02oaX0
0_l700;o5@04o`P00_l600;o1@02o`H00_l700;o2@02o`H00_l600;o1P02oa00000C00;o4002o`H0
2_l:00;o5P02o`<01Ol400;o0P02o`800_l800;o2@02o`D00_l900;o2@02o`<01Ol400;o1002o`H0
0_l700;o4@02o`H00_l500;o1`02o`D00ol300;o2@02o`P00_l700;o4`02o`@00_l900;o2P02o`@0
0_l600;o0P02oaH02olD00;o0P02o`L00_l200;o0P02o`D00_l600;o1`02o`T00_l700;o1@02o`H0
0_l@00004`02o``01?l00`3oo`0500[o2P02oaH00_l300;o00<0ool01002o`800_l<00;o2@02o`D0
0_l900;o2@02o`<00_l00`3oo`0400?o0P03o`h00olA00;o1P02o`d00ol600;o0`02o`T00_l@00?o
4`03o`800ol900;o2P03o`800ol600;o0P02oaL02OlE00;o0P02o`L00_l200;o2@02o`H00_l700;o
2@02o`L00_l500;o1P02oa00000C00;o2P09o`D00_l400;o3002oaH00_l200?o00<0ool01006o``0
0_l900;o1@02o`T00_l900;o0P03o`030?oo00@01ol:00Oo6P02o`P01ol700?o3@02o`/01olD00Oo
2P02o`X01ol700Ko5`02o`D00_lD00?o0P03o`H01_l900;o1@03o`L00_l900;o1`02o`D00_lH0000
4`02o`X00_l400?o1P02o`<00_l<00;o5P02o`800_l200;o1006o``00_l900Wo2@02o`T00_l200;o
0P02o`@01Ol:00Oo7002o`H01ol:00?o3002o`T01olF00Go3002o`X01Ol900Ko6002o`<00_lE00;o
1002o`H01_l900Wo2002o`T00_l700;o1@02oaP0000D00;o2002o`H00_l70004o`0000;o2`02oaL0
0_l00`3oo`0300;o1002o`800_l700;o0`02o`<00_l400Wo2@02o`T00_l00`3oo`0300;o1002o`04
0?ooo`P00olQ00;o1@03o`/00_l300;o3002o`P00olK00;o00@0oooo2`02o`X00_l0103oool800;o
0P02oaP00_l300;o5@02o`@00_l600;o0P02o`T02?l400;o0`02o`<00_l400;o1`02o`D00_lH0000
5002o`P00_l600;o1`02o`800_l;00;o5`05o`<00_l400;o0P02o`800_l300;o0`02o`<00_l400;o
1@02o`T00_l900Go0`02o`@00_l200?o1`02o`L000?o00006002o`D00_l70003o`0000800_l300?o
2`02o`P00_l70003o`0001800_l200?o2P02o`X00_l200?o1`02o`800_l200;o5@02o`040?oooa@0
0_l600;o1@02o`800_l200;o1@02o`@00ol300;o0`02o`<00_l400;o1`02o`D00_lH00005003o`L0
0_l600;o20000ol00002o`/00_lG00Co1002o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o
2@04o`@00_l400;o0`03o`H00_l600;o6P02o`D00_l600;o1002o`@00ol:00;o2002o`H00_lD00;o
0`03o`T00_l:00;o0`03o`H00_l600;o5@02o`030?oo01D00_l600;o1@02o`H00_l500;o1@02o`<0
0_l300;o0`02o`@00_l600;o1P02oaP0000E00;o1`02o`H000?o000020001?l0ool:00;o6004o`@0
0_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T01?l400;o1002o`@00ol500?o1003oaX0
0_l500?o1003o`@00_l500;o2P02o`P00ol400?o5002o`@00ol800;o2P02o`@00ol500;o1P02oaD0
1OlD00?o1P03o`@00_l600;o1@02o`@00ol300;o0`02o`<00_l400;o1004o`H00_lH00005P02o`L0
0_l400;o2P04o`T00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co100:o`@01?l200Ko00<0ool0
0ol300Go1009oaD02_l300Wo100:o`D02_l500Wo4P05o`<01Ol200[o1005o`<01Ol00`3oo`0:oa80
1olD00Ko0P06o`030?oo00[o0`0:o`@03?l300[o1008oaD0000G0003o`0000D01ol<00?o2@000ol0
000G00?o0`06o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool00ol300Go1P05o`03
0?l001@02_l500Go00<0o`000`0:o`D02_l700Go00<0o`004@05o`<01Ol200[o1005o`<01Ol00`3o
o`0:oa801olD00Ko0P06o`030?oo00[o0`09o`D03?l300So1P08oaD0000Q00Co3@03ool0a@000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(95\\) NETHIMKS JSZIS LIKE B WEATDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3005o``00_lF00Ko0`02o`803?l500So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`03o`H00_l300;o00<0ool00olF00Ko1`02o`030?oo00?o1P0:o`D0
2_l400;o00<0ool00olD00go0P0:o`@01Ol600;o00<0ool02_lA00[o5@02o`@00_l400co0P06o`<0
1_l200So1@08o`H01Ol600;o400001<00_l900Oo2009o`/00_lE00Ko0P03o`803?l500So1@04o`<0
1?l400[o0`05o`<01Ol00`3oo`03o`D00ol300[o4P09o`H02_l400[o1@0:o`@02_lB00go0P0:o`@0
1Ol500?o00<0ool02_lA00_o5002o`@00_l400co0P06o`<01_l200So1@0:o`@01Ol500?o400001<0
0_l>00?o1`02o`D00_l;00;o5P02o`@01?l400;o1P02o`P00_l900;o1@02o`T00_l800;o1`02o`@0
0_l500?o1003o`D00olA00?o1003o`D00ol500?o1002o`D00_l900;o2003o`D00olD00;o1P02o`H0
0_l:00;o1@03o`@00_l600;o4`02o`D00olB00?o1003o`D00_l600;o1002o`L00_l700;o2@02o`@0
1?l500;o1@03oa40000C00;o3`03o`h00_l:00;o5P02o`@01?l400;o1P02o`P00_l900;o1@02o`T0
0_l800;o1`02o`@00_l500;o1@02o`L00_lA00;o1P02o`D00_l700;o1003o`@00_l900;o2002o`L0
0_lD00;o1P02o`H00_l:00;o1@02o`D00_l600;o4`02o`H00_lB00Co0`03o`D00_l600;o1002o`L0
0_l700;o2@02o`H00_l500;o1@02oa80000C00;o4002o`h00_l:00;o5P02o`<01Ol400;o0P02o`80
0_l800;o2@02o`D00_l900;o2002o`<00_l200;o1002o`@00_l600;o1`02oa400_l600;o1@02o`L0
0_l500?o0`02o`T00_l800;o1`02oa@00_l600;o1P02o`X00_l400;o1P02o`800_l200;o4`02o`H0
0_lB00Co0P04o`D00_l200;o0P02o`@02ol700;o2@02o`L00_l400;o1002oa<0000C00;o3004o`03
0?oo00d00_l:00;o5P02o`<00_l00`3oo`0400;o0P02o``00_l900;o1@02o`T00_l800;o0P03o`80
0_l400?o0P03o`h00olA00;o1P02o`d00ol600;o0`02o`T00_l@00?o5002o`H00_l600;o2P03o`80
0ol600;o0P02oaL00_l600;o4P02o`040?l000Co1@02o`800_l900Wo2002o`T00_l700;o1003o`80
0olC00004`02o`X02Ol=00;o2P02oaH00_l200?o00<0ool01006o``00_l900;o1@02o`T00_l800;o
0P000ol0o`0200;o1007o`X01olJ00;o2007o`L00ol=00;o2`07oaD00_l>00;o2P07o`L01_lG00;o
1@03oa800_l01P3o003o00;o1@06o`T00_l500;o2002o`T00_l700;o1007oa@0000C00;o2P02o`@0
0ol600;o1002o`/00_lF00;o0P02o`800_l400Ko3002o`T02Ol900;o2002o`040?oo00;o00<0ool0
1005o`X01olL00;o1P07o`X00ol<00;o2@07oaL00_l>00;o2P05o`T01_lG00Wo4`02o`030?oo00;o
00<0ool01@06o`X00_l300;o2@02o`T00_l700;o1005oaH0000D00;o2002o`H00_l600So2P02oaL0
0_l00`3oo`0300;o1002o`800_l700;o0`02o`<00_l400Wo2@02o`P00_l00`3oo`020004o`3oo`@0
0_l0103oool800?o8@02o`D00ol;00;o0`02o``00_l800?o7002o`h00_l:00;o00@0oooo2002o`80
0_lG00So5002o`030?oo00;o00<0ool01@02o`800_l:00;o0`02o`@00_l300;o0`02o`@00_l700;o
1002o`040?oooaD0000D00;o2002o`H00_l600Oo2`02oaL01Ol300;o1002o`800_l200;o0`02o`<0
0_l300;o1002o`D00_l900;o2002o`030?l0008000Co0?oo1002o`800ol700;o1`000ol0000H00;o
1@02o`L000?o00000P02o`<00ol;00;o2002o`L000?o00004`02o`h00_l:00;o0P03o`L00_l200;o
0P02oa<00_l400?o4P02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`@00_l300;o0`02o`@0
0_l700;o1002o`800olD00005003o`L00_l600;o1P02oa000_lG00Co1002o`@00_l600;o0`02o`<0
0_l300;o1002o`D00_l900;o2004o`<01?l400;o0`03o`H00_l600;o6P02o`D00_l600;o1002o`@0
0ol:00;o2002o`H00_lE00;o3P02o`X00_l300?o1P02o`H00_lC00;o1@02oa800_l300;o0`02o`@0
0_l600;o1`02o`030?oo00D00_l300;o0`02o`@00_l600;o1@02o`<00olC00005@02o`L00_l60003
o`0000D00_l?00;o6004o`@00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`P01?l400?o
1002o`@00ol500?o1003oaX00_l500?o1003o`@00_l500;o2P02o`P00ol400?o5@02o`h00_l:00;o
1003o`D00_l600;o4`02o`@00olB00;o2002o`@00_l600;o1`05o`D00_l300;o0`02o`@00_l400Co
1@02o`@00olB00005P02o`L00_l400;o1`02o`h00_lH00Co0P06o`030?oo00[o0`0<o`<01?l300Co
100:o`<01?l500Co00<0ool00ol300Go1009oaD02_l300Wo100:o`D02_l500Wo4P08o`L02_l400Go
0`05o`030?oo00[o4@0:oa801_l200Ko00<0ool02_l400Oo1P0<o`<02_l400Go0`05oa00000G0003
o`0000D01ol800So20000ol0000G00?o0`06o`030?oo00[o0`0<o`<01?l300Co100:o`<01?l500Co
00<0ool00ol300Go1P05o`030?l001@02_l500Go00<0o`000`0:o`D02_l700Go00<0o`004@08o`L0
2_l400Go0`05o`030?oo00[o4@09oa<01_l200Ko00<0ool02_l400Oo1P0<o`<02?l600Go0`05oa00
000Q00Co2@08ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(96\\) METIIMJS JS IS LILE B WEATDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o0`05o`<01Ol300Ko2002o`030?oo00?o5P06o`L00_l00`3oo`03oaD02_l400;o00<0ool0
0olD00go0P0:o`@03Ol00`3oo`0:oa402_lE00;o1002o`@03?l200Ko0`06o`802?l500So1P0=oa00
000C00;o2@07o`X01ol;00;o5005o`<01Ol00`3oo`0:o`D02?l500[o1@0:o`<01Ol300Go00<0ool0
1ol700[o4P09o`H02_lC00[o100:oa803Ol200[o100=o`030?oo00[o4@0;oa@00_l400;o100<o`80
1_l300Ko0P08o`D02_l400go400001<00_l>00?o2002o`@00_l;00;o5@02o`L00_l400;o1P02o`P0
0_l<00;o3@02o`P00_l700;o0P03o`@00ol600?o1@03oa400ol400?o1@03o`D00olF00;o2003o`D0
0olD00;o1P02o`H00_l;00;o1P02o`<00_l600;o4`02o`D00olB00?o1003o`D00_l600;o1002o`L0
0_l700;o2@02o`@01?l600;o1P02oa00000C00;o3`03o`H00_l600;o2P02oaD00_l700;o1002o`H0
0_l800;o3002o`d00_l800;o1`02o`800_l600;o1P02o`L00_lA00;o1P02o`D00_l700;o5P02o`P0
0_l700;o5002o`H00_l600;o2`02o`H00_l300;o1P02oa<00_l600;o4P04o`<00ol500;o1P02o`@0
0_l700;o1`02o`T00_l600;o1P02o`H00_l@00004`02oa000_l600;o1P02o`X00_lE00;o0`02o`80
0_l400;o0P02o`800_l800;o3002o`d00_l800;o0`02o`800_l200;o1P02o`H00_l700;o4@02o`H0
0_l500;o1`02oaH00_l800;o1`02oa@00_l600;o1P02o`/00_l600;o0`02o`800_l200;o4`02o`H0
0_lB00Co0P04o`D00_l200;o0P02o`@02ol700;o2@02o`L00_l500;o1P02oa00000C00;o3004o`03
0?oo00D00_l600;o2P02oaD00_l200?o0P02o`@00_l200;o3002o``00_l=00;o2002o`800ol200;o
0P02o`H00_l>00?o4@02o`H00_l=00?o5P02oa000olD00;o1P02o`H00_l;00;o1P02o`<00_l200;o
5`02o`H00_lB00;o00@0o`001?l500;o0P02o`T02Ol800;o2@02o`L00_l500;o1P02oa00000C00;o
2P09o`D00_l600;o2P02oaD00_l20003o`3o00800_l400Ko3002o``00_l=00;o2002o`8000?o0?l0
0P02o`X00_l900Oo6P02o`P01olG00;o2`07oaD00_l>00;o2`02o`/01_lG00;o1@03oa800_l01P3o
003o00;o1@06o`T00_l500;o2002o`T00_l700;o1@02oaP0000C00;o2P02o`@00ol500?o1002o`/0
0_lE00;o00@0ool00_l00`3oo`0400Ko3002o``00_l=00;o2002o`040?oo00;o00<0ool02P02o`L0
1olL00;o1P07oaT00_l900Oo5`02o`h00_l;00;o2`06oaL02OlC00;o00<0ool00_l00`3oo`0500Ko
2P02o`<00_l900;o2@02o`L00_l500;o600001@00_l800;o1P02o`D02Ol:00;o5P02o`030?oo0080
00Co0?oo1002o`800_l700;o0`02o`<00_l700;o3@02o`P00_l00`3oo`020004o`3oo`X00_l600?o
8@02o`D00olN00;o2003oa`00_l>00;o2`02o`/00_l200;o5`08oa@00_l00`3oo`02o`030?oo00D0
0_l200;o2P02o`<00_l400;o0`02o`<00_l400;o1`02o`D00_lH00005002o`P00_l600;o1@02o`03
0?oo00;o3002oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`L00_l=00;o
2002o`030?l0008000Co0?oo2P02o`H00_l70003o`0001P00_l500;o1`000ol0000E00;o2002o`L0
00?o00004`02o`h00_l;00;o2`02o`800_l200;o4`02o`@00olB00;o0`02o`<00_l400;o0P02o`80
0_l700;o00@0oooo1002o`<00_l300;o1002o`L00_l500;o600001@00ol700;o1P02o`H00_l@00;o
5P04o`<01?l400;o1P02o`<00_l300;o0`02o`L00_l=00;o2004o`<01?l:00;o1P02o`H00_lJ00;o
1@02o`H00_lG00;o2002o`H00_lE00;o3P02o`/00_l;00;o1P02oa<00_l500;o4P02o`<00_l300;o
1002o`H00_l700;o00<0ool01@02o`<00_l300;o1002o`H00_l600;o600001D00_l700;o1P000ol0
000500?o3P02oaL01?l400?o1002o`H00_l300;o0`02o`<00_l700;o3@02o`P01?l400?o2P02o`H0
0ol400?o6P02o`D00ol400?o5`02o`P00ol400?o5@02o`h00_l;00;o2`02o`H00_lC00;o1003oa80
0_l800;o1002o`H00_l700Go1@02o`<00_l300;o1002o`@01?l600;o600001H00_l700;o1002o`P0
0ol<00;o5`04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`<01?l500Co100:o`@02OlE00[o0`09oa<0
2_l500Wo4P08o`L02_l400So1P0<oa402_lB00Ko0P06o`030?oo00[o1007o`H03?l300[o1008oaD0
000G0003o`0000D01ol:00Oo1`000ol0000F00Co1@04o`030?oo00[o0`0<o`<02_l500[o0`04o`D0
1?l400[o1P05o`030?l001@02_l500Go00<0o`004P0:o`L01Ol00`3o000A00So1`0:o`@02?l600co
4@09oa<01_l200Ko00<0ool02_l400Oo1P0<o`<02?l600So5@0002401?l=00Goo`330000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(97\\) METIINKS JSZJR LILE B XEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@02o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
2_l500[o1006o`<00_l200Go1P02o`<00_l00`3oo`03oaH01_l700;o00<0ool00ol600[o1P06o`H0
1Ol600?o3`0=o`802_l400go00<0ool02_lA00[o4`05o`801Ol200co0P06o`<01_l0103oo`05o`H0
2?l600go400001<00_l900Oo2`02o`l00_lD00Go0`05o`030?oo00[o1@08o`D02_l500[o1006o`80
0ol200Go1@03o`<02_lB00Wo1P0:o`@02_l400Wo1@05o`D01?l?00go0P0:o`@03Ol00`3oo`0:oa40
2olB00Go0P05o`803?l200Ko0`06o`030?oo00So100:o`@03Ol@00004`02o`h00ol;00;o3P02oaD0
0_l700;o1002o`H00_l800;o3002o`d00_l900;o1004o`@00_l500?o1003o`D00olA00?o1003o`D0
0ol500?o1002o`D00_l400?o1003o`H00_l500?o5002o`H00_l600;o2`02o`H00_l300;o1P02oa<0
0_l500?o4P03o`@00ol500;o1P02o`@00_l700;o0`03o`D00ol400;o1004o`H00_l600;o400001<0
0_l?00?o2P02o`h00_lE00;o1`02o`@00_l600;o2002o``00_l=00;o2@02o`@01?l400;o1@02o`D0
0_l700;o4@02o`H00_l500;o1`02o`@00ol400;o1002o`H00_l600;o1@02oaD00_l600;o1P02o`/0
0_l600;o0`02o`H00_lC00;o1P02oa<00ol200?o1P02o`H00_l400;o1`02o`<00_l700;o1002o`H0
0_l600;o1P02oa00000C00;o4002o`X00_l>00;o5@02o`<00_l200;o1002o`800_l200;o2002o``0
0_l=00;o2@02o`<01Ol400;o1002o`H00_l700;o4@02o`H00_l500;o1`02o`D00ol300;o1002o`H0
0_l600;o1002oaH00_l600;o1P02o`/00_l600;o0`02o`800_l200;o4`02o`H00_lD00;o0P02o`L0
0_l200;o0P02o`@02ol300;o1`02o`@00_l700;o1@02o`H00_l@00004`02o``01?l00`3oo`0:0003
o`0000`00_lE00;o0P03o`800_l400;o0P02o``00_l<00;o3@02o`T00_l300;o00<0ool01003o`80
0ol>00?o4@02o`H00_l=00?o1P02o`<00_l400;o1P02o`H00_l300?o5P02o`H00_l600;o2`02o`H0
0_l300;o0P02oaL00_l600;o5@04o`P00_l200;o2@09o``00ol400;o1`02o`D00_l600;o400001<0
0_l:00Wo2P02o`d00_lE00;o0P000ol0o`0200;o1006o``00_l<00;o3@02o`T00_l200?o00<0ool0
1007o`X01olJ00;o2007o`L00ol@00;o1P07oaL00_l>00;o2`02o`/01_lG00;o1@03oaD01?l800Ko
2@02o`D00_l700Oo1@02o`L00_l500;o600001<00_l:00;o1003o`X00_l=00;o5@02o`040?oo00;o
00<0ool01006o``00_l<00;o3@02o`T00_l200;o0P02o`@01Ol:00Oo7002o`H01ol:00?o3`02o`H0
2OlE00;o3P02o`/00_l;00Ko5`09oaH00ol900Ko2P02o`<00_l600Oo1`02o`L00_l500;o600001@0
0_l800;o1P02o`/000?o00002P02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o
1`02o`d00_l900;o00<0ool00`02o`@00_l0103oool800?o8@02o`D00ol;00;o0`02o`l00_l600;o
1@03oa@00_l>00;o2`02o`/00_l200;o5`08oaL01?l800;o0P02o`X00_l300;o1@03o``00_l700;o
1@02oaP0000D00;o2002o`H00_l;00;o2`02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<0
0_l300;o0`02o`L00_l=00;o2@05o`<00_l400;o0P03o`L00_l70003o`0001P00_l500;o1`000ol0
000200;o0`03o`h00_l600;o1P02oa@00_l>00;o2`02o`/00_l200;o0P02oa<00_l400?o5@06o`L0
0_l200;o0P02o`L00_l0103oool500;o1`000ol0000300;o1`02o`D00_lH00005003o`L00_l600;o
2`02o`/00_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02o`d00_l900Co1002o`@00_l300?o
1P02o`H00_lJ00;o1@02o`H00_l400;o1003o`d00_l600;o1P02oa@00_l>00;o2`02o`/00_l600;o
4`02o`D00_lD00?o0P03o`H00_l600;o1`02o`030?oo00H00_l600;o1@02o`H00_l600;o600001D0
0_l700;o1P000ol0000;0003o`0000P00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o1`02o`d0
0_l900Co1002o`@00_l400?o1@03o`@00olJ00;o1@03o`@00ol400;o1@02o`d00_l600;o1@03oa@0
0_l>00;o2`02o`/00_l600;o4`02o`@00olD00;o1002o`H00_l600;o1`05o`H00ol400?o1@02o`@0
1?l600;o600001H00_l700;o1002o`H00_l500;o2002oaL01?l500Co00<0ool02_l300co0`0:o`D0
2_l400Co0P06o`030?oo00?o0`05o`@02OlE00[o0`09o`@02_l700[o00<0ool02OlB00So1`0:o`@0
2?l600co4@0:oa<01Ol200Go0P0<o`@01ol800Wo100:o`@02?lE00005`000ol0000500Oo1`09o`P0
00?o00005P04o`D01?l00`3oo`0:o`<03?l300[o1@0:o`@00ol300Ko00<0ool00ol300Go1P05o`03
0?l001@02_l500Go00<0o`000`0:o`L02_l00`3oo`07oa@02?l700[o1008o`H03?lA00Wo5005o`80
1Ol200co1007o`X01Ol00`3o000300So1P08oaD0000Q00Co2009ool0a0000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(98\\) METHINKS JS JSZLILE B XEASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o0P05o`H00_l300;o00<0ool00olF00Ko1`02o`030?oo00?o5P06o`L0
0_l00`3oo`03o`L02_l300go0P0:o`@03Ol00`3oo`0:oa402_lC00Go0P05o`803?l200Ko0`06o`04
0?oo00Go1P08o`H03Ol@00004`02o`T01ol900So2`02oa@01Ol300Go00<0ool02_l500So1@04o`<0
1?l400[o1006o`800ol200Go1@03o`<02_lB00Wo1P0:oa802Ol600[o1@0:o`<03Ol200[o100=o`03
0?oo00[o4@0;oa801Ol200Go0P0<o`801_l300Ko00<0ool02?l400[o100=oa00000C00;o3P03o`L0
0ol400?o2P02oaD00_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l400;o1@03o`@0
0ol500?o4@03o`@00ol500?o1@03oa400ol400?o1@03o`D00ol500;o1@02o`H00_l600;o1P02o`/0
0_l600;o0`02o`H00_lC00;o1@03oa800ol400?o1@02o`H00_l400;o1`02o`<00ol500?o1002o`@0
1?l600;o1P02oa00000C00;o3`03o`H00_l600;o2P02oaD00_l700;o1002o`H00_l800;o2@02o`D0
0_l900;o2@02o`@01?l400;o1@02o`D00_l700;o4@02o`H00_l500;o1`02oa400_l600;o1@02o`L0
0_l500?o1002o`H00_l600;o1P02o`/00_l600;o0`02o`H00_lC00;o1P02oa<00ol200?o1P02o`H0
0_l400;o1`02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4002o`H00_l600;o2P02oaD0
0_l300;o0P02o`@00_l200;o0P02o`P00_l900;o1@02o`T00_l900;o0`05o`@00_l400;o1P02o`L0
0_lA00;o1P02o`D00_l700;o4@02o`H00_l500;o1`02o`H00ol300;o1P02o`H00_l600;o2`02o`H0
0_l300;o0P02o`800_lC00;o1P02oa@00_l200;o1`02o`800_l200;o100;o`<00_l700;o1002o`L0
0_l500;o1P02oa00000C00;o3004o`030?oo00D00_l600;o2P02oaD00_l200?o0P02o`@00_l200;o
3002o`T00_l500;o2@02o`T00_l300;o00<0ool01003o`800ol>00?o4@02o`H00_l=00?o4@02o`H0
0_l=00?o1`02o`<00_l600;o1P02o`H00_l;00;o1P02o`<00_l200;o5`02o`H00_lE00Co2002o`80
0_l900Wo3003o`@00_l700;o1@02o`H00_l@00004`02o`X02Ol600;o1002o`/00_lE00;o0P000ol0
o`0200;o1006o``00_l900;o1@02o`T00_l900;o0P03o`030?oo00@01ol:00Oo6P02o`P01olJ00;o
2007o`P00ol:00;o3P02o`/00_l;00Ko5`02o`D00olE00Co2006o`T00_l500;o1`07o`D00_l700;o
1@02oaP0000C00;o2P02o`@00ol700Oo2`02oaD00_l0103oo`02o`030?oo00@01_l<00;o2@09o`T0
0_l900;o0P02o`800_l400Go2P07oa`00_l600Oo7002o`H01ol;00?o2@02o`h00_l;00;o2`06oaL0
2OlF00?o2@06o`X00_l300;o1P07o`L00_l700;o1@02oaP0000D00;o2002o`H00_l700Ko2`02oaH0
0_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool00`02o`@0
0_l0103oool800?o8@02o`D00olQ00;o1@03o``00_l300;o2@02o`h00_l;00;o2`02o`800_lG00So
5`04o`P00_l200;o2P02o`<00_l500?o3002o`L00_l500;o600001@00_l800;o1P02o`H00_l400;o
2P02oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`<00_l300;o0`02o`@00_l500;o2@02o`T0
1Ol300;o1002o`800ol700;o1`000ol0000H00;o1@02o`L000?o00006002o`D00_l70003o`0000<0
0_l300?o2002o`h00_l;00;o2`02o`800_l200;o4`02o`@00olE00Ko1`02o`800_l200;o1`02o`04
0?ooo`D00_l70003o`0000<00_l700;o1@02oaP0000D00?o1`02o`H00_l500;o1P02o`T00_lF00Co
0`04o`@00_l600;o0`02o`<00_l300;o1002o`D00_l900;o2@04o`@00_l400;o0`03o`H00_l600;o
6P02o`D00_l600;o6P02o`D00_l600;o1@02o`@00ol700;o3P02o`/00_l;00;o1P02oa<00_l500;o
5003o`800ol600;o1P02o`L00_l00`3oo`0600;o1P02o`D00_l600;o1P02oaP0000E00;o1`02o`H0
00?o00001002o`H00_l800;o5`04o`@00ol400;o1P02o`<00_l300;o0`02o`@00_l500;o2@02o`T0
1?l400;o1002o`@00ol500?o1003oaX00_l500?o1003oaX00_l500?o1003o`D00_l500;o1`02o`h0
0_l;00;o2`02o`H00_lC00;o1003oa@00_l400;o1P02o`H00_l700Go1P03o`@00ol500;o1004o`H0
0_lH00005P02o`L00_l400;o1P03o`@00ol700;o5`04o`D01?l00`3oo`0:o`<03?l300Co0`04o`@0
2_l400Co0P06o`030?oo00?o0`05o`@02OlE00[o0`09oaD02_l300Wo1@0:o`<02?l700[o1008o`H0
3?lA00[o4`05o`801Ol200co1007o`P02Ol400[o1008oaD0000G0003o`0000D01ol800So20000ol0
000F00Co1@04o`030?oo00[o0`0<o`<01?l300Co100:o`@00ol300Ko00<0ool00ol300Go1P05o`03
0?l001@02_l500Go00<0o`00500:o`D01Ol00`3o000400[o0`08o`L02_l400So1P0<oa402OlD00Go
0P05o`803?l400Oo2P05o`030?l000<02?l600So5@0002401?l:00Koo`350000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(99\\) METHINJS JT IRZLIKE B XFBSDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2P05o`h00_lE00Go0`05o`030?oo00[o1@08o`D0
1?l300Co100:o`@01_l300;o1006o`P00_l00`3oo`03oaH01_l800So500:o`<01Ol600?o0P0:o`<0
3Ol200[o1005o`H00_l00`3oo`0:oa402_lC00Go0P05o`801ol800[o1@02o`030?oo00?o1P08o`H0
3Ol@00004`02o`T01ol800Oo3@02oa@01Ol300Go00<0ool02_l500So1@04o`<01?l400[o1006o`80
0ol200Wo1`0:oa802Ol700So500:o`<01Ol500Co0P0:o`<03Ol200[o1005o`D00ol00`3oo`0:oa40
2olB00Go0P05o`801ol800_o100:o`@02_l400go400001<00_l>00?o3003o``00_lE00;o1`02o`@0
0_l600;o2002o`T00_l500;o2@02o`T00_l400Co0P03o`@00ol600?o1@03oa400ol400?o2@02oa/0
0_l900;o1@03o`D00_l500;o1P02o`H00_l600;o2P02o`D00ol400;o1P02oa<00_l500?o4P03o`@0
0ol500;o3@02o`D00ol300?o1@03o`@00_l400Co1P02o`H00_l@00004`02o`l00ol<00?o2`02oaD0
0_l700;o1002o`H00_l800;o2@02o`D00_l900;o2@02o`@01?l200;o1P02o`H00_l700;o4@02o`H0
0_l900;o6`02o`T00_l500;o1P03o`@00_l600;o1P02o`H00_l:00;o1@02o`D00_l600;o4`02o`H0
0_lC00?o0P03o`H00_l=00;o1P02o`<00_l700;o1002o`H00_l600;o1P02oa00000C00;o4002o`d0
0_l;00;o5@02o`<00_l200;o1002o`800_l200;o2002o`T00_l500;o2@02o`T00_l300Go0P02o`H0
0_l600;o1`02oa400_l600;o2@02oa/00_l900;o1002o`P00ol300;o1P02o`H00_l600;o2P02o`@0
0_l600;o0P02o`800_lC00;o1P02oa@00_l200;o1`02o`800_l900;o1P02o`<00_l700;o1002o`L0
0_l500;o1P02oa00000C00;o3004o`030?oo00P01?l00`3oo`0:00;o5@02o`800ol200;o1002o`80
0_l<00;o2@02o`D00_l900;o2@02o`<00_l00`3oo`0200;o1P02o`h00olA00;o1P02o`T00_lK00;o
2@02o`<00ol900;o0`02o`H00_l600;o1P02o`X00ol200?o1P02o`800_lG00;o1P02oaD01?l800;o
0P02o`T00_l600;o2`03o`@00_l700;o1@02o`H00_l@00004`02o`X02Ol600Wo2P02oaD00_l20003
o`3o00800_l400Ko3002o`T00_l500;o2@02o`T00_l200?o00<0ool02P02o`T01olJ00;o2@02oa/0
0_l900Oo2P03o`X00_l>00;o2P07o`L01_lG00;o1@03oaD01?l800Ko2@02o`D00ol600Oo1@02o`L0
0_l500;o600001<00_l:00;o1003o`H00_l400?o2P02oaD00_l0103oo`02o`030?oo00@01_l<00;o
2@09o`T00_l900;o0P02o`800_l:00;o1`07oa`00_l900;o6`02o`T02Ol900?o2@02o`h00_l:00Go
2@06oaL02OlF00?o2@06o`T02Ol500Oo1`02o`L00_l500;o600001@00_l800;o1P02o`D00_l600;o
2@02oaH00_l00`3oo`020004o`3oo`@00_l200;o1`02o`<00_l300;o1009o`T00_l900;o00<0ool0
0`02o`X00_l600?o8@02o`@00_l300;o0`02oaH00_l900;o1@03o`@00_l300;o2@02o`h00_l:00;o
00@0oooo2002o`800_lG00So5`04o`P00_l200;o2@08o`D00ol<00;o1`02o`D00_lH00005002o`P0
0_l600;o1@02o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`800_l200;o0`02o`<00_l300;o
1002o`D00_l900;o2@05o`<00_l:00;o1P02o`L000?o00006002o`@00_l300;o0`02oaH00_l900;o
1P02o`@00_l300?o2002o`h00_l:00;o0P03o`L00_l200;o0P02oa<00_l400?o5@06o`L00_l200;o
0P02o`D00_l400?o1002o`L000?o00000`02o`L00_l500;o600001@00ol700;o1P02o`D00_l600;o
2@02oaH01?l300Co1002o`H00_l300;o0`02o`<00_l400;o1@02o`T00_l900Co1002o`X00_l600;o
1P02oaX00_l400;o0`02o`<00_lF00;o2@02o`H00_l400;o1003o`L00_l>00;o2P02o`<00ol600;o
1P02oa<00_l500;o5003o`800ol600;o1P02o`D00_l500;o1002o`H00_l500;o1P02o`H00_lH0000
5@02o`L00_l60003o`0000@00_l60003o`0000L00_lG00Co1003o`@00_l600;o0`02o`<00_l300;o
1002o`D00_l900;o2@04o`@00_l:00;o1P03o`@00olJ00;o1002o`<00_l300;o5P02o`T00_l500?o
1002o`D00_l700;o3P02o`X00_l400?o1@02o`H00_lC00;o1003oa@00_l400;o1P02o`H00_l500;o
1003o`@00ol400?o1@02o`@01?l600;o600001H00_l700;o1002o`L00_l400;o2002oaL01?l500Co
00<0ool02_l300co0`04o`<01?l400[o1004o`801_l400[o1009oaD02_l00`3oo`0:oa802_l300_o
1@0:o`<02?l700[o1005o`<01Ol00`3oo`0:oa402_lC00Go0P05o`803?l300[o1P09o`@02_l400So
5@0001L000?o00001@07o`P01ol90003o`0001H01?l500Co00<0ool02_l300co0`04o`<01?l400[o
1003o`<01_l400[o1P05o`030?l001@02_l00`3oo`0:oa802_l300Wo1`0:o`<02?l700[o1005o`<0
1Ol00`3oo`0:oa402OlD00Go0P05o`803?l300Wo2@05o`030?l000<02?l600So5@0002401?l;00Co
o`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(100\\) NETHIOJT JT ISZKIKE A XFBSDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`X01?l=00;o5@06o`<00_l300co1008o`H0
1?l300Co0`0:o`L01Ol800Ko2008oaD01_l800So500:o`D00_l00`3oo`03o`H02_l300Go1P02o`<0
2_l300Go1P02o`803?l?00Ko0`06o`l01Ol200Go0`07o`L02_l500;o00<0ool00ol700So1@0=o`T0
000<00;o2P09o`L01_l800Ko3@02oa@01_l200?o0`0<o`@02?l600Co0`04o`<02_l500Wo1009o`L0
2?lC00Wo1`08oa@02_l500[o100:o`<01Ol500?o0`0:o`<01Ol500?o0P0<o`l01_l300Ko3`05o`80
1Ol300Oo1`0;o`@02_l500[o0`0=o`T0000<00;o3P02o`T00ol200?o1P03o`800ol<00;o5@02o`@0
1?l500;o1P02o`L00_l:00;o1@02o`P00_l800?o1@03o`<00ol400?o2@02oaH00ol400?o2@02oa/0
0_l900?o1@03o`@00_l500;o1@02o`D00ol800;o2@02o`D00ol500;o1P02oa400_l700;o4P03o`@0
0ol600;o3002o`D00ol300?o1@03o`D00_l400Co1@02o`H00_l900003002o`h00_l900;o1002o`H0
0_l400;o3002oaD00_l400Co1@02o`H00_l700;o2P02o`D00_l800;o2002o`L00_l300;o1P02o`T0
0_lF00;o1P02o`T00_lK00;o2@02o`L00_l400?o1002o`D00_l500;o2@02o`T00_l500;o1P02o`H0
0_lA00;o1`02oa<00ol200?o1`02o``00_l600;o0`02o`L00_l500;o1P02o`D00_l600;o2@0000`0
0_l>00;o2002o`H00_l400;o1P02o`/00_lE00;o0`05o`D00_l200;o0P02o`L00_l:00;o1@02o`P0
0_l700;o2@02o`800_l600;o2@02oaH00_l600;o2@02oa/00_l900;o1`02o`D00ol300;o1@02o`@0
0_l:00;o2@02o`@00_l700;o0P02o`800_lA00_o5002o`800_l800;o0P02o`P00_l600;o0`02o`L0
0_l500;o1`02o`@00_l600;o2@0000`00_l>00;o2002o`H00_l400;o1P02o`/00_lE00;o0`02o`03
0?oo00D00_l200;o2`02o`X00_l500;o2002o`L00_l900;o0P02o`H00_l900;o5P02o`H00_l900;o
6`02oa400ol600;o0`02o`D00ol200?o2P02o`T00ol200?o1`02o`800_lF00Wo5P04o`T00_l200;o
2002o`H00_l;00?o1@02o`L00_l400;o1P02o`T0000<00;o3P02o`P00_l600;o1002o`H00_l;00;o
5@02o`800ol00`3oo`0500Ko2`02o`X00_l500;o2002o`L00_l900;o2P02o`T00_lN00;o2@02oa/0
0_l<00Oo1`03o`T01ol;00;o2@07o`P01_lF00;o1@02oaH01?l900Ko2002o`D00ol600Oo1P02o`L0
0_l400;o4@0000`00_l>00;o2002o`H00_l400;o1P02o`/00_lE00;o0P02o`800_l500Ko2`02o`X0
2Ol800;o1`02o`T00_l:00;o2@02oah00_l900;o6`02o`X01ol:00?o2005o`d00_l900Go2P06oaL0
0_l300;o5`03o`X01_l800Wo1@07o`P00_l700;o1002oa40000=00;o3@02o`P00_l600;o1002o`H0
0_l:00;o5P02o`030?oo00<00_l500;o0P02o`H00_l300;o0`02o`D02Ol800;o1`02o`T00_l:00;o
1002o`<00_l300;o6@02o`@00_l300;o0`02oaH00_l900?o2`02o`<00_l800;o00@0oooo3002o`T0
0_l0103oool900;o0P02oaL00_l300;o5`04o`T00_l200;o2008o`D00ol=00;o1`02o`@00_lA0000
3@02o`d00_l800;o1P02o`@00_l600;o2P02oaH01Ol300;o1@02o`800_l200;o0P02o`<00_l300;o
1@02o`D00_l800;o1`02o`T00_l:00;o1002o`<00_l300;o6@02o`@00_l300;o0`02oaH00_l900;o
1`000ol0000200;o0`03o`L00_l200?o2`02o`T00_l200?o2002o`800_l200;o5002o`040?oooaH0
1_l800;o0P02o`800_l400;o1003o`@00_l70003o`0000@00_l700;o1002oa40000=00?o3002o`P0
0_l600;o1002o`H00_l:00;o5P04o`@00_l500;o1P02o`800_l300;o0`02o`D00_l500;o2002o`P0
0_l700;o2`02o`@00_l300;o0`02oaT00_l400;o0`02o`<00_lF00;o2@02o`H00_l400;o1003o`H0
0_l300?o2P02o`T00_l300?o1`02o`H00_lD00;o00<0ool05P03o`800ol700;o1P02o`@00_l500;o
1002o`H00_l600;o1P02o`D00_lA00003P02o``00_l900;o1002o`H00_l400;o2P02oaL01?l400;o
1@02o`H00_l200;o0`02o`<00_l500;o1@02o`P00_l800?o1@03o`/00_l400;o0`02o`<00_lI00;o
1002o`<00_l300;o5P02o`T00ol400?o1002o`D00_l600;o1003o`T00_l900;o1003o`H00_l600;o
5005oaH00_l400;o1`02o`H00_l400;o1003o`@00ol400?o1P02o`@01?l500;o4@0000l00_l700?o
00<0ool02@03o`800ol600?o0P03o`T00_lG00Co0P06o`803?l200co1004o`<01?l300[o1@09o`L0
2_l00`3oo`0:oa@02_l00`3oo`0:oa802_l600Wo100:o`<01Ol300Go0`0:o`<01Ol300Go0P0<oa40
1olE00Go0P05o`<03?l200[o1P09o`D02_l300So3P00010000?o00001@06o`X01_l800Ko2P000ol0
000F00?o0`06o`803?l200co1004o`<01?l300[o1`05o`T02_l00`3oo`0:oa@02_l00`3oo`0:oa80
2_l800Go00<0o`000`0:o`<01Ol300Go0`0:o`<01Ol300Go0P0<oa401olE00Go0P05o`<03?l200Wo
2@05o`030?l000@02?l500So3P0001/00ol;00Co2P04ool0_`000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(101\\) NEUHJOKS JT JSZLIKE A XFBSDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`P02Ol:00;o5@06o`<00_l300co1`04o`L0
1?l300Co1006o`X01Ol600Go1P02o`800_l00`3oo`03oaH01_l800So5@06o`P00_l00`3oo`03o`H0
2_l300go0`0:o`<01Ol600;o0P0<o`l01_l300Ko3`05o`801Ol300Oo1`0:o`D00_l00`3oo`03o`L0
2?l500go2@0000`00_l:00Wo1`06o`L02Ol;00;o5006o`800ol300co1@08o`D01?l300Co0P09o`L0
2Ol400Go1@03o`802_lB00Wo1`08oa<02Ol700[o100:o`<03Ol300[o0`05o`D00ol200co3`06o`<0
1_l?00Go0P05o`<01ol700_o100:o`D02_l300go2@0000`00_l>00;o2@03o`800ol:00;o3P02oaD0
0_l400Co1@02o`H00_l500;o1002o`H00_l500;o0`03o`@00ol500?o1@03o`D00_l500?o0`03o`D0
0olA00?o1003o`T00_lF00?o1003o`H00ol500?o1002o`D00_l600;o1P02o`L00_l900;o1@03o`D0
0_l600;o4@02o`L00_lB00?o1003o`H00_l<00;o1@03o`<00ol500?o1@02o`@01?l500;o1P02o`T0
000<00;o3P02o`T00_l400;o2P02o`h00_lE00;o1004o`D00_l600;o1002o`H00_l500;o1@02o`<0
0_l600;o1@02o`L00_l500;o1@02o`@00_l700;o4@02o`H00_l900;o5P02o`H00_l600;o1`02o`@0
0ol400;o1P02o`H00_l700;o2@02o`D00_l600;o1P02oa400_l700;o4`03o`800ol700;o3002o`H0
0_l300;o1`02o`D00_l600;o1@02o`H00_l900003002o`h00_l800;o1P02o`T00_l>00;o5@02o`<0
1Ol500;o0P02o`800_l400;o1P02o`D00_l500;o0`02o`H00_l400;o2@02o`@00_l400;o1@02o`L0
0_lA00;o1P02o`T00_lF00;o1P02o`H00_l700;o1@03o`<00_l600;o1P02o`L00_l900;o1002o`L0
0_l200;o0P02oa402olD00;o0P02o`P00_l200;o2002o`H00_l300;o1`02o`D00_l700;o1002o`H0
0_l900003002o`h00_l800;o1P02o`T00_l>00;o5@02o`<00_l00`3oo`0500;o0P02o`P00_l600;o
1@02o`D00_l300;o1P02o`@00_l900;o1003o`800ol=00?o4@02o`H00_l900;o5P02o`H00_l>00?o
1P02o`<00_l600;o1P02o`L00_l900?o0P03o`L00_l200;o5P09oaH01?l900;o0P02o`P00_l600;o
2`03o`D00_l700;o1002o`H00_l900003002o`h00_l800;o1P02o`T00_l>00;o5@02o`800ol00`3o
o`0500Ko2002o`H00_l500;o1@02o`/00_l400;o2@02o`@01ol900Oo6P02o`T00_lN00;o2@07o`L0
0ol:00;o3`02o`T01ol800Ko5P02o`D00_lF00Co2@06o`P00_l500?o1P07o`H00_l700;o1002oa40
000<00;o3P02o`P00_l600;o2@02o`h00_lE00;o0P02o`800_l500Ko2002o`H00_l500Wo2`02o`@0
0_l900;o1005o`T01olL00;o2@02oah00_l700Oo2P03o`T00_l?00;o2@05o`X01_lG00;o0`02oaL0
0ol:00Ko2009o`D01ol800;o1`02o`@00_lA00003@02o`d00_l800;o1P02o`T00_l=00;o5P02o`03
0?oo00<00_l500;o0P02o`P00_l600;o1@09o`/00_l400;o2@02o`@00_l0103oool700?o8@02o`@0
0_l300;o0`02oaT00_l600?o2`02o`<00_l900;o3`02o`T00_l0103oool900;o0P02oaL00_l300;o
5`04o`T00_l200;o2008o`D00ol=00;o1`02o`@00_lA00003@02o`d00_l800;o1P02o`T00_l=00;o
5P05o`<00_l500;o0P02o`800_l400;o1P02o`D00_l500;o2`02o`@00_l900;o1002o`800ol600;o
1`000ol0000H00;o1002o`<00_l300;o6@02o`H00_l70003o`0000800_l300?o2002o`l00_l900;o
0P03o`P00_l200;o0P02oa@00_l0103ooolF00Ko2002o`800_l200;o1002o`@00ol400;o1`000ol0
000400;o1`02o`@00_lA00003@03o``00_l800;o1P02o`T00_l=00;o5P04o`@00_l500;o1P02o`@0
0_l600;o1@02o`D00_l;00;o1@02o`L00_l500;o0`03o`D00_l600;o6P02o`@00_l300;o0`02oaT0
0_l600;o1P02o`@00_l400?o1`02o`l00_l900;o0`03o`L00_l600;o5002o`030?oo01H00ol200?o
1`02o`H00_l400;o1@02o`@00_l600;o1P02o`H00_l500;o4@0000h00_l<00;o2@02o`@00_l:00;o
3002oaL01?l400;o1@02o`H00_l400;o1P02o`D00_l500;o2`02o`D00ol500?o1@02o`@00ol400?o
1003oaX00_l400;o0`02o`<00_lI00;o1P03o`@00ol400;o1@02o`L00_l?00;o2@02o`@00ol600;o
1P02oa@01OlF00;o1002o`L00_l600;o1002o`@00ol400?o1003o`H00_l400Co1@02oa40000?00;o
1`03o`030?oo00T00ol200?o1P03o`030?oo00/00_lG00Co0P06o`803?l300Co1004o`<01?l300Co
1@0:o`<02Ol400Go0`05o`<02OlE00[o00<0ool02_lD00[o1009o`@02_l300So200:o`<01Ol300Go
0P0<oa401olE00Go0P05o`<03?l200[o1P09o`D02_l300So3P00010000?o00001@06o`X01_l700Ko
2`000ol0000F00?o0`06o`803?l300Co1004o`<01?l300Co1@0:o`D01Ol600Go0`05o`D01Ol00`3o
000D00[o00<0ool02_lD00[o1P05o`030?l000<02_l300So200:o`<01Ol300Go0P0<oa401olE00Go
0P05o`<03?l200Wo2@05o`030?l000@02?l500So3P0001/00ol;00Co2`03ool0_`000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(102\\) MFUHJOJS JT IS LIKE A WFBREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`L02_l:00;o5005o`<01Ol200Oo3004o`L0
1?l300Co1006o`X01Ol800Ko1`02o`030?oo00?o5P06o`P02?lD00[o1@02o`030?oo00?o4`0=o`<0
2_l300Go1P02o`803?l?00Ko0`06oa400_l400;o1@07o`L02_l400Go1P03o`030?oo00[o0P0=o`T0
000<00;o2P09o`L01_l600[o2`02oa<01Ol300Go0P07o`X02?l500Co0`04o`802Ol700Wo1009o`H0
2_lB00Wo1`08oa@02_l500[o4@0=o`<02_l300Go1@03o`803?l?00Ko0`06oa400_l400;o1@07o`L0
2ol300Go1@04o`030?oo00[o0P0=o`T0000<00;o3P02o`T00ol200?o1P02o`D00_l;00;o5002o`L0
0_l500;o3@02o`@00_l600;o1@02o`<00ol400?o1@03o`D00ol300?o1003o`D00ol500?o4@03o`@0
0ol900;o6`02o`T00ol500?o4`02o`H00_l700;o2@02o`D00ol500;o1P02oa400_l700;o4P03o`@0
0ol600;o3002o`D00ol400;o1@03o`D00_l600;o1@02o`H00_l900003002o`h00_l900;o1002o`L0
0ol@00;o5002o`L00_l500;o3002o`H00_l500;o1@02o`<00_l600;o1@02o`L00_l300;o1P02o`D0
0_l700;o4@02o`H00_l900;o6`02o`T00_l700;o4`02o`H00_l700;o2@02o`D00_l600;o1P02oa40
0_l700;o4P04o`<00ol600;o3002o`H00_l400;o1@02o`H00_l600;o1@02o`H00_l900003002o`h0
0_l800;o1P02o`L00ol?00;o5002o`<00_l200;o1@02o`800_l800;o1P02o`D00_l500;o0`02o`H0
0_l400;o2@02o`800_l600;o1@02o`L00_lA00;o1P02o`T00_lK00;o2@02o`L00_lC00;o1P02o`L0
0_l900;o1002o`L00_l200;o0P02oa402olB00Co0P04o`H00_l200;o2002o`H00_l400;o1002o`L0
0_l200;o0P02o`D00_l600;o2@0000`00_l>00;o2002o`H00_l800?o3P02oa@00_l200?o0P02o`D0
0_l200;o2002o`H00_l500;o1@02o`<00_l600;o1002o`T00_l200;o1P02o`d00olA00;o1P02o`T0
0_lK00;o4@03oa<00_l600;o1`02o`T00ol200?o1`02o`800_lF00Wo4`02o`040?l000Co1P02o`80
0_l800;o1P02o`@00_l300?o1`02o`800_l900;o1P02o`T0000<00;o3P02o`P00_l600;o2@03o`d0
0_lD00;o0P000ol0o`0200;o1@06o`P00_l600;o1@02o`D00_l;00;o1002o`T00_l:00;o2007oaX0
0_l900;o6`02o``01olD00;o3`02o`T01ol800Ko5P02o`D00_lC00;o00H0o`00o`02o`H01_l800;o
1@03o`@01ol800Ko2@02oa40000<00;o3P02o`P00_l600;o2P03o``00_lD00;o00@0ool00_l00`3o
o`0500Ko2002o`H00_l500Wo2`02o`@00_l900;o2P02o`H01olL00;o2@02oa/00_l:00Oo5P02o`l0
0_l900Go2P06oaL00_l300;o5002o`030?oo00;o00<0ool01P06o`P02Ol500Wo1P06o`T00_lA0000
3@02o`d00_l800;o1P02o`/00_l;00;o5@02o`030?oo008000Co0?oo1@02o`800_l800;o1P02o`D0
2Ol;00;o1002o`T00_l:00;o1@03ob400_l400;o0`02o`<00_lF00;o2@03oa/00_l?00;o2@02o`04
0?ooo`T00_l200;o5`02o`<00_lD00;o00<0ool00_l00`3oo`0600;o0P02o`P02?l600;o1@03o`D0
0_l200;o2@02oa40000=00;o3@02o`P00_l600;o3002o`X00_lE00;o00<0o`000P001?l0ool500;o
0P02o`800_l400;o1P02o`D00_l500;o2`02o`@00_l900;o2P02o`D00_l70003o`0001P00_l400;o
0`02o`<00_lF00;o2@02o`L000?o00004P02o`l00_l900;o0P03o`P00_l200;o0P02oa@00_l0103o
oolC00;o0`02o`<00_l500;o0P02o`800_l400;o1003o`D00_l600;o1@02o`800_l200;o1@02oa40
000=00?o3002o`P00_l600;o3002o`X00_lE00Co0`04o`D00_l600;o1002o`H00_l500;o1@02o`/0
0_l500;o1`02o`/00_l500;o1P02oaX00_l400;o0`02o`<00_lF00;o2@02o`H00_lD00;o3`02o`T0
0_l300?o1`02o`H00_lD00;o00<0ool05002o`<00_l300;o1@02o`H00_l400;o1@02o`D00_l600;o
1@02o`H00_l500;o4@0000h00_l<00;o2@02o`@00_l600;o1@02o`T00_lF00Co1003o`D00_l600;o
1002o`H00_l500;o1@02o`/00_l500?o1@03o`/00_l500?o1003oaX00_l400;o0`02o`<00_lF00;o
2@03o`@00olD00;o3`02o`T00_l400?o1P02o`H00_lD00Go5002o`P00_l500;o1P02o`@00_l400?o
1@02o`D00ol500;o1P02o`D00_lA00003`02o`L00ol00`3oo`0900?o0P03o`H00ol300?o2002oaH0
1?l500Co0P0<o`<01?l400Co0`04o`<01?l500[o0`09o`L02_l300Wo5@0:o`030?oo00[o4P0:o`H0
2OlA00So200:o`<01Ol300Go0P0<oa401olD00Ko0P06o`803?l200[o100;o`@03?l200So3P000100
00?o00001@06o`X01_l800Oo2@000ol0000E00Co1@04o`803?l300Co1004o`<01?l300Co1@0:o`D0
1Ol900[o1@05o`030?l001@02_l00`3oo`0:oa802_l800Go00<0o`004008o`P02_l300Go0`05o`80
3?lA00Oo5006o`801_l200co0P09o`D02Ol600co0P08o`h0000K00?o2`04o`X01Ooo0;h0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(103\\) NFTHJOKSZJT IT LIKE A WEBSEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`T01Ol=00;o5@06o`<00_l300Oo2@08o`H0
1?l300Co1006o`X01Ol600Go1P02o`800_l00`3oo`03o`L02_l500Ko2008oa@02_l600So4P0=o`<0
2_l300Go1P02o`803?l?00Ko0`06oa400_l400;o1@0<o`802_l500;o00<0ool00ol600co0P05o`H0
0_l900003002o`X02Ol700Ko1P09o``00_lD00Ko0P03o`<01ol900So1P04o`<01?l200Wo1`09o`@0
1Ol500?o0P0:o`D02_l300Wo1`08oa@02_l600So4P0=o`<02_l300Go1@03o`803?l?00Ko0`06oa40
0_l400;o1@0<o`802ol400[o100<o`801Ol500?o2@0000`00_l>00;o2@03o`800ol500;o1@02o``0
0_lE00;o1004o`D00_l?00;o2P02o`D00_l300?o1003o`D00ol500?o1@02o`D00ol300?o1@03o`D0
0_l500;o0`03o`@00ol900;o6`02o`d00_lH00;o1P02o`L00_l900;o1@03o`D00_l600;o4@02o`L0
0_lB00?o1003o`H00_l600;o1002o`D00ol300?o1@03o`D00_l600;o1002o`D00ol:00003002o`h0
0_l900;o1002o`d00_l;00;o5@02o`@01?l500;o3`02o`X00_l500;o0`02o`H00_l500;o1`02o`D0
0_l500;o1002o`L00_l500?o1002o`<00_l600;o2@02oa/00_l=00;o6002o`H00_l700;o2@02o`D0
0_l600;o1P02oa400_l700;o4P04o`<00ol600;o1P02o`@00_l600;o0`02o`L00_l500;o1P02o`@0
0_l500;o2`0000`00_l>00;o2002o`H00_l<00;o2`02oaD00_l300Go1@02o`800_l;00;o2P02o`D0
0_l300;o1P02o`@00_l900;o1002o`@00_l500;o1`02o`H00ol300;o0`02o`H00_l900;o6`02o`d0
0_lH00;o1P02o`L00_l900;o1002o`L00_l200;o0P02oa402olB00Co0P04o`H00_l200;o0P02o`@0
0_l600;o0`02o`L00_l500;o0P02o`800_l400;o1002o``0000<00;o3P02o`P00_l600;o3002o`/0
0_lE00;o0`02o`030?oo00D00_l200;o2`02o`X00_l500;o0`02o`H00_l400;o2@02o`@00ol200?o
3@03o`L00_l300;o0`02o`H00_l900;o6`02o`d00_lH00;o1P02o`L00_l900?o0P03o`L00_l200;o
5P09oa<00_l0103o0004o`H00_l200;o2002o`H00_l;00?o1@02o`800_l800?o0P03o``0000<00;o
3P02o`P00_l600;o2`02o``00_lE00;o0P03o`030?oo00D01_l;00;o2P02o`D00_l;00;o1002o`T0
0_l400Oo2@07o`P00ol?00;o2@02oa/00_l=00;o6002o`l00_l900Oo2006oaH00_l500;o4`02o`06
0?l00?l00_l600Ko2002o`D00ol600Oo1P06o`P01ol=00003002o`h00_l800;o1P02o`P01?l=00;o
5@02o`800_l200;o1@06o`/00_l:00Wo2`02o`@00_l900;o1005o`T01ol;00?o3P02o`T00_lK00;o
3@02oaP00_l?00;o2@05o`X01_lG00;o0`02oa@00_l00`3oo`02o`030?oo00H01_l800Wo1@07o`P0
1_l800Go3`0000d00_l=00;o2002o`H00_l800?o3@02oaH00_l00`3oo`0300;o1@02o`800_l600;o
0`02o`<00_l500Wo2`02o`@00_l900;o1002o`040?ooo`L00ol<00;o0`02o`h00_l400;o0`02o`<0
0_lF00;o2002o`<00_l300;o4`02o`l00_l900;o00@0oooo2@02o`800_lG00;o0`02oa@00_l00`3o
o`02o`030?oo00H00_l200;o2008o`D00ol=00;o0P02o`P00_l0103oool>00003@02o`d00_l800;o
1P02o`X00_l<00;o5P05o`<00_l500;o0P02o`800_l200;o0`02o`<00_l500;o1@02o`/00_l400;o
2@02o`@00_l200?o1P02o`L000?o00000`02o`<00ol=00;o1002o`<00_l300;o5P02o`P00_l300;o
0`02oa<00_l?00;o2@02o`800ol800;o0P02o`800_lD00;o00@0oooo4`02o`<00_l300;o1@02o`80
0_l200;o1002o`@00ol400;o1`000ol0000400;o0P02o`800_l400;o0P03o`d0000=00?o3002o`P0
0_l600;o2`02o`/00_lF00Co1002o`D00_l600;o0P02o`<00_l300;o1@02o`D00_l;00;o1@02o`L0
0_l500;o0`03o`D00_l600;o1@02o`@00ol<00;o1002o`<00_l300;o5P02o`P00_l300;o0`02oa<0
0_l?00;o2@02o`<00ol700;o1P02oa@00_l00`3oo`0D00;o0`02o`<00_l500;o1P02o`@00_l500;o
1002o`H00_l600;o1P02o`@00_l300?o300000h00_l<00;o2@02o`@00_l<00;o2P02oaL01?l400;o
1@02o`H00_l200;o0`02o`<00_l500;o1@02o`/00_l500?o1@03o`D00_l400?o1003o`@00ol500;o
1@02o``00_l400;o0`02o`<00_lF00;o2002o`<00_l300;o4`02o`l00_l900;o1003o`H00_l600;o
5005oa@00_l800;o1@02o`H00_l400;o1003o`@00ol400?o1P02o`H00_l400;o1003o`/0000?00;o
1`03o`030?oo00T00ol200?o1P02o`<00ol900;o5`04o`801_l200co0P0<o`@01?l300Co1@0:o`<0
2Ol400Go0`05o`<02Ol500[o1P0:o`030?oo00[o4P0:o`@03?l@00So200:o`<01Ol300Go0P0<oa40
1olD00Ko0P06o`803?l200[o1P09o`@03?l200Go0`05o`T0000@0003o`0000D01_l:00Ko1`07o`X0
00?o00005P03o`<01_l200co0P0<o`@01?l300Co1@0:o`D01Ol600Go0`05o`D01Ol00`3o000400[o
1P0:o`030?oo00[o4P0:o`@03?l@00So200:o`<01Ol300Go0P0<oa401olD00Ko0P06o`803?l200Wo
2@05o`030?l000<03?l200Go0`05o`T0000K00?o2`04o`X01?oo0;l0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(104\\) MFTGJOJSZIT IT LIJE A WEAREK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`/01_l:00;o5005o`<01Ol200Oo2@08o`T0
1_l600Ko2P05o`P01_l700;o00<0ool00ol700[o100:o`D02?lD00[o1P08oa803Ol300[o1@06o`L0
3?l?00Ko0`06oa400_l400;o1@0<o`030?oo00Co0`0;o`H00ol00`3oo`0:o`801Ol600;o2@0000`0
0_l:00Wo1`06o`X01_l;00;o4`05o`<01Ol200Oo2@08o`L02_l200Wo1`09o`@02Ol600[o1@0:o`@0
2_l500So500:o`H02?lB00go0`0:o`<02Ol600co3`06o`<01_lA00;o1002o`D03?l00`3oo`04o`<0
2ol500Co00<0ool02_l200Go1@03o`T0000<00;o3P02o`T00ol200?o2`02o`d00_lD00;o1`02o`D0
0_l?00;o2@04o`D00_l200?o1003o`D00ol500?o0`03o`@00ol500?o1@03o`D00_l500;o2002o``0
0_lK00;o3@02oaP00_l600;o1`02o`L00ol400?o1`02o`H00_lA00;o1`02oa800ol400?o1P02o`H0
0_l300;o1`02o`@00_l500?o1@02o`H00_l400;o1@03o`X0000<00;o3P02o`T00_l400;o2`02o`d0
0_lD00;o1`02o`D00_l?00;o2@02o`L00_l200;o1P02o`D00_l700;o0`02o`H00_l500;o1`02o`D0
0ol400;o2002o``00_lK00;o3@02oaP00_l600;o1`02o`L00_l600;o1`02o`H00_lA00;o1`02oa80
1?l300?o1P02o`H00_l300;o1`02o`@00_l500;o1P02o`H00_l400;o1@02o`/0000<00;o3P02o`P0
0_l600;o100:o`/00_lD00;o0`02o`800_l500;o0P02o`/00_l800?o1`02o`800_l600;o1002o`T0
0_l200;o1P02o`D00_l700;o1P03o`<00_l800;o3002oa/00_l=00;o6002o`H00_l700;o1`02o`H0
0_l700;o0P02o`800_lA00_o4P04o`801?l600;o0P02o`800_l300_o1002o`@00_l700;o0P02o`80
0_l400;o1002o``0000<00;o3P02o`P00_l600;o100:o`/00_lD00;o0P03o`800_l500;o0P02o`/0
0_l800;o1007o`030?oo00H00_l400;o2@02o`800_l600;o3@03o`L00_l300;o2002o``00_lK00;o
3@02oaP00_l600;o1`02o`L00_l600;o1`02o`800_lF00Wo4`02o`040?l000Co1P02o`800_l800Wo
1@02o`<00ol700;o0P02o`P00ol200?o300000`00_l>00;o2002o`H00_l400;o1002o`d00_lD00;o
0P000ol0o`0200;o1@06o`/00_l800;o1007o`T00_l400;o2@02o`X00_l800Oo2003o``00_l<00;o
6`02o`d00_lH00;o3`02o`l00_l700Ko5P02o`D00_lC00;o00H0o`00o`02o`H01_l800;o1@02o`D0
1ol800Ko2007o`d0000<00;o3P02o`P00_l600;o1@02o`<00_l=00;o5002o`040?oo00;o00<0ool0
1@06o`/00_l800;o5002o`@00_l900;o2P02o`H01ol;00?o2`02o``00_lK00;o3@02oaP00_l?00;o
3`02o`L01_lG00;o0`02oa@00_l00`3oo`02o`030?oo00H01_l900;o0`02o`H02Ol600Ko2005o`l0
000=00;o3@02o`P00_l600;o1P001?l00002o``00_lE00;o00<0ool00P001?l0ool500;o0P02o`H0
0_l300;o0`02o`<00_lD00;o1002o`T00_l:00;o1@03o``00_l300;o2`02o`L00_l300;o0`02oaH0
0_l800;o0`02o`<00_lC00;o3`02o`l00_l700;o0P02oaL00_l300;o5002o`030?oo00;o00<0ool0
1P02o`800_l900;o0`02o`H00_l500?o1@02o`800_l800;o00@0oooo3P0000d00_l=00;o2002o`H0
0_l600;o0P02o``00_lE00;o00<0o`000P001?l0ool500;o0P02o`800_l200;o0`02o`<00_l300;o
2002o`X00_l400;o2@02o`X00_l500;o1`000ol0000300;o0`03o`X00_l700;o0`02o`<00_lF00;o
2002o`<00_l300;o4`02o`l00_l?00;o1`02o`800_l200;o5002o`040?oooa<00_l300;o0`02o`D0
0_l200;o0P02o`H00_l0103oool600;o1P02o`D00_l200;o0P02o`@00_l200?o3@0000d00ol<00;o
2002o`H00_l70003o`0000;o3002oaD01?l300Co1@02o`H00_l200;o0`02o`<00_l400;o1P03o`X0
0_l500;o1`02o`/00_l500;o1P02o`D00_l400?o2@02o`L00_l300;o0`02oaH00_l800;o0`02o`<0
0_lC00;o3`02o`l00_l700;o1P02oa@00_l00`3oo`0D00;o0`02o`<00_l500;o1P02o`H00_l00`3o
o`0700;o1P02o`D00_l600;o1002o`<00ol<00003P02o``00_l900;o1002o`T000Co0?oo2`02oaH0
1?l400?o1@02o`H00_l200;o0`02o`<00_l400?o1004o`X00_l500?o1@03o`/00_l500?o1003o`D0
0_l500;o2@02o`L00_l300;o0`02oaH00_l800;o0`02o`<00_lC00;o3`02o`l00_l700;o1P02oa@0
1OlD00;o2002o`D00_l600;o1P05o`L00_l500?o1@02o`H00_l400;o1003o`/0000?00;o1`03o`03
0?oo00T00ol200?o2@04o`X00_lF00Co1@04o`803?l200co1@0:o`D02_l300Wo1`0:o`<02Ol500[o
100:o`<03?lB00[o100<oa002?l800[o1P0:o`803?lA00Oo5006o`801_l200co0`07o`H02ol400co
0P05o`<01Ol9000040000ol0000500Ko2P06o`/00ol:0003o`0001D01?l500Co0P0<o`803?l700Go
00<0ool01@0:o`D01Ol900[o1@05o`030?l000@02_l400[o0`0<oa802_l400co4008o`P02_l600[o
0P0<oa401olD00Ko0P06o`803?l300Oo1P09o`H03?l200Go0`05o`T0000K00?o2`04o``00ooo0;h0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(105\\) NFTGJOJSZIT IT LIJE A WFAREK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`T01Ol=00;o5@06o`<00_l300Oo2@08o`T0
1_l600Ko2P05o`P01_l700;o00<0ool00ol700[o100:o`D02?lD00[o1P08oa803Ol300[o1@06o`L0
3?l?00Ko0`06oa400_l400;o1@07o`H01_l300_o1P03o`030?oo00[o0P05o`H00_l900003002o`X0
2Ol700Ko1P09o``00_lD00Ko0P03o`<01ol900So1`0:o`802Ol700Wo1009o`H02_l500[o100:o`D0
2?lD00[o1P08oa803Ol300[o0`09o`H03?l?00Ko0`06oa400_l400;o1@07o`H01_l300_o1@04o`03
0?oo00[o0P05o`D00ol900003002o`h00_l900?o0P03o`D00_l500;o3002oaD00_l400Co1@02o`l0
0_l900Co1@02o`800ol400?o1@03o`D00ol300?o1003o`D00ol500?o1@02o`D00_l800;o3002oa/0
0_l=00;o6002o`H00_l700;o1`03o`@00ol700;o1P02oa400_l700;o4P03o`@00ol600;o2`02o`L0
0_l400;o1@03o`D00_l600;o1002o`D00ol:00003002o`h00_l900;o1002o`d00_l;00;o5@02o`@0
1?l500;o3`02o`T00_l700;o0P02o`H00_l500;o1`02o`<00_l600;o1@02o`L00_l500?o1002o`P0
0_l<00;o6`02o`d00_lH00;o1P02o`L00_l700;o1P02o`L00_l600;o4@02o`L00_lB00Co0`03o`H0
0_l;00;o1`02o`@00_l500;o1P02o`H00_l400;o1@02o`/0000<00;o3P02o`P00_l600;o3002o`/0
0_lE00;o0`05o`D00_l200;o2`02o`P00ol700;o0P02o`H00_l400;o2@02o`800_l600;o1@02o`L0
0_l600?o0`02o`P00_l<00;o6`02o`d00_lH00;o1P02o`L00_l700;o1P02o`L00_l200;o0P02oa40
2olB00Co0P04o`H00_l200;o1`0;o`@00_l400;o1`02o`800_l200;o1002o`@00_l<00003002o`h0
0_l800;o1P02o``00_l;00;o5@02o`<00_l00`3oo`0500;o0P02o`/00_l800;o1007o`030?oo00H0
0_l400;o2@02o`800_l600;o3@03o`L00_l300;o2002o``00_lK00;o3@02oaP00_l600;o1`02o`L0
0_l600;o1`02o`800_lF00Wo4`02o`040?l000Co1P02o`800_l800Wo1@02o`<00ol700;o0P02o`P0
0ol200?o300000`00_l>00;o2002o`H00_l<00;o2`02oaD00_l200?o00<0ool01@06o`/00_l800;o
1007o`T00_l400;o2@02o`X00_l800Oo2003o``00_l<00;o6`02o`d00_lH00;o3`02o`l00_l700Ko
5P02o`D00_lC00;o00H0o`00o`02o`H01_l800;o1@02o`D01ol800Ko2007o`d0000<00;o3P02o`P0
0_l600;o1@02o`@00_l<00;o5@02o`800_l200;o1@06o`/00_l800;o5002o`@00_l900;o2P02o`H0
1ol;00?o2`02o``00_lK00;o3@02oaP00_l?00;o3`02o`L01_lG00;o0`02oa@00_l00`3oo`02o`03
0?oo00H01_l900;o0`02o`H02Ol600Ko2005o`l0000=00;o3@02o`P00_l600;o1@08o`/00_lF00;o
00<0ool00`02o`D00_l200;o1P02o`<00_l300;o0`02oa@00_l400;o2@02o`X00_l500?o3002o`<0
0_l;00;o1`02o`<00_l300;o5P02o`P00_l300;o0`02oa<00_l?00;o3`02o`L00_l200;o5`02o`<0
0_lD00;o00<0ool00_l00`3oo`0600;o0P02o`T00_l300;o1P02o`D00ol500;o0P02o`P00_l0103o
ool>00003@02o`d00_l800;o1P02o`D01ol<00;o5P05o`<00_l500;o0P02o`800_l200;o0`02o`<0
0_l300;o2002o`X00_l400;o2@02o`X00_l500;o1`000ol0000300;o0`03o`X00_l700;o0`02o`<0
0_lF00;o2002o`<00_l300;o4`02o`l00_l?00;o1`02o`800_l200;o5002o`040?oooa<00_l300;o
0`02o`D00_l200;o0P02o`H00_l0103oool600;o1P02o`D00_l200;o0P02o`@00_l200?o3@0000d0
0ol<00;o2002o`H00_l500;o4@02oaH01?l400;o1@02o`H00_l200;o0`02o`<00_l400;o1P03o`X0
0_l500;o1`02o`/00_l500;o1P02o`D00_l400?o2@02o`L00_l300;o0`02oaH00_l800;o0`02o`<0
0_lC00;o3`02o`l00_l700;o1P02oa@00_l00`3oo`0D00;o0`02o`<00_l500;o1P02o`H00_l00`3o
o`0700;o1P02o`D00_l600;o1002o`<00ol<00003P02o``00_l900;o1002o`H00_l@00;o5`04o`@0
0_l500;o1P02o`800_l300;o0`02o`@00ol400Co2P02o`D00ol500?o2`02o`D00ol400?o1@02o`D0
0_l900;o1`02o`<00_l300;o5P02o`P00_l300;o0`02oa<00_l?00;o3`02o`L00_l600;o5005oa@0
0_l800;o1@02o`H00_l600Go1`02o`D00ol500;o1P02o`@00_l400?o2`0000l00_l700?o00<0ool0
2@03o`800ol600;o3`02oaL01?l200Ko0P0<o`803?l500[o1@0:o`<02Ol700[o0`09o`D02_l400[o
0`0<oa802_l400co4008o`P02_l600[o0P0<oa401olD00Ko0P06o`803?l300Oo1P0;o`@03?l200Go
0`05o`T0000@0003o`0000D01_l:00Ko1`08o`T000?o00005P03o`<01_l200co0P0<o`L01Ol00`3o
o`0500[o1@05o`T02_l500Go00<0o`00100:o`@02_l300co4P0:o`@03?l@00So200:o`H02_l200co
4@07oa@01_l200Ko0P0<o`<01ol600Wo1P0<o`801Ol300Go2@0001/00ol;00Co2008ool0_@000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(106\\) NESGJNKSZIT IT LIJE A WFARDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`X01?l=00;o5@06o`<00_l300co0`02o`03
0?oo00?o2P06o`H01_l700Ko0`02o`<01Ol600;o0P02o`030?oo00?o1`0:o`@02_l500So500:o`H0
2?lB00go0`0:o`D01_l700co3`06o`<01_lA00;o1002o`D01ol600Ko0`0;o`H00ol200So1@05o`H0
0_l900003002o`X02Ol700Ko2007o``00_lD00Ko0P03o`<03?l300[o1P0:o`802Ol600Ko0P03o`<0
1Ol500?o0P0:o`D02_l400[o1@08oa@02_l600So4P0=o`<02_l300Wo1P0<o`l01_l300Ko4@02o`@0
0_l500Oo1P06o`<02ol500Co0P0:o`<01Ol500?o2@0000`00_l>00;o2@03o`800ol600;o1002o``0
0_lE00;o1004o`D00_l600;o0`03o`D00ol400Co1@02o`800ol400?o1P02o`@01?l500;o1@03o`<0
0ol500?o1@02o`D00_l800;o3002oa/00_l=00;o6002o`H00_l700;o1`03o`@00ol700;o1P02oa40
0_l700;o4P03o`@00ol600;o2`02o`L00_l400;o1@03o`D00_l400Co1002o`D00ol:00003002o`h0
0_l900;o1002o`D00_l600;o2`02oaD00_l400Co1@02o`H00_l300;o1`02o`@00_l700;o0P02o`H0
0_l600;o1004o`D00_l500;o1002o`L00_l500?o1002o`P00_l<00;o6`02o`d00_lH00;o1P02o`L0
0_l700;o1P02o`L00_l600;o4@02o`L00_lB00Co0`03o`H00_l;00;o1`02o`@00_l500;o1P02o`H0
0_l400;o1@02o`/0000<00;o3P02o`P00_l600;o1002o`H00_l;00;o5@02o`<01Ol500;o0P02o`80
0_l300;o1`02o`<00ol700;o0P02o`H00_l600;o0`05o`D00_l400;o1@02o`L00_l600?o0`02o`P0
0_l<00;o6`02o`d00_lH00;o1P02o`L00_l700;o1P02o`L00_l200;o0P02oa402olB00Co0P04o`H0
0_l200;o1`0;o`@00_l400;o1`02o`L00_l300;o1002o``0000<00;o3P02o`P00_l600;o1002o`H0
0_l;00;o5@02o`<00_l00`3oo`0500;o0P02o`l00ol300;o1007o`030?oo00H00_l600;o0`02o`03
0?oo00D00ol200?o3@03o`L00_l300;o2002o``00_lK00;o3@02oaP00_l600;o1`02o`L00_l600;o
1`02o`800_lF00Wo4`02o`040?l000Co1P02o`800_l800Wo1@02o`<00ol700;o1`02o`<00ol200?o
300000`00_l>00;o2002o`H00_l400;o1P02o`/00_lE00;o0P03o`030?oo00D01_l:00Oo1002o`@0
1ol900;o1P02o`800ol00`3oo`0500Oo2@07o`P00ol<00;o3002oa/00_l=00;o6002o`l00_l?00;o
1`06oaH00_l500;o4`02o`060?l00?l00_l600Ko2002o`D00_l500Oo2002o`L00_l300Oo3@0000`0
0_l>00;o2002o`H00_l400?o1002o``00_lE00;o0P02o`800_l500Ko2007o`H00_lD00;o1P02o`80
0_l200;o1@05o`T01ol;00?o2`02o``00_lK00;o3@02oaP00_l?00;o3`02o`L01_lG00;o0`02oa@0
0_l00`3oo`02o`030?oo00H01_l900;o0`02o`H02Ol600;o1`02o`<01Ol?00003@02o`d00_l800;o
1P02o`@02Ol;00;o5P02o`030?oo00<00_l500;o0P02o`L00ol;00;o5002o`H00_l00`3oo`0300;o
1@02o`040?ooo`L00ol<00;o0`02o`/00_l700;o0`02o`<00_lF00;o2002o`<00_l300;o4`02o`l0
0_l?00;o1`02o`800_lG00;o0`02oa@00_l00`3oo`02o`030?oo00H00_l200;o2@02o`<00_l600;o
1@03o`D00_l700;o0`02o`040?ooo`h0000=00;o3@02o`P00_l600;o1002o`030?oo00;o3@02oaH0
1Ol300;o1@02o`800_l200;o0`02o`L000?o00000P02o`P00_l:00;o1P05o`<00_l500;o0P03o`H0
0_l70003o`0000<00_l300?o2P02o`L00_l300;o0`02oaH00_l800;o0`02o`<00_lC00;o3`02o`l0
0_l700;o0P02o`800_lD00;o00@0oooo4`02o`<00_l300;o1@02o`800_l200;o1P02o`040?ooo`H0
0_l600;o1@02o`L00_l300;o0P03o`d0000=00?o3002o`P00_l600;o1@02oa400_lF00Co1002o`D0
0_l600;o0`02o`H00_l500;o1P03o`X00_l600Co1002o`D00_l300?o1@02o`H00_l500;o1003o`T0
0_l700;o0`02o`<00_lF00;o2002o`<00_l300;o4`02o`l00_l?00;o1`02o`H00_lD00;o00<0ool0
5002o`<00_l300;o1@02o`H00_l600;o00<0ool01`02o`H00_l500;o1P02o`@00_l300?o300000h0
0_l<00;o2@02o`@00_l600?o3`02oaL01?l400;o1@02o`H00_l300?o1003o`D00ol400Co2P02o`H0
1?l400;o1@02o`@00ol400?o1003o`D00_l500;o2@02o`L00_l300;o0`02oaH00_l800;o0`02o`<0
0_lC00;o3`02o`l00_l700;o1P02oa@01OlD00;o2002o`D00_l600;o1P05o`L00_l500?o1@02o`@0
1?l400;o1003o`/0000?00;o1`03o`030?oo00T00ol200?o1`03o`d00_lG00Co0P06o`803?l400Wo
1P0:o`D02_l200Co0P06o`801Ol300Go0`09o`D02_l400[o0`0<oa802_l400co4008o`P02_l600[o
0P0<oa401olD00Ko0P06o`803?l300Oo1P0;o`D02_l300Go0`05o`T0000@0003o`0000D01_l:00Ko
2@07o`P000?o00005P03o`<01_l200co1P05o`030?l000L01Ol00`3oo`0500[o0P03o`<01_l200Go
0`05o`D01Ol00`3o000400[o100:o`<03?lB00[o100<oa002?l800[o1P0:o`803?lA00Oo5006o`80
1_l200co0`07o`H02Ol700So1@05o`<01Ol900006`03o`/01?l<00Goo`2l0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(107\\) NESGJNKSZIU IT KIKE A WFASDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`X00_l?00;o5@06o`<00_l300co0`02o`03
0?oo00?o2P06o`H01_l700Ko0`02o`<01Ol600;o0P02o`030?oo00?o1`0:o`@02_l800Co5@0:o`H0
2?lB00Go1P02o`<02_l300Go1P02o`803?l?00Ko0`06oa400_l400;o1@07o`H01_l300Ko00@0ool0
1Ol700So1@0=o`T0000<00;o2P09o`L01_l900;o4002oa@01_l200?o0`0<o`<02_l600[o0P09o`H0
1_l200?o0`05o`D00ol200[o1@0:o`@02_l600So4`0:o`H02?lB00Go1@03o`<02_l300Go1@03o`80
3?l?00Ko0`06oa400_l400;o1@07o`H01_l300Ko00<0ool02?l500[o0`0=o`T0000<00;o3P02o`T0
0ol200?o2@02o`l00_lE00;o1004o`D00_l600;o0`03o`D00ol400Co1@02o`800ol400?o1P02o`@0
1?l500;o1@03o`<00ol500?o1@02o`D00_l800;o2P02o`@00_lG00;o3@02oaL00_l500?o2002o`T0
0_l500?o1@02o`H00_lA00;o1`02oa800ol400?o1P02o`/00_l700;o0`03o`D00ol500;o1004o`D0
0_l600;o2@0000`00_l>00;o2@02o`@00_l900;o3`02oaD00_l400Co1@02o`H00_l300;o1`02o`@0
0_l700;o0P02o`H00_l600;o1004o`D00_l500;o1002o`L00_l500?o1002o`P00_l900;o1P02oaH0
0_l=00;o5`02o`D00_l900;o2@02o`D00_l600;o1P02oa400_l700;o4P04o`<00ol600;o2`02o`L0
0_l300;o1`02o`D00_l600;o1@02o`H00_l900003002o`h00_l800;o1P02o`P00_l?00;o5@02o`<0
1Ol500;o0P02o`800_l300;o1`02o`<00ol700;o0P02o`H00_l600;o0`05o`D00_l400;o1@02o`L0
0_l600?o0`02o`P00_l900;o1P02oaH00_l=00;o5`02o`@00_l:00;o2@02o`@00_l700;o0P02o`80
0_lA00_o4P04o`801?l600;o0P02o`L02ol300;o1`02o`D00_l700;o1002o`H00_l900003002o`h0
0_l800;o1P02o`T000?o00003@02oaD00_l300;o00<0ool01@02o`800_l?00?o0`02o`@01ol00`3o
o`0600;o1P02o`<00_l00`3oo`0500?o0P03o`d00ol700;o0`02o`P00_l900;o1P02oaH00_l=00;o
5`03o`800ol:00;o2@03o`800ol700;o0P02oaH02OlC00;o00@0o`001?l600;o0P02o`P02Ol<00?o
1@02o`L00_l400;o1P02o`T0000<00;o3P02o`P00_l600;o2@02o`h00_lE00;o0P03o`030?oo00D0
1_l:00Oo1002o`@01ol900;o1P02o`800ol00`3oo`0500Oo2@07o`P00ol<00;o2@02o`H00_lF00;o
3@02oaL01ol;00;o2@07o`P01_lF00;o1@02oa<00_l01P3o003o00;o1P06o`P00_l500;o1`07o`H0
0_l700;o1002oa40000<00;o3P02o`P00_l600;o2@02o`h00_lE00;o0P02o`800_l500Ko2007o`H0
0_lD00;o1P02o`800_l200;o1@05o`T01ol;00?o2`02o`T00_l600;o5P02o`d00_lG00Go3@02o`T0
1Ol:00Ko5`02o`<00_lD00;o00<0ool00_l00`3oo`0600Ko2@02o`<00_l600Oo2002o`L00_l400;o
4@0000d00_l=00;o2002o`H00_l:0003o`0000/00_lF00;o00<0ool00`02o`D00_l200;o1`03o`/0
0_lD00;o1P02o`030?oo00<00_l500;o00@0oooo1`03o``00_l300;o2`02o`T00_l600;o5P02o`P0
0_l300;o0`02oa800_l0103oool<00;o2@02o`040?ooo`T00_l200;o5`02o`<00_lD00;o00<0ool0
0_l00`3oo`0600;o0P02o`T00_l300;o1@03o`d00_l700;o1002oa40000=00;o3@02o`P00_l600;o
2P02o``00_lF00Go0`02o`D00_l200;o0P02o`<00_l70003o`0000800_l800;o2P02o`H01Ol300;o
1@02o`800ol600;o1`000ol0000300;o0`03o`X00_l900;o1P02oaH00_l800;o0`02o`<00_lB00;o
0P03o`/00_l900;o0P03o`P00_l200;o0P02oa@00_l0103ooolC00;o0`02o`<00_l500;o0P02o`80
0_l600;o00@0oooo1@02o`L000?o00001002o`L00_l400;o4@0000d00ol<00;o2002o`H00_l:00;o
3002oaH01?l400;o1@02o`H00_l300;o1P02o`D00_l600?o2P02o`H01?l400;o1@02o`<00ol500;o
1P02o`D00_l400?o2@02o`T00_l600;o5P02o`P00_l300;o0`02oa800_l300?o2P02o`T00_l300?o
1`02o`H00_lD00;o00<0ool05002o`<00_l300;o1@02o`H00_l600;o00<0ool01P02o`H00_l600;o
1P02o`D00_lA00003P02o``00_l900;o1002o``000?o00002@02oaL01?l400;o1@02o`H00_l300?o
1003o`D00ol400Co2P02o`H01?l400;o1@02o`@00ol400?o1003o`D00_l500;o2@02o`T00_l600;o
5P02o`P00_l300;o0`02oa800_l400?o2@02o`T00_l400?o1P02o`H00_lD00Go5002o`P00_l500;o
1P02o`H01Ol600?o1003o`H00_l400Co1@02oa40000?00;o1`03o`030?oo00T00ol200?o1@02o`D0
0_l900;o5`04o`801_l200co1009o`H02_l500[o0P04o`801_l200Go0`05o`<02Ol500[o100:o`@0
1?l400Co4@0:o`@03?l@00Go0`05o`<02_l300Go0`05o`803?lA00Oo5006o`801_l200co0`07o`P0
2Ol500[o0`08o`h0000@0003o`0000D01_l:00Ko1P09o`T000?o00005P03o`<01_l200co1P05o`03
0?l000L01Ol00`3oo`0500[o0P03o`<01_l200Go0`05o`D01Ol00`3o000400[o100:o`@01?l400Co
4@0:o`@03?l@00Go0`05o`<02_l300Go0`05o`803?lA00Oo5006o`801_l200co0`07o`X01Ol00`3o
000400So1@08o`h0000K00?o2`04o`L02Ooo0;d0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(108\\) NESGJNKSZJT IT LIKE AZWEBTDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`X01?l=00;o5@06o`<00_l300co0`02o`03
0?oo00?o2P06o`H01_l700Ko0`02o`<01Ol600;o0P02o`030?oo00?o1`0:o`D01_l800So500:o`H0
2?lB00go0`0:o`<01Ol600;o0P0<o`l01_l300Ko0P0:o`D00_l400;o1@0<o`802_l600So1P08o`D0
3Ol900003002o`X02Ol700Ko1`08o``00_lD00Ko0P03o`<03?l300[o1P0:o`802Ol600Ko0P03o`<0
1Ol500?o0P0:o`D02_l300Wo1`08oa@02_l600So4P0=o`<02_l300Go1@03o`803?l?00Ko0`06o`80
2_l500;o1002o`D03?l200_o1@08o`H02_l300go2@0000`00_l>00;o2@03o`800ol500?o1003o`/0
0_lE00;o1004o`D00_l600;o0`03o`D00ol400Co1@02o`800ol400?o1P02o`@01?l500;o1@03o`<0
0ol500?o1@02o`D00_l300?o1003o`T00_lK00;o3@02oaP00_l600;o1`02o`T00_l500?o1@02o`H0
0_lA00;o1`02o`D00_l500;o1003o`@00ol600;o1P02o`@00_l500?o1`02o`X00_l400Co1@02o`H0
0_l900003002o`h00_l900;o1002o`D00_l600;o2`02oaD00_l400Co1@02o`H00_l300;o1`02o`@0
0_l700;o0P02o`H00_l600;o1004o`D00_l500;o1002o`L00_l500?o1002o`<00_l600;o2@02oa/0
0_l=00;o6002o`H00_l700;o2@02o`D00_l600;o1P02oa400_l700;o1@03o`@00_l400Co0`03o`H0
0_l600;o1002o`H00_l700;o2P02o`H00_l500;o1P02o`T0000<00;o3P02o`P00_l600;o1002o`H0
0_l;00;o5@02o`<01Ol500;o0P02o`800_l300;o1`02o`<00ol700;o0P02o`H00_l600;o0`05o`D0
0_l400;o1@02o`L00_l600?o0`02o`<00_l600;o2@02oa/00_l=00;o6002o`H00_l700;o2@02o`@0
0_l700;o0P02o`800_lA00_o1P03o`<00_l400Co0P04o`H00_l200;o0P02o`@00_l600;o1`02o`X0
0_l700;o1002o`H00_l900003002o`h00_l800;o1P02o`@00_l600;o2`02oaD00_l300;o00<0ool0
1@02o`800_l?00?o0`02o`@01ol00`3oo`0600;o1P02o`<00_l00`3oo`0500?o0P03o`d00ol700;o
0`02o`<00_l600;o2@02oa/00_l=00;o6002o`H00_l700;o2@03o`800ol700;o0P02oaH02Ol800;o
0`02o`@00_l0103o0004o`H00_l200;o2002o`H00_l700;o2P02o`L00_l400;o1P02o`T0000<00;o
3P02o`P00_l600;o1@02o`@00_l<00;o5@02o`800ol00`3oo`0500Ko2P07o`@00_l400Oo2@02o`H0
0_l200?o00<0ool01@07o`T01ol800?o3`02o`T00_lK00;o3@02oaP00_l?00;o2@07o`P01_lF00;o
1@02o`P00ol800;o00H0o`00o`02o`H01_l800;o1@03o`L00_l:00;o1`02o`@00_lA00003002o`h0
0_l800;o1P02o`H01ol<00;o5@02o`800_l200;o1@06o`P01ol600;o5002o`H00_l200;o0P02o`D0
1Ol900Oo2`03o`h00_l900;o6`02o`d00_lH00;o3`02o`T01Ol:00Ko5`02o`<00_l:00?o1`02o`03
0?oo00;o00<0ool01P06o`P02Ol800;o2P02o`L00_l400;o4@0000d00_l=00;o2002o`H00_l600Ko
3002oaH00_l00`3oo`0300;o1@02o`800_l700?o2`02oa@00_l600;o00<0ool00`02o`D00_l0103o
ool700?o3002o`<00_l>00;o1002o`<00_l300;o5P02o`P00_l300;o0`02oa<00_l?00;o2@02o`04
0?ooo`T00_l200;o5`02o`<00_l600;o0`02o`L00_l00`3oo`02o`030?oo00H00_l200;o2008o`@0
0_l300;o0`02o`D00_l700;o1002oa40000=00;o3@02o`P00_l600;o1@02o`@00_l;00;o5P05o`<0
0_l500;o0P02o`800_l300;o1`000ol0000200;o2002o`X00_l600Go0`02o`D00_l200?o1P02o`L0
00?o00000`02o`<00ol=00;o1002o`<00_l300;o5P02o`P00_l300;o0`02oa<00_l?00;o2@02o`80
0ol800;o0P02o`800_lD00;o00@0oooo1P02o`<00ol500;o0`02o`<00_l500;o0P02o`800_l400;o
1003o`<00_l300;o0`02o`D00_l700;o1002oa40000=00?o3002o`P00_l600;o1002o`H00_l:00;o
5P04o`@00_l500;o1P02o`<00_l600;o1@02o`H00ol:00;o1P04o`@00_l500;o0`03o`D00_l600;o
1@02o`@00ol<00;o1002o`<00_l300;o5P02o`P00_l300;o0`02oa<00_l?00;o2@02o`<00ol700;o
1P02oa@00_l00`3oo`0700;o1003o`@00_l300;o0`02o`D00_l600;o1002o`D00_l300;o0`02o`<0
0_l500;o1P02o`D00_lA00003P02o``00_l900;o1002o`D00_l600;o2@02oaL01?l400;o1@02o`H0
0_l300?o1003o`D00ol400Co2P02o`H01?l400;o1@02o`@00ol400?o1003o`D00_l500;o3002o`@0
0_l300;o0`02oaH00_l800;o0`02o`<00_lC00;o3`02o`T00_l400?o1P02o`H00_lD00Go1`02o`D0
0_l400;o2002o`D00_l600;o1002o`@00ol300;o0`02o`<00_l500;o1004o`D00_lA00003`02o`L0
0ol00`3oo`0900?o0P03o`D00ol400?o2002oaL01?l200Ko0P0<o`@02Ol600[o1@0:o`801?l200Ko
0P05o`<01Ol300Wo1@0:o`H02_l00`3oo`0:oa802_l400co4008o`P02_l300Go0`05o`803?lA00Oo
200:o`801_l200Ko0P0<o`802_l400co100:o`<02?l>000040000ol0000500Ko2P06o`L02?l90003
o`0001H00ol300Ko0P0<o`H01Ol00`3o000700Go00<0ool01@0:o`800ol300Ko0P05o`<01Ol500Go
00<0o`00100:o`H02_l00`3oo`0:oa802_l400co4008o`P02_l300Go0`05o`803?lA00Oo200:o`80
1_l200Ko0P0<o`802Ol500co1008o`D02?l>00006`03o`/01?l900Koo`2n0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(109\\) NDTGJNJS ITZIT LIKE AZWEBTDL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`L01Ol?00;o5@06o`<00_l400So1`08o`T0
1_l600Ko1`06o`<00_l500Ko1`02o`030?oo00?o5@0:o`D02?l600[o100:o`H02?lB00go0`0:o`<0
1Ol600;o0P0<o`l01_l300Ko0P0:o`D00_l400;o1@0<o`802_l600So1P08o`D03Ol900003002o`X0
2Ol700Ko1P07o`h00_lD00Ko0P03o`@02_l500So1`0:o`802Ol600Ko0P03o`<02Ol600[o4`0:o`D0
2?l600[o100:o`H02?lB00go0`0:o`<01Ol500?o0P0<o`l01_l300Ko0P0:o`D00_l400;o1@0<o`80
2ol500So1P0:o`<03Ol900003002o`h00_l900?o0P03o`X00ol=00;o5@02o`@01?l500;o1004o`L0
0_l900Co1@02o`800ol400?o1P02o`@01?l300?o1003o`D00ol500?o5P02o``00_l:00;o1@02o`P0
0_l=00;o6002o`H00_l700;o2@02o`D00ol500;o1P02oa400_l700;o1@02o`D00_l400?o1003o`H0
0_l600;o1002o`D00ol700;o2P02o`@01?l500;o1P02o`T0000<00;o3P02o`T00_l400;o2`03o``0
0_lE00;o1004o`D00_l600;o1`02o`T00_l700;o0P02o`H00_l600;o1004o`<00_l600;o1@02o`L0
0_lF00;o3002o`X00ol400;o2002o`d00_lH00;o1P02o`L00_l900;o1@02o`H00_l600;o4@02o`L0
0_l500?o1002o`@01?l300?o1P02o`H00_l400;o1P02o`L00_l:00;o1P02o`D00_l600;o2@0000`0
0_l>00;o2002o`H00_l;00;o3002oaD00_l300Go1@02o`L00_l600;o2003o`L00_l200;o1P02o`H0
0_l300Go0`02o`H00_l500;o1`02oaH00_l<00;o2`03o`<00_l800;o3@02oaP00_l600;o1`02o`T0
0_l400;o1`02o`800_l200;o4@0;o`H00ol300;o1004o`801?l600;o0P02o`800_l400;o1P02o`L0
0_l:00;o1`02o`@00_l600;o2@0000`00_l>00;o2002o`H00_l700Co00<0ool02`02oaD00_l300;o
00<0ool01@02o`L00_l600;o2002o`@01ol00`3oo`0600;o1P02o`<00_l00`3oo`0300;o1P02o`d0
0olF00;o3002o``00_l300;o2002o`d00_lH00;o1P02o`L00_l900?o0P03o`L00_l200;o5P09o`P0
0_l300;o1002o`040?l000Co1P02o`800_l800;o1P02o`L00_l:00;o1`02o`@00_l600;o2@0000`0
0_l>00;o2002o`H00_l500Wo2`02oaD00_l200?o00<0ool01@02o`L00_l600;o2002o`@01ol900;o
1P02o`800ol00`3oo`0;00;o2007oaL00_l<00;o3003o``00_l=00;o6002o`l00_l900Oo2006oaH0
0_l500;o2003o`P00_l01P3o003o00;o1P06o`P00_l500?o1`02o`X00_l700;o1002oa40000<00;o
3P02o`P00_l600;o1@02o`@00ol;00;o5@02o`800_l200;o1@02o`L00_l600;o2002oa@00_l600;o
0P02o`800_l;00;o1P07oaT00_l<00;o3@03o`/00_l=00;o6002o`l00_l900Go2P06oaL00_l300;o
2P03o`L00_l00`3oo`02o`030?oo00H01_l800Wo2002o`X00_l700;o1002oa40000=00;o3@02o`P0
0_l600;o1002o`H00_l:00;o5P02o`030?oo00<00_l500;o1`02o`030?oo00<00_l300;o0`02oa@0
0_l600;o00<0ool00`02o`/00_l500?o7P02o`L00_l300;o0`02o`@00_l300;o2`02o`P00_l300;o
0`02oa<00_l?00;o2@02o`040?ooo`T00_l200;o5`02o`<00_l600;o0`02o`L00_l00`3oo`02o`03
0?oo00H00_l200;o2008o`@00_l300;o0`02o`D00_l700;o1002oa40000=00;o3@02o`P00_l600;o
1002o`H00_l:00;o5P05o`<00_l500;o1`02o`030?oo00<00_l300;o0`02o`P00_l:00;o1P05o`<0
0_l;00;o1@02o`L000?o00005@02o`L00_l300;o0`02o`@00_l300?o2P02o`P00_l300;o0`02oa<0
0_l?00;o2@02o`800ol800;o0P02o`800_lD00;o00@0oooo1P02o`<00ol500;o0`02o`<00_l500;o
0P02o`800_l400;o1003o`<00_l300;o0`02o`D00_l700;o1002oa40000=00?o3002o`P00_l600;o
1002o`H00_l:00;o5P04o`@00_l500;o1P02o`800_l300;o0`02o`@00_l600?o2P02o`H01?l400;o
2`02o`D00_l600;o5`02o`L00_l300;o0`02o`@00_l400?o2@02o`P00_l300;o0`02oa<00_l?00;o
2@02o`<00ol700;o1P02oa@00_l00`3oo`0700;o1003o`@00_l300;o0`02o`D00_l600;o1002o`D0
0_l300;o0`02o`<00_l500;o1P02o`D00_lA00003P02o``00_l900;o1002o`D00_l60003o`0000P0
0_lG00Co1002o`D00_l400Co0P02o`<00_l300;o1003o`@01?l:00;o1P04o`@00_l;00;o1@03o`@0
0olG00;o1`02o`<00_l300;o1002o`D00_l900;o2002o`<00_l300;o4`02o`l00_l900;o1003o`H0
0_l600;o5005o`L00_l500;o1002o`P00_l500;o1P02o`@00_l400?o0`02o`<00_l300;o1@02o`@0
1?l500;o4@0000l00_l700?o00<0ool02@03o`800ol600;o1002o`T00_lG00Co0P06o`<02_l300co
1@0:o`D02_l200Co0P06o`D02_l300Wo4`0:o`<03?l400[o100:o`@03?l@00So200:o`<01Ol300Go
0P0<oa401ol800[o0P06o`801_l200co0P0:o`@03?l400[o0`08o`h0000@0003o`0000D01_l:00Ko
1`07o`X000?o00005P03o`<01_l300So1@0<o`L01Ol00`3oo`0500[o0P03o`<01_l500[o1@05o`03
0?l001802_l300co100:o`@02_l400co4008o`P02_l300Go0`05o`803?lA00Oo200:o`801_l200Ko
0P0<o`802Ol500co1008o`D02?l>00006`03o`/01?l:00Coo`2o0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(110\\) METGJNJT IS IT LIKEZA WEBTEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo1P09o`L01?l=00;o5005o`<01Ol200co1008o`T0
1_l600Ko1`06o`<00_l500Ko2008oa@02_l400;o00<0ool00olE00[o1P08oa803Ol300[o0`05o`H0
0_l200co0`0:o`801_l300Ko4@02o`@00_l500co0P0:o`H02?l500co0P0=o`T0000<00;o2P09o`H0
2Ol600Ko3@02oa<01Ol300Go0P0<o`@02?l700[o0P09o`H01_l200?o0`09o`L02?lD00[o100:oa<0
2_l600So4P0=o`<02_l300Go1@03o`803?l300[o0P06o`<01_lA00;o1002o`D03?l200_o1@08o`D0
3?l200go2@0000`00_l>00;o3@02o`P00ol200?o3002oa@00_l700;o1@02o`H00_l700;o2@04o`D0
0_l200?o1003o`H00_l400Co0`03o`@00ol900;o6`02o`P00ol500?o5P02o`d00_lH00;o1P02o`L0
0_l900;o1@03o`D00_l600;o1002o`D00_l400;o1`02oa800ol400?o1P02o`H00_l400;o1@03o`L0
0_l:00;o1P02o`D00_l600;o2@0000`00_l>00;o3@02o`P00_l400;o3002oa@00_l700;o1@02o`H0
0_l700;o2@02o`L00_l200;o1P02o`H00_l400Co0`02o`H00_l900;o6`02o`P00_l700;o5P02o`d0
0_lH00;o1P02o`L00_l900;o1@02o`H00_l600;o1003o`@00_l400;o1`02oa801?l300?o1P02o`H0
0_l400;o1P02o`L00_l:00;o1P02o`D00_l600;o2@0000`00_l>00;o3@02o`L00_l600;o2`02oa@0
0_l300;o0P02o`D00_l200;o0P02o`L00_l800?o1`02o`800_l600;o1P02o`<01Ol300;o1P02o`T0
0_lK00;o2002o`L00_lF00;o3@02oaP00_l600;o1`02o`T00_l400;o1`02o`800_l200;o1@03o`<0
0_l400_o4P04o`801?l600;o0P02o`800_l400;o1P02o`L00_l:00;o0P02o`800_l500;o1P02o`T0
000<00;o3P02o`d00_l700;o1P02o`/00_lD00;o0P03o`800_l500;o0P02o`/00_l800;o1007o`03
0?oo00H00_l600;o0`02o`030?oo00<00_l600;o2@02oa/00_l@00?o5P02o`d00_lH00;o1P02o`L0
0_l900?o0P03o`L00_l200;o2P02o`<00_l500Wo4`02o`040?l000Co1P02o`800_l800;o1P02o`L0
0_l:00;o0P02o`T00_l600;o2@0000`00_l>00;o3@02o`L00_l600;o2`02oa@00_l20003o`3o0080
0_l500Ko2`02o`P00_l400Oo2@02o`H00_l200?o00<0ool02`02o`T00_lK00;o2`07oaL00_l=00;o
6002o`l00_l900Oo2006o`X00ol900;o1@02oa<00_l01P3o003o00;o1P06o`P00_l500?o1`02o`X0
1_l900;o4@0000`00_l>00;o3@02o`L00_l600;o2`02oa@00_l0103oo`02o`030?oo00D01_l;00;o
2002oa@00_l600;o0P02o`800_l;00;o2@02oa/00_l900Oo6@02o`d00_lH00;o3`02o`T01Ol:00Ko
2`03o`T00_l300;o5002o`030?oo00;o00<0ool01P06o`P02Ol800;o2P06o`T00_lA00003@02o`d0
0_l=00;o1`02o`H00_l:00;o5@02o`030?oo008000Co0?oo1@02o`800_l600;o0`02o`<00_l300;o
5002o`H00_l00`3oo`0300;o2`02o`@00_l300;o0`02oaH00_l800?o7P02o`P00_l300;o0`02oa<0
0_l?00;o2@02o`040?ooo`T00_l200;o1`02o`<00_l900;o0`02oa@00_l00`3oo`02o`030?oo00H0
0_l200;o2008o`@00_l300;o0`02o`D00_l200;o2@02oa40000=00;o3@02o`d00_l700;o1P02o`X0
0_lE00;o00<0o`000P001?l0ool500;o0P02o`800_l200;o0`02o`<00_l300;o2002o`X00_l600Go
0`02o`/00_l400;o0`02o`<00_lF00;o2002o`L000?o00005@02o`P00_l300;o0`02oa<00_l?00;o
2@02o`800ol800;o0P02o`800_l300;o0`03o`T00_l0103ooolC00;o0`02o`<00_l500;o0P02o`80
0_l400;o1003o`<00_l300;o0`02o`D00_l200;o0P02o`D00_lA00003@03o``00_l=00;o1`02o`H0
0_l:00;o5@04o`<01?l500;o1P02o`800_l300;o0`02o`@00_l600?o2P02o`H01?l400;o2`02o`@0
0_l300;o0`02oaH00_l800;o1P02oaL00_l800;o0`02o`<00_lC00;o3`02o`T00_l300?o1`02o`H0
0_l300;o1003o`P00_l00`3oo`0D00;o0`02o`<00_l500;o1P02o`@00_l500;o0`02o`<00_l300;o
1@02o`H00_l500;o4@0000h00_l<00;o3@02o`P00_l400;o2P02oaH01?l400?o1@02o`H00_l200;o
0`02o`<00_l400?o1004o`X00_l600Co1002o`/00_l400;o0`02o`<00_lF00;o2003o`@00olG00;o
2002o`<00_l300;o4`02o`l00_l900;o1003o`H00_l600;o0`02o`D00_l800Go5002o`P00_l500;o
1P02o`@00_l400?o0`02o`<00_l300;o1@02o`H00_l500;o4@0000l00_l700?o00<0ool02@03o`03
0?oo00P00ol200?o2@02oaH01?l500Co0P0<o`803?l500[o1@0:o`801?l200Ko1@0:o`030?oo00[o
4P0:o`D02OlC00[o100<oa002?l800[o0`05o`<01Ol200co0`0:o`@01olD00Ko0P06o`803?l200[o
100<o`<03?l200So3P00010000?o00001@06o`T01_l900Ko2P000ol0000E00Co1@04o`803?l200co
1`05o`030?oo00D02_l200?o0`06o`D02_l00`3oo`0:oa802_l700Go00<0o`004P0:o`@03?l@00So
200:o`<01Ol300Go0P0<o`<02_l400Oo5006o`801_l200co0P09o`D03?l300co0P08o`h0000K00?o
3003o`X01?oo0;l0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(111\\) METGINJT IS IT LIJE A WFBTEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo1P09o`D02Ol:00;o5005o`<01Ol200co1008o`T0
1_l500[o1006o`<00_l500Ko2008oa@02_l400;o00<0ool00olE00[o1P08oa803Ol300[o1@06o`L0
3?l?00Ko0`06oa400_l400;o1@07o`L02_l600So1@0<o`803Ol900003002o`X02Ol600Wo1@09o`/0
0_lC00Go0`05o`803?l400So1`0:o`<02_l400Ko0P03o`<02Ol700So500:o`@02_lC00[o1P08oa80
3Ol300[o0`09o`H03?l?00Ko0`06oa400_l400;o1@07o`L02ol500So1@0<o`803Ol900003002o`h0
0_l=00;o3002o`h00_lD00;o1`02o`D00_l600;o1`02o`T01?l500;o1`02o`T00_l400Co0`03o`@0
0ol900;o6`02o`P00ol500?o5P02o`d00_lH00;o1P02o`L00_l700?o1003o`L00_l600;o4@02o`L0
0_lB00?o1003o`H00_l<00;o1@03o`L00_l:00;o1P02o`D00_l600;o2@0000`00_l>00;o3@02o``0
0_l>00;o5002o`L00_l500;o1P02o`L00_l900;o1`02o`L00_l900;o1004o`<00_l600;o2@02oa/0
0_l800;o1`02oaH00_l=00;o6002o`H00_l700;o1`02o`H00_l700;o1P02oa400_l700;o4P04o`<0
0ol600;o3002o`H00_l700;o2P02o`H00_l500;o1P02o`T0000<00;o3P02o`d00_l<00;o3P02oa@0
0_l300;o0P02o`D00_l200;o0P02o`L00_l800?o1`02o`L00_l900;o0`05o`<00_l600;o2@02oa/0
0_l800;o1`02oaH00_l=00;o6002o`H00_l700;o1`02o`H00_l700;o0P02o`800_lA00_o4P04o`80
1?l600;o0P02o`P00_l600;o1`02o`X00_l200;o0P02o`D00_l600;o2@0000`00_l>00;o3@02o``0
0_l>00;o5002o`800ol200;o1@02o`800_l;00;o2002o`@01ol600;o2@02o`<00_l00`3oo`0300;o
1P02o`T00_lK00;o4003oaH00_l=00;o6002o`H00_l700;o1`02o`H00_l700;o0P02oaH02OlC00;o
00@0o`001?l600;o0P02o`P00_l600;o1`02o`X00_l200;o2@02o`H00_l900003002o`h00_l=00;o
3002o`h00_lD00;o0P000ol0o`0200;o1@06o`/00_l800;o1007o`H00_l900;o0P03o`030?oo00/0
0_l900;o6`02o`/01olG00;o3@02oaP00_l?00;o3`02o`L01_lF00;o1@02oa<00_l01P3o003o00;o
1P06o`P00_l500?o1`02o`X01_l900;o4@0000`00_l>00;o3@02o``00_l>00;o5002o`040?oo00;o
00<0ool01@06o`/00_l800;o4@02o`T00_l200;o0P02o`/00_l900;o6`02o`T01olI00;o3@02oaP0
0_l?00;o3`02o`L01_lG00;o0`02oa@00_l00`3oo`02o`030?oo00H01_l800Wo2002o`X01_l900;o
4@0000d00_l=00;o3@02o``00_l=00;o5@02o`030?oo008000Co0?oo1@02o`800_l600;o0`02o`<0
0_l300;o4@02o`T00_l00`3oo`0300;o2`02o`@00_l300;o0`02oaH00_l800?o7P02o`P00_l300;o
0`02oa<00_l?00;o3`02o`L00_l200;o5`02o`<00_lD00;o00<0ool00_l00`3oo`0600;o0P02o`P0
2?l400;o0`02o`<00_l500;o0P02o`T00_lA00003@02o`d00_l=00;o3002o`d00_lE00;o00<0o`00
0P001?l0ool500;o0P02o`800_l200;o0`02o`<00_l300;o2002o`L00_l900Go0`02o`/00_l400;o
0`02o`<00_lF00;o2002o`L000?o00005@02o`P00_l300;o0`02oa<00_l?00;o3`02o`L00_l200;o
0P02oa@00_l0103ooolC00;o0`02o`<00_l500;o0P02o`800_l400;o1003o`<00_l300;o0`02o`D0
0_l200;o0P02o`D00_lA00003@03o``00_l=00;o3002o`d00_lE00Co0`04o`D00_l600;o0P02o`<0
0_l300;o1002o`H00ol700;o2@04o`@00_l;00;o1002o`<00_l300;o5P02o`P00_l600;o5`02o`P0
0_l300;o0`02oa<00_l?00;o3`02o`L00_l600;o5002o`030?oo01@00_l300;o0`02o`D00_l600;o
1002o`D00_l300;o0`02o`<00_l500;o1P02o`D00_lA00003P02o``00_l=00;o3002o``00_lF00Co
1003o`D00_l600;o0P02o`<00_l300;o1003o`@01?l700;o2@04o`@00_l;00;o1002o`<00_l300;o
5P02o`P00ol400?o5`02o`P00_l300;o0`02oa<00_l?00;o3`02o`L00_l600;o5005oa@00_l800;o
1@02o`H00_l400;o1003o`<00_l300;o0`02o`D00_l600;o1@02oa40000?00;o1`03o`030?oo00T0
0ol00`3oo`0800?o00<0ool02`02oaH01?l500Co0P0<o`803?l500[o0`0:o`@01?l200Ko1@0:o`03
0?oo00[o4P0:o`D02OlC00[o100<oa002?l800[o1P0:o`803?lA00Oo5006o`801_l200co0P0:o`@0
3?l300co0P08o`h0000@0003o`0000D01_l900Ko2006o`/000?o00005@04o`D01?l200co0P0<o`L0
1Ol00`3oo`0300[o1003o`<01_l500[o00<0ool02_lB00[o1`05o`030?l001802_l400co4008o`P0
2_l600[o0P0<oa401olD00Ko0P06o`803?l200Wo1@0<o`<03?l200So3P0001/00ol<00?o2`03ool0
_`000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(112\\) METGINJT ISZIS LIKE A VFBTEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo1P09o`@02_l:00;o5005o`<01Ol200co1008o`T0
1_l500[o1006o`<00_l500Ko2008oa@02_l400;o00<0ool00ol700[o100:o`D00_l00`3oo`03oa<0
3Ol300[o0`05o`H00_l200co3`06o`<01_lD00;o2007o`L02_l600So1@0<o`803Ol900003002o`X0
2Ol600Wo100:o`/00_lC00Go0`05o`803?l400So1`0:o`<02_l400Ko0P03o`<02Ol700So500:o`@0
2_l500[o100:o`D02_lA00go0`0:o`<01Ol500?o0P0<o`l01_l300Ko4`04o`L01ol700_o1@08o`D0
3?l200go2@0000`00_l>00;o3@02o`P00_l500;o2`02oa@00_l700;o1@02o`H00_l700;o2@04o`D0
0_l700;o2@02o`@01?l300?o1003o`T00_lK00;o2003o`D00ol500;o1@02o`P00_l900?o1@03oa<0
0_l600;o1`02o`T00_l500?o1@02o`H00_lA00;o1`02oaD01?l900;o3002o`D00ol700;o2P02o`H0
0_l500;o1P02o`T0000<00;o3P02o`d00_l900?o4002oa@00_l700;o1@02o`H00_l700;o2@02o`L0
0_l700;o2@02o`@01?l300;o1P02o`T00_lK00;o2002o`L00_l500?o1002o`P00_l900;o1`02oa<0
0_l600;o1`02o`T00_l500;o1P02o`H00_lA00;o1`02oaD01?l900;o3002o`H00_l700;o2P02o`H0
0_l500;o1P02o`T0000<00;o3P02o`d00_l:00?o3`02oa@00_l300;o0P02o`D00_l200;o0P02o`L0
0_l800?o1`02o`L00_l900;o0`05o`<00_l600;o2@02oa/00_l800;o1`02o`H00ol300;o2002o`T0
0_l700;o4`02o`H00_l700;o2@02o`@00_l700;o0P02o`800_lA00_o5002o`800_l800;o0P02o`P0
0_l600;o1`02o`X00_l200;o0P02o`D00_l600;o2@0000`00_l>00;o3@02o`/00ol>00;o5002o`80
0ol200;o1@02o`800_l;00;o2002o`@01ol600;o2@02o`<00_l00`3oo`0300;o1P02o`T00_lK00;o
4003o`L00_l300;o2002oa400olC00;o1P02o`L00_l900?o0P03o`L00_l200;o5P09oaD00_l200;o
2002o`800_l800;o1P02o`L00_l:00;o0P02o`T00_l600;o2@0000`00_l>00;o3@02o``00ol=00;o
5002o`8000?o0?l00P02o`D01_l;00;o2002o`@01ol600;o2@02o`800ol00`3oo`0;00;o2@02oa/0
0_l;00Oo2003o``00_l<00Oo5002o`l00_l900Oo2006oaH00_l500;o5003o`800ol700Ko2002o`D0
0ol700;o2P06o`T00_lA00003002o`h00_l=00;o3@03o``00_lD00;o00@0ool00_l00`3oo`0500Ko
2`02o`P00_lA00;o2@02o`800_l200;o2`02o`T00_lK00;o2@07o`/00ol;00;o2P07oaH00_l?00;o
2@05o`X01_lG00;o0`02oaD00_l400;o1`06o`P02Ol800;o2P06o`T00_lA00003@02o`d00_l=00;o
3P02o`/00_lE00;o00<0ool00P001?l0ool500;o0P02o`H00_l300;o0`02o`<00_lA00;o2@02o`03
0?oo00<00_l;00;o1002o`<00_l300;o5P02o`P00ol<00;o0`02o`/00_l900?o6`02o`l00_l900;o
00@0oooo2@02o`800_lG00;o0`02oaD00_l400;o1`02o`800_l800So1002o`<00_l300;o1@02o`80
0_l900;o4@0000d00_l=00;o3@02o`l00_l:00;o5@02o`030?l0008000Co0?oo1@02o`800_l200;o
0P02o`<00_l300;o0`02o`P00_l700;o2@05o`<00_l;00;o1002o`<00_l300;o5P02o`P00_l70003
o`0000<00_l300?o2P02o`T00_l70003o`0001800_l?00;o2@02o`800ol800;o0P02o`800_lD00;o
00@0oooo5002o`H00_l600;o0P02o`800_l400;o1003o`<00_l300;o0`02o`D00_l200;o0P02o`D0
0_lA00003@03o``00_l=00;o3`02o`X00_lE00Co0`04o`D00_l600;o0P02o`<00_l300;o1002o`H0
0ol700;o2@04o`@00_l;00;o1002o`<00_l300;o5P02o`P00_l600;o1@02o`@00ol900;o2@02o`H0
0_lD00;o3`02o`T00_l300?o1`02o`H00_lD00;o00<0ool05@02o`H00_l600;o1P02o`@00_l500;o
0`02o`<00_l300;o1@02o`H00_l500;o4@0000h00_l<00;o3@02o`P00_l500;o2@02oaH01?l400?o
1@02o`H00_l200;o0`02o`<00_l400?o1004o`L00_l900Co1002o`/00_l400;o0`02o`<00_lF00;o
2003o`@00ol500;o1@02o`T00_l900?o1003oa@00_l?00;o2@02o`@00ol600;o1P02oa@01OlD00?o
1P03o`D00_l600;o1002o`@00ol300;o0`02o`<00_l500;o1P02o`D00_lA00003`02o`L00ol00`3o
o`0900?o00<0ool02003o`<00ol800;o5P04o`D01?l200co0P0<o`D02_l300[o1004o`801_l500[o
00<0ool02_lB00[o1@09o`D02_l400[o1P09oa402?l800[o0`05o`<01Ol200co4@07oa@01_l200Ko
0P0<o`802_l400co0`0<o`802?l>000040000ol0000500Ko2@06o`T01ol90003o`0001D01?l500Co
0P0<o`803?l700Go00<0ool00`0:o`@00ol300Ko1@0:o`030?oo00[o4P0:o`L01Ol00`3o000400[o
100:o`P01Ol00`3o000@00So200:o`<01Ol300Go0P0<oa401olD00Ko0P06o`803?l200Wo1@0<o`<0
3?l200So3P0001/00ol<00?o2P05ool0_P000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "See also the QuickTime movie ",
  StyleBox["Weasel-50-1-0.5.movie",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  " in the directory \[RightGuillemet]Movies\[LeftGuillemet]. The first \
parameter indicates the population size (50), the second and third parameters \
denote mutation radius (1) and mutation rate (0.1), respectively."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Experiment 4:\n\[Dash] 50 individuals, mutation radius: 5, mutation rate: \
0.5"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Iterated selection and mutation", "Subsubsection"],

Cell["We define an objective sentence.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(weaselSentence = encodeSentence["\<METHINKS IT IS LIKE A WEASEL.\>"]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({77, 69, 84, 72, 73, 78, 75, 83, 91, 73, 84, 91, 73, 83, 91, 76, 73, 
      75, 69, 91, 65, 91, 87, 69, 65, 83, 69, 76, 93}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We start an evolution experiment with a population size of ",
  StyleBox["m=50",
    FontSlant->"Italic"],
  ", that is, we will have 30 individual sentences per generation. Mutations \
are applied with a probability of ",
  StyleBox["\[Mu]=0.5",
    FontSlant->"Italic"],
  ", the mutation radius is set to ",
  StyleBox["\[Rho]=5",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveSentences[weaselSentence, 50, 5, .5]\)], "Input"],

Cell["\<\
0: Min.: 1971
OPVWVMQOUDZQQHOYOBMUJSWKL KC
1: Min.: 1707
QPUWSMSQUBXRQIOZJAIUHSTIKWFC
2: Min.: 1403
QPVSSMSVYBXRQLOZJDIVGSUIKWFF
3: Min.: 1060
LLVONNQVYEWRQQLVJDIVGTUIKWKF
4: Min.: 931
LIRNNNOUYFTRQQQSLGIVGOUIKWOF
5: Min.: 781
MEUNONOPYFTRLVQSGGHVFOQHJRKF
6: Min.: 660
MEUJKNOPYFPRLVQSDGCVFQQHGRKF
7: Min.: 570
PAUJJPOMYFPVLVQSIGASFUTHBTKE
8: Min.: 402
NDUJGMLK FQ IQTPIGAUFUTIBPJE
9: Min.: 286
NDUNGOGO FQ JQTPHJBWFYSIASJI
10: Min.: 245
MDZNGOGO FQ JSYPDJBWFYVHAQFK
11: Min.: 187
MIVLGOGO FQ JSWLDJAXBY GARFK
12: Min.: 164
MHVLGOGTXFQ JSWLDJFXBXYGDRFJ
13: Min.: 166
MHVGIQFT JQ JSZLAJFXA  GCRFJ
14: Min.: 149
QHVJIOFTXIQ JSWLFJFXA  BAQFJ
15: Min.: 147
QHVJIOFTXIQYJSVLGLFXA YBARFO
16: Min.: 156
NEQKIOFQVIQYJSVLHLF A YADRFO
17: Min.: 141
JAQKIOFP IVYJTVJHJF A YCCUFN
18: Min.: 89
NAQKJMJQ ISYJTVMHJF A WCBRDN
19: Min.: 135
PASKIMGO KS HTVOGIF A XCBRDI
20: Min.: 121
OAVHIMGO KU KTVNGIF AYXCBRDJ
21: Min.: 112
OFVHGMKN IV KUVJGIF BZXABRDM
22: Min.: 101
PFVJGNKN IV KVZJGIF B XEAWFN
23: Min.: 118
RFVHGPKS HV KVZKFNHZB XEAXFN
24: Min.: 138
RFVIKPKS FV KVZKFNHZAWXEAVFP
25: Min.: 115
RFUIKPLS IV FVZKFIHYAWXEBSFO
26: Min.: 134
RFUIKOLS GV KTZJFIHZAWWEAXBO
27: Min.: 128
RFTEGPLS FX KQZMFIHZA YEAUBO
28: Min.: 146
MGUEGPLS FT IQZRFIHZA  EDSAO
29: Min.: 125
MFUFKPLPWJT IQYRIHGZA WIDSEK
30: Min.: 137
MEUHKPLPWHTWGTYRIMF D WIDSEK
31: Min.: 118
LEUHFLLPWHTXJTYMIOF D WIDSEI
32: Min.: 137
LEUHFNLRYHSXJTZMIOF EXWKDSHI
33: Min.: 125
OIUGHMLRYJUXJUZLFOF EXWHASHI
34: Min.: 81
OIUGHMLRYJU JU LJMF E WHASCI
35: Min.: 73
OIUGLMLR JU JU LLMF A VCASCI
36: Min.: 84
KETJKLGS JT JT LLMF B ZCAOCK
37: Min.: 74
MITJKNJPZJT IT LJJI B YCBQCK
38: Min.: 90
MEXJKNJO HP KTZJJLG B YGBQDK
39: Min.: 109
MEXJKNJO HP LWZJJLG A VGBQDN
40: Min.: 120
MDXJKNJQ HP LWZKJLD AYVGCNCK
41: Min.: 81
ODXJKNKT HR HU KILD DYWICSCK
42: Min.: 112
ODXEJNKT HRZKUYKMLD BYVJCSCJ
43: Min.: 142
MDWIJNKW HM KUZKMLD BYVJASCK
44: Min.: 128
MBUGJPNWZHP KQ KMLD BY GAUCI
45: Min.: 129
MBUGJQMWZHPYMQ KMLD B WGAVCI
46: Min.: 121
HGUGJLNTZHPYMQ KHLFXB UFAVCM
47: Min.: 148
HGSGILNTVHPYMT KHLCXCZUFAVCK
48: Min.: 164
HGSGJLNTVHPYMTXKHLCXC UFCVCJ
49: Min.: 181
HGSGJLNWZHSYNTVKHLC CVUGCVCK
50: Min.: 174
MGSFJLNXZMQZIQVKLLF CVUGCQCO
51: Min.: 161
MGUFJLNXZMQ LQVKMLF AXUGCQDN
52: Min.: 171
NGUFJONSYMQ LQVMMLF A UEGQAN
53: Min.: 161
NGUFJLNSYJO JV MMLE A WHFNAN
54: Min.: 152
JHUJJLLSYJOZJVZMMNE A WCBNAO
55: Min.: 138
JJVJJLLVYKSZJVYMINB A VDBNFO
56: Min.: 119
JHTJKLLT IVXFQYIINF A VDBNFO
57: Min.: 89
NDTJKLLT IVXKQYIJNF A VABPFL
58: Min.: 76
NDTJKLLT IVXKQ JJNF A VABUFK
59: Min.: 89
NDTJLPKTVIRXKQ JJLFYA VCBUFK
60: Min.: 91
KDRJLPKTWIQZIR JJMFYC VBAUCK
61: Min.: 101
KGRJLKKTWIQZIU JJMC C VCAUBK
62: Min.: 122
KGVJLJKTWIQ IU MJICYA SEAUAK
63: Min.: 104
JCVJJLKTWIQXLU MHJE A SEATBK
64: Min.: 114
JCVJJPKTWIR LU MHGJ A WEATBK
65: Min.: 103
JCUEJLKTZIR LU IDKE A  EAUDK
66: Min.: 93
JDUIJLHTZIR JS IIOE A  IATDK
67: Min.: 103
ODUIGLMTYIT JU IIQE D VIATDK
68: Min.: 120
KDPIGLMOYIQ JU ILLA D XGATDK
69: Min.: 124
KAPIGLLO IQ JUXMLLA C XGATDK
70: Min.: 107
OAPIGMLRZLV JUWMLLE C XFATDO
71: Min.: 114
ODPEIMLV JV LUWNLLE C YBAQEJ
72: Min.: 118
ODNEIMLV JV LUWNILE C YBASEK
73: Min.: 121
OIREGMLV JVYNUZNILE C YAASCK
74: Min.: 128
OIRJGMLV JVZNQ NILEWC YEAUAK
75: Min.: 139
OIRHGMLV IV NVYNILFWC YGAUAJ
76: Min.: 134
ODRHFMLV IT NWYNHLF C  GAUAO
77: Min.: 151
TDRHFRLQ IR NT NHJF CZ GASDJ
78: Min.: 98
PDRHFRLTYIR NT NIJF C YEAQDJ
79: Min.: 81
PDRHFRLTYIR IT NHJG C YECQDJ
80: Min.: 83
LDRHIRLPYHR ITYKGNG C YGCTDK
81: Min.: 112
LDREIMKPXHU ITYKGKG AWTDFTDI
82: Min.: 125
LGREINKRXHV IRYKHJG AWTFAYBI
83: Min.: 137
LHRHJNKRXHT JOYKIMF AWTJAWBI
84: Min.: 145
NHWCJNKRXHW JR KIMF AWTJAVCI
85: Min.: 144
QIWCINLRXEW KS KIHF AYTEARCI
86: Min.: 132
QISGINLVXEWWKS KKHF AYTEARCM
87: Min.: 107
LDSGIPLWXIWWKS JKHF A SCBSCM
88: Min.: 111
LISGIPLWZIWZHS KKHHXB SCBSCM
89: Min.: 100
LEPGIPKW IWZHRYMHHHXBZUCBTCM
90: Min.: 117
PEPGINJX HWZHP IHMD BZUDBTAN
91: Min.: 107
PIPGILJV IWZHP LHHG AZUDATFO
92: Min.: 128
LIRGILJTVFW HN LHHG AZUDATFO
93: Min.: 148
PDWHNLJTVIX GR HHKG A YDATBP
94: Min.: 117
ODWHNJJTWISZGR HIKG A  EATEL
95: Min.: 105
OAWHKOJT ISZGO HIKG A  BBREL
96: Min.: 108
RFWFGOMR ISZGO MKKG A  DBREI
97: Min.: 97
NGWFGOJT IVZGOWMKJC A  DAUEL
98: Min.: 113
NGWFIQJT IVZGOYMKJC A  BEUEL
99: Min.: 105
NGSFIQJR IVZJOYMKJA A  EEUEL
100: Min.: 103
NGSFIMIR IWZMPYOKJC A  EAVGK
101: Min.: 114
NGUFELJR ITZMP OKMCZAZ EAQGI
102: Min.: 103
NGUFGMLR IT MQ PKMAZBZVEAQHI
103: Min.: 107
NGUFGQLR IT LV PKIAZAZVCAQCI
104: Min.: 112
NGUFGNIR FTZKT PKMAZA SCAQCI
105: Min.: 106
NBSFHNIR HTZKT OIME AWSCAQAI
106: Min.: 119
NCSFHNIT JT KSVNIME AWSCAQAI
107: Min.: 128
KCSEHNIT JT GSVNHNE AWTBAPAK
108: Min.: 114
KCSEHKJT JTZGSYKGNE AWXBAPAO
109: Min.: 127
KASEGMMQ JTYHSZKGNA AWXAAPFN
110: Min.: 115
NASIGMMQ JSYHS KDJC A SECPEP
111: Min.: 102
NASIGMMQYJS HS KIJA A SECPEP
112: Min.: 114
KASIFKMQYIW GT KIJA CYVCCPEN
113: Min.: 148
HASIFKMQYIW GS KIMC EY CBUGN
114: Min.: 114
LAUIGLMQ IU GS KIMC EY CBQIN
115: Min.: 128
LDUIKLMV IU GS KIOC CY CFQIN
116: Min.: 103
LDUIKLMS HU FR KHOC AX CAQIN
117: Min.: 118
LDUILLMSXHU FR GHOC AXZCAQEN
118: Min.: 124
LEUJKLMSXHU GT LMOA AX GAPEN\
\>", "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitness plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0157385 0.00807103 -0.00792351 0.000310118 [
[(20)] .17716 .00758 0 2 Msboxa
[(40)] .33858 .00758 0 2 Msboxa
[(60)] .5 .00758 0 2 Msboxa
[(80)] .66142 .00758 0 2 Msboxa
[(100)] .82284 .00758 0 2 Msboxa
[(120)] .98426 .00758 0 2 Msboxa
[(250)] .00324 .06961 1 0 Msboxa
[(500)] .00324 .14714 1 0 Msboxa
[(750)] .00324 .22466 1 0 Msboxa
[(1000)] .00324 .30219 1 0 Msboxa
[(1250)] .00324 .37972 1 0 Msboxa
[(1500)] .00324 .45725 1 0 Msboxa
[(1750)] .00324 .53478 1 0 Msboxa
[(2000)] .00324 .61231 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.17716 .00758 m
.17716 .01383 L
s
P
[(20)] .17716 .00758 0 2 Mshowa
p
.002 w
.33858 .00758 m
.33858 .01383 L
s
P
[(40)] .33858 .00758 0 2 Mshowa
p
.002 w
.5 .00758 m
.5 .01383 L
s
P
[(60)] .5 .00758 0 2 Mshowa
p
.002 w
.66142 .00758 m
.66142 .01383 L
s
P
[(80)] .66142 .00758 0 2 Mshowa
p
.002 w
.82284 .00758 m
.82284 .01383 L
s
P
[(100)] .82284 .00758 0 2 Mshowa
p
.002 w
.98426 .00758 m
.98426 .01383 L
s
P
[(120)] .98426 .00758 0 2 Mshowa
p
.001 w
.04802 .00758 m
.04802 .01133 L
s
P
p
.001 w
.08031 .00758 m
.08031 .01133 L
s
P
p
.001 w
.11259 .00758 m
.11259 .01133 L
s
P
p
.001 w
.14487 .00758 m
.14487 .01133 L
s
P
p
.001 w
.20944 .00758 m
.20944 .01133 L
s
P
p
.001 w
.24173 .00758 m
.24173 .01133 L
s
P
p
.001 w
.27401 .00758 m
.27401 .01133 L
s
P
p
.001 w
.3063 .00758 m
.3063 .01133 L
s
P
p
.001 w
.37086 .00758 m
.37086 .01133 L
s
P
p
.001 w
.40315 .00758 m
.40315 .01133 L
s
P
p
.001 w
.43543 .00758 m
.43543 .01133 L
s
P
p
.001 w
.46772 .00758 m
.46772 .01133 L
s
P
p
.001 w
.53228 .00758 m
.53228 .01133 L
s
P
p
.001 w
.56457 .00758 m
.56457 .01133 L
s
P
p
.001 w
.59685 .00758 m
.59685 .01133 L
s
P
p
.001 w
.62914 .00758 m
.62914 .01133 L
s
P
p
.001 w
.6937 .00758 m
.6937 .01133 L
s
P
p
.001 w
.72599 .00758 m
.72599 .01133 L
s
P
p
.001 w
.75827 .00758 m
.75827 .01133 L
s
P
p
.001 w
.79056 .00758 m
.79056 .01133 L
s
P
p
.001 w
.85513 .00758 m
.85513 .01133 L
s
P
p
.001 w
.88741 .00758 m
.88741 .01133 L
s
P
p
.001 w
.91969 .00758 m
.91969 .01133 L
s
P
p
.001 w
.95198 .00758 m
.95198 .01133 L
s
P
p
.002 w
0 .00758 m
1 .00758 L
s
P
p
.002 w
.01574 .06961 m
.02199 .06961 L
s
P
[(250)] .00324 .06961 1 0 Mshowa
p
.002 w
.01574 .14714 m
.02199 .14714 L
s
P
[(500)] .00324 .14714 1 0 Mshowa
p
.002 w
.01574 .22466 m
.02199 .22466 L
s
P
[(750)] .00324 .22466 1 0 Mshowa
p
.002 w
.01574 .30219 m
.02199 .30219 L
s
P
[(1000)] .00324 .30219 1 0 Mshowa
p
.002 w
.01574 .37972 m
.02199 .37972 L
s
P
[(1250)] .00324 .37972 1 0 Mshowa
p
.002 w
.01574 .45725 m
.02199 .45725 L
s
P
[(1500)] .00324 .45725 1 0 Mshowa
p
.002 w
.01574 .53478 m
.02199 .53478 L
s
P
[(1750)] .00324 .53478 1 0 Mshowa
p
.002 w
.01574 .61231 m
.02199 .61231 L
s
P
[(2000)] .00324 .61231 1 0 Mshowa
p
.001 w
.01574 .08511 m
.01949 .08511 L
s
P
p
.001 w
.01574 .10062 m
.01949 .10062 L
s
P
p
.001 w
.01574 .11612 m
.01949 .11612 L
s
P
p
.001 w
.01574 .13163 m
.01949 .13163 L
s
P
p
.001 w
.01574 .16264 m
.01949 .16264 L
s
P
p
.001 w
.01574 .17815 m
.01949 .17815 L
s
P
p
.001 w
.01574 .19365 m
.01949 .19365 L
s
P
p
.001 w
.01574 .20916 m
.01949 .20916 L
s
P
p
.001 w
.01574 .24017 m
.01949 .24017 L
s
P
p
.001 w
.01574 .25568 m
.01949 .25568 L
s
P
p
.001 w
.01574 .27118 m
.01949 .27118 L
s
P
p
.001 w
.01574 .28669 m
.01949 .28669 L
s
P
p
.001 w
.01574 .3177 m
.01949 .3177 L
s
P
p
.001 w
.01574 .33321 m
.01949 .33321 L
s
P
p
.001 w
.01574 .34871 m
.01949 .34871 L
s
P
p
.001 w
.01574 .36422 m
.01949 .36422 L
s
P
p
.001 w
.01574 .39523 m
.01949 .39523 L
s
P
p
.001 w
.01574 .41074 m
.01949 .41074 L
s
P
p
.001 w
.01574 .42624 m
.01949 .42624 L
s
P
p
.001 w
.01574 .44175 m
.01949 .44175 L
s
P
p
.001 w
.01574 .47276 m
.01949 .47276 L
s
P
p
.001 w
.01574 .48827 m
.01949 .48827 L
s
P
p
.001 w
.01574 .50377 m
.01949 .50377 L
s
P
p
.001 w
.01574 .51928 m
.01949 .51928 L
s
P
p
.001 w
.01574 .55029 m
.01949 .55029 L
s
P
p
.001 w
.01574 .56579 m
.01949 .56579 L
s
P
p
.001 w
.01574 .5813 m
.01949 .5813 L
s
P
p
.001 w
.01574 .59681 m
.01949 .59681 L
s
P
p
.001 w
.01574 .0541 m
.01949 .0541 L
s
P
p
.001 w
.01574 .03859 m
.01949 .03859 L
s
P
p
.001 w
.01574 .02309 m
.01949 .02309 L
s
P
p
.002 w
.01574 0 m
.01574 .61803 L
s
P
P
.004 w
.02381 .60332 m
.03188 .52145 L
.03995 .42717 L
.04802 .3208 L
.05609 .2808 L
.06416 .23428 L
.07224 .19675 L
.08031 .16884 L
.08838 .11674 L
.09645 .08077 L
.10452 .06806 L
.11259 .05007 L
.12066 .04294 L
.12873 .04356 L
.1368 .03828 L
.14487 .03766 L
.15295 .04045 L
.16102 .0358 L
.16909 .01968 L
.17716 .03394 L
.18523 .0296 L
.1933 .02681 L
.20137 .0234 L
.20944 .02867 L
.21751 .03487 L
.22559 .02774 L
.23366 .03363 L
.24173 .03177 L
.2498 .03735 L
.25787 .03084 L
.26594 .03456 L
.27401 .02867 L
.28208 .03456 L
.29015 .03084 L
.29822 .0172 L
.3063 .01472 L
.31437 .01813 L
.32244 .01503 L
.33051 .01999 L
.33858 .02588 L
.34665 .02929 L
.35472 .0172 L
.36279 .02681 L
.37086 .03611 L
.37893 .03177 L
.38701 .03208 L
.39508 .0296 L
.40315 .03797 L
.41122 .04294 L
.41929 .04821 L
Mistroke
.42736 .04604 L
.43543 .04201 L
.4435 .04511 L
.45157 .04201 L
.45964 .03921 L
.46772 .03487 L
.47579 .02898 L
.48386 .01968 L
.49193 .01565 L
.5 .01968 L
.50807 .0203 L
.51614 .0234 L
.52421 .02991 L
.53228 .02433 L
.54036 .02743 L
.54843 .02402 L
.5565 .02092 L
.56457 .02402 L
.57264 .02929 L
.58071 .03053 L
.58878 .02526 L
.59685 .02743 L
.60492 .02867 L
.61299 .0296 L
.62107 .03177 L
.62914 .03518 L
.63721 .03363 L
.64528 .0389 L
.65335 .02247 L
.66142 .0172 L
.66949 .01782 L
.67756 .02681 L
.68563 .03084 L
.6937 .03456 L
.70178 .03704 L
.70985 .03673 L
.71792 .03301 L
.72599 .02526 L
.73406 .0265 L
.74213 .02309 L
.7502 .02836 L
.75827 .02526 L
.76634 .03177 L
.77441 .03797 L
.78249 .02836 L
.79056 .02464 L
.79863 .02557 L
.8067 .02216 L
.81477 .02712 L
.82284 .02464 L
Mistroke
.83091 .02402 L
.83898 .02743 L
.84705 .02402 L
.85513 .02526 L
.8632 .02681 L
.87127 .02495 L
.87934 .02898 L
.88741 .03177 L
.89548 .02743 L
.90355 .03146 L
.91162 .02774 L
.91969 .02371 L
.92776 .02743 L
.93584 .03797 L
.94391 .02743 L
.95198 .03177 L
.96005 .02402 L
.96812 .02867 L
.97619 .03053 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06P000?l06P000?l06P000?l06P0003h0
1?l300;o8@03o`<00_lQ00;o1002ob000_l400;o7@03o`@00_l400;o6P03o`<01?l300;o0`0003l0
00?o00000P001?l00?lQ0005o`000?l00P000ol0000M0004o`00o`8000Co003o7P001?l00?l20004
o`00oad000?o00000P001?l00?l20004o`00oaX000?o00000`000ol000020004o`00o`8000100005
o`000?l00P000ol0000M00Co0P001?l00?lO0004o`00o`8000Co003o7P001?l00?l20004o`00oad0
00?o00000P001?l00?l20004o`00oaX000?o000010001Ol0003o00800Ol1004000110004o`00o`80
00?o00007@000ol0o`030004o`00oal00ol30004o`00oal00_l30004o`00oad000?o00000P001?l0
0?l20004o`00oaX000?o00001@001?l00?l2007o0@010000?P001?l00?l20004o`00oal000?o0?l0
0`001?l00?lO0003o`0000<000Co003o7P001?l00?l20004o`00oad000?o00000P001?l00?l20004
o`00oaX000?o00000P001?l00?l20004o`00o`80000o00;o1002ob400_l400;o8@03o`<00_lP00;o
1002oad00_l500;o1002oaX00_l500;o1002o`<0003o01X0003o01X0003o01X0003o01X0000K0003
o`000?/0000K0003o`000?/0000G0?co1P0001/000?o00001@000ol000050003o`0000D000?o0000
1@000ol000050003o`0000D000?o00001P000ol000050003o`0000D000?o00001@000ol000050003
o`0000D000?o00001@000ol000050003o`0000H000?o00001@000ol000050003o`0000D000?o0000
1@000ol000050003o`0000D000?o00001@000ol000060003o`0000D000?o00001@000ol000050003
o`0000D000?o00001@000ol000050003o`0000H000?o00001`0001/000?o0000A004o`040?ooo`H0
00?o00007`03obP00omI00006`000ol0000S0003o`0001h000Go0000o`0300;o10000ol0000M00;o
0`04o`T00olG0004o`00oeT0000K00;o90000ol0000400?o5P000ol0000800;o00@0o`3o7@000ol0
000700;o00D0oooo0002o`<00_l400;o3P000ol000020003o`0000X00ol01@3oool000;o1P07o`03
0?oo00?o00<0ool00ol0103oool900?o2002o`l0000K0003o`00028000?o0?l00P03o`<000Co0000
0ol:0003o`00008000?o00002P001Ol0003o00H00_lC0003o`0000X000Go0000o`0700;o00@0o`00
1_l80003o`0000<00_l90005o`000?l00`001?l00?l40003o`0000D000?o00000`000ol000030004
o`0000;o00D0oooo0002o`<000Co00000_l0103o0002o`d0000K0003o`00028000Go0?l0o`070003
o`3o00<01?l02@3oool0o`3o0002oa8000?o0?l00ol00`3o000A0003o`0001T000?o00001`02o`03
0?oo008000?o00001P02o`D00_l<0005o`000?l06@001Ol0003o00D000Oo0000o`3o00D000?o0000
2P0001/000?o00007003o`030?oo00<000?o00001`000ol000060005o`000?l00`000ol0000C0003
o`0000@000?o00003@02obP000Ko003o0?l:00Go3`000ol0o`0U0003o`3o01D0000K00;o6`02o`<0
00?o0000?002o`/00_l^0003o`0001h000?o00009@000ol0000D00006`000ol0000G00?oAP02o`<0
1_n@00006`000ol0000F0003o`0004T00onF00006`000ol0000E0003o`000><0000K00;o5P000ol0
003S00001`04o`800ol400;o1@000ol0000D0003o`000>@000080003o`0000D000Co003o0P000ol0
00020003o`0001@000?o0000i00000T000?o000010001?l00?l20003o`0000800_lD0003o`000>D0
000:0003o`0000?o0`001?l00?l40003o`0001<000?o0000i@0000L000Co003o0P000ol000030004
o`00o`@000?o00004P000ol0003V00002002o`<01?l300;o1@000ol0000A0003o`000>L0000K00;o
4P000ol0003W00006`000ol0000A0003o`000>L0000K0003o`00010000?o0000j00001/000?o0000
40000ol0003X00006`02oa4000?o0000j00001/000?o000040000ol0003X00006`000ol0000@0003
o`000>P0000K0003o`0000l000?o0000j@0001/00_l@0003o`000>T0000K0003o`0000l000?o0000
j@0001/000?o00003`000ol0003Y00006`000ol0000?0003o`000>T0000K00;o3`000ol0003Z0000
6`000ol0000>0003o`000>X0000700?o1002o`@00_l50003o`0000h000?o0000jP0000X000Co003o
0P001?l00?l20003o`00008000?o00003P000ol0003Z00002P001?l00?l20004o`00o`8000?o0000
0P02o`l000?o0000jP0000L00ol30004o`00o`8000Co003o10000ol0000>0003o`000>X000070003
o`0000<000Co003o0P001?l00?l40003o`0000h000?o0000jP0000L01?l300;o1002o`D000?o0000
3@000ol0003[00006`02o`h000?o0000j`0001/000?o00003@000ol0003[00006`000ol0000=0003
o`000>/0000K0003o`0000d000?o0000j`0001/00_l=0003o`000>`0000K0003o`0000`000?o0000
k00001/000?o000030000ol0003/00006`000ol0000;0003o`000>d0000K00;o30000ol0003]0000
6`000ol0000;0003o`000>d0000K0003o`0000/000?o0000k@0001/000?o00002P000ol0003^0000
6`02o`/000?o0000kP0001/000?o00002P000ol0003^000020000ol0000200?o1002o`D000?o0000
2P000ol0003^000020000ol000050004o`00o`8000?o00000P000ol0000:0003o`000>h000090003
o`0000@000Co003o0P000ol0000200;o2P000ol0003_00002@001?l00003o`<000Co003o10000ol0
00090003o`000>l0000:0004o`00o`D000Co003o10000ol000090003o`000>l0000700Co0P04o`<0
0_l500;o2P000ol0003_00006`000ol000090003o`000>l0000K0003o`0000T000?o0000k`0001/0
00?o000020000ol0003`00006`02o`T000?o0000l00001/000?o000020000ol0003`00006`000ol0
00080003o`000?00000K0003o`0000P000?o0000l00001/00_l90003o`000?00000K0003o`0000L0
00?o0000l@0001/000?o00001`000ol0003a00006`000ol000070003o`000?40000K00;o20000ol0
003a00006`000ol000070003o`000?400000103oool400;o1002o`@00_l50003o`0000H000?o0000
lP00008000?o00000P001?l00?l20004o`00o`8000Co003o10000ol000060003o`000?8000020003
o`00008000Co003o0P001?l00?l20004o`00o`@00_l70003o`000?8000020003o`00008000Co003o
0P001?l00?l20004o`00o`@000?o00001P000ol0003b00000P000ol000020004o`00o`8000Co003o
0P001?l00?l40003o`0000H000?o0000lP0000030?oo00D00_l400;o1002o`D000?o00001@000ol0
003c00006`02o`H000?o0000l`0001/000?o00001@000ol0003c00006`000ol000050003o`000?<0
000K0003o`0000D000?o0000l`0001/00_l60003o`000?<0000K0003o`0000D000?o0000l`0001/0
00?o00001@000ol0003c00006`000ol000050003o`000?<0000K00;o1P000ol0003c00006`000ol0
00040003o`000?@0000K0003o`0000@000?o0000m00001/000?o000010000ol0003d00006`02o`D0
00?o0000m00001/000?o000010000ol0003d000000@0oooo0`04o`800ol400;o1@000ol000040003
o`000?@000020003o`0000<000?o00001@001?l00?l20003o`00008000?o000010000ol0003d0000
0P000ol000040003o`0000@000Co003o0P000ol0000200;o1@000ol0003d00000P000ol000050003
o`0000?o0`001?l00?l40003o`0000@000?o0000m000008000?o00000P001?l00?l20003o`0000<0
00Co003o10000ol000040003o`000?@000000`3oo`0500;o0`04o`<00_l500;o1@000ol0003d0000
6`000ol000040003o`000?@0000K0003o`0000@000?o0000m00001/000?o00000`000ol0003e0000
6`02o`@000?o0000m@0001/000?o00000`000ol0003e00006`000ol000030003o`000?D0000K0003
o`0000<000?o0000m@0001/00_l40003o`000?D0000K0003o`0000<000?o0000m@0001/000?o0000
0`000ol0003e00006`000ol000030003o`000?D0000K00;o10000ol0003e00006`000ol000030003
o`000?D00000103oool300?o1002o`@00_l50003o`0000<000?o0000m@00008000?o00001@001?l0
0?l20004o`00o`8000?o00000P000ol000030003o`000?D000020003o`0000D000Co003o0P001?l0
0?l20003o`0000800_l30003o`000?H000020003o`0000800ol30004o`00o`8000Co003o10000ol0
00020003o`000?H000020003o`00008000?o00000`001?l00?l20004o`00o`@000?o00000P000ol0
003f000000<0ool01004o`<00_l400;o1@000ol000020003o`000?H0000K00;o0`000ol0003f0000
6`000ol000020003o`000?H0000K0003o`00008000?o0000mP0001/000?o00000P000ol0003f0000
6`02o`<000?o0000mP0001/000?o00000P000ol0003f00006`000ol000020003o`000?H0000K0005
o`000?l0n@0001/00_l20003o`000?L0000K0005o`000?l0n@0001/000Go0000o`3i00006`001Ol0
003o0?T0000K00;o0P000ol0003g00006`001Ol0003o0?T00000103oool40003o`0000800ol400;o
1@001Ol0003o0?T000020003o`0000<000?o00001@001?l00?l20003o`00008000Go0000o`3i0000
0P000ol000040003o`0000@000Co003o0P000ol0000200;o0P000ol0003g00000P000ol000040004
o`0000?o0`001?l00?l40005o`000?l0n@00008000?o00001@001?l00?l50004o`00o`@000Co003o
nP0000030?oo00@01?l200Co0`02o`D000Co003onP0001/00_l00`3o003i00006`001?l00?oj0000
6`001?l00?oj00006`02o`030?l00?T0000K0004o`00ooX0000K0004o`00ooX0000K0004o`00ooX0
000K00;o00<0o`00n@0001/000Co003onP0001/000?o0?l0n`0001/000?o0?l0n`0001/00ook0000
6`000ol0o`3k000000<0ool00_l300;o1002o`@00_l50003o`3o0?/000020003o`00008000Co003o
0P001?l00?l20004o`00o`@000?o0000n`0000<000Go0000o`020004o`00o`8000Co003o0P000ol0
000200;oo00000@000Co003o0P001?l00?l20004o`00o`8000?o00000P000ol0003k000000D0o`00
o`020004o`00o`8000Co003o0P001?l00?l40003o`000?/0000200;o1002o`@00_l400;oo`040000
o`0J0000o`0J0000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-13.3597, -146.878, 0.492103, 
  12.8073}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[bestFitnesses, PlotJoined \[Rule] True, 
      PlotRange \[Rule] {{20, 120}, {60, 200}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.2 0.01 -0.264872 0.00441453 [
[(40)] .2 0 0 2 Msboxa
[(60)] .4 0 0 2 Msboxa
[(80)] .6 0 0 2 Msboxa
[(100)] .8 0 0 2 Msboxa
[(120)] 1 0 0 2 Msboxa
[(60)] -0.0125 0 1 0 Msboxa
[(80)] -0.0125 .08829 1 0 Msboxa
[(100)] -0.0125 .17658 1 0 Msboxa
[(120)] -0.0125 .26487 1 0 Msboxa
[(140)] -0.0125 .35316 1 0 Msboxa
[(160)] -0.0125 .44145 1 0 Msboxa
[(180)] -0.0125 .52974 1 0 Msboxa
[(200)] -0.0125 .61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(40)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(60)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(80)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(100)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(120)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(60)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .08829 m
.00625 .08829 L
s
P
[(80)] -0.0125 .08829 1 0 Mshowa
p
.002 w
0 .17658 m
.00625 .17658 L
s
P
[(100)] -0.0125 .17658 1 0 Mshowa
p
.002 w
0 .26487 m
.00625 .26487 L
s
P
[(120)] -0.0125 .26487 1 0 Mshowa
p
.002 w
0 .35316 m
.00625 .35316 L
s
P
[(140)] -0.0125 .35316 1 0 Mshowa
p
.002 w
0 .44145 m
.00625 .44145 L
s
P
[(160)] -0.0125 .44145 1 0 Mshowa
p
.002 w
0 .52974 m
.00625 .52974 L
s
P
[(180)] -0.0125 .52974 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(200)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .01766 m
.00375 .01766 L
s
P
p
.001 w
0 .03532 m
.00375 .03532 L
s
P
p
.001 w
0 .05297 m
.00375 .05297 L
s
P
p
.001 w
0 .07063 m
.00375 .07063 L
s
P
p
.001 w
0 .10595 m
.00375 .10595 L
s
P
p
.001 w
0 .12361 m
.00375 .12361 L
s
P
p
.001 w
0 .14126 m
.00375 .14126 L
s
P
p
.001 w
0 .15892 m
.00375 .15892 L
s
P
p
.001 w
0 .19424 m
.00375 .19424 L
s
P
p
.001 w
0 .2119 m
.00375 .2119 L
s
P
p
.001 w
0 .22956 m
.00375 .22956 L
s
P
p
.001 w
0 .24721 m
.00375 .24721 L
s
P
p
.001 w
0 .28253 m
.00375 .28253 L
s
P
p
.001 w
0 .30019 m
.00375 .30019 L
s
P
p
.001 w
0 .31785 m
.00375 .31785 L
s
P
p
.001 w
0 .3355 m
.00375 .3355 L
s
P
p
.001 w
0 .37082 m
.00375 .37082 L
s
P
p
.001 w
0 .38848 m
.00375 .38848 L
s
P
p
.001 w
0 .40614 m
.00375 .40614 L
s
P
p
.001 w
0 .42379 m
.00375 .42379 L
s
P
p
.001 w
0 .45911 m
.00375 .45911 L
s
P
p
.001 w
0 .47677 m
.00375 .47677 L
s
P
p
.001 w
0 .49443 m
.00375 .49443 L
s
P
p
.001 w
0 .51209 m
.00375 .51209 L
s
P
p
.001 w
0 .5474 m
.00375 .5474 L
s
P
p
.001 w
0 .56506 m
.00375 .56506 L
s
P
p
.001 w
0 .58272 m
.00375 .58272 L
s
P
p
.001 w
0 .60038 m
.00375 .60038 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
0 .33109 m
.01 .26929 L
.02 .22956 L
.03 .181 L
.04 .25604 L
.05 .34433 L
.06 .2428 L
.07 .32668 L
.08 .30019 L
.09 .37965 L
.1 .28694 L
.11 .33992 L
.12 .25604 L
.13 .33992 L
.14 .28694 L
.15 .09271 L
.16 .05739 L
.17 .10595 L
.18 .0618 L
.19 .13244 L
.2 .21631 L
.21 .26487 L
.22 .09271 L
.23 .22956 L
.24 .36199 L
.25 .30019 L
.26 .3046 L
.27 .26929 L
.28 .38848 L
.29 .45911 L
.3 .53416 L
.31 .50326 L
.32 .44587 L
.33 .49001 L
.34 .44587 L
.35 .40614 L
.36 .34433 L
.37 .26046 L
.38 .12802 L
.39 .07063 L
.4 .12802 L
.41 .13685 L
.42 .181 L
.43 .2737 L
.44 .19424 L
.45 .23838 L
.46 .18982 L
.47 .14568 L
.48 .18982 L
.49 .26487 L
Mistroke
.5 .28253 L
.51 .20748 L
.52 .23838 L
.53 .25604 L
.54 .26929 L
.55 .30019 L
.56 .34875 L
.57 .32668 L
.58 .40172 L
.59 .16775 L
.6 .09271 L
.61 .10153 L
.62 .22956 L
.63 .28694 L
.64 .33992 L
.65 .37523 L
.66 .37082 L
.67 .31785 L
.68 .20748 L
.69 .22514 L
.7 .17658 L
.71 .25163 L
.72 .20748 L
.73 .30019 L
.74 .38848 L
.75 .25163 L
.76 .19865 L
.77 .2119 L
.78 .16334 L
.79 .23397 L
.8 .19865 L
.81 .18982 L
.82 .23838 L
.83 .18982 L
.84 .20748 L
.85 .22956 L
.86 .20307 L
.87 .26046 L
.88 .30019 L
.89 .23838 L
.9 .29577 L
.91 .2428 L
.92 .18541 L
.93 .23838 L
.94 .38848 L
.95 .23838 L
.96 .30019 L
.97 .18982 L
.98 .25604 L
.99 .28253 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l06`000?l06`000?l06`0004@00ol300;o
:@02o`@00_lZ00;o1002obD00ol400;o1002ob<00ol300Co0`02o`D000150005o`000?l00P000ol0
000U0004o`00o`8000Co003o:0001?l00?l20004o`00obD000?o00000P001?l00?l20004o`00ob<0
00?o00000`000ol000020004o`00o`@0001300Co0P001?l00?lW0004o`00o`8000Co003o:0001?l0
0?l20004o`00obD000?o00000P001?l00?l20004o`00ob<000?o000010001Ol0003o008000?o0000
0P0004<000?o0?l00`001?l00?lW00?o0`001?l00?lY00;o0`001?l00?lU0003o`00008000Co003o
0P001?l00?lS0003o`0000D000Co003o0P000ol000020000@`000ol0o`030004o`00obL000?o0000
0`001?l00?lX0004o`00o`8000Co003o9@000ol000020004o`00o`8000Co003o8`000ol000020004
o`00o`8000Co003o100004@00_l400;o:@03o`<00_lZ00;o1002obD00_l500;o1002ob<00_l500;o
1002o`D0003o01/0003o01/0003o01/0003o01/0000900;o1002ool02P0000P000Co003o0P001?l0
0?oo00T000080004o`00o`8000Co003o103io`/0000800?o0`001?l00?l40003o`0000L000?o0000
1`000ol000070003o`0000L000?o00001`000ol000070003o`0000L000?o00001P000ol000070003
o`0000L000?o00001`000ol000070003o`0000L000?o00001`000ol000070003o`0000L000?o0000
1`000ol000070003o`0000H000?o00001`000ol000070003o`0000L000?o00001`000ol000070003
o`0000L000?o00002@0000P000?o00000`001?l00?l40003o`0002l000?o0000;P000ol0000_0003
o`0002h000?o0000;`000ol0000900002@03o`<00_l50003o`000?l00P0001H000?o0000o`020000
5P02ool00`0001H000?o0000o`0200005P000ol0003o0080000F0003o`000?l00P0001H00_oo00<0
000F0003o`000?l00P0001H000?o0000o`0200005P000ol0003o0080000F0003o`000?l00P0001H0
0_oo00<0000F0003o`0002D000?o0000f@0001H000?o00009@000ol000020003o`000=@0000F0003
o`0002@00_l40003o`000=@0000F00;o9@02o`@000?o0000<@000ol0002P00005P000ol0000T0003
o`3o00800_lc0003o`000:00000900;o1002o`D000?o00008`001?l00?l200;o<`000ol0002P0000
20001?l00?l20004o`00o`@000?o00008`001?l00?l20003o`3o03400_nR000020001?l00?l20004
o`00o`@00olS0006o`00o`3o0P000ol0000_0003o`3o0:40000900;o0`001?l00?l40003o`000280
00Oo0000o`3o008000?o00001P000ol0000V0003o`3o038000?o0000K00000P000Co003o0P001?l0
0?l40003o`00028000Oo0000o`3o008000?o00001P000ol0000V0003o`3o038000?o0000K00000T0
0_l400;o1@000ol0000R0003o`0000800_l20003o`0000H000?o00009P000ol0o`0b00;oK@0001H0
00?o00008P000ol000020005o`000?l020000ol0000U0004o`00oc8000?o0?l0K00001H00_lS0003
o`00008000Go0000o`080003o`0002D000Co003o<@001?l00?m/00005P000ol0000R0003o`0000H0
00?o00001P000ol0000U0004o`00oc4000Co003oK00001H000?o00008P000ol000060003o`0000H0
00?o00009@001Ol0003o030000Co003oK00001H000?o00008P000ol000070003o`0000D000?o0000
9@001Ol0003o030000Co003oK00001H00_lS0003o`0000L000?o00001002obH000?o00000P000ol0
000^0004o`00of`0000F0003o`00028000?o00001`000ol000040003o`3o02D000?o00000P02obl0
00Go0000o`1[00005P000ol0000R0003o`0000L000?o000010000ol0o`0U0003o`0000@000?o0000
:`000ol000020003o`0006T0000F0003o`00028000?o00001`000ol000040003o`3o02D000?o0000
1@000ol0000Z0003o`00008000?o0000J@0001H00_lS0003o`0000L000?o000010000ol0o`0U0003
o`0000D000?o0000:P000ol000020003o`0006T0000F0003o`00024000?o000020000ol000040003
o`3o02D000?o00001@000ol0000Z0003o`00008000?o0000J@0001H000?o00008@000ol000090003
o`0000<000?o0?l09@000ol000050003o`0000`000?o00006`000ol000020003o`0006T0000F0003
o`00024000?o00002@000ol000030003o`3o02D000?o00001P000ol0000;0003o`0001/000?o0000
0P000ol0001Y00005P000ol0000Q0003o`0000T000?o00000`000ol0o`0U0003o`0000H000?o0000
2`000ol0000K0003o`00008000?o0000J@0001H00_lR0003o`0000T000?o00000`000ol0o`0U0003
o`0000H000?o00002P000ol0o`0K0003o`0000<000?o0000J@0001H000?o00008@000ol000090003
o`0000<000?o0?l090000ol000070003o`0000X000?o0?l06`000ol000030003o`0002H000?o0000
@00000800ol400;o1002o`D000?o00008@000ol000090003o`0000<000?o0?l090000ol000070003
o`0000X000?o0?l06`000ol000040003o`0002D000?o0000@00000<000?o00000P001?l00?l20004
o`00o`@000?o00008@000ol000090003o`0000<000?o0?l090000ol000080003o`0000P000Co003o
6`000ol000040003o`0002D000?o0000@00000<000?o00000P001?l00?l20004o`00o`@00olQ0003
o`0000X000?o00000P000ol0o`0T0003o`0000P000?o000020001?l00?lK0003o`0000@000?o0000
4P000ol0000@0003o`00040000030003o`00008000Co003o0P001?l00?l40003o`0000D000?o0000
6@000ol0000:0005o`000?l00P000ol0000R0003o`0000P000?o000020001Ol0003o01X000?o0000
10000ol0000B0003o`0000l000?o0?l0@@0000<000?o00000P001?l00?l20004o`00o`@000?o0000
1@000ol0000I0003o`0000X000Go0000o`020003o`00028000?o000020000ol000070003o`000080
00?o000060000ol000040003o`00018000?o00003`000ol0o`0Q0003o`0001d0000200;o1@02o`@0
0_l50003o`0000D000?o00006@000ol0000:0005o`000?l00P000ol0000R0003o`0000P000?o0000
1`000ol000020003o`0001P000?o000010000ol0000A00;o4@000ol0o`060003o`00008000?o0000
4`000ol000090003o`000140000F0003o`0000@00_lK0003o`0000X000Go0000o`020003o`000280
00?o000020000ol000070003o`00008000?o000060000ol000040003o`0001400_lA0003o`3o00D0
0_l40003o`0001<000?o00002@000ol0000A00005P02o`D00_lK0003o`0000X000Go0000o`030003
o`00024000?o000020000ol000020003o`00008000?o00000P000ol0000H0003o`0000@000?o0000
4@02oa4000?o0?l010000ol0o`0400;o50000ol000090003o`000140000F0003o`0000@00_lK0003
o`0000X000Go0000o`030003o`00024000?o00002@001Ol0003o00@000?o00000P000ol0000H0003
o`0000@000?o00004@000ol0o`0<0005o`000?l00P001?l00?l20007o`000?l0o`0D00;o2P000ol0
000A00005P000ol000040003o`3o01X000?o00002`001?l00?l30003o`00024000?o00002@001Ol0
003o00<000?o000010000ol0000G0003o`0000@000?o000040001?l00?l<00;o00<0o`000P001?l0
0?l30006o`00o`3o1@000ol0000;0003o`3o00X00_lB00005P000ol000030004o`00oaX000?o0000
2`001?l00?l30003o`00024000?o00002@001?l00002o`8000?o000010000ol000040003o`000100
00?o000010000ol0000=0004o`00o`8000Go0000o`080004o`3oo`<000Co003o0`001?l00?l20003
o`00008000?o00002`000ol0o`0:00;o4P0001H00_l40004o`00oaX000?o00002`001?l00?l30003
o`00024000?o00002@001?l00002o`8000?o000010000ol000040003o`00010000?o00001@000ol0
000<0004o`00o`8000Go0000o`080004o`00o`<000?o0?l010001?l00?l20004o`0000;o3@000ol0
o`0:00;o4P0001H000?o00000`001?l00?lJ0003o`0000/000Co003o0`000ol0000Q0003o`0000T0
00Co00000_l20003o`0000@000?o000010000ol0000@0003o`0000D000?o00003002o`050?l00?l0
0`000ol000050003o`0000D000?o0?l010000ol0o`040006o`00o`3o30000ol0o`0:00;o4P0001H0
00?o00000`001?l00?lJ0003o`0000/000Co003o0`000ol0000Q0003o`0000T000Co003o0P000ol0
o`060003o`0000@00_lA0003o`0000D000?o00003003o`<000?o00000_l70003o`0000D000?o0?l0
10000ol0o`050005o`3o0?l030000ol0o`090003o`3o0180000F0003o`00008000Go0000o`0J0003
o`0000/000Co003o0`000ol0000Q0003o`0000T000Co003o0P000ol0o`060003o`0000<000?o0?l0
4@000ol000050003o`0000`000?o0?l00`000ol00002o`L000?o00001P02o`@000?o0?l01@02o`80
00?o00002P000ol0o`090004o`00oa40000F00;o0`001Ol0003o01X000?o00002`001?l00?l30003
o`00024000?o00002P000ol0o`020003o`3o00L000?o00000P000ol0o`0@0003o`0000H000?o0000
2`000ol000040003o`0000;o1`000ol000060003o`0000<000?o0?l01P001?l00?l<0004o`00o`P0
00Co003o4@0001H000?o00000P001Ol0003o01X000?o000030000ol0o`030003o`00020000?o0000
2`000ol0o`0200;o20000ol000020003o`3o010000?o00001P000ol0000;0003o`0000@000Go0?l0
o`070003o`0000H000?o00001002o`T000?o00002@001Ol0003o00P000Co003o4@0001H000?o0000
0P001Ol0003o01X000?o000030000ol0o`030003o`00020000?o00002`000ol0o`030003o`0000H0
00?o00000P001?l00?l?0003o`0000H000?o00002`000ol0000500;o0P000ol000040003o`0000d0
00?o00002@000ol000080005o`000?l020001?l00?lA00005P001Ol0003o00D000?o00005`000ol0
000<00;o10000ol0000P0003o`0000/000?o0?l00`000ol000060003o`00008000Co003o3`000ol0
00060003o`0000/000?o00001@02o`8000?o000010000ol0000=0003o`0000T000?o00000`000ol0
00020005o`000?l010001Ol0003o008000?o00003`0001H000Go0000o`050003o`00008000?o0000
4@000ol0000=00;o10000ol0000P0003o`0000/000?o0?l030000ol000020004o`00o`l000?o0000
1P000ol0000;0003o`0000D00_l20003o`0000<000?o00006P000ol000030003o`00008000Go0000
o`040005o`000?l00P000ol0000?00005P02o`8000?o00000`000ol000020003o`00014000?o0000
3@02o`@000?o000080000ol0000;0003o`3o00`000Go0000o`040003o`0000`000?o00001`000ol0
000:0003o`0000D000Go0000o`050003o`0001X000?o00000`000ol000020005o`000?l010001Ol0
003o00<000?o00003P0001H000Go0000o`050003o`00008000?o00004@000ol0000=00;o1@000ol0
000O0003o`0000/000?o0?l030001Ol0003o00@000?o000030000ol000070003o`0000X000?o0000
1@001Ol0003o00D000?o00006P000ol0000200;o10001Ol0003o00@00_l20005o`000?l040000080
0ol300Co0`02o`D000Go0000o`050003o`00008000?o000030000ol000020003o`0000h000?o0000
0`000ol0000O0003o`0000/00_l>0004o`00o`D000?o00002`000ol000070003o`0000X000?o0000
2@000ol000030003o`0001/000Oo0000o`3o008000?o00000P000ol0000200;o0P001Ol0003o0100
00030003o`0000<000?o00000P001?l00?l40004o`00o`H000?o00000P02o`d000?o00000P000ol0
000>0003o`0000<000?o00007`000ol0000<0003o`0000`000Co003o1P000ol0000:0003o`0000L0
00?o00002P000ol000090003o`0000<000?o00006`001ol0003o0?l00P000ol000020003o`000080
0_l20005o`000?l0400000<000?o000010001Ol0003o008000?o00000P04o`H000?o00000P02o`d0
00?o00000P000ol0000>0003o`0000<000?o00007`000ol0000<0003o`0000`000Co003o1`000ol0
00090003o`0000L000?o00002@000ol0000:0003o`0000<000?o00006`001ol0003o0?l00P000ol0
00020003o`0000800_l20003o`00008000?o00003@0000<000?o00001@001?l00?l20003o`000080
00Co003o1P000ol0000200;o3@000ol000020003o`0001@000?o00001P000ol0000F0003o`0000`0
00?o000030001?l00?l80003o`0000P000?o00001`000ol000090003o`0000X000?o00000`000ol0
000K0007o`000?l0o`020003o`0000<000Co00000_l20003o`00008000?o00003@0000<000?o0000
0P001?l00?l20004o`00o`@000Co003o1P001ol0003o0?l03@000ol000020003o`0001@000?o0000
1P000ol0000F0003o`0000`000?o00003@02o`T000?o000020000ol000070003o`0000T000?o0000
2P000ol000030003o`0001`000?o0?l00P000ol0o`060009o`000?l0o`3o00@000?o00003@000080
0_l500;o1002o`D000Co003o1`001_l00?l0o`d000?o00000P000ol0000D0003o`0000H000?o0000
5@000ol0000M00;o2@000ol000080003o`0000P000?o000020000ol0000:0003o`0000<000?o0000
70000ol0o`020003o`3o00H000Ko0000o`02o`H000?o0000300001H00ol80006o`00o`3o30000ol0
o`030003o`0001@000?o00001@02oaL000?o00007P000ol000080003o`0000L000?o000020000ol0
00080003o`0000/000Go0000o`0O0003o`3o008000?o0?l01P001?l00?l200;o1P000ol0000<0000
5P000ol0o`080006o`00o`3o30000ol0o`030003o`0001@000?o00001@02oaL000?o0000:@000ol0
00070003o`0000P000?o000020000ol0000;0005o`000?l07`000ol0o`0300;o1P001?l00?l200;o
5@0001H000?o0?l020001?l00?l20003o`0000D000Oo0000o`3o00<000?o000050000ol0000500;o
5`000ol0000Y0003o`0000L000?o000020000ol000080003o`0000/000Go0000o`0O0003o`3o00<0
0_l60004o`00o`800_lE00005P000ol0o`080004o`00o`8000?o00001@001ol0003o0?l00`000ol0
000D0003o`0000D000?o0?l05P000ol0000Y0003o`0000L000?o000020000ol000080003o`0000/0
00Go0000o`0P0003o`00008000?o00001@001?l00?l30003o`0001<0000F0003o`3o00P000Co003o
0P000ol000050007o`000?l0o`030003o`0001D000?o000010000ol0o`0F0003o`0002X000?o0000
1P000ol000080003o`0000P000?o00002`001Ol0003o020000?o00000P000ol000050004o`00o`<0
00?o00004`0001H00_l90004o`00o`8000Co003o1002o`8000?o0?l00P000ol0000F0003o`0000Co
0P000ol0000D0003o`0002X000?o00001P000ol000090003o`0000H000?o000030001Ol0003o0200
00?o00002P001?l00?l30003o`0001<0000F00;o2P000ol0o`020004o`00o`@00_l20003o`3o0080
00?o00005P001?l00?l20004o`00oaD000?o0000:`000ol000060003o`0000T000?o00001P000ol0
000<0005o`000?l0;@001?l00?lI00005P02o`X000?o0?l00P001?l0ool400;o0P000ol0o`020003
o`0001H000Co003o1@000ol0000C0003o`0002/000?o00001P000ol000090003o`0000H000?o0000
30001Ol0003o02d000Co003o6@0001H00_l:0003o`3o008000Co0?oo0`000ol0o`020003o`3o0080
00?o00005P001?l00?l50003o`0001<000?o0000;0000ol000050003o`0000T000?o00001P000ol0
000<0005o`000?l0;@001?l00?lI00005P02o`X000?o0?l00`02o`050?l00?l00P001ol0o`3o0?l0
6@001?l00?l50003o`0001<000?o0000;0000ol000050003o`0000X000?o00001@000ol0000<0005
o`000?l0;P000ol0o`0I00005P000ol000090003o`3o00<000Co003o0P002_l00?l0o`3o0?lI0003
o`3o00H000?o00004`000ol0000/0003o`0000D000?o00002P000ol000050003o`0000`000Go0000
o`0^0003o`3o01T0000F0003o`0000T00_l40004o`00o`8000?o00000_l300;o6@000ol0o`060003
o`0001<000?o0000;0001Ol0003o00<000?o00002P000ol000050003o`0000d000?o0?l0;`000ol0
o`0I00005P000ol0000900;o1`001?l00?l200;o0`02oaT000?o0?l01P000ol0000C0003o`0002d0
00Co003o0`000ol0000:0003o`0000D000?o00003@000ol0o`0_0003o`3o01T0000F0003o`0000X0
00?o00001@001?l00?l200;o0`02oaT000?o0?l01`000ol0000A0003o`0002h000Co0?oo0`000ol0
000:0003o`0000@000?o00003P000ol0o`0_0003o`3o01T0000F00;o2`000ol000050004o`00o`<0
00Go0000o`0J0003o`3o00L000?o00004@000ol0000^0004o`3oo`<000?o00002`000ol000030003
o`0000h000?o0?l0;`000ol0o`0I00005P000ol0000:0003o`0000H000?o0?l00`001Ol0003o01/0
0_l70003o`00014000?o0000;P001Ol0o`3o008000?o00002`000ol000030003o`0000h000?o0?l0
;`000ol0o`0I00000P03o`@00ol300;o1@000ol0000:0003o`0000H000?o0?l08`02o`L000?o0000
4@000ol0000_0006o`00o`3o3P000ol000030003o`0000h000?o0?l0;`000ol0o`0I00000`000ol0
00040005o`000?l00P000ol000020003o`0001<000?o0?l08`000ol000060003o`00014000?o0000
;`001_l00?l0o`h000?o00000`000ol0000>0003o`3o02l000?o0?l06@0000<000?o00000P04o`80
00Co003o1003oa<000?o0?l08`000ol000060003o`00014000?o0000<P000ol0o`0?0003o`000080
00?o00003P000ol0o`0_0003o`3o01T000030003o`00008000?o0?l00`001?l00?l40003o`0001<0
0_lT0003o`0000H000?o00004@000ol0000b0003o`3o00l000?o00000P000ol0000>0003o`3o02l0
0_lJ00000`000ol000020003o`3o00<000Co003o10000ol0000C00;o90000ol000060003o`000140
00?o0000<P000ol0o`0?0005o`000?l04@000ol0o`0_00;o6P0000800_l500;o1002o`D000?o0000
4`02obd000?o000040000ol0000d00;o3`001Ol0003o014000?o0?l0;`02oaX0000F00;o5@000ol0
000[0003o`00010000?o0000=002oa0000Co0?oo4P000ol0000_0003o`0001P0000F0003o`0001@0
00?o0000;0000ol0000?0003o`0003@00_l@00;o50000ol0000_0003o`0001P0000F0003o`0001@0
00?o0000;0000ol0000?0003o`0003@00_lV0003o`0002l000?o0000600001H000?o0000@`000ol0
000?0003o`0003@00_lV0003o`0002l000?o0000600001H000?o0000@`000ol0000?0003o`0003@0
0_lV0003o`0002l000?o0000600001H00_m40003o`0000l000?o0000=002obH000?o0000;`000ol0
000H00005P000ol000130003o`0000h000?o0000=P000ol0001a00005P000ol000130003o`0000h0
00?o0000=P000ol0001a00005P000ol000130003o`0000h000?o0000=P000ol0001a00005P02od@0
00?o00003P000ol0002Z00005P000ol000140003o`0000d000?o0000ZP0001H000?o0000A0000ol0
000=0003o`000:X0000F0003o`0004@000?o000030000ol0002[00005P02odD000?o000030000ol0
002[00005P000ol000140003o`0000`000?o0000Z`0001H000?o0000A0000ol0000;0003o`000:`0
000200?o1002o`@00_l50003o`0004@000?o00002`000ol0002/00000`000ol000020004o`00o`80
00Co003o10000ol000140003o`0000/000?o0000[00000<000?o00000P001?l00?l20004o`00o`@0
0om40003o`0000X000?o0000[@0000<000?o00000P03o`<000Co003o10000ol000150003o`0000@0
00?o00000P000ol0002]00000`000ol000020003o`0000<000Co003o10000ol000150003o`0000@0
00?o00000P000ol0002]00000P02o`D00ol300;o1@000ol000150003o`0000@000?o00000P000ol0
002]00005P02odH000?o00001002o`<000?o0000[@0001H000?o0000A@000ol000030003o`3o0080
00?o0000[P0001H000?o0000A@000ol000030003o`3o008000?o0000[P0001H000?o0000A@000ol0
00030006o`00o`3o/00001H000?o0000AP000ol000020006o`00o`3o/00001H00_m70003o`000080
00Ko003o0?n`00005P000ol000160003o`00008000?o00000_na00005P000ol000160003o`000080
00Go0000o`2a00005P000ol000160005o`000?l010000ol0002_00005P02odL000Go0000o`2f0000
5P000ol000170004o`00okH0000F0003o`0004L000Co003o]P0001H000?o0000A`001?l00?nf0000
5P02odP000Co003o]P0001H000?o0000A`000ol0o`2g00005P000ol000170003o`3o0;L0000200?o
1002o`@00_l50003o`0004L000?o0?l0]`0000<000?o00000P001?l00?l20004o`00o`@000?o0000
B002okL000030003o`00008000Co003o0P001?l00?l400?oB0000ol0002f00000`000ol0000300;o
0`001?l00?l40003o`0004P000?o0000]P0000<000?o00000P001?l00?l20004o`00o`@000?o0000
o`0200000P02o`D00_l400;o1@000ol0003o0080000F00;oo`0300005P000ol0003o0080000F0003
o`000?l00P0001H000?o0000o`0200005P02ool00`0001H000?o0000o`0200005P000ol0003o0080
000F0003o`000?l00P0001H000?o0000o`0200005P02ool00`0001H000?o0000o`0200005P000ol0
003o0080000F0003o`000?l00P0001H00_oo00<0000F0003o`000?l00P0000801?l300;o1002o`D0
00?o0000o`0200000`000ol000020004o`00o`8000Co003o10000ol0003o008000040005o`000?l0
0P001?l00?l20003o`0000800ooo008000050004o`00o`8000Co003o0P000ol0003o00L000020004
o`00o`8000Co003o0P001?l00?oo00T0000300;o1002o`@00_oo00X0003o01/0003o01/00000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {10.8029, 46.2738, 0.403945, 
  0.915036}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sentences overview", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[interpretSentence/@bestSentences]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("OPVWVMQOUDZQQHOYOBMUJSWKL KC"\)},
          {\("QPUWSMSQUBXRQIOZJAIUHSTIKWF      C"\)},
          {\("QPVSSMSVYBXRQLOZJDIVGSUIKWFF"\)},
          {\("LLVONNQVYEWRQQLVJDIVGTUIKWKF"\)},
          {\("LIRNNNOUYFTRQQQSLGIVGOUIKWOF"\)},
          {\("MEUNONOPYFTRLVQSGGHVFOQHJRKF"\)},
          {\("MEUJKNOPYFPRLVQSDGCVFQQHGRKF"\)},
          {\("PAUJJPOMYFPVLVQSIGASFUTHBTKE"\)},
          {\("NDUJGMLK FQ IQTPIGAUFUTIBPJE"\)},
          {\("NDUNGOGO FQ JQTPHJBWFYSIASJI"\)},
          {\("MDZNGOGO FQ JSYPDJBWFYVHAQFK"\)},
          {\("MIVLGOGO FQ JSWLDJAXBY GARFK"\)},
          {\("MHVLGOGTXFQ JSWLDJFXBXYGDRFJ"\)},
          {\("MHVGIQFT JQ JSZLAJFXA  GCRFJ"\)},
          {\("QHVJIOFTXIQ JSWLFJFXA  BAQFJ"\)},
          {\("QHVJIOFTXIQYJSVLGLFXA YBARFO"\)},
          {\("NEQKIOFQVIQYJSVLHLF A YADRFO"\)},
          {\("JAQKIOFP IVYJTVJHJF A YCCUFN"\)},
          {\("NAQKJMJQ ISYJTVMHJF A WCBRDN"\)},
          {\("PASKIMGO KS HTVOGIF A XCBRDI"\)},
          {\("OAVHIMGO KU KTVNGIF AYXCBRDJ"\)},
          {\("OFVHGMKN IV KUVJGIF BZXABRDM"\)},
          {\("PFVJGNKN IV KVZJGIF B XEAWFN"\)},
          {\("RFVHGPKS HV KVZKFNHZB XEAXFN"\)},
          {\("RFVIKPKS FV KVZKFNHZAWXEAVFP"\)},
          {\("RFUIKPLS IV FVZKFIHYAWXEBSFO"\)},
          {\("RFUIKOLS GV KTZJFIHZAWWEAXBO"\)},
          {\("RFTEGPLS FX KQZMFIHZA YEAUBO"\)},
          {\("MGUEGPLS FT IQZRFIHZA  EDSAO"\)},
          {\("MFUFKPLPWJT IQYRIHGZA WIDSEK"\)},
          {\("MEUHKPLPWHTWGTYRIMF D WIDSEK"\)},
          {\("LEUHFLLPWHTXJTYMIOF D WIDSEI"\)},
          {\("LEUHFNLRYHSXJTZMIOF EXWKDSHI"\)},
          {\("OIUGHMLRYJUXJUZLFOF EXWHASHI"\)},
          {\("OIUGHMLRYJU JU LJMF E WHASCI"\)},
          {\("OIUGLMLR JU JU LLMF A VCASCI"\)},
          {\("KETJKLGS JT JT LLMF B ZCAOCK"\)},
          {\("MITJKNJPZJT IT LJJI B YCBQCK"\)},
          {\("MEXJKNJO HP KTZJJLG B YGBQDK"\)},
          {\("MEXJKNJO HP LWZJJLG A VGBQDN"\)},
          {\("MDXJKNJQ HP LWZKJLD AYVGCNCK"\)},
          {\("ODXJKNKT HR HU KILD DYWICSCK"\)},
          {\("ODXEJNKT HRZKUYKMLD BYVJCSCJ"\)},
          {\("MDWIJNKW HM KUZKMLD BYVJASCK"\)},
          {\("MBUGJPNWZHP KQ KMLD BY GAUCI"\)},
          {\("MBUGJQMWZHPYMQ KMLD B WGAVCI"\)},
          {\("HGUGJLNTZHPYMQ KHLFXB UFAVCM"\)},
          {\("HGSGILNTVHPYMT KHLCXCZUFAVCK"\)},
          {\("HGSGJLNTVHPYMTXKHLCXC UFCVCJ"\)},
          {\("HGSGJLNWZHSYNTVKHLC CVUGCVCK"\)},
          {\("MGSFJLNXZMQZIQVKLLF CVUGCQCO"\)},
          {\("MGUFJLNXZMQ LQVKMLF AXUGCQDN"\)},
          {\("NGUFJONSYMQ LQVMMLF A UEGQAN"\)},
          {\("NGUFJLNSYJO JV MMLE A WHFNAN"\)},
          {\("JHUJJLLSYJOZJVZMMNE A WCBNAO"\)},
          {\("JJVJJLLVYKSZJVYMINB A VDBNFO"\)},
          {\("JHTJKLLT IVXFQYIINF A VDBNFO"\)},
          {\("NDTJKLLT IVXKQYIJNF A VABPFL"\)},
          {\("NDTJKLLT IVXKQ JJNF A VABUFK"\)},
          {\("NDTJLPKTVIRXKQ JJLFYA VCBUFK"\)},
          {\("KDRJLPKTWIQZIR JJMFYC VBAUCK"\)},
          {\("KGRJLKKTWIQZIU JJMC C VCAUBK"\)},
          {\("KGVJLJKTWIQ IU MJICYA SEAUAK"\)},
          {\("JCVJJLKTWIQXLU MHJE A SEATBK"\)},
          {\("JCVJJPKTWIR LU MHGJ A WEATBK"\)},
          {\("JCUEJLKTZIR LU IDKE A  EAUDK"\)},
          {\("JDUIJLHTZIR JS IIOE A  IATDK"\)},
          {\("ODUIGLMTYIT JU IIQE D VIATDK"\)},
          {\("KDPIGLMOYIQ JU ILLA D XGATDK"\)},
          {\("KAPIGLLO IQ JUXMLLA C XGATDK"\)},
          {\("OAPIGMLRZLV JUWMLLE C XFATDO"\)},
          {\("ODPEIMLV JV LUWNLLE C YBAQEJ"\)},
          {\("ODNEIMLV JV LUWNILE C YBASEK"\)},
          {\("OIREGMLV JVYNUZNILE C YAASCK"\)},
          {\("OIRJGMLV JVZNQ NILEWC YEAUAK"\)},
          {\("OIRHGMLV IV NVYNILFWC YGAUAJ"\)},
          {\("ODRHFMLV IT NWYNHLF C  GAUAO"\)},
          {\("TDRHFRLQ IR NT NHJF CZ GASDJ"\)},
          {\("PDRHFRLTYIR NT NIJF C YEAQDJ"\)},
          {\("PDRHFRLTYIR IT NHJG C YECQDJ"\)},
          {\("LDRHIRLPYHR ITYKGNG C YGCTDK"\)},
          {\("LDREIMKPXHU ITYKGKG AWTDFTDI"\)},
          {\("LGREINKRXHV IRYKHJG AWTFAYBI"\)},
          {\("LHRHJNKRXHT JOYKIMF AWTJAWBI"\)},
          {\("NHWCJNKRXHW JR KIMF AWTJAVCI"\)},
          {\("QIWCINLRXEW KS KIHF AYTEARCI"\)},
          {\("QISGINLVXEWWKS KKHF AYTEARCM"\)},
          {\("LDSGIPLWXIWWKS JKHF A SCBSCM"\)},
          {\("LISGIPLWZIWZHS KKHHXB SCBSCM"\)},
          {\("LEPGIPKW IWZHRYMHHHXBZUCBTCM"\)},
          {\("PEPGINJX HWZHP IHMD BZUDBTAN"\)},
          {\("PIPGILJV IWZHP LHHG AZUDATFO"\)},
          {\("LIRGILJTVFW HN LHHG AZUDATFO"\)},
          {\("PDWHNLJTVIX GR HHKG A YDATBP"\)},
          {\("ODWHNJJTWISZGR HIKG A  EATEL"\)},
          {\("OAWHKOJT ISZGO HIKG A  BBREL"\)},
          {\("RFWFGOMR ISZGO MKKG A  DBREI"\)},
          {\("NGWFGOJT IVZGOWMKJC A  DAUEL"\)},
          {\("NGWFIQJT IVZGOYMKJC A  BEUEL"\)},
          {\("NGSFIQJR IVZJOYMKJA A  EEUEL"\)},
          {\("NGSFIMIR IWZMPYOKJC A  EAVGK"\)},
          {\("NGUFELJR ITZMP OKMCZAZ EAQGI"\)},
          {\("NGUFGMLR IT MQ PKMAZBZVEAQHI"\)},
          {\("NGUFGQLR IT LV PKIAZAZVCAQCI"\)},
          {\("NGUFGNIR FTZKT PKMAZA SCAQCI"\)},
          {\("NBSFHNIR HTZKT OIME AWSCAQAI"\)},
          {\("NCSFHNIT JT KSVNIME AWSCAQAI"\)},
          {\("KCSEHNIT JT GSVNHNE AWTBAPAK"\)},
          {\("KCSEHKJT JTZGSYKGNE AWXBAPAO"\)},
          {\("KASEGMMQ JTYHSZKGNA AWXAAPFN"\)},
          {\("NASIGMMQ JSYHS KDJC A SECPEP"\)},
          {\("NASIGMMQYJS HS KIJA A SECPEP"\)},
          {\("KASIFKMQYIW GT KIJA CYVCCPEN"\)},
          {\("HASIFKMQYIW GS KIMC EY CBUGN"\)},
          {\("LAUIGLMQ IU GS KIMC EY CBQIN"\)},
          {\("LDUIKLMV IU GS KIOC CY CFQIN"\)},
          {\("LDUIKLMS HU FR KHOC AX CAQIN"\)},
          {\("LDUILLMSXHU FR GHOC AXZCAQEN"\)},
          {\("LEUJKLMSXHU GT LMOA AX GAPEN"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {"OPVWVMQOUDZQQHOYOBMUJSWKL KC", "QPUWSMSQUBXRQIOZJAIUHSTIKWF      C", 
        "QPVSSMSVYBXRQLOZJDIVGSUIKWFF", "LLVONNQVYEWRQQLVJDIVGTUIKWKF", 
        "LIRNNNOUYFTRQQQSLGIVGOUIKWOF", "MEUNONOPYFTRLVQSGGHVFOQHJRKF", 
        "MEUJKNOPYFPRLVQSDGCVFQQHGRKF", "PAUJJPOMYFPVLVQSIGASFUTHBTKE", 
        "NDUJGMLK FQ IQTPIGAUFUTIBPJE", "NDUNGOGO FQ JQTPHJBWFYSIASJI", 
        "MDZNGOGO FQ JSYPDJBWFYVHAQFK", "MIVLGOGO FQ JSWLDJAXBY GARFK", 
        "MHVLGOGTXFQ JSWLDJFXBXYGDRFJ", "MHVGIQFT JQ JSZLAJFXA  GCRFJ", 
        "QHVJIOFTXIQ JSWLFJFXA  BAQFJ", "QHVJIOFTXIQYJSVLGLFXA YBARFO", 
        "NEQKIOFQVIQYJSVLHLF A YADRFO", "JAQKIOFP IVYJTVJHJF A YCCUFN", 
        "NAQKJMJQ ISYJTVMHJF A WCBRDN", "PASKIMGO KS HTVOGIF A XCBRDI", 
        "OAVHIMGO KU KTVNGIF AYXCBRDJ", "OFVHGMKN IV KUVJGIF BZXABRDM", 
        "PFVJGNKN IV KVZJGIF B XEAWFN", "RFVHGPKS HV KVZKFNHZB XEAXFN", 
        "RFVIKPKS FV KVZKFNHZAWXEAVFP", "RFUIKPLS IV FVZKFIHYAWXEBSFO", 
        "RFUIKOLS GV KTZJFIHZAWWEAXBO", "RFTEGPLS FX KQZMFIHZA YEAUBO", 
        "MGUEGPLS FT IQZRFIHZA  EDSAO", "MFUFKPLPWJT IQYRIHGZA WIDSEK", 
        "MEUHKPLPWHTWGTYRIMF D WIDSEK", "LEUHFLLPWHTXJTYMIOF D WIDSEI", 
        "LEUHFNLRYHSXJTZMIOF EXWKDSHI", "OIUGHMLRYJUXJUZLFOF EXWHASHI", 
        "OIUGHMLRYJU JU LJMF E WHASCI", "OIUGLMLR JU JU LLMF A VCASCI", 
        "KETJKLGS JT JT LLMF B ZCAOCK", "MITJKNJPZJT IT LJJI B YCBQCK", 
        "MEXJKNJO HP KTZJJLG B YGBQDK", "MEXJKNJO HP LWZJJLG A VGBQDN", 
        "MDXJKNJQ HP LWZKJLD AYVGCNCK", "ODXJKNKT HR HU KILD DYWICSCK", 
        "ODXEJNKT HRZKUYKMLD BYVJCSCJ", "MDWIJNKW HM KUZKMLD BYVJASCK", 
        "MBUGJPNWZHP KQ KMLD BY GAUCI", "MBUGJQMWZHPYMQ KMLD B WGAVCI", 
        "HGUGJLNTZHPYMQ KHLFXB UFAVCM", "HGSGILNTVHPYMT KHLCXCZUFAVCK", 
        "HGSGJLNTVHPYMTXKHLCXC UFCVCJ", "HGSGJLNWZHSYNTVKHLC CVUGCVCK", 
        "MGSFJLNXZMQZIQVKLLF CVUGCQCO", "MGUFJLNXZMQ LQVKMLF AXUGCQDN", 
        "NGUFJONSYMQ LQVMMLF A UEGQAN", "NGUFJLNSYJO JV MMLE A WHFNAN", 
        "JHUJJLLSYJOZJVZMMNE A WCBNAO", "JJVJJLLVYKSZJVYMINB A VDBNFO", 
        "JHTJKLLT IVXFQYIINF A VDBNFO", "NDTJKLLT IVXKQYIJNF A VABPFL", 
        "NDTJKLLT IVXKQ JJNF A VABUFK", "NDTJLPKTVIRXKQ JJLFYA VCBUFK", 
        "KDRJLPKTWIQZIR JJMFYC VBAUCK", "KGRJLKKTWIQZIU JJMC C VCAUBK", 
        "KGVJLJKTWIQ IU MJICYA SEAUAK", "JCVJJLKTWIQXLU MHJE A SEATBK", 
        "JCVJJPKTWIR LU MHGJ A WEATBK", "JCUEJLKTZIR LU IDKE A  EAUDK", 
        "JDUIJLHTZIR JS IIOE A  IATDK", "ODUIGLMTYIT JU IIQE D VIATDK", 
        "KDPIGLMOYIQ JU ILLA D XGATDK", "KAPIGLLO IQ JUXMLLA C XGATDK", 
        "OAPIGMLRZLV JUWMLLE C XFATDO", "ODPEIMLV JV LUWNLLE C YBAQEJ", 
        "ODNEIMLV JV LUWNILE C YBASEK", "OIREGMLV JVYNUZNILE C YAASCK", 
        "OIRJGMLV JVZNQ NILEWC YEAUAK", "OIRHGMLV IV NVYNILFWC YGAUAJ", 
        "ODRHFMLV IT NWYNHLF C  GAUAO", "TDRHFRLQ IR NT NHJF CZ GASDJ", 
        "PDRHFRLTYIR NT NIJF C YEAQDJ", "PDRHFRLTYIR IT NHJG C YECQDJ", 
        "LDRHIRLPYHR ITYKGNG C YGCTDK", "LDREIMKPXHU ITYKGKG AWTDFTDI", 
        "LGREINKRXHV IRYKHJG AWTFAYBI", "LHRHJNKRXHT JOYKIMF AWTJAWBI", 
        "NHWCJNKRXHW JR KIMF AWTJAVCI", "QIWCINLRXEW KS KIHF AYTEARCI", 
        "QISGINLVXEWWKS KKHF AYTEARCM", "LDSGIPLWXIWWKS JKHF A SCBSCM", 
        "LISGIPLWZIWZHS KKHHXB SCBSCM", "LEPGIPKW IWZHRYMHHHXBZUCBTCM", 
        "PEPGINJX HWZHP IHMD BZUDBTAN", "PIPGILJV IWZHP LHHG AZUDATFO", 
        "LIRGILJTVFW HN LHHG AZUDATFO", "PDWHNLJTVIX GR HHKG A YDATBP", 
        "ODWHNJJTWISZGR HIKG A  EATEL", "OAWHKOJT ISZGO HIKG A  BBREL", 
        "RFWFGOMR ISZGO MKKG A  DBREI", "NGWFGOJT IVZGOWMKJC A  DAUEL", 
        "NGWFIQJT IVZGOYMKJC A  BEUEL", "NGSFIQJR IVZJOYMKJA A  EEUEL", 
        "NGSFIMIR IWZMPYOKJC A  EAVGK", "NGUFELJR ITZMP OKMCZAZ EAQGI", 
        "NGUFGMLR IT MQ PKMAZBZVEAQHI", "NGUFGQLR IT LV PKIAZAZVCAQCI", 
        "NGUFGNIR FTZKT PKMAZA SCAQCI", "NBSFHNIR HTZKT OIME AWSCAQAI", 
        "NCSFHNIT JT KSVNIME AWSCAQAI", "KCSEHNIT JT GSVNHNE AWTBAPAK", 
        "KCSEHKJT JTZGSYKGNE AWXBAPAO", "KASEGMMQ JTYHSZKGNA AWXAAPFN", 
        "NASIGMMQ JSYHS KDJC A SECPEP", "NASIGMMQYJS HS KIJA A SECPEP", 
        "KASIFKMQYIW GT KIJA CYVCCPEN", "HASIFKMQYIW GS KIMC EY CBUGN", 
        "LAUIGLMQ IU GS KIMC EY CBQIN", "LDUIKLMV IU GS KIOC CY CFQIN", 
        "LDUIKLMS HU FR KHOC AX CAQIN", "LDUILLMSXHU FR GHOC AXZCAQEN", 
        "LEUJKLMSXHU GT LMOA AX GAPEN"}]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation ...", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MapIndexed[
      Show[Graphics[
            Text["\<(\>"<>ToString[First[#2]]<>"\<) \>"<>
                interpretSentence[#1], {0, 0}], 
            DefaultFont \[Rule] {"\<Courier\>", 24}], 
          AspectRatio \[Rule] .1]&, bestSentences]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(1\\) OPVWVMQOUDZQQHOYOBMUJSWKL KC)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  AnimationCycleOffset->0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002og000_l400?o?`02o`@00ol500;o1003oo40
000L00;o6P02ofl02_ln00[o100:oo00000K00;o7002ofl01Ol200;o?`05o`800_l500Go0P02oo00
000K00;o7002ofl000?o0000A@000ol0000;0003o`000?H0000K00;o2@09o`X00_lI00Go1@08o`/0
0_l:00;o1002o`T00_l800Go0`05o`D01Ol900Go2`04o`H02?l700[o1`05o`T01Ol700Co0`04o`H0
1Ol800So2005o`D02_l500Go0`05o`H01?l800Ko1`02o`030?oo00?o1`02o`@00_l500Go1P02o`03
0?oo00_o4005o`H00_l500Go700001X00_l:00Wo2`02oaH02Ol300So2P04o`T00_l400;o2004o`L0
1Ol300Go0`09o`D02Ol700So100:o`D02_l500Wo1@09o`D01?l300Co1009o`H02?l600Wo0`0;o`@0
1Ol300Go1008o`@02Ol600[o1@02o`@00_l500Go1@03o`030?oo00_o4005o`D00ol300Wo6P0001X0
0_l>00;o3P02oaD00ol500?o1002o`h01?l800?o1003o`L01?l800;o1`02o`<00ol500?o0`03o`D0
0ol600;o1002o`D00_l400Co1@02o`D00_l400?o1@03o`<00ol500?o1@02o`D00_l400?o1@03o`P0
0_l800?o1@03o`@00_l500?o1002o`L00_l500;o1002o`@00ol400?o1@03o`D00ol300?o1003o`H0
0_l500?o1@02o`H00_lB00;o1@03o`<00ol500?o6@0001X00_l>00;o3P02oaD00_l700;o1002o`h0
1?l800Co0`03o`L01?l800;o1`02o`<00_l700;o0`02o`L00_l500;o1P02o`@00_l600;o1@03o`@0
0_l400;o1`02o`<00_l700;o1@02o`D00_l400;o1`02o`P00_l800;o1`02o`@00_l600;o1002o`L0
0_l400;o1P02o`<00_l600;o1@02o`L00_l300Co0`03o`H00_l500;o1P02o`H00_lB00;o1@02o`@0
0_l700;o6@0001X00_l>00;o3P02oa@00_l900;o0`02o`d00_l200;o1`04o`801?l600;o0P02o`L0
0_l300;o0P02o`800_l900;o00<0ool02@02o`@00_l600;o1002o`L00_l500?o0`02o`<00_l900;o
00<0ool02@02o`@00_l500;o0`02o`T00_l700;o1`02o`T00_l300;o1P02o`@00_l300;o0P02o`@0
0_l600;o0`02o`H00_l500;o1`02o`<01?l200Co1P02o`@00_l700;o1P02oa800_l400;o1003ob80
000J00;o3P02o`h00_lD00;o2@02o`<01ol800;o0P02o`L00_l0103o0004o`H00_l200;o1`02o`80
0ol200;o0P02o`T00_l00`3oo`0900;o1002o`H00_l400;o1`02o`H00_l300;o0`02o`T00_l00`3o
o`0900;o1002o`D00_l300;o2@02o`L00_l700;o2@02o`<00_l600;o1002o`800ol200;o1002o`H0
0_l300;o1P02o`d00ol300;o00@0o`001?l600?o0P03o`L00_l600;o4P03o`800ol400;o8`0001X0
0_l>00;o3P02oa@00_l900;o0`09o`D00ol200?o1P02o`060?l00?l00_l500?o0P03o`H00_l20003
o`3o00800_l200;o2@02o`030?oo00T00_l400;o1P02o`@00_l700;o1P03o`L00_l900;o00<0ool0
2@02o`@00_l500;o0`02o`T00_l700?o1P02o`T00_l300;o1@03o`@00_l20003o`3o00800_l400;o
1P02o`/00_l800Oo1002o`060?l00?l00_l600Oo2002oaX01ol500;o8`0001X00_l>00;o3P02oa@0
0_l900;o0`02o`D00ol400;o1002o`H00_l00`3oo`02o`030?oo00D00_l400;o1P02o`040?oo00;o
00<0ool00P02o`T00_l00`3oo`0900;o1002o`H00_l400;o1`02o`L00ol600;o2@02o`030?oo00T0
0_l400Wo0`02o`T00_l600Co1P02o`T00_l300Wo1@02o`040?oo00;o00<0ool01002o`H00_l;00;o
1P07o`H00_l00`3oo`02o`030?oo00H01Ol:00;o6P05o`L00_lS00006`02o`d00_l=00;o5@02o`T0
0_l300;o1P02o`@00_l400;o1P02o`030?oo00;o00<0ool01@02o`@00_l600;o00<0ool00P001?l0
ool200;o2@02o`030?oo00T00_l400;o1P02o`@00_l700;o0`02o`<00_l600;o2@02o`030?oo00T0
0_l400Wo0`02o`T00_l500Ko1@02o`T00_l300So1P02o`030?oo008000Co0?oo1002o`H00_l;00;o
1@03o`/00_l00`3oo`02o`030?oo00H00_l0103oool900;o6P02o`040?ooo`H00_lS00006`02o`d0
0_l=00;o5@02o`T00_l300;o1P02o`<00_l600;o1002o`<00_l300;o0`02o`H00_l500;o00<0o`00
0P001?l0ool200?o2002o`030?oo00T00_l400;o1P02o`@00_l700;o0`02o`<00ol500?o2002o`04
0?ooo`P00_l400;o1@02o`<00_l900;o1@02o`800_l500;o2@02o`<00_l400?o1@02o`030?l00080
00Co0?oo1002o`H00_l;00;o1@02o`L000Co00000_l300;o0`02o`D00_l200?o2002oaX00_l200?o
1@03o`L00_lI00006`03o``00_l=00;o5P02o`L00_l400;o1P02o`<00_l600;o1002o`<00_l300;o
0`02o`H00_l500Co0`04o`<00_l700;o0`02o`L00_l500;o1P02o`@00_l600;o1002o`@00ol500;o
1`02o`<00_l700;o1@02o`D00_l400;o1`02o`D00ol300;o1@02o`L00_l400;o1@02o`D01?l300Co
1002o`H00_l;00;o1@02o`H00_l300;o0`02o`<00_l500;o0`03o`L00_lJ00;o0`03o`D00_l700;o
6@0001`00_l<00;o3002oaL00ol500?o1002o`D00ol200?o1P03o`<00_l800;o0P03o`H00ol400Co
1003o`@00_l500;o1003o`D00ol500;o1P02o`@00_l400Co1002o`D00_l600;o1@02o`D00_l500;o
1P02o`D00_l400?o1@03o`D00_l400;o1@03o`D00ol400;o1003o`D01?l400?o1002o`H00_l;00;o
1@03o`@00ol300;o2002o`D00_l400?o1P02oaX00_l400?o1003o`D00olI00007@02o`L00ol00`3o
o`0;00;o6@09o`<02ol200Ko0P06o`030?oo00Co0P0<o`801_l200Co1@04o`<02Ol500Wo1@04o`@0
1?l200[o1@0:o`D02Ol500Wo1@04o`<01?l400Wo1005o`801Ol400Wo0`0:o`D01?l500Co0P04o`@0
1?l500[o0`09o`801_l200Ko0P05o`<01Ol00`3oo`06oaD01Ol300Go0`0:oaT0000N0003o`0000D0
1_l;0003o`0001X01Ol500Wo1006o`801_l00`3oo`04o`803?l200Ko0P04o`D01?l500Go2@05o`L0
1?l400Co0P08o`L02_l700Go2@05o`L01?l300Co1P05o`H01Ol200Go1P05o`D02Ol600Co1@04o`80
1?l400Co1@0:o`D01Ol0103o0006o`801_l200Go0`05o`030?oo00Ko5@05o`<01Ol500Go00<0ool0
6@0002T00ooo0<h0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(2\\) QPUWSMSQUBXRQIOZJAIUHSTIKWFC)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?oF`02o`@00olo00;o1003oo40
000L00;o6P02oaT02_mJ00[o?P0:oo00000K00;o7002oaT01Ol200;oF`05o`800_lo00Go0P02oo00
000K00;o7002oaT000?o0000H@000ol000150003o`000?H0000K00;o200:o`X00_lI00Go1@08o`/0
1?l800;o1002o`D00_l00`3oo`03o`H01Ol300Go0P02o`030?oo00?o2@05o`/01?l500[o1@05o`80
1Ol200Go1P03o`@01Ol700[o1`05o`L02_l500Ko1@06o`<01_l200[o2004o`L01?l300Co0`02o`03
0?oo00?o1`08o`H02_l300Go1P02o`@00_l400;o1007o`/01OlL00006P02o`T02_l;00;o5P09o`<0
2?l900So1P02o`@00_l500[o1005o`<01Ol200[o1@09o`L02?l300_o1005o`801Ol200Go1@04o`80
2Ol500[o1@09o`D02_l300Wo1006o`<01_l200[o1P08o`D01?l300Co0`0:o`D02?l600[o0`05o`D0
0ol400;o1002o`@01ol900Wo6P0001X00_l:00;o1@02o`/00_lE00?o1@03o`@00_l=00;o1002o`D0
0ol400?o1003o`D00ol400;o1`02o`<00ol500?o0`03o`D00ol600;o1002o`D00_l500?o1003o`@0
0ol500;o1@03o`<00ol500?o2002o`P00ol500?o1@02o`D00_l300?o1003o`D00_l700;o2002o`X0
0_l400;o1P02o`D00_l400?o1@03o`L00_l=00;o2@02o`D00ol400?o1003o`D00_l;00?o1@03oaT0
000J00;o2`03oa000_lE00;o1`02o`@00_l<00;o1P02o`@01?l300?o1002o`L00_l400;o1`02o`<0
0_l700;o0`02o`L00_l500;o1P02o`@00_l600;o1@03o`800ol600;o1@02o`@00_l700;o2002o`P0
0_l700;o1@03o`@00_l300;o1P02o`D00_l700;o2002o`T00_l600;o1@02o`D00_l400;o1`02o`L0
0_l=00;o2@02o`D00_l500Co0`03o`D00_l;00;o1`02oaT0000J00;o3003o`l00_lD00;o2@02o`<0
0_l<00;o1P02o`@01?l200Co1002o`L00_l400;o0`02o`800_l300;o1`02o`800_l900;o1002o`H0
0_l400;o1P02o`H00_l200;o1`02o`@00_l400;o2@02o`L00_l700;o2@02o`D00ol300;o0`02o`H0
0_l500_o2002o`T00_l600;o1@02o`D00_l400;o1`02o`L00_l=00;o2@02o`@00_l600Co0P04o`D0
0_l200;o1P03ob80000J00;o3@03o`h00_lD00;o2@02o`<01ol700;o1P02o`@00_l0103o0004o``0
0ol400;o0P03o`800_l;00?o0P02o`T00_l400;o1P02o`@00_l600;o1`04o`P00_l300?o1002o`T0
0_l700;o1`02o`T00_l600;o0`02o`<00_l600;o1P09o`T00_l900;o1P02o`D00_l500;o3003o`L0
0_l=00;o2@03o`800ol600;o00@0o`001?l500;o0P02o`H00_lS00006P02o`h00ol=00;o5002o`T0
0_l300Wo1@02o`H00_l400;o00H0o`00o`02o`L01ol500;o0P000ol0o`0200;o1P07o`<00_l900;o
1002o`H00_l400;o1@03o`L01?l800Oo1@02o`T00_l700;o1`02o`T00_l600?o3`02o`H00_l500;o
2@02o`T00_l600;o1@02o`D00_l700Oo2002o`d00_l900Oo1`02o`060?l00?l00_l500Ko1P02ob<0
000J00;o3`03o``00_lD00;o2@02o`<00_l500?o1002o`H00_l400;o00<0ool00_l00`3oo`0500Oo
1`02o`040?oo00;o00<0ool01007o`D00_l900;o1002o`H00_l400Wo2003o`T02Ol300;o2@02o`L0
0_l700;o2@02o`L00ol>00;o1`02o`<00_l:00;o2@02o`H00_l500Wo1@07o`X00_l=00;o2@05o`T0
0_l00`3oo`02o`030?oo00D01_l600;o8`0001/00_l?00;o2`02oaD00_l900;o0`02o`H00_l400;o
1P02o`@00_l00`3oo`02o`030?oo00@00ol<00;o00<0ool00P001?l0ool300?o2P02o`T00_l400;o
1P02o`@02?l900Co2002o`D00ol200;o2@02o`L00_l700;o2@02o`<00_l300;o3P02o`L00_l300;o
2P02o`T00_l600;o1@09o`@00ol:00;o0`02o`<00_l800;o2@02o`040?ooo`P00_l00`3oo`02o`03
0?oo00D00_l200;o1P02ob<0000K00;o4002o`X00_lE00?o2002o`<00_l600;o1002o`H00_l300;o
0`02o`<00_l300;o1`000ol0000300;o00<0o`000P001?l0ool300;o1`001?l00003o`P00_l400;o
1P02o`@00_l400?o1`06o`L00_l600;o0P03o`P00_l700;o1`02o`T00_l300;o0`03o`d00_l800;o
00@0oooo2P02o`T00_l600;o1@02o`D00_l400;o1`001?l00002o`<00_l300;o2002o`T00_l200?o
1P02o`<00_l300;o1002o`800_l200;o0P03o`L00_lI00006`03o`l00_l:00;o5P02o`L00_l400;o
1P02o`@00_l600;o0`02o`<00_l300;o0`02o`H00_l500Co0`04o`<00_l600;o1002o`L00_l500;o
1P02o`@00_l500;o1P03o`800ol600;o1P02o`<00_l700;o2002o`P00_l700;o1002o`@00ol<00;o
2002o`030?oo00/00_l900;o1P02o`D00_l500;o1002o`H00_l300;o0`02o`<00_l800;o2@02o`<0
0ol500;o0`02o`<00_l400;o1P02o`<00_l700;o6@0001`00_l800;o1@02o`T00_lH00;o1@02o`D0
0_l500?o1002o`H00_l300;o2002o`<00ol400?o1@04o`@00ol300?o1003o`D00_l500;o1P02o`H0
0_l400;o1003o`H00_l400;o1P02o`D00ol400;o1@02o`T00_l800?o1@03o`@00_l500;o3002o`P0
1Ol;00;o2@02o`H00_l500;o1@02o`@00ol400?o0`02o`<00_l300;o2002o`T00_l400?o1002o`P0
0_l400;o1P02o`<00ol500?o6@0001d00_l700?o0`03o`P00_lI00Wo0`0;o`@01?l400Co00<0ool0
1?l200Ko0`09o`@01?l500Co0`09o`D02Ol500Co1004o`030?oo00So1@05o`801Ol200_o1@09o`D0
2_l500Wo1@0:o`H02_l200Oo200:o`@01?l400Co0`04o`<01?l400Wo0`0<o`@02_l300Go0`05o`03
0?oo00Co0P06o`030?oo00[o100:oaT0000N0003o`0000H01ol90003o`0001X01Ol500Wo1P04o`@0
1?l00`3oo`04o`801_l500Go00<0o`000`04o`D01?l500Go00<0o`001P05o`L01?l400Co00<0ool0
1ol600Go0P05o`802Ol900Go1`0:o`L01Ol700[o1P0:o`801ol800[o1004o`@01?l300Co0`04o`H0
1Ol00`3o000200co100:o`<01Ol300Go00<0ool01?l200Ko00<0ool02_l600Go00<0ool06@0002P0
1Ooo0<d0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(3\\) QPVSSMSVYBXRQLOZJDIVGSUIKWFF)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002oaX00_l400?oX`02o`@00ooa00007002oaX0
0_lI00[oXP0:oo00000K00;o7002oaT01Ol200;oX`05o`800_o`00006`02oa`00_lI0003o`000:T0
00?o0000mP0001/00_l:00Go3@02oaT01Ol500So2`02o`T00_l00`3oo`03o`H00_l00`3oo`03o`H0
1Ol300Go0P02o`030?oo00?o2P02o`X02?l400[o1@05o`801Ol200Go1P03o`@01Ol600go1@05o`L0
2_l500Ko1`08o`L02_l800;o3006o`D00_l00`3oo`03o`X01?l700[o0`05o`H00_l400;o1002o`@0
1ol700Oo7P0001X00_l900Wo3002oaH02Ol300So2P04o`P02_l400[o1005o`<01Ol200[o1`04o`T0
2?l400_o1005o`801Ol200Go1@04o`802Ol400go0`09o`D02_l300Wo1P0:o`D02_l700Co2@0:o`<0
2_l600So1@0:o`<01Ol500?o1002o`@00_l400Oo1`07oah0000J00;o2@02o`D00_l<00;o5@03o`D0
0ol400;o3P04o`P00ol500?o0`03o`D00ol400;o1`02o`<00ol500?o1P04o``00_l900;o1@03o`@0
0ol400?o1@02o`D00ol300?o1@03o`H00_l600;o0P03o`D00ol500;o1@02o`<00ol400?o1P02o`@0
1?l800;o2`04o`P01?l500;o0`03o`D00ol500;o1002o`T00_l900;o1@03o`@00ol400?o1@02o``0
0_lQ00006P02oa400_l;00;o5@02o`L00_l400;o3P04o`P00_l700;o0`02o`L00_l400;o1`02o`<0
0_l700;o1P04o``00_l900;o1P02o`D00ol200?o1P02o`D00_l400;o1`02o`H00_l600;o0P02o`L0
0_l500?o1002o`<00_l600;o1P02o`H00_l800;o2`04o`P00_l700;o0`02o`L00_l400;o1P02o`P0
0_l900;o1@02o`D01?l300?o1@02o``00_lQ00006P02oa400_l;00;o5002o`T00_l300;o3@02o`80
0_l700;o1`02o`<00_l700;o1002o`<00_l200;o0`02o`L00_l500;o0P02o`/00_l900;o1P02o`H0
0_l200;o1`02o`@00_l400;o2@02o`D00_l600;o00<0ool02@02o`D00ol300;o0`02o`H00_l600;o
1`02o`L00_l:00;o0P02o`H00ol700;o0`02o`L00_l400;o1P02o`P00_l900;o1002o`H01?l200Co
1@02o`800_l800;o0P02oad0000J00;o4@02o`/00_lD00;o2@02o`<01ol800;o0P02o`l00ol;00?o
1002o`800ol200;o2`03o`D00_l200;o2`02o`T00_l600;o1`04o`P00_l300?o1002o`T00_l500;o
1P02o`030?oo00T00_l600;o0`02o`<00_l600;o1P02o`L00_l700;o2P02o`800_l600;o1007o`X0
0ol400;o1P02o`P00_l900?o0P03o`H00_l0103o0004o`D00_l200;o2002o`800_lM00006P02oa00
0_l<00;o5002o`T00_l300Wo1@03o`800ol900Oo1`07o`D00_l20003o`3o00800_l600Oo1@03o`80
0ol:00?o2002o`D00ol700Co2007o`D00_l900;o1@02o`T00_l900;o1P03o`l00_l600;o1`02o`L0
0_l900?o0P03o`D00_l400Oo1@07o`D00_l600;o2002o`T01ol700;o00H0o`00o`02o`D01_l800Ko
7@0001X00_l=00Co3@02oa@00_l900;o0`02o`D00ol400;o1002o`L01ol700Oo1`02o`040?oo00;o
00<0ool01007o`L00_l400;o2@04o`P02Ol800?o2@09o`<00_l900;o1@02o`T00_l900;o1`03o`h0
0_l600;o1`02o`L00_l900;o1002o`D00_l>00Oo1`02o`H00_l800;o2@05o`T00_l00`3oo`02o`03
0?oo00D01_l800Ko7@0001/00_l<00?o3@02oaD00_l900;o0`02o`H00_l400;o1002o`H00ol;00?o
3002o`030?oo008000Co0?oo0`03o``00_l400;o2006o`L02?l900Co2002o`D00ol200;o2@02o`D0
0_l900;o2@02o`<00_l300;o3P02o`H00_l700;o1`02o`T00_l400;o1@02o`d00ol<00;o1P02o`P0
0_l900;o00@0oooo2002o`030?oo00;o00<0ool01@02o`800_l800;o0P02oad0000K00;o3P02o``0
0_lE00?o2002o`<00_l600;o0`02o`H00_l500;o1`000ol0000200;o1`000ol0000300;o00<0o`00
0P001?l0ool300;o1`000ol0000200;o1P02o`L00_l200;o1`02o`@00ol700Ko1`02o`H00_l200?o
2002o`D00_l900;o2@02o`<00_l300?o3@02o`H00_l700;o1`02o`P00_l600;o1002o`P00_l300;o
1`000ol0000300;o1P02o`P00_l900;o0P03o`H00_l300;o0`02o`@00_l200;o0P02o`@00_l200;o
0P02oaT0000K00?o3P02o`/00_lF00;o1`02o`@00_l600;o0`02o`H00_l500;o1P02o`@00_l600;o
1@04o`<01?l300;o1P02o`@00_l600;o1P03o`<00_l600;o1@02o`H00ol200?o1P02o`H00_l300;o
1`02o`H00_l:00;o1`02o`@00_l400?o3002o`H00_l600;o2002o`P00_l600;o1@02o`H00ol300;o
1P02o`D00_l600;o2002o`T00_l300?o1@02o`<00_l300;o1002o`H00_l400;o1P02oaT0000L00;o
3P02o`X00_lH00;o1@02o`D00_l500?o0P03o`H00ol400?o1003o`@00ol400?o1@04o`@00ol300?o
1003o`<00ol600?o1@02o`@00_l600;o1003o`H00_l400;o1P02o`D00ol400;o1@02o`L00_l:00?o
1@03o`@00_l500;o3002o`H00_l400Co2002o`L00ol600?o1003o`@01?l300?o1003o`D00_l600;o
2002o`T00_l400?o1002o`P00_l400;o1P02o`@00_l600;o6@0001d00_l700;o0`03o`T00_lI00Wo
0`0;o`801_l200Ko1009o`D02Ol400Co1@04o`<02Ol200Ko0P06o`801Ol200Go0P0:o`D01Ol200Go
0P0;o`D02Ol400So2009o`D02_l600[o0P0:o`D02_l200Ko0P06o`@02_l400Wo1004o`@01?l300[o
0`05o`<01Ol00`3oo`04o`801_l00`3oo`0:o`803?lI00007P000ol0000500Oo2P000ol0000J00Go
1@09o`@01_l200Ko1P05o`030?l000H01Ol00`3o000300Co1@04o`D01Ol0103o0006o`801_l200Go
0P05o`802Ol600Go0P05o`802Ol900Go1P08o`X01Ol700[o1P0:o`802?l700[o0P06o`801_l600Go
00<0ool01P05o`030?l000<01?l400Co0`0:o`<01Ol300Go00<0ool01?l200Ko00<0ool02_l200co
6@0002P01?oo0<h0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(4\\) LLVONNQVYEWRQQLVJDIVGTUIKWKF)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002og000_l400?oC@02o`@00ol600;o1003on80
000L00;o6P02ofl02_m<00[o1@0:on40000K00;o7002ofl01Ol200;oC@05o`800_l600Go0P02on40
000K00;o7002ofl000?o0000D`000ol0000<0003o`000>L0000K00;o3006o`X00_lE00go00<0ool0
2ol600;o3005o`H01_l300;o1006o`<00_l600Go2P02o`X02?l400co1@02o`@00_l400Go1P03o`@0
1Ol:00Go1@0=o`L00_l900Ko1`08o`L02_l800;o3006o`H02?l900Co1`0:o`<01Ol600;o1002o`@0
0_l400Go1P02o`030?oo00Go7P0001X00_l=00Ko2`02oa@03Ol00`3oo`0;o`D01?l900Wo1006o`80
0ol400Ko0P03o`@02Ol700Co2@08o`@03?l500;o1002o`@01Ol500Co0P09o`H02Ol300go1P04o`H0
2Ol600[o1@0:o`L01?l900[o1008o`L02?l500[o0`05o`D00ol400;o1002o`@01Ol500?o00<0ool0
1OlN00006P02o`l00_l=00;o5`02o`H00_l400;o1P02o`D01?l800?o1@03o`@00_l400Co1@02o`@0
1?l300?o1@03o`H01?l<00;o2@02o`H00_l400?o1003o`D00_l500?o0`03o`D00ol400?o1@03o`D0
0_l600;o1P04o`H00ol400?o1P02o`@01?l800;o2`04o`P01?l500;o1`02o`X00_l400;o2@02o`T0
0_l500?o1003o`@00ol500;o1@03o`@00_lQ00006P02o`l00_l=00;o5`02o`H00_l400;o1P02o`D0
1?l800;o1`02o`@00_l400Co1@02o`@01?l300;o1`02o`H01?l<00;o2@02o`H00_l400Co0`03o`D0
0_l500;o1002o`L00_l400;o1`02o`D00_l600;o1P04o`H00_l600;o1P02o`H00_l800;o2`04o`P0
0_l700;o1`02o`T00_l600;o2002o`T00_l500;o1@04o`<00ol500;o1@02o`D00_lQ00006P02o`T0
2_l;00;o5`02o`H00_l400;o1P02o`@00_l200;o1P02o`T00_l300;o0`05o`D00_l300Go0P02o`T0
0_l400;o0P02o`/00_l900;o0P02o`800_l400Co0P04o`D00_l400;o1002o`T00_l200;o2@02o`@0
0_l600;o1@02o`800_l500;o1P02o`H00_l700;o1`02o`X00_l200;o1P03o`L00_l700;o2@02o`H0
0_l800;o2@02o`@00_l600Co0P04o`D00_l400;o1P02o`800_lM00006P02o`T02_l;00;o5`02o`H0
0_l400;o1P02o`@00_l200;o1P02o`T00_l300;o0`02o`030?oo00D00_l300;o00<0ool00P02o`T0
0_l400;o0P02o`/00_l900;o0P02o`P00_l0103o0004o`D00_l300?o1002o`T00_l200;o2@02o`@0
0_l600;o1@02o`800_l500;o1P02o`H00_l700;o1`02o`X00_l200;o1P02o`@01ol600;o2@02o`H0
0_l800;o2@03o`800ol600;o00@0o`001?l500?o0P03o`H00_l200;o7@0001X00_l900;o1002o`d0
0_lG00;o3002o`/00ol200?o1@02o`T00_l300;o0P03o`030?oo00D00_l200?o00<0ool00P02o`T0
0_l300?o0P03o`X00ol800Ko2002o`060?l00?l00_l500Oo1@02o`T00_l200;o2@02o`@00_l<00?o
0P03o``00_l600;o1`02o`L00_l900?o0P03o`D00_l400Oo1P02o`T00_l600;o2002o`T01ol700;o
00H0o`00o`02o`D01ol700Ko7@0001X00_l:00;o0`02o`d00_lG00;o3002o`/00_l400;o1@02o`T0
0_l300;o0P02o`800_l500;o0P02o`800_l200;o2@02o`<00_l400;o2@04o`P01_l800;o00<0ool0
0_l00`3oo`0500Wo0`02o`T00_l200;o2@02o`@00_l<00;o1002o``00_l600;o1`02o`L00_l900;o
1002o`D00_lA00;o2@02o`H00_l800;o2@05o`T00_l00`3oo`02o`030?oo00D01Ol900Ko7@0001/0
0_l:0004o`0000;o3002oaP00_l<00;o2`02o`@00_l500;o2@02o`<00_l00`3oo`0300;o1@02o`03
0?oo00<00_l200;o2@02o`<00_l400;o2006o`L00_l200;o2002o`030?oo00;o00<0ool01@02o`D0
0ol200;o2@02o`800_l900;o1002o``00_l400;o3002o`H00_l700;o1`02o`T00_l400;o1@02o``0
0_l300;o0`02o`@00_l600;o2002o`T00_l0103oool800;o00<0ool00_l00`3oo`0500;o00@0oooo
2002o`800_lM00006`02o`X00_l200;o3002oaP00_l<00;o2P02o`H00_l400;o2@02o`<01Ol300;o
1@05o`<00_l200?o2002o`800_l600;o1`02o`800_l700;o0P02o`800_l300;o0`02o`<00_l400;o
1P02o`800ol800;o0P03o`P00_l400;o2`02o`H00_l;00;o1P02o`L00_l700;o2002o`H00_l400;o
2002o`800_l300;o0`02o`@00_l600;o2002o`T00_l200?o1P02o`<00_l300;o1002o`800ol700;o
0P02o`800_lI00006`03o`X000?o00000_l<00;o6002o``00_l:00;o1P02o`D00_l700;o1004o`@0
0_l500Co1002o`<00_l700;o0`02o`H00_l600?o0`02o`H00_l600;o0`02o`<00_l300;o1002o`H0
0_l300;o1`02o`@00_l700;o1@02o`/00_l600;o2`02o`H00_l600;o2002o`P00_l600;o1@02o`H0
0ol200;o0`02o`<00_l400;o1P02o`P00_l900;o0`03o`D00_l300;o0`02o`@00_l300?o1P02o`H0
0_lI00007002o`/000Co0?oo2`02oaT00_l<00;o2@03o`H00ol400?o1@03o`@01?l400;o1@04o`@0
0_l400;o1@02o`<00ol600?o1@02o`@00_l600;o1P02o`<00_l800;o1002o`D00ol400;o1@02o`H0
0_l500;o1P02o`X00ol600?o2P02o`H00_l400Co2002o`L00ol600?o1003o`@01?l200;o0`02o`<0
0_l400;o1P02o`P00_l900;o1003o`@00_l800;o1002o`@00ol500;o1P02oaT0000M00;o2P04o`X0
0_lG00So1P08o`D01_l200Ko1009o`@01?l200Ko0`04o`801_l300Wo0P06o`801_l200Go0P05o`80
3?l200Ko0P06o`030?oo00Wo1@09o`H02Ol300So1P06o`801_l400[o0P0:o`D02_l200Ko0P06o`@0
2_l200co0`04o`@01?l300[o0`05o`<01Ol00`3oo`04o`801_l00`3oo`03o`<01Ol00`3oo`0:oaT0
000N0003o`0000T00ol:0003o`0001H02?l600So1@06o`801_l600Go1P03o`<01_l300?o0`06o`D0
1Ol400Ko0P06o`801Ol200Go0P0<o`801_l200Ko00<0ool01ol900Go2P05o`D02?l600Ko0P06o`@0
2_l200So1`0:o`801_l200Ko1P05o`030?oo00803?l300Co1004o`<02_l300Go0`05o`030?oo00Co
0P06o`030?oo00?o0`05o`030?oo00[o6@0002X00ooo0<d0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(5\\) LIRNNNOUYFTRQQQSLGIVGOUIKWOF)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002olH00_l400?o1P02o`@00ol500;o1003om@0
000L00;o6P02olD02_l500[o100:om<0000K00;o7002olD01Ol200;o1P05o`800_l500Go0P02om<0
000K00;o7002olD000?o000030000ol0000;0003o`000=T0000K00;o2P05o`d00_lE00go0P0:o`<0
1Ol600?o0P06o`<00_l300Ko0`02o`@01_l300;o1P05o`X01?l800So1007o`X02?l400Go1P03o`@0
1Ol:00Go2@05o`L00_l00`3oo`03o`D03Ol500Ko1P0:o`P00_l<00Ko2005o`X01?l700[o0`05o`H0
0_l400;o1002o`P01Ol500Oo7P0001X00_l900Wo3002oa@03Ol200[o0`05o`D01?l200Ko0P03o`<0
1_l200?o1006o`800ol400Wo1P08o`H02?l400Oo2P08o`@01Ol500Co0P09o`H02Ol500Wo1@0:o`<0
3Ol300[o100:o`L01?l900[o1009o`H02?l500[o0`05o`D00ol400;o1002o`H02Ol300Oo7P0001X0
0_l900;o1@02o``00_lG00;o1P02o`H00_l900;o1@03o`D00_l400Co1002o`@01?l500;o1004o`<0
0ol500?o1@02o`@00_l900;o2@02oa000_l900;o1@03o`<00ol500?o1003o`D00ol300?o1@03o`@0
0ol500?o1@02o`H00_l200Co1@02o`P00_l;00Co2004o`D00_l300?o1@03o`D00_l400;o2@02o`T0
0_l500?o1003o`@00ol400?o1@03o`@00_lQ00006P02oa400_l;00;o5`02o`H00_l600;o2@02o`D0
0_l600;o1004o`@00_l400Co1@02o`@01?l300;o1`02o`@00_l600;o2002o`T00_l@00;o2@02o`D0
0_l400;o1`02o`@00_l700;o0`02o`L00_l400;o1`02o`D00_l600;o0P02o`L00_l800;o2`04o`P0
0_l700;o0`02o`L00_l400;o1P02o`P00_l900;o1@02o`D01?l300?o1002o`L00_l400;o8@0001X0
0_lA00;o2`02oaL00_l600;o1P02o`T00_l400;o1`02o`<01Ol400;o0`05o`D00_l300Go0P02o`T0
0_l300;o1P02o`P00_l900;o0P02o``00_l900;o1002o`@00_l900;o0P02o`T00_l00`3oo`0900;o
0`02o`L00_l500;o1P02o`040?ooo`L00_l800;o2P02o`800_l600?o1`02o`800_l900;o0`02o`H0
0_l800;o2@02o`@00_l600Co0P04o`<00_l900;o0`02o`800_lM00006P02oa400_l;00;o5`02o`H0
0_l600;o2@02o`<00ol700;o0`02o`030?oo00@00_l300;o00<0ool01@02o`<00_l00`3oo`0200;o
2@02o`<00_l600;o2002o`T00_l200;o3002o`T00_l300?o1002o`T00_l200;o2@02o`030?oo00T0
0_l;00?o1@02o`H00_l00`3oo`0400Oo1`02o`X00_l200;o1P02o`@01ol00`3oo`0900;o0`02o`H0
0_l800;o2@03o`800ol600;o00@0o`001?l300;o2@02o`<00_l200;o7@0001X00_lA00;o2`02oaL0
0_l>00;o2@07o`P00_l200?o00<0ool01002o`800ol00`3oo`0500;o0P03o`030?oo00800_l900;o
0`02o`H00_l800?o2006o``00_l900Oo1@02o`T00_l200;o2@02o`030?oo00T00_l600Oo1P02o`T0
0_l400Oo1`02o`T00ol200?o1@02o`@01ol00`3oo`0900;o0`02o`H00_l800;o2@07o`L00_l01P3o
003o00;o0`02o`T00_l300Ko7@0001X00_l:00;o1002o``00_lG00;o3P02o`T02Ol600;o0P02o`80
0_l400;o0P02o`800_l500;o0P02o`800_l200;o2@02o`<00_l600;o1`04o`P01_l<00;o2@09o`<0
0_l900;o0P02o`T00_l00`3oo`0900;o1007o`P00_l900;o4P02o`T00_l400;o1@02o``00_l900;o
0`02o`H00_l800;o2@05o`T00_l00`3oo`02o`030?oo00<00_l900;o0`06oad0000K00;o2@08o`/0
0_lH00;o3P02o`T00_l500?o1@02o`030?oo00<00_l400;o00<0ool00`02o`D00_l00`3oo`0300;o
0P02o`T00_l300;o1P02o`H01_l700;o0P02o`L00_l300;o0`02o`@00_l500?o0P02o`T00_l200;o
2@02o`030?oo00T00_l300?o3@02o`T00_lB00;o2@02o`@00_l500;o3002o`T00_l300;o1P02o`P0
0_l900;o00@0oooo2002o`030?oo00;o00<0ool00`02o`T00_l300;o0P02oad0000K00;o2@07o``0
0_lH00;o3P02o`T00_l600;o1@05o`<00_l400Go0`02o`D01Ol300;o0P02o`T00_l300;o1P02o`H0
0_l200;o1`02o`800_l200;o0`02o`<00_l300;o1002o`H00_l200?o2002o`800ol800;o00@0oooo
2002o`<00_l70003o`0000@00_l900;o2002o`P00_l800;o1P02o`@00_l800;o0P02o`T00_l300;o
1P02o`P00_l900;o0P03o`H00_l300;o0`02o`800_l900;o0`02o`800_l200;o6@0001/00ol800;o
4@02oaP00_l>00;o2@02o`H00_l500Co1002o`@01?l400;o1@04o`@00_l300;o1`02o`@00_l600;o
1@03o`<00_l600;o1P02o`<00_l300;o0`02o`@00_l600;o0`02o`L00_l400;o1`02o`<00_l700;o
1002o`H00_l600;o2P02o`H00ol800;o2002o`H00_l500;o1P03o`<00_l700;o1002o`H00_l800;o
2@02o`<00ol500;o0`02o`<00_l300;o1`02o`@00_l600;o6@0001`00_l800;o4002oaT00_l>00;o
2@02o`D00ol500Co1002o`@01?l400;o1@04o`@00_l300?o1@03o`@00_l600;o1@02o`@00_l600;o
1P02o`<00_l300;o0`02o`@00_l500?o1002o`D00_l600;o1@02o`D00_l500;o1@03o`@00ol600;o
2P03o`@01?l800;o1`03o`H00ol400?o1004o`<00ol500?o1002o`H00_l800;o2@02o`@00ol400;o
2002o`<00ol500?o1002o`H00_lI00007@02o`L00_l?00;o5`08o`L02_l300_o1@04o`801_l200Co
0P06o`<01?l200Ko0`09o`@01?l400Co0P05o`801Ol200co0`0<o`802ol500Wo1P09o`D02Ol600Wo
0`08o`P02_l400[o0P06o`801_l400[o1009o`@01?l400Co0`0:o`<01Ol300Go00<0ool01?l200Ko
0`09o`<03?lI00007P000ol0000500So2@000ol0000F00So1`0:o`<02Ol700?o0`06o`800ol300Ko
0`03o`<01_l500Go1P04o`@01?l200Go0P05o`803?l300co0P09o`T01Ol:00Go2@05o`X01Ol00`3o
000200So2P05o`030?oo00@02_l200Ko0P06o`H01Ol00`3oo`0600Go1P04o`@01?l300[o0`05o`<0
1Ol00`3oo`04o`801_l500Go1@0<oaT0000V00Soo`3<0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(6\\) MEUNONOPYFTRLVQSGGHVFOQHJRKF)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002on<00_l400?oJP02o`@00omQ00007002oaX0
0_oR00[oJ@0:of00000K00;o7002on801Ol200;oJP05o`800_mP00006`02oa`00_oR0003o`000700
00?o0000IP0001/00_l;00Co3@02oaD01Ol300Go00<0ool02_l700Co1`06o`<00_l600Go1`06o`<0
0_l600Go1@08o`T02?l400Oo2P08o`@01Ol6013o1`02o`/01Ol700;o00<0ool00ol900Ko2006o`H0
1?l300Co1`02o`P01ol;00Go2@05o`L01?l300Co1006o`L01Ol600So1P02o`030?oo00Go7P0001X0
0_l;00Oo3002oa@01Ol300Go00<0ool02_l500So1@06o`800ol400Wo1@06o`800ol400Wo0`08o`T0
2?l400Oo2P08o`@01Ol5017o1P04o`P02Ol500[o1@0:o`@02_l400Co0`04o`H01?l700Oo2@09o`D0
2Ol500Co0`04o`802Ol600Go1@09o`D00ol00`3oo`05oah0000J00;o2P02o`@00_l<00;o5@02o`L0
0_l400;o1P02o`D00_l400;o1P02o`@01?l300?o1@03o`D00_l400Co0`03o`D00ol400;o4002o`T0
0_l@00;o2@02o`D00ol500;o1P02o`H01?l700?o1@03o`@00ol500?o0`04o`D00_l300Co1@02o`D0
0_l500;o1`04o`T00_l;00?o1@03o`<00ol500?o1@02o`D00_l300?o1003o`L00_l500?o1002o`D0
0ol400;o8@0001X00_l900;o1P02o`/00_lE00;o1`02o`@00_l600;o1002o`H00_l500;o1004o`<0
0_l700;o1@02o`@01?l300;o1`02o`@00_l@00;o2@02oa000_l900;o1@02o`H00_l600;o1P04o`L0
0_l700;o1002o`L00_l300;o1`02o`<00_l700;o1@02o`D00_l700Co2@02o`/00_l700;o0`02o`L0
0_l500;o1@02o`<00_l600;o1`02o`D00_l500;o1@02o`D00_lQ00006P02o`T00_l600;o2`02oaD0
0_l300;o0P02o`@00_l200;o0P02o`@00_l600;o1@02o`<01Ol200;o2@02o`@00_l300Go0P02o`T0
0_l300;o4002o`T00_l200;o3002o`T00_l400;o1`02o`H00_l500;o0P02o`D00_l900;o0`02o`L0
0_l200?o1`02o`800ol700;o1@02o`D00_l600;o0P02o`P00_l200;o1P02o`T00_l00`3oo`0900;o
1002o`D00_l300;o1P02o`L00_l400;o1P02o`@00_l600;o0P02oad0000J00;o2@02o`H00_l;00;o
5@02o`800ol200;o1002o`800_l800;o1P02o`D00_l300;o00<0ool00P02o`T00_l400;o0`02o`03
0?oo00800_l900;o0`07o`/00_l900;o0P02o``00_l900;o0`03o`L00_l600;o1@02o`800_l500;o
2@02o`/00ol200;o1007o`030?oo00@01ol400;o1@02o`H00_l200;o2002o`800_l600;o2@02o`03
0?oo00T00_l400;o1@02o`<00_l600;o1`02o`<00ol600?o0P03o`H00_l200;o7@0001X00_l900;o
1P02o`/00_lE00;o0P000ol0o`0200;o1006o`P00_l600;o1@02o`800ol00`3oo`0200;o2@02o`@0
0_l200?o00<0ool00P02o`T00_l300Wo2@03o`P01_l<00;o2@07o`P00_l<00?o0P03o`@00_l900;o
1P07o`<00_l400Oo00<0ool01007o`@00_l500;o1@03o`800ol700Ko1P02o`T00_l00`3oo`0900;o
1002o`D00_l;00;o1`07o`L01ol700Ko7@0001X00_l900?o1002o``00_lE00;o00@0ool00_l00`3o
o`0400Ko2002o`H00_l500;o0P02o`800_l200;o2@02o`@00_l200;o0P02o`800_l900;o0`02o`D0
0ol700Co2006o``00_l900Wo1P02o``00_l400;o1002o`T00_l400Oo1@02o``00_l?00Wo1@02o`@0
0_l700Ko1P02o`T00_l00`3oo`0900;o1009o`/00_l700Wo1@05o`T01_lM00006`02o`P02Ol;00;o
5P02o`030?oo008000Co0?oo1002o`800_l800;o1P02o`D00_l00`3oo`0300;o0P02o`T00_l400;o
00<0ool00`02o`800_l900;o0`02o`H00_l600Ko1`02o`800_l700;o0`02o`<00_l400;o1@03o`D0
0_l<00;o1002o`@00_l900;o0`03o`X00_l<00;o3`09o`D00_l400;o1`02o`800_l600;o2@02o`03
0?oo00T00_l400Wo2`02o`L00_l500?o1002o`040?ooo`P00_l200;o7@0001/00_l800;o00<0ool0
0_l=00;o5P02o`030?l0008000Co0?oo1002o`800_l200;o1002o`H00_l500Go0`02o`800_l900;o
1005o`<00_l200;o2@02o`<00_l600;o1P02o`800_l700;o0P02o`800_l300;o0`02o`<00_l400;o
1P02o`D00_l;00;o1P02o`<00ol800;o0`02o`L000Co00000_l800;o0P02o`P00_l500;o1@02o`@0
0_l600;o1P02o`800_l200;o0P02o`T00_l0103oool800;o1002o`D00_l;00;o1`02o`H00_l400;o
0P03o`L00_l200;o0P02oaT0000K00?o2002oa400_lF00Co0`04o`@00_l600;o1002o`H00_l500Co
1002o`<00_l700;o1@04o`@00_l300;o1`02o`@00_l600;o1@03o`<00_l600;o1P02o`<00_l300;o
0`02o`@00_l600;o1@02o`/00_l600;o1002o`L00_l400;o1P02o`@00_l600?o0`02o`H00ol500;o
1@02o`@00_l600;o1P02o`H00_l300;o1`02o`<00_l700;o1@02o`D00_l;00;o1`02o`H00_l400;o
0`03o`H00_l600;o6@0001`00_l800?o3`02oaL01?l400?o1002o`H00_l400;o1P02o`D01?l400;o
0`03o`D00ol500Co1002o`<00ol500?o1002o`D00ol500;o1002o`H00_l600;o0`02o`<00_l300;o
1002o`D00ol500;o2P03o`H00ol400;o1@02o`D00ol400?o1003o`@01?l300?o1004o`D00_l500;o
0`03o`H00ol500;o1P02o`<00ol500?o1002o`D00_l600;o1@02o`/00_l700;o1@03o`@00_l400?o
1@02o`H00_lI00007@02o`P00ol=00;o5`04o`D01?l00`3oo`0:o`<01?l400Co0`04o`801_l300Wo
1@04o`801_l300Wo0`0;o`@01Ol200Go0P0<o`<03?l200_o0`08o`H01_l200Ko0`09o`H02Ol500[o
100:o`@01?l300Co00<0ool01?l200Ko0P0<o`@02Ol500Wo1@04o`<01?l500[o0P0;o`<01Ol300Go
00<0ool02_lI00007P000ol0000700Oo20000ol0000F00Co1@04o`030?oo00[o0`04o`@01?l300?o
0`06o`D01Ol700?o0`06o`D01Ol500Wo1P05o`801Ol200co0`0<o`802Ol500So1P06o`801_l500Go
2P05o`030?l000H01Ol00`3oo`0600Go00<0ool01004o`<01?l00`3oo`04o`801_l200co1P05o`T0
1Ol700Co0`04o`D02_l200Wo1@05o`<01Ol00`3oo`0:oaT0000Z00Goo`3;0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(7\\) MEUJKNOPYFPRLVQSDGCVFQQHGRKF)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002on<00_l400?oG002o`@00ol500;o1003of40
000L00;o6P02on802_mK00[o100:of00000K00;o7002on801Ol200;oG005o`800_l500Go0P02of00
000K00;o7002on8000?o0000HP000ol0000;0003o`0006H0000K00;o2`02o`l00_lE00Go0`05o`03
0?oo00[o1`04o`P01_l600Go1P02o`<01_l300;o1P05o`D02?l900So1007o`P02?l600Go1P0@o`L0
0_l;00Go1`02o`030?oo00?o1P08o`T01_l900Go2P02o`P01ol;00Go2@05o`L01?l300Co1P06o`D0
1Ol600So1P02o`030?oo00Go7P0001X00_l<00;o4002oa@01Ol300Go00<0ool02_l500So1009o`D0
1Ol500?o0`06o`800ol400Wo0`08o`T02?l400Oo2008o`H01Ol5017o1P04o`P02Ol500[o100:o`D0
2_l500Wo1`04o`L01ol900Wo1@09o`D01?l300Co100:o`<01Ol500Wo1@03o`030?oo00Go7P0001X0
0_l=00;o3`02oaD00_l700;o1002o`H00_l500;o1002o`@00ol400?o1P02o`D00ol500;o1004o`<0
0ol500?o1002oa000_l900;o3@02o``00_l500?o1@02o`H00_l600Co1`03o`D00ol400?o1@03o`@0
0_l400Co0`04o`D00_l400?o1@03o`H01?l900;o2`03o`D00ol300?o1@03o`D00_l500;o1004o`D0
0_l500;o1@03o`@00_l500?o1002ob40000J00;o3@02o`l00_lE00;o1`02o`@00_l600;o1002o`H0
0_l300;o1P02o`H00_l500;o1P02o`@01?l300;o1`02o`@00_l@00;o2@02o`d00_l<00;o1@02o`H0
0_l600;o1P04o`L00_l700;o1002o`L00_l400;o1P02o`<00_l700;o1002o`L00_l600Co2@02o`/0
0_l700;o0`02o`L00_l500;o1@02o`@00_l700;o1@02o`D00_l500;o1@02o`D00_lQ00006P02o`d0
0_l?00;o5@02o`<00_l200;o1002o`800_l200;o1002o`H00_l300;o1P02o`H00_l400;o1`02o`<0
1Ol200;o2@02o`<00_l@00;o2@02o`800_l900;o3002o`@00_l700;o1P02o`D00_l200;o1@02o`T0
0_l300;o1`02o`@00_l700;o00@0oooo1`02o`<00ol>00;o0P02o`P00_l200;o1P02o`T00_l00`3o
o`0900;o1002o`D00_l300?o1`02o`D00_l400;o1P02o`@00_l600;o0P02oad0000J00;o3P000ol0
000=00;o5@02o`800ol200;o1002o`800_l800;o1P02o`<00_l600;o1P03o`800ol700;o0`02o`03
0?oo00800_l900;o0`07o`/00_l900;o0P02o`T01ol700;o0`03o`L00_l600;o1@02o`800_l500;o
2@02o`/00ol400;o1`02o`030?oo00@01ol200;o3`02o`800_l800;o0P02o`H00_l900;o00<0ool0
2@02o`@00_l500;o0`02o`@01ol400;o0`03o`H00ol200?o1P02o`800_lM00006P02o`h00_l>00;o
5@02o`8000?o0?l00P02o`@01_l800;o1P02o`/00_l600Oo2002o`800ol00`3oo`0200;o2@02o`<0
2Ol900?o2006o`T02Ol500Oo2002o``00ol200?o1002o`T00_l600Oo1@02o`L00_l00`3oo`0400Oo
0P02o`h00ol200?o1`06o`H00_l900;o00<0ool02@02o`@00_l500;o0`02o`@01ol400Oo1`07o`L0
1_lM00006P02o`h00_l>00;o5@02o`040?oo00;o00<0ool01006o`P00_l600;o2`02o`H01Ol:00;o
0P02o`800_l200;o2@02o`<00_l500?o1`04o`P01_l900;o1@03o`@02Ol600;o3002o`@00_l400;o
2@02o`@01ol700;o1`02o`030?oo00d00_l>00;o1002o`L01_l600;o2@02o`030?oo00T00_l400Wo
0`02o`l02Ol500Go2@06oad0000K00;o3P000ol0000;00;o5P02o`030?oo008000Co0?oo1002o`80
0_l800;o1P02o`/00_l600;o00@0oooo2@02o`030?oo00<00_l200;o2@02o`<00_l600;o1P06o`L0
0_l200;o2@02o`H00_l400;o1@03o`D00_l<00;o1002o`@00_l900;o0`03o``00_l700;o00<0ool0
3@02o`h00_l400;o1`02o`800_l600;o2@02o`030?oo00T00_l400Wo0`02o`l00_l500?o1002o`04
0?ooo`P00_l200;o7@0001/00_l>00;o3002oaH00_l00`3o00020004o`3oo`@00_l200;o0P02o`@0
0_l600;o2`02o`H00_l200?o2005o`<00_l200;o2@02o`<00_l600;o1P02o`800_l700;o0P02o`80
0_l500;o1P02o`@00_l600;o1@02o`/00_l600;o0`03o`P00_l300;o1`000ol0000300;o1`02o`03
0?oo00P00_l300?o1`02o`<00_l600;o1P02o`800_l200;o0P03o`P00_l0103oool800;o1002o`D0
0_l300;o2002o`D00_l600;o1002o`800ol700;o0P02o`800_lI00006`03o`d00_l<00;o5P04o`<0
1?l400;o1P02o`@00_l600;o2`02o`H00_l300?o1`04o`@00_l300;o1`02o`@00_l600;o1@03o`<0
0_l600;o1P02o`D00_l600;o1002o`H00_l500;o2`02o`H00_l400;o1`02o`@00_l600;o1@02o`H0
0_l300;o1P03o`@00_l700;o0`02o`H00_l600;o1P02o`<00_l700;o0`02o`L00_l500;o1@02o`@0
0_l600?o1@02o`H00_l400;o0`03o`H00_l600;o6@0001`00_l>0003o`0000T00_lG00Co1003o`@0
0_l600;o1002o`H00_l;00;o1P02o`@00ol600Co1002o`<00ol500?o1002o`D00ol500;o1002o`H0
0_l600;o1@02o`D00ol400;o1@03o`D00_l:00?o1P03o`@00_l500;o1@03o`@00ol500;o1004o`<0
0ol400Co1003o`D00ol200?o1P03o`D00_l600;o1002o`D00_l500;o1@02o`H00_l500;o1003o`@0
1?l500;o1@03o`@00_l400?o1@02o`H00_lI00007@02o`H00_l500;o2@02oaL01?l500Co00<0ool0
2_l300Co1004o`D02_l00`3oo`03o`<01Ol300Co0P06o`<02Ol300_o1005o`801Ol200co0`0;o`<0
2ol300So1P06o`801_l300Wo1P09o`@02_l500[o1@0:o`030?oo00Co0P06o`803?l400Wo1@09o`D0
1?l300Co100:o`<02ol300Go0`05o`030?oo00[o6@0001h000?o00001009o`T000?o00005P04o`D0
1?l00`3oo`0:o`<01?l400Co1@0:o`030?oo00?o0`05o`<00ol300Ko1@05o`D02Ol600Go0P05o`80
3?l300Wo1@09o`D02?l600Ko0P06o`D01Ol:00Go00<0o`000`08o`T01Ol00`3oo`0700Go00@0ool0
1_l200Ko0P0<o`H01Ol900Go1`04o`<01?l600Go00<0ool00`09o`D01Ol300Go00<0ool02_lI0000
9@09ool0c0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(8\\) PAUJJPOMYFPVLVQSIGASFUTHBTKE)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002on<00_l400?oe00001`00_lJ00;ohP0:om<0
000K00;o7002on801Ol200;od`0001/00_lL00;ohP000ol0003I00006`02o`/01?l=00;o5@08o`D0
1_l300Ko1@04o`P01_l800Ko1`08o`X01Ol500Go0`05o`@02?l400Oo2008o`/00_l700go1`02o`/0
1Ol700;o00<0ool00ol600[o1`06o`@01_l300Ko00@0ool01Ol600Oo3004o`L02?l600Co0`04o`80
2_l700So1005o`H00_l00`3oo`0:oaT0000J00;o2P08o``00_lD00So1@06o`<01_l300So1009o`D0
2Ol600So2009o`<01Ol300Go1008o`@01ol800So2P04o`H03Ol600Co2009o`D02_l400[o1@0:o`80
1_l300Ko00<0ool02?l400Oo2P08o`D02?l600Co0`04o`802ol600So1005o`D00ol00`3oo`0:oaT0
000J00;o2@03o`@00ol;00;o5P02o`/00_l700;o1@02o`@00_l400?o1003o`@00ol400?o1`02o`/0
0ol500?o0`02o`L00_l800;o2@02o`d00_l>00Co2@02o`H00_l600Co1`03o`D00ol400?o1@03o`L0
0_l800Co1@02o`@00_l700;o0`03o`D00ol500;o3@02o`@00_l800;o2P02o`D00_l500;o1@03o`P0
0_l900;o1@03o`@00_l600;o6@0001X00_l900;o1P02o`/00_lF00;o2`02o`L00_l400;o1P02o`<0
0_l600;o1002o`H00_l700;o2`02o`L00_l300;o1`02o`P00_l900;o3@02o`h01?l900;o1P02o`H0
1?l700;o1`02o`@00_l700;o1`02o`P00_l700;o1002o`L00_l300;o1`02o`D00_l<00;o1P02o`L0
0_l:00;o1@02o`D00_l600;o2002o`T00_l500;o1@02o`H00_lI00006P02o`T00_l600;o2`02oaH0
0_l;00_o1002o`H00_l300;o1P02o`@00_l600;o1`02o`X00_l900;o0P02o`<00_l200;o2002o`T0
0_l200;o2@02o`d00_l200;o2002o`H00_l500;o0P02o`D00_l900;o0`02o`L00_l700;o1`03o`L0
0_l400_o0`02o`L00_l500;o0P02o`P00_l600;o1`02o`X00_l500;o1@02o`H00_l800;o2@02o`@0
0_l600;o0P02o`800_lI00006P02o`T00_l600;o2`02oaH01ol700Wo1@02o`H00_l300;o1P02o`@0
0_l600;o1`07o`D00_l900;o0P02o`800ol200;o2002o`T00_l200;o2@07o`P00_l200;o2002o`H0
0_l500;o0P02o`D00_l900;o2`03o`L00_l700;o1007o`@02Ol<00?o1@02o`800_l800;o1P02o`L0
0_l:00;o1@02o`D00_l600;o2002o`T00ol200?o1P02o`800_lM00006P02o`X00_l400;o3002oaH0
2Ol500;o1@02o`D00_l600;o2`02o``00_l700Wo0`02o`T00_l200;o0P000ol0o`0200;o2003o`P0
1_l900Wo1@03o`800ol700;o3003o`800ol400;o2@02o`H01ol800;o1`02o`@01ol400;o1@02o`L0
1ol600Ko2002o`H00_l700;o2P02o`D00_l500;o1@03o`P00_l900Oo1`06oad0000J00;o2`07o``0
0_lF00;o1@03o`D00_l300;o1P02o`H00_l;00;o3002o`L00_l500?o0P02o`T00_l200;o00@0ool0
0_l00`3oo`0700Co2006o`T00_l500?o1002o`@00_l700;o3002o`@00_l400;o2@02o`@01ol:00;o
1`02oa000_l300;o1P07o`P01_l800;o1P02o`L00_l:00Wo1@09o`T00_l900Go2@06oad0000K00;o
2P06o``00_lG00;o1P02o`D00_l300;o1P02o`H00_l;00;o3002o`L00_l600;o0P02o`T00_l200;o
00<0ool00P001?l0ool600Ko1`02o`800_l900;o1P02o`@00_l400;o1`02o``00_l400;o1002o`T0
0_l300?o3`02o`L00_l@00;o0`02o`D00ol=00;o0P02o`P00_l600;o0P02o`<00_l300;o1@09o`D0
2?l500;o0`02o`<00_l400;o00@0oooo2002o`800_lM00006`02o`T00_l400;o2`02oaL00_l600;o
1P02o`040?ooo`H00_l600;o2`02o``00_l700;o1P02o`800_l900;o0P02o`030?l0008000Co0?oo
1P02o`800_l700;o0P02o`800_l500;o1P02o`<00_l600;o1P02o`/00_l600;o0`03o`P00_l300;o
1`000ol0000600;o1`02o`P00_l700;o00@0oooo1@02o`L000?o00001002o`800_l200;o1002o`H0
0_l200;o0`02o`<00_l500;o1@02o`D00_l400?o1002o`<00_l300;o1002o`800ol700;o0P02o`80
0_lI00006`03o`L00_l600;o2P02oaL00_l600;o1P02o`030?oo00L00_l600;o2`02o``00_l700;o
1P02o`<00_l700;o0`04o`<01?l500?o0`02o`H00_l600;o1@02o`H00_l300;o1P02o`H00_l;00;o
1P02o`@00_l700;o1002o`H00_l800;o2002o`H00ol700;o00<0ool01P02o`H00_l600;o1P02o`@0
0_l600;o0P02o`<00_l300;o1@02o`D00_l500;o1@02o`@00_l300;o0`02o`@00_l300?o1P02o`H0
0_lI00007002o`L00_l600;o2@02oaP00_l500?o1P05o`L00_l600;o2`02o``00_l700;o1@03o`<0
0ol500?o0`04o`@00ol500;o1002o`H00_l600;o1@02o`D00ol200?o1P03o`D00_l:00?o1P03o`@0
0_l500;o1@03o`@00ol800;o2003o`@01?l700Go1P03o`@00ol600;o1P02o`@00_l600;o0P02o`<0
0_l300;o1@02o`D00_l500;o1003o`@00_l300;o0`02o`@00_l400?o1@02o`H00_lI00007@02o`H0
0ol400?o2002oaL02ol400Oo1`04o`@01?l500[o100:o`802ol500Wo0`04o`D01?l200Go0P05o`80
3?l300_o0P06o`801_l00`3oo`06o`H01_l200Ko0`09o`H02Ol400[o1@0:o`@01ol800Wo100<o`<0
1?l400Co00<0ool02_l400Co0`04o`802_l500co0P05o`<01Ol00`3oo`0:oaT0000N0003o`0000D0
2?l90003o`0001H02Ol600Oo1`04o`@01?l500[o100:o`802Ol900Go1@04o`D01?l200Go0P05o`80
3?l300Wo1006o`801_l00`3oo`06o`H01_l200Ko1@05o`X01Ol00`3o000300[o1`05o`030?oo00@0
1ol:00Go00<0o`000`0<o`<01?l400Co00<0ool02_l400Co0`04o`802Ol600co0P05o`<01Ol00`3o
o`0:oaT0000W00Koo`3=0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(9\\) NDUJGMLK FQ IQTPIGAUFUTIBPJE)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001h000?o00005P000ol0003o0<00000M00;o6002ojX00_l400?o8P02o`@00ooR00007002oaX0
0_nY00[o8@0:on40000K00;o7002ojT01Ol200;o8P05o`800_oQ00006`02oa`00_nY0003o`0002P0
00?o0000i`0001/00_l800Go3`02oaH01_l300;o0`08o`X01?l800Ko2P06o`D01Ol300Go00<0ool0
2ol00`3oo`03o`H00_l@00Oo3005oa@02_l800Go1`08o`D02?l700[o1`06o`@01_l300Ko1@04o`H0
1ol<00Co1`08o`H02_l300[o1@08o`P01_l600co6@0001X00_l900Oo3P02oaD01_l200?o0`0:o`H0
2?l400Wo1`0:o`<01Ol300Go00<0ool02ol00`3oo`03o`D00ol@00Oo2P09oa802_l600Wo1@08o`D0
2?l700[o1@0:o`801_l300Ko0`08o`@01ol:00So1@08o`H02_l300_o1008o`H02Ol500co6@0001X0
0_l>00?o3@02oaH00_l400Co1002o`@01?l500;o1002o`@00ol400?o1@04o`D00_l400;o1`02o`D0
0_l600;o0`02o`D00olC00;o3003o`D00olE00;o2@03o`D00ol700;o2P02o`l00_l800Co1@02o`@0
0_l700;o1@02o`@00_l600;o3@02o`@00_l800;o3@02o`T00_l500?o1@02o`X00ol400?o1P02o`H0
0_lI00006P02o`l00ol<00;o5P02o`@01?l400;o1P02o`@00_l600;o0`02o`H00_l500;o1`02o`@0
0_l700;o1@02o`H00_l300;o1@02oa@00_l<00;o1`02oaD00_l900;o1`02o`L00_l:00;o3`02o`P0
0_l700;o1002o`L00_l400;o1P02o`D00_l<00;o1P02o`L00_l=00;o2@02o`H00_l500;o2P02o`H0
0_l600;o1P02oaT0000J00;o4002o``00_lF00;o0`05o`@00_l700;o0`02o`H00_l300;o1P02o`@0
0ol700;o1002o`<00_l200;o1@02o`H00_l300;o1002oaD00_l200;o1`02o`T00_lD00;o2002o`T0
0_l600;o2P02o`l00_l700?o1`02o`@02ol400;o1P02o`D00_l200;o2002o`H00_l700;o3@02o`T0
0_l600;o1@02o`X00_l600;o1P02o`800_l200;o6@0001X00_l<00Co00<0ool02`02oaH00_l300;o
00<0ool01002o`L00_l300;o1P02o`<00_l600;o1002o`@01ol300;o0P03o`800_l500;o1P02o`<0
0ol200?o5@02o`800_l700;o2@02oa@00_l800;o2@02o`H00_l:00Oo2P02o`L00_l400Oo1009o`D0
0_l600;o1@02o`800_l800;o1P02o`L00_l=00;o2@02o`H00_l500Oo1@02o`H00_l600;o0P02oad0
000J00;o2P09o`/00_lF00;o0P03o`030?oo00@00_l700;o0`02o`H00_l;00;o1002o`@01ol300;o
0P000ol0o`0200;o1@02o`/01olF00Ko1`02o`T00_lD00;o2002o`T00_l600;o2P09o`P00_l700;o
1007o`@00_l500;o1@02o`H00_l500Ko2002o`H00_l700;o3@02o`T00_l500?o1@09o`/00_l600Ko
7@0001X00_l:00;o1003o`/00_lF00;o0P02o`800_l400;o1`02o`<00_l600;o2`02o`@00_l>00;o
00@0ool00_l00`3oo`0500;o2`05oaP01_l700;o2@02oa@00_l800;o2@02o`H00_l:00;o1@03o`L0
0_l700;o4002o`<00_l600;o1P02o`D01_l800;o1P02o`L00_l=00;o2@09o`H00_l500?o2P02o`H0
1_lM00006`02o`P00_l600;o2P02oaL00_l00`3oo`0300;o1002o`L00_l300;o1P02o`/00_l400;o
3P02o`030?oo008000Co0?oo1@02o`/00_l0103ooolG00;o0P02o`L00_l900;o5002o`P00_l900;o
00<0ool00`02o`<00_l500;o1P02o`L00_l700;o4002o`<00_l600;o1P02o`D00_l200;o2002o`H0
0_l200;o0`02o`<00_l800;o2@08o`L00_l600;o2P02o`H00_l200;o7@0001/00_l800;o1P02o`X0
0_lG00Go0`02o`@00_l700;o0`02o`H00_l;00;o1002o`P00_l400;o00<0o`000P001?l0ool500;o
2`02o`800olF00;o0P02o`800_l300?o2002oa@00_l800?o2002o`030?oo00<00_l300;o1@02o`H0
0_l700;o1`02o`P00_l700;o00@0oooo1P02o`H00_l500;o0P02o`800_l400;o1P02o`800_l300;o
0`02o`P00_l900;o1003o`H00_l600;o2P02o`H00_l200;o0P02oaT0000K00?o1`02o`H00_l:00;o
5`04o`@00_l400;o1P02o`@00_l600;o2`02o`D00_l600?o1004o`<01?l500;o2`02o`<00olE00;o
1P02o`@00_l700;o5@02o`T00_l700;o0P02o`<00_l300;o1@02o`H00_l700;o2002o`H00ol700;o
00<0ool01`02o`H00_l500;o1P02o`@00_l600;o0P02o`<00_l300;o2002o`T00_l500;o1P02o`H0
0_l:00;o1P02o`H00_lI00007002o`L00_l60003o`0000P00_lH00Co1002o`@00_l400Co1002o`H0
0_l;00;o1@03o`@01?l400Co1003o`D00_l;00;o1003oa@00_l600;o1@02o`D00_lF00;o2P02o`D0
0_l300;o0`02o`<00_l500;o1@03o`L00_l800?o1004o`L01Ol700;o1P02o`D00_l600;o1002o`H0
0_l200;o0`02o`<00_l800;o2@02o`@00ol600;o1@03o`X00_l600;o1P02oaT0000M00;o1`02o`@0
0_l900;o6004o`801_l200[o1004o`@01?l500[o0`0:o`<01?l500Co00<0ool01_l600Go0`05oa00
3?l500Wo4P0:o`H02Ol300co0`0;o`@02_l500[o1007o`L01?l400Co0P0<o`<01?l400Co00<0ool0
2_l400[o0`0:o`D02ol600[o00<0ool02_lI00007P000ol0000500Oo2P000ol0000G00?o0`06o`80
2?l600Co1004o`D02_l500Go00<0ool00`04o`D01?l00`3oo`06o`H01Ol300Go400<o`L01OlD00[o
2005o`D03?l300Wo1P0:o`L01Ol00`3oo`0400Oo1`04o`@01?l200co0`04o`@01?l00`3oo`0:o`@0
2_l300Wo1P09o`P02_l00`3oo`0:oaT0000X00Coo`3>0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(10\\) NDUNGOGO FQ JQTPHJBWFYSIASJI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00ooK00005@02obP0
0_nY00[o8@0:omX0000D00;o:P02ojT01Ol200;o8P05o`800_oJ00005002obX00_nY0003o`0002P0
00?o0000h00001@00_l900Wo2004o``00_lF00Ko0`02o`<02?l;00Co1P06o`<00_l700Ko2005o`T0
1_l900Go5007o`/01OlF00Ko2P05o`P02?l400So1`04o`<01?l500Ko1P0:o`L00_l400;o1007o`T0
2?l600;o00<0ool00ol600[o0`06o`<01_l0103oo`05o`L01_l800[o4P0001<00_l:00Wo1`06o``0
0_lE00Ko0P03o`<02_l700So1006o`800ol500[o1009o`D02_l500Wo4P07o`T02OlB00Wo1`09o`H0
2?l400So1`04o`<01?l300Wo1@0;o`H00_l400;o1007o`T02?l600[o100:o`<01_l300Ko00<0ool0
2?l300Wo1`0:oa80000C00;o3P02o`T00ol200?o2`02oaH00_l400Co1002o`@01?l600;o1002o`D0
0_l400Co1004o`D00_l300?o1@03o`<01?l500;o1003o`D00olC00;o2`03o`D00olA00?o1003o`D0
0ol500?o2002o`T00_l<00;o1@02o`@00ol400?o1P02o`D00ol400?o1003o`D00_l?00;o2@03o`D0
0ol700;o2@02o`L00_l300?o1@03o`800ol400?o2P02oaH0000C00;o3P02o`T00_l400;o2`02oaH0
0_l400Co1002o`H00_l500;o1P02o`@00_l400Co1002o`L00_l300;o1`02o`<00_l700;o1002o`L0
0_lC00;o2`02o`L00_lA00;o1P02o`D00_l700;o2002o`T00_l<00;o1@02o`@00_l600;o1P02o`H0
0_l400Co0`03o`D00_l?00;o2@02o`L00_l700;o2@02o`L00_l300;o1`02o`800_l600;o2P02oaH0
000C00;o3P02o`P00_l600;o2P02oaH00_l300Go1002o`L00_l400;o1P02o`@00_l300Go0`03o`L0
0_l200;o2@02o`040?ooo`L00_l300;o2@02oa800_l200;o1P02o`T00_l@00;o1P02o`@00_l900;o
1`02o`T00_l<00;o1@02o`@00_l600;o1P02o`H00_l400Co0P04o`D00_l200;o2`02o`T00_l700;o
1`02o`T02ol300;o1`02o`800_l600;o2P02oaH0000C00;o3P02o`P00_l600;o2P02oaH00_l300;o
00<0ool01002o`L00_l400;o1P02o`@00_l300;o00<0ool00`02o`@01ol00`3oo`0900;o00<0ool0
1007o`800_l900;o4P02o`800_l600;o2@02oa000_l600;o1002o`T00_l700;o2@07o`L00_l500;o
1002o`H00_l600;o1P02o`@00_l0103o0004o`D00_l200;o2`02oa400ol700;o2P09o``00ol200;o
1P02o`X00_lF00004`02o`h00_l800;o1P02o`X00_lF00;o0P03o`030?oo00@00_l700;o1002o`H0
0_l400;o0P03o`030?oo00<00_l400Oo00<0ool02@02o`030?oo00@01ol200;o2@02oa801_l600;o
2@02oaP00_l400;o2@02o`L00_l900Wo1@02o`D00_l<00;o1P02o`D00ol400;o00H0o`00o`02o`D0
1_l;00?o2`07o`P00_l:00;o1@02o`L01ol;00;o2P02oaH0000C00;o3P02o`P00_l600;o2P02oaH0
0_l200;o0P02o`@00_l700;o1002o`H00_l400;o0P02o`800_l300;o3002o`T00_l00`3oo`0=00;o
2@02oa801_l600;o2@02oaP00_l400;o2@02o`L00_l900;o1@03o`@02Ol<00;o1P09o`D00_l00`3o
o`02o`030?oo00D01_l:00Co2@07o`X00_l;00;o0`02o`H01ol=00;o2P02oaH0000D00;o3@02o`P0
0_l600;o2@02oaL00_l00`3oo`0300;o1002o`L00_l400;o1P02o`@00_l00`3oo`0300;o0`02o``0
0_l900;o00<0ool03@02o`T00_lB00;o0P02o`H00_l900;o6002o`@00_l900;o0P02o`<00_l300;o
1002o`H00_l400Wo3002o`H02?l600;o00<0ool00_l00`3oo`0500;o0P02o`T01_l700?o3`02o`/0
0_l300;o1@03oa800_l:00;o5P0001@00_l=00;o2002o`H00_l900;o5`05o`<00_l400;o1`02o`@0
0_l600;o1005o`<00_l300;o2002o`800_l900;o00<0ool02002o`<00_l900;o4P02o`800_l200;o
0P03o`P00_lH00;o1003o`P00_l200;o0`02o`<00_l400;o1P02o`@00_l500;o3002o`H00_l400?o
1002o`<00_l300;o1002o`800_l200;o1@02o`800_l700;o1`000ol0000600;o3002o`040?ooo`D0
0_l70003o`0000T00_l:00;o5P0001@00ol<00;o2002o`H00_l900;o5`04o`@00_l400;o1P02o`D0
0_l600;o1004o`@00_l400;o1P03o`<00_l700;o0`02o`H00ol400;o1`02oa<00_l600;o0`02o`L0
0_lI00;o1@02o`L00_l300;o0`02o`<00_l400;o1P02o`@00_l500;o3002o`H00_l500;o1002o`<0
0_l300;o1002o`H00_l400?o0`02o`H00_l600;o2002o``00_l00`3oo`0600;o1P02o`/00_l:00;o
5P0001D00_l<00;o2@02o`@00_l900;o6004o`@00_l400;o1004o`D00_l600;o1004o`@00_l400?o
1004o`<00ol500?o0`03o`@01?l400?o1@03oa<00_l600;o1002o`D00_lJ00;o1P02o`D00_l400;o
0`02o`<00_l400;o1@03o`@00_l500;o3002o`H00_l400?o1002o`P00_l400;o1P02o`@00_l400;o
1P03o`@00ol800;o3005o`H00ol400?o2`02o`X00_lF00005P02o`L00ol00`3oo`0900?o0P03o`P0
0_lH00Co0P06o`802_l500Co1004o`801?l200Ko100:o`@02Ol500[o1@09oa803?l400Wo5@0:o`<0
2Ol400co0P0;o`@01?l300Co1P0:o`030?oo00So1006o`801_l00`3oo`0:o`801Ol200Go1@09o`@0
2_l500Oo2009o`H02_l300[o4P0001L000?o00001@06o`X01_l90003o`0001L00ol300Ko0P08o`L0
1?l400Co0P03o`<01_l600Go00<0ool01P05o`T01Ol00`3oo`0700Go500<o`H01OlG00[o1@05o`H0
3?l200Wo1P04o`<01?l600[o00<0ool01ol500Ko0P06o`030?oo00[o0P05o`801Ol700Go00<0o`00
0`0:o`D01ol:00Go00<0o`001@0:o`<02_lB00008P03o`/01?oo0<H0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(11\\) MDZNGOGO FQ JSYPDJBWFYVHAQFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oc`02o`@00ol^00005@02obP0
0_nY00[ocP0:obd0000D00;o:P02ojT01Ol200;oc`05o`800_l]00005002obX00_nY0003o`000=D0
00?o0000<`0001@00_l900Wo1P09o`T00_lE00Go0`05o`802?l700[o1006o`<00_l700Ko2005o`T0
1_l900Go5007o`/01OlF00Ko1`02o`030?oo00?o2008o`@02?l700So2006o`H02_l700;o1002o`@0
1ol900So2P02o`P01?l300Co0P06o`<01_l400Go1@07o`P01Ol600;o400001<00_l:00Wo1P09o`X0
0_lD00Go0`05o`802_l500[o1006o`800ol500[o1009o`D02_l500Wo4P07o`T02OlB00Wo1P0:o`H0
2?l400So1`0:o`@02Ol500_o1P02o`@00_l400Oo2@08o`T01?l700Co0`04o`801_l300Ko0P09o`<0
1ol800Go1@03oa00000C00;o3P02o`d00_l=00;o5@02o`L00_l400;o1004o`D00_l500;o1@02o`@0
1?l400Co1@02o`<00ol500?o0`04o`D00_l400?o1@03oa<00_l;00?o1@03oa400ol400?o1@03o`D0
0ol800;o2@02o``00_l400Co0`03o`@00ol600;o1@03o`@00ol400?o1@02o`l00_l<00Co2002o`D0
0_l500;o1`02o`<00ol500?o1002o`d00_l500?o4@0001<00_l>00;o3@02o`d00_lE00;o1`02o`@0
0_l600;o1@03o`@00_l500;o1004o`@00_l700;o0`02o`L00_l300;o1`02o`@00_l700;o4`02o`/0
0_l700;o4@02o`H00_l500;o1`02o`P00_l900;o3002o`H00_l300;o1P02o`H00_l600;o1004o`<0
0ol500;o3`02o``01?l800;o1@02o`D00_l700;o0`02o`L00_l400;o3@02o`D00_lB00004`02o`h0
0_l=00;o3@02oaD00_l300;o0P02o`@00_l700;o1@03o`<00_l500;o0`05o`<00ol700;o0P02o`T0
0_l0103oool700;o0`02o`T00_lB00;o0P02o`H00_l900;o4002o`H00_l500;o1`02o`P00_l900;o
3002o`L00_l200;o1P02o`H00_l600;o1004o`801?l500;o0P02o`/00_l;00;o0P02o`L00_l500;o
1@0;o`800_l900;o0`02o`800_l900;o1002oa<0000C00;o3P02o`d00_l=00;o5@02o`800ol200;o
1002o`L00_l600;o0`02o`D00_l300;o00<0ool00`02o`@01ol00`3oo`0900;o00<0ool01007o`80
0_l900;o4P02o`800_l600;o2@02oa000_l600;o3@03o`P00_l900Oo1`02o`L00_l200;o1P02o`H0
0_l600;o1002o`040?l000Co1@02o`800_l;00;o2`02o`800_l700;o1@02o`H02Ol300;o2@02o`<0
0_l200;o2@03o`800olC00004`02o`h00_l=00;o3@02oaD00_l20003o`3o00800_l400;o1`02o`H0
0ol900;o0P03o`030?oo00<00_l400Oo00<0ool02@02o`030?oo00@01ol200;o2@02oa801_l600;o
2@02oaP00_l800Oo2@03o`P02Ol500;o1`02o`X00_l600;o1@03o`@00_l01P3o003o00;o1@06o`/0
0ol900?o0P03o`H00_l500;o1P02o`D00_l300;o2@02o`<01_l900Oo500001<00_l>00;o3@02o`d0
0_lE00;o00@0ool00_l00`3oo`0400;o1`02o`L00ol800;o0P02o`800_l300;o3002o`T00_l00`3o
o`0=00;o2@02oa801_l600;o2@02oaP00_l600Oo2P04o`P00_l500?o1002o`L00_l:00;o1P09o`D0
0_l00`3oo`02o`030?oo00D01_l:00Co2@02o`@00_l600Wo1`02o`<00_l400;o2@02o`<01_l900Go
5P0001@00_l=00;o3@02o``00_lF00;o00<0ool00P001?l0ool400;o1`02o`<00_l300;o2002o`03
0?oo00<00_l300;o3002o`T00_l00`3oo`0=00;o2@02oa800_l200;o1P02o`T00_lH00;o1@03o`h0
1_l700;o1P02o`@00_l700;o2P02o`H02?l600;o00<0ool00_l00`3oo`0500;o0P02o`T01_l800;o
1002o`H02Ol700;o0`02o`@00_l900;o0`02o`800_l900;o00@0oooo5@0001@00_l=00;o3@02o``0
0_lF00;o00<0o`000P001?l0ool400;o1`02o`<00_l300?o1`05o`<00_l300;o2002o`800_l900;o
00<0ool02002o`<00_l900;o4P02o`800_l200;o0P03o`P00_lH00;o1@02o`L000?o00001@02o`80
0_l700;o1P02o`@00_l700;o2P02o`H00_l400?o1002o`<00_l300;o1002o`800_l200;o1@02o`80
0_l700;o1P02o`D00_l500;o2002o`040?ooo`@00ol800;o0`02o`800_l200;o1@02o`800olD0000
5003o``00_l=00;o3002oaH01?l300Co1002o`H00_l400;o1003o`H01?l400;o1002o`H00ol300;o
1`02o`<00_l600?o1002o`L00_lC00;o1P02o`<00_l700;o6@02o`D00_l600;o1P03o`<00_l600;o
1P02o`@00_l600;o2`02o`H00_l500;o1002o`<00_l300;o1002o`H00_l400?o0`02o`H00_l600;o
1@02o`D00_l800;o00<0ool01P02o`L00_l400;o1P02o`D00_l300?o4`0001D00_l<00;o3@02o`/0
0_lG00Co1003o`@00_l400Co1002o`D00_l600Co1002o`@00ol400Co0`03o`D00ol300?o1004o`@0
0ol500?o4`02o`H00_l400;o1@02oaX00_l500?o1003o`H00_l400;o1P02o`D00ol400;o1004o`/0
0_l600;o1003o`@00_l800;o1002o`H00_l400;o1002o`D00ol600?o1002o`D00_l800Go1`02o`D0
0_l500;o1P02o`D00_l400?o4P0001H00_l700?o00<0ool02@03o`030?oo00X00_lG00Co1@04o`80
2_l500[o1004o`801_l400[o1009o`D02_l500Wo4P0<o`@02OlE00[o0`09o`@01Ol200Go0P0;o`@0
2_l700[o00<0ool02?l400Ko0P06o`030?oo00[o0P05o`801Ol200Ko0P06o`801?l300Co1007o`P0
2Ol300co0`05o`<01Ol@00005`000ol0000500Ko2@06o`X000?o00005P04o`D01?l200So1`0:o`@0
0ol300Ko1P05o`030?oo00H01Ol900Go00<0ool01`05oa@03?l600Go5`0:o`D01Ol00`3o000300Go
0P05o`802Ol600So2@0:o`030?oo00Oo1@06o`801_l00`3oo`0:o`801Ol200Go0P06o`801_l200Co
0`04o`@01ol:00Go1@0<o`<01Ol300Go400002800ol<00?oo`360000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(12\\) MIVLGOGO FQ JSWLDJAXBY GARFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2@09o`D0
2_l900;o5@05o`<01Ol200[o2@02o`L03Ol600Ko2005o`T01_l900Go5007o`/01OlF00Ko1`02o`03
0?oo00?o2002o`@00_l400go0P08o`P01_l500Ko0`06o`030?oo00?o0P05o`802_l600So5`06o`@0
1_l300_o1P0:o`P01Ol600;o400001<00_l:00Wo1@0:o`X00_lD00Go0`05o`802_l800Co1P0=o`@0
2_l400Wo1@0:o`D02OlB00Oo2@09oa802Ol600[o1P02o`@00_l400go0P0:o`@02Ol400Ko0`06o`03
0?oo00?o0P05o`802ol500So5@0:o`801_l300_o1@0;o`P01Ol500?o400001<00_l>00;o2@02o`D0
0_l:00;o5@02o`L00_l700;o3004o`T00_l600;o0`04o`D00_l300?o1@03o`<01?l500;o1003o`D0
0olC00;o2`03o`D00olA00?o1003o`D00ol500?o1003o`@00ol600;o1P02o`<00_l400Co0`03o`@0
0ol500;o1`02o`@00ol400?o1@02o`D00ol700;o5`04o`D00_l400;o1`02o`@00_l500?o1002o`d0
0_l500?o4@0001<00_l>00;o2P03o`l00_lE00;o1`02o`L00_l<00Co2@02o`H00_l300;o1`02o`<0
0_l700;o0`02o`L00_l400;o1`02oa<00_l;00;o1`02oa400_l600;o1@02o`L00_l400Co0`03o`H0
0_l600;o0`02o`H00_l300;o1P02o`D00_l700;o1@03o`800ol600;o1P02o`L00_lG00;o1`02o`@0
0_l700;o1002o`D00_l500;o3@02o`D00_lB00004`02o`h00_l;00?o3P02oaD00_l300;o0P02o`L0
0_l;00;o0P02o`P00_l600;o0P03o`L00_l200;o2@02o`040?ooo`L00_l300;o2@02oa800_l200;o
1P02o`T00_l@00;o1P02o`D00_l700;o1004o`801?l600;o1P02o`<00_l700;o0P02o`H00_l500_o
1P02o`800_l700;o1P02o`L00_lF00?o1`02o`@02ol400;o1002o`H00_l200;o2@02o`@00_lC0000
4`02o`h00_l<00?o3@02oaD00_l200?o0P02o`L00_l;00;o0P02o`P00_l600;o0P02o`@01ol00`3o
o`0900;o00<0ool01007o`800_l900;o4P02o`800_l600;o2@02oa000_l600;o3@03o`@00_l0103o
0004o`H00_l600;o0`02o`L00_l200;o1P02o`H02Ol800Co2002o`H00_l700;o5P02o`@01ol400Wo
1@02o`<00ol600;o0P02o`T00ol200?o4`0001<00_l>00;o3@03o``00_lE00;o0P000ol0o`0200;o
1`02o`X00ol200?o1`02o`X00_l400Oo00<0ool02@02o`030?oo00@01ol200;o2@02oa801_l600;o
2@02oaP00_l800Oo1@02o`060?l00?l00_l600;o2`02o`L00_l:00;o1P02o`D00_l800Co2002o`D0
0ol700?o5@02o`@01ol400;o1@02o`D01ol700Ko2@07oa@0000C00;o3P02o`h00ol;00;o5@02o`04
0?oo00;o00<0ool01`02o`X00_l400;o1`02o`X00_l<00;o2@02o`030?oo00d00_l900;o4P06o`H0
0_l900;o6002o`H01ol700;o00<0ool00_l00`3oo`0600;o2`02o`L00_l:00;o1`02o`<00_l900?o
2@09o`L01?lE00;o4002o`<00_l600Wo1@06o`T01OlF00005002o`d00_l?00;o2P02oaH00_l00`3o
o`020004o`3oo`L00_l:00;o1002o`L00_l:00;o3002o`T00_l00`3oo`0=00;o2@02oa800_l200;o
1P02o`T00_lH00;o1@03o``00_l00`3oo`02o`030?oo00H00_l;00;o1`02o`X00_l700;o0`02o`T0
1?l800So1`06oa@00_l@00;o0`02o`H00_l500?o1002o`800_l900;o00@0oooo5@0001@00_l=00;o
4002o`T00_lF00;o00<0o`000P001?l0ool700;o2@02o`H00_l600;o2P02o`P00_l200;o2@02o`03
0?oo00P00_l300;o2@02oa800_l200;o0P02o`800ol800;o6002o`D00_l70003o`0000800_l300;o
0`02o`D00_l;00;o1`02o`X00_l800;o00@0oooo2006o`L00_l400?o1P02o`800_lD00;o2002o`L0
0_l0103oool600;o1P02o`@00_l200;o0P02o`D00_l200?o500001@00ol<00;o4002o`T00_lF00Co
0`04o`L00_l900;o1P02o`H00_l;00;o1P03o`<00_l700;o0`02o`H00ol400;o1`02oa<00_l600;o
0`02o`L00_lI00;o1@02o`H00_l400;o0`02o`<00_l500;o2`02o`H00_l;00;o2002o`030?oo00P0
0ol200?o1P02o`D00_l500?o0`02oa@00_l600?o1`02o`030?oo00L00_l600;o1002o`H00_l500;o
0`03oa<0000E00;o3002o`T00_l500;o2002oaL01?l400?o1`02o`P00ol600?o1@02o`/00ol400Co
0`03o`D00ol300?o1004o`@00ol500?o4`02o`H00_l400;o1@02oaX00_l500?o1003o`@00_l800;o
1@02o`/00_l400Co2`02o`P01Ol800;o1002o`H00_l400?o1@02o`@00_lD00?o1004o`L01Ol700;o
1@03o`@00_l600;o1@02o`@00olB00005P02o`L00ol00`3oo`0900?o0`03o`L00_lG00Co1@04o`80
2_l300Ko0P06o`030?oo00Ko2@0:o`@02Ol500[o1@09oa803?l400Wo5@0:o`<02Ol300Ko0P06o`03
0?oo00Ko1`0:o`L02_l200Oo1`05o`801Ol200[o1005o`801OlC00[o1007o`H02ol300co0`05o`<0
1Ol@00005`000ol0000500Ko2P07o`P000?o00005P04o`D01?l200[o0`06o`801_l00`3oo`06o`/0
1Ol00`3oo`0600Go2@05o`030?oo00L01OlD00co1P05oaL02_l500Go00<0o`000P06o`801_l00`3o
o`06o`L02?l900[o0P07o`L01Ol200Go0P09o`D01Ol200Go5@05o`030?oo00@01ol600Wo1@0<o`<0
1Ol300Go400002800ol;00Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(13\\) MHVLGOGTXFQ JSWLDJFXBXYGDRFJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2@09o`L0
1Ol<00;o5@05o`<01Ol200Co0`04o`P00_l700go1P06o`P01Ol900Ko1`08o`@01Ol200Go0`07o`/0
1OlF00Ko1`02o`030?oo00?o2002o`@00_l400go0P08o`P01_l600Oo2005o`801Ol200[o1005o`80
1Ol500So2006o`H02?l500Go1P0:o`X01_lE00004`02o`X02Ol500Wo2`02oa@01Ol300Go0P04o`<0
1?l700Co1P0=o`@02_l400Wo1@0:o`D02?l400Go0P05o`<01ol900Wo4P09o`H02_l600;o1002o`@0
3Ol200[o1009o`D01ol800Go0P05o`802ol300Go0P05o`D02?l600[o100:o`<01Ol500_o2009oa@0
000C00;o3P02o`P00_l500;o2`02oaD00_l700;o1002o`D00_l800Co2@02o`H00_l300Co1@02o`<0
0ol500?o0`04o`D00_l800;o2003o`@00ol600;o2`03o`D00olA00?o1003o`D00ol500?o1003o`@0
0ol600;o1P02o`<00_l400Co0`03o`@00ol600;o3003o`@00ol500;o1@03o`<00ol400?o2@02o`P0
1?l500;o1@02o`@01?l400;o1@03o`@00_l;00?o1003oa<0000C00;o3P02oa000_l:00;o5@02o`L0
0_l400;o1@02o`P01?l900;o1P02o`<00_l700;o0`02o`L00_l300;o1`02o`P00_l900?o0P03o`L0
0_l;00;o1`02oa400_l600;o1@02o`L00_l400Co0`03o`H00_l600;o0`02o`H00_l300;o1P02o`H0
0_l=00?o0P03o`H00_l600;o1003o`800ol:00;o2002o`L00_l500;o1P02o`@00_l500;o1@02o`/0
0_l600;o4`0001<00_l>00;o4002o`X00_lE00;o0`02o`800_l400;o1@02o`L00_l200;o2002o`H0
0_l200?o1`02o`800_l900;o00@0oooo1`02o`P00_l:00;o0P02o`P00_l200;o1P02o`T00_l@00;o
1P02o`D00_l700;o1004o`801?l600;o1P02o`<00_l700;o0P02o`H00_l600;o0P02o`X00_l200;o
1`02o`H00_l500;o0P02o`/00_l700?o1`02o`D00_l700;o0`02o`@00_l600;o0P02o`L00_l600;o
4`0001<00_l>00;o4002o`X00_lE00;o0P03o`800_l400;o1@02o`L00_l200;o2002o`H00_l200;o
1007o`030?oo00T00_l00`3oo`0400Oo1`02o`/01?l900;o0P02o`H00_l900;o4002o`H00_l=00?o
1002o`040?l000Co1P02o`H00_l300;o1`02o`800_l600;o1P02o`800_l;00Co2002o`H00_l600Co
3002o`L00_l400Oo1002o`L00_l300;o0`03o`H00_l200;o1`02o`H00_lC00004`02o`h00_l?00;o
2`02oaD00_l20003o`3o00800_l400;o1@02o`H00ol200?o1`02o`X00_l400Oo00<0ool02@02o`03
0?oo00@01ol700;o2`04o`T01_l600;o2@02oaP00_l800Oo1@02o`060?l00?l00_l600;o2`02o`L0
0_l:00;o1P06o`/01?l800;o1@03o`H01?l<00?o1P02o`@01ol400;o1`02o`<01ol700Ko3`02oa<0
000C00;o3P02o``01?l<00;o5@02o`040?oo00;o00<0ool01009o`H00_l400;o1`02o`X00_l<00;o
2@02o`030?oo01800_l;00?o2P06o`H00_l900;o6002o`H01ol700;o00<0ool00_l00`3oo`0600;o
2`02o`L00_l:00;o1P06o`/00ol900Wo1`03o``01?l600;o3`02o`L00_l300Wo1@06o`l00_lC0000
5002o`d00_l<00?o3002oaH00_l00`3oo`020004o`3oo`@02Ol600;o1002o`L00_l:00;o3002o`T0
0_l00`3oo`0=00;o0`02o`<00_l600Co2@02o`800_l600;o2@02oaP00_l500?o3002o`030?oo00;o
00<0ool01P02o`/00_l700;o2P02o`H00_l200;o2`04o`P02?l800Co2P06o`D00_l?00;o1`02o`<0
0_l500?o1002o`800_l?00;o4`0001@00_l=00;o3P02o`/00_lF00;o00<0o`000P001?l0ool400;o
1@02o`D00_l600;o1P02o`X00_l800;o0P02o`T00_l00`3oo`0800;o0`02o`<00_l300;o1@06o`P0
0_l200;o0P02o`800ol800;o6002o`D00_l70003o`0000800_l300;o0`02o`D00_l;00;o1`02o`X0
0_l600;o0P02o`800_l600Ko1`02o`@00ol600Ko2@02o`800_l500;o2002o`D00_l700;o0`02o`H0
0_l400;o0P02o`800_l;00;o4`0001@00ol<00;o3`02o`X00_lF00Co0`04o`@00_l500;o1@02o`H0
0_l600;o2`02o`H00ol300;o1`02o`<00_l600?o0`02o`<00_l300;o1003o`800ol700;o1P02o`<0
0_l700;o6@02o`D00_l600;o1002o`<00_l300;o1@02o`/00_l600;o2`02o`H00_l600;o1@03o`80
0ol600;o1@02o`D00ol200?o1`03o`<00_l500;o1P03o`D00_l600;o1002o`H00_l400;o1P02o`/0
0_lC00005@02o``00_l?00;o2@02oaL01?l400?o1002o`D00_l400?o1P03o`D00_l;00?o1004o`<0
0ol500?o0`03o`@01?l300;o0`02o`<00_l400;o1002o`L00_l600;o1002o`D00_lJ00;o1@03o`@0
0ol400;o2002o`D00_l;00;o1004o`/00_l600;o1P02o`D00_l400;o1P02o`@00ol500;o1002o`L0
0_l400;o1@03o`@01?l500;o1004o`@00_l500?o1002o`H00_l;00;o4`0001H00_l700?o00<0ool0
2@02o`<00ol800;o5`04o`D01?l200Co0`04o`801_l200Ko00<0ool01_l900[o1009o`D02_l300co
0P05o`801Ol300co1009oaD02_l300Wo0`06o`801_l00`3oo`06o`L02_l700[o00<0ool02_l300Go
0P05o`802_l400Go0P05o`<01Ol200Go100:o`@02_l300_o0`0<o`H02_l@00005`000ol0000500Ko
2@07o`T000?o00005P04o`D01?l200Co0`04o`801_l200Ko00<0ool01_l;00Go00<0ool01P05o`T0
1Ol00`3oo`0300co0P05o`801Ol300co1P05oaL02_l500Go00<0o`000P06o`801_l00`3oo`06o`L0
2?l900[o00<0ool02_l300Go0P05o`802Ol500Go0P05o`<01Ol200Go1P05o`030?oo00@02?l500Wo
1@0<o`H02_l@00008P03o`/01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(14\\) MHVGIQFT JQ JSZLAJFXA  GCRFJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?o?`02o`@00ooo00L0000E00;o
:002of402_ln00[oo`0600005002obX00_mQ00Go0P02ocl01Ol200;oo`0600005002obX00_mQ0003
o`0004D000?o0000o`0<00005002o`T02Ol900Ko2@02oaD01Ol300Go0P04o`<01?l800;o2`06o`H0
2_l700Go1@07o`X02?lE00Ko2P05oaH01_l700;o00<0ool00ol700[o0`0Co`<01_l300Ko1P07o`P0
1Ol200Go00<0ool01?l300Ko8@06o`T01Ol500Go1P0:o`X01_lE00004`02o`X02Ol900Ko2P02oa@0
1Ol300Go0P04o`<01?l700Co200:o`@02_l500Wo0`07o`X02?lC00Wo1`09oa802Ol600[o1@0:o`<0
4ol300Ko00<0ool01ol500Oo2005o`801Ol00`3oo`04o`<01_lO00[o1@09o`<01Ol500_o2009oa@0
000C00;o3P02o`h00_l<00;o5@02o`L00_l400;o1@02o`P01?l700Co1@02o`P00_l800?o1@03o`@0
0_l@00;o5P03o`@00ol500?o1@03oa400ol400?o1@03o`D00ol500;o1@02o`H00_l600;o0P02o`L0
0_l300?o1003o`H00_l<00?o1003o`@00_l700;o8004o`D00_l400?o1@03o`@00_l500?o1002o`/0
0ol400?o4`0001<00_l>00;o3P02o``00_lE00;o1`02o`@00_l500;o2004o`L00_l700;o2002o`P0
0_l700;o1002oa000_lF00;o1P02o`D00_l700;o4@02o`H00_l500;o1`02o`D00ol400;o1P02o`H0
0_l200;o1`02o`<00_l600;o1P02o`d00ol200?o1@02o`L00_lP00;o1`02o`@00_l700;o1002o`D0
0_l500;o2`02o`H00_lC00004`02o`h00_l800[o2P02oaD00_l300;o0P02o`@00_l500;o1`02o`80
0_l500?o1`02o`P00_l700;o2@02o`<00_l200;o3002oaH00_l600;o1002o`T00_l@00;o1P02o`D0
0_l700;o1P03o`<00_l600;o1P02o`802ol300;o1P02o`H00_l200;o2P02o`800_l600_o7`03o`L0
0_l300?o3@02o`@00_l600;o0P02o`L00_l600;o4`0001<00_l>00;o200:o`X00_lE00;o0P03o`80
0_l400;o1@02o`L00_l200;o1@02o`@01ol700;o1`02o`T00_l300;o0P02o``00_lF00;o1P02o`@0
0_l900;o4002o`H00_l=00?o1`02o`<00_l600;o1P02o`<02Ol400;o1P02o`H00_l200;o2`04o`P0
2OlP00;o1007o`800_l>00;o0`03o`H00_l200;o1`02o`H00_lC00004`02o`h00_l800;o1002o``0
0_lE00;o0P000ol0o`0200;o1002o`D00_l600?o0P03o`@00_l400Oo1`02o`L00_l900;o0`06o``0
0_lN00;o1002o`T00_lH00;o2007o`P00ol:00;o2`02o`D00_l<00;o1P06o`/01?l800;o1@02ob00
0_l400Oo0P02o`h01ol700Ko3`02oa<0000C00;o3P02o`T00_l300;o3002oaD00_l0103oo`02o`03
0?oo00@02Ol600;o1002o`@00_lB00;o1`02o`T00_l300Ko3002oah00_l400;o2@02oaP00_l600Oo
2`03o`T00_l<00;o0`02o`d00_l600Ko2`03o`X00_l300;o8@02o`d00_l>00Wo1@06o`l00_lC0000
5002o`d00_l:0004o`0000;o2`02oaH00_l00`3oo`020004o`3oo`@02Ol600;o1002o`@00_lB00;o
1`02o`T00_l300;o0P02o`L00_l300;o0`02oaT00_l400;o2@02oaP00_l500?o3002o`<00_l900;o
3002o`<00_l=00;o1P02o`800_l;00Co2@02o`<00_lQ00;o3@02o`h00_l500?o1002o`800_l?00;o
4`0001@00_l=00;o2P02o`800_l;00;o5P02o`030?l0008000Co0?oo1002o`D00_l500;o1P02o`<0
0_l800;o2002o`L00ol800;o0`02o`800_l200;o0`02o`<00_l300;o6@02o`@00ol800;o6002o`D0
0_l70003o`0000<00_l300?o2002o`d00_l0103oool=00;o1P02o`800_l200;o1P06o`T00_l0103o
oolQ00;o2002o`<00ol700;o1002o`H00_l400;o0P02o`800_l;00;o4`0001@00ol<00;o2`000ol0
0002o`/00_lF00Co0`04o`@00_l500;o1@02o`H00_l400;o1P03o`P00_l800;o1`02o`@00_l600;o
0`02o`<00_l300;o6@02o`D00_l700;o6@02o`D00_l600;o1@02o`@00ol700;o3@02o`030?oo00h0
0_l600;o1P02o`D00ol200?o2002o`030?oo02<00_l600?o1002o`L00_l400;o1P02o`@00_l600;o
2`02oa<0000E00;o3002o``000Co0?oo2P02oaL01?l400?o1002o`D00_l400?o1P03o`<00ol400Co
2002o`T00_l500;o1@02o`H00_l300;o0`02o`<00_lI00;o1P02o`D00_lJ00;o1@03o`@00ol500;o
1@02o`L00_l=00Go3P02o`H00_l600;o1@02o`@00_l800Go8`03o`@01?l400?o1@03o`@00_l500?o
1002o`H00_l;00;o4`0001H00_l700?o00<0ool03004o`T00_lG00Co1@04o`801?l300Co0P06o`80
1_l300[o100:o`D02Ol300co0`0<oa@02_l300Wo5@0:o`<02Ol500[o0`08o`L01ol:00[o00<0ool0
2_l300Go0P05o`<01olU00[o1@0:o`802ol300co1P0:oa00000G0003o`0000D01_l=00?o2@000ol0
000F00Co1@04o`801?l300Co0P06o`801_l500Go00<0ool0100:o`L01Ol500co0`0<oa@02_l500Go
5`0:o`D01Ol00`3o000400[o0`08o`L01ol:00[o00<0ool02_l300Go0P05o`<01olW00Go00<0ool0
1`05o`030?oo00802Ol500co1P0:oa00000R00?o3@03ool0a@000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(15\\) QHVJIOFTXIQ JSWLFJFXA  BAQFJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oQ`02o`@00oo?00;o1003obh0
000E00;o:002oaT02_n600[ocP0:obd0000D00;o:P02oaT01Ol200;oQ`05o`800_o?00Go0P02obd0
000D00;o:P02oaT000?o0000S@000ol0003E0003o`0003<0000D00;o2@09o`L01Ol<00;o6@05o`H0
1?l300Co2002o`T01_l800[o1`05o`D01ol:00So1005o`801Ol400[o1`05oaH01_l700;o00<0ool0
0ol800;o1002o`@03Ol00`3oo`05o`X01_l600Oo2005o`801Ol00`3oo`04o`<01_lM00[o1006o`<0
1_l400Go1@07o`X01_lE00004`02o`X02Ol500Wo2`02oaH02Ol400Co0`04o`L01?l600Wo1`0:o`D0
2Ol300Oo2P08o`@01Ol200Go100:o`D02OlB00Wo1P0:o`H00_l400;o100=o`030?oo00Go2009o`D0
1ol800Go0P05o`030?oo00Co0`06oad02ol300Ko0`06o`802Ol300Oo2009oa@0000C00;o3P02o`P0
0_l500;o2`02oaD00ol500?o1002o`D00_l800Co1P03o`@00ol:00;o2003o`D00ol400;o4002o`P0
0ol400?o2@02o`P00ol500?o4@03o`@00ol500?o1@03o`@00ol400?o1P02o`H00_l300;o2`03o`@0
0ol600;o3003o`@00ol400;o1`02ob400_l500?o1002o`L00_l300?o1@03o`@00_l;00?o1003oa<0
000C00;o3P02oa000_l:00;o5@02o`L00_l400;o1@02o`P01?l600;o1P02o`X00_l800;o1`02o`@0
0_l@00;o2@03o`800ol:00;o2002o`L00_lA00;o1P02o`D00_l700;o1004o`<00ol600;o1P02o`<0
0_l;00;o1P02o`H00_l=00?o0P03o`D00_l700;o8@02o`H00_l400;o1`02o`<00_l700;o1002o`/0
0_l600;o4`0001<00_l>00;o4002o`X00_lD00;o2@02o`<00_l500;o1`02o`800_l500;o1P02o`X0
0_l700;o2@02o`<00_l200;o3002o`X00_l200;o2`02o`L00_l900;o4002o`H00_l500;o1`02o`@0
1?l200Co1P02o`H00_l300;o0P02o`L00_l600;o1P02o`800_l:00;o0P02o`H02olQ00;o1P02o`@0
2ol200;o2@02o`<00_l200;o1`02o`H00_lC00004`02o`h00_l@00;o2P02oa@00_l900;o0`02o`D0
0_l700;o0P02o`D00_l600;o2P02o`L00_l900;o0`02o`800_l<00;o2`04o``00_l700;o2@02oa00
0_l600;o3@03o`@00_l0103o0004o`H00_l600;o0`02o`800_l700;o1P02o`H00_l200;o2`04o`P0
2OlR00;o1P02o`D02Ol300;o2@02o`<00_l200;o1`02o`H00_lC00004`02o`h00_l@00;o2P02oa@0
0_l900;o0`02o`D00_l600?o0P03o``00_l:00;o1`02o`T00_l300Ko3002o`/01?l<00;o1`02o`T0
0_lH00;o2007o`D00_l01P3o003o00;o1P02o`/01_l?00;o1P06o`/01?l800;o1@02ob800_l500?o
1@02o`D00_l300;o2@02o`<01_l?00;o4`0001<00_l>00;o2@02o`@00_l;00;o5002o`T00_l300Wo
1P02o`@00_l<00;o2P02o`L00_l900;o0`06o``00_l;00?o3@02o`L00_l900;o6002o`H01ol700;o
00<0ool00_l00`3oo`0600;o2`06o`l00_l600Ko2`03o`X00_l300;o8`09o`L00_l300;o1002o`T0
0_l300Ko3`02oa<0000D00;o3@02o`T02?l:00;o5@02o`T00_l300Wo1P02o`@00_l<00;o2P02o`L0
0_l900;o0`02o`800_l700;o0`02o`<00_l600Co3002o`L00_l900;o6002o`D00ol<00;o00<0ool0
0_l00`3oo`0600;o2`02o`800_l?00;o1P02o`800_l;00Co2@02o`<00_lS00So2002o`<00_l400;o
2@02o`<00_l200;o3`02oa<0000D00;o3@02o`T01ol;00;o5@03o`P00_l300;o1@02o`D00_l600;o
2`02o`X00_l700;o2@02o`<00_l200;o0P02o`<00_l300;o0`02o`D01_l;00;o1`03o`P00_lH00;o
1@02o`L000?o00000P02o`<00_l300;o1@02o`/00_l200;o0P02o`/00_l600;o0P02o`800_l600Ko
2@02o`040?ooob<00_l400?o2002o`040?ooo`@00ol800;o0`02o`800_l200;o2`02oa<0000D00?o
3002o`T00_l@00;o5P02o`L00_l400;o1@02o`D00_l600;o2`02o`X00_l800;o1`02o`@00_l600;o
0`02o`<00_l300;o1003o`800ol:00;o2002o`L00_lI00;o1@02o`H00_l400;o0`02o`<00_l500;o
2`02o`H00_l;00;o1P02o`H00_l500?o0P03o`P00_l00`3oo`0T00;o1@02o`P00_l00`3oo`0600;o
1`02o`@00_l600;o2`02oa<0000E00;o3002o`T00_l?00;o6002o`D00_l500;o1@02o`@00ol600?o
2P02o`X00_l800?o1@03o`@00_l600;o0`02o`<00_l300;o1002o`@00_l:00;o2@02o`D00_lJ00;o
1@03o`@00ol400;o2002o`D00_l;00;o1P02o`/00_l600;o1P02o`D00_l400;o2005ob@00_l400?o
2005o`L00_l500;o1@02o`H00_l;00;o4`0001H00_l700?o00<0ool02@02o`h00_lI00Wo1004o`<0
1?l200Ko0P06o`@02_l300[o1@09o`<03?l300co0P05o`801Ol400[o1@09oaD02_l300Wo0`06o`80
1_l00`3oo`06o`H03?l600[o00<0ool02_l300Go0P05o`<01olS00[o1P07o`P02Ol300co1P0:oa00
000G0003o`0000D01_l900So20000ol0000J00Go1P04o`<01?l200Ko0P06o`@02_l300[o1`05o`D0
3?l300co0P05o`801Ol400[o1`05oaL02_l500Go00<0o`000P06o`801_l00`3oo`06o`H03?l600[o
00<0ool02_l300Go0P05o`<01olS00Wo1`07o`X01Ol500co1P0:oa00000R00?o2@08ool0a0000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(16\\) QHVJIOFTXIQYJSVLGLFXA YBARFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oQ`02o`@00ooo00L0000E00;o
:002oaT02_n600[oo`0600005002obX00_lI00Go0P02ohL01Ol200;oo`0600005002obX00_lI0003
o`0008d000?o0000o`0<00005002o`T02Ol800Co3002oaT01Ol600Co0`04o`P00_l900Ko200:o`L0
1Ol500Oo2P08o`@01Ol200Go100:o`L01Ol700So1`06o`L00_l00`3oo`03o`/00_l700go1@06o`D0
3Ol00`3oo`05o`P01Ol200Go00<0ool01?l300Ko4@08o`@02_l400Ko0`0;o`H02_l<00Go500001<0
0_l:00Wo1`07o`/00_lF00Wo1004o`<01?l700Co1P09o`L02_l500Wo0`07o`X02?l400Go0P05o`@0
2_l500Wo1@08o`D02Ol600[o2004o`H03Ol300[o0`0=o`030?oo00Go2005o`801Ol00`3oo`04o`<0
1_lA00So100;o`<01_l300_o1@0;o`X02OlB00004`02o`h00_l900;o1002o`/00_lE00?o1@03o`@0
0_l500;o2004o`H00ol400?o2P02o`P00ol500?o1002oa000_l800?o1003o`T00_l800?o1@03o`L0
0_l800?o1003o`D00ol500?o1`04o`T00_l600;o0P04o`D00_l600;o1P02o`<00_l<00?o1003o`@0
0_l700;o5P02o`T00_l500?o1002o`L00_l400;o1@03o`@00_l<00?o1@03oa40000C00;o3P02o`P0
0_l600;o2P02oaD00_l700;o1002o`D00_l800Co1P02o`H00_l:00;o2002o`L00_l400;o4002o`T0
0ol200?o2P02o`P00_l700;o1`02o`P00_l600;o1@02o`L00_l700Co2@02o`H00_l200;o1`02o`H0
0_l600;o0`02o`d00ol200?o1@02o`L00_lF00;o2@02o`H00_l400;o1`02o`@00_l500;o1@02o``0
0_l700;o4@0001<00_l>00;o2002o`H00_l:00;o5002o`T00_l300;o1@02o`L00_l200;o1@02o`H0
0_l:00;o1`02o`T00_l300;o0P02o``00_l:00;o0P02o`/00_l700;o2@02o`H00_l800;o1P02o`D0
0_l700;o1P02o`800_l800;o1P02o`040?ooo`L00_l600;o1P02o`<00_l200;o2P02o`800_l600_o
5P02o`T00_l600;o100;o`@00_l400;o1P02o`800_l700;o2@02oa00000C00;o3P02o`P00_l600;o
2P02oa@00_l900;o0`02o`D00_l700;o0P02o`D00_l600;o2P02o`L00_l900;o0`02o`800_l<00;o
2`04o``00_l700;o2@02o`H00_l800;o1P02o`d00ol600;o0P02o`P00_l600;o00<0ool01007o`D0
0_l600;o0`02o`800_l;00Co2009oaL00_l900;o1P02o`D02Ol500;o0`03o`H00_l200;o1`02o`T0
0_l@00004`02o`h00_l800;o1P02o`X00_lD00;o2@02o`<00_l500;o1P03o`800ol<00;o2P02o`L0
0_l900;o0`06o``00_l;00Co3002o`L00_l900;o1P03o`l00_l800Oo1P03o`800ol700;o2@02o`@0
1ol500;o2`06o`/01?l800;o1@02oaL00ol800;o1@03o`D00_l500;o1@07o`L01_l700;o2@02oa00
000C00;o3P02o`P00ol400;o2`02oa@00_l900;o0`09o`H00_l400;o3002o`X00_l700;o2@02o`<0
1_l<00;o2`03o`d00_l700;o2@02o`D01?l?00;o1P07o`P00_l400;o1`02o`T00_l@00;o2`06o`/0
0ol:00;o0`02oaL01?l800Wo1`02o`<00_l600Wo1@06o`L00_l900;o400001@00_l=00;o2009o`X0
0_lE00;o2@02o`<02Ol600;o1002o``00_l:00;o1`02o`T00_l300;o0P02o`L00_l300;o0`02o`H0
1?l<00;o1`02o`T00_l400Ko3P02o`D00ol=00;o1002o`L00_l900;o4002o`/00_l200;o2`04o`T0
0_l300;o5P06o`L02?l800;o0`02o`H00_l500?o1002o`800_l700;o2@02oa00000D00;o3@02o`P0
0_l00`3oo`02o``00_lE00?o2002o`<00_l500;o1@02o`H00_l;00;o2P02o`L00_l900;o0`02o`80
0_l200;o0`02o`<00_l300;o1@06o`/00_l700?o2002o`@00_l200;o3P02o`D00_l70003o`0000<0
0_l600;o1P02o`T00_l800;o1P02o`/00_l200;o0P02o`H01_l900;o00@0oooo5P02o`800_l700;o
1003o`P00_l0103oool600;o1P02o`@00_l200;o0P02o`<00_l900;o400001@00ol<00;o2@02oa00
0_lF00;o1`02o`@00_l500;o1@02o`H00_l;00;o2P02o`P00_l700;o1002o`H00_l300;o0`02o`<0
0_l400?o0P03o`X00_l800;o1`02o`@00ol300;o3@02o`D00_l600;o1@02o`H00_l600;o2P02o`H0
0ol600;o2`02o`H00_l500?o0P03o`P00_l00`3oo`0F00?o0`02o`H00_l500;o2002o`030?oo00L0
0_l600;o1002o`H00_l400;o1`02oa40000E00;o3002o`T00ol>00;o6002o`D00_l500;o1@02o`@0
0ol600?o2P02o`X00_l800?o1@03o`@00_l600;o0`02o`<00_l300;o1002o`@00_l:00;o2@02o`D0
0_l500;o1002o`d00_l500?o1003o`@00ol600?o1@02o`X00ol400Co1P02o`/00_l600;o1@02o`@0
0_l800Go5P02o`@00_l600;o1003o`P01Ol700;o1@03o`@00_l600;o1003o`D00olA00005P02o`L0
0ol00`3oo`0:00?o3002oaT02Ol400Co0`04o`801_l200Ko100:o`<02_l500Wo0`0<o`<03?l200Go
0P05o`@02_l500Wo0`05o`801Ol600[o0`09o`<01_l200Ko00<0ool01_l800[o0`08o`H03?l300Go
0P05o`<01olE00Go0P05o`802_l600Oo1P0;o`<03?l500Wo4P0001L000?o00001@06o`/01ol70003
o`0001X01Ol600Co0`04o`801_l200Ko100:o`<02_l700Go1@0<o`<03?l200Go0P05o`@02_l700Go
1@05o`801Ol600[o1@05o`030?l000801_l200Ko00<0ool01_l:00Go00<0ool00`08o`H03?l300Go
0P05o`<01olE00Go0P05o`802Ol700Oo1P09o`D03?l700Go500002800ol=00Goo`330000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(17\\) NEQKIOFQVIQYJSVLHLF A YADRFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?o?`02o`@00olR00;o1003ool0
1`0001D00_lX00;o=P0:och02_lQ00[oo`0600005002obX00_lf00Go0P02ocl01Ol200;o8P05o`80
0_oo00H0000D00;o:P02ocH000?o0000A@000ol0000X0003o`000?l0300001@00_l900Wo2002o`h0
0_lF00Ko0`02o`803?l700Go1@05o`H00_l300[o1`05o`D01ol<00Go2P02o`T02_l700Go1`08o`L0
1_l700;o00<0ool00ol;00;o1`0=o`801?l300Co0`0=o`030?oo00Go5@06o`<01_lA00So0`06o`<0
1_l200So1@05o`H02_l<00Go500001<00_l:00Wo2002o`l00_lE00Ko0P03o`803?l500Wo0`05o`D0
0ol300[o1@09o`<01ol:00Wo1`04o`P02_l500Wo1@08o`D02Ol600[o2004o`H03Ol200Co0`04o`<0
3Ol00`3oo`05oaD01_l300Ko4@08o`<01_l300Ko0P0:o`<01Ol500_o2P09oa80000C00;o3P02o``0
0_l>00;o5P02o`@01?l400;o1P02o`@00ol500?o1002o`D00ol800;o2003o`D00ol400;o3003o`D0
0ol600Co3002o`P00ol500?o1`02o`P00ol400?o1@03o`D00ol700Co2@02o`H00_l300;o1@02o`L0
0_l600;o0`02oaX00_l700;o5P02o`P00_l700;o1@02o`@01?l400;o1@03o`@00_l<00?o1@03oa40
000C00;o3P02o``00_l>00;o5P02o`@01?l400;o1P02o`@00_l700;o1002o`D00_l900;o2002o`L0
0_l400;o3002o`L00_l600Co3002o`P00_l700;o1`02o`P00_l600;o1@02o`L00_l700Co2@02o`H0
0_l300;o1@02o`L00_l600;o0`02oaX00_l700;o5P02o`P00_l700;o1@02o`H00_l400;o1@02o`D0
0_l<00;o1`02oa40000C00;o3P02o``00_l>00;o5P02o`<01Ol400;o0P02o`800_l300;o2@02o`<0
0_l400;o2P02o`L00_l900;o0`02o`800_l700;o2@02o`@00_l200;o2`02o`L00_l900;o1P02o`P0
0_l600;o1@02o`L00_l600;o0P02o`P00_l600;o0`02o`D00_l700;o1P02o`<00_l200;o5P0;oaH0
0_l800_o1@02o`L00_l300;o1002o`H00_l200;o1`02o`T00_l@00004`02o`h00_l=0003o`0000`0
0_lF00;o0`02o`030?oo00@00_l200;o1`02o`T00_l300?o0P03o`X00_l700;o2@02o`<00_l200;o
1`02o`T00_l400;o0P02o`/00_l700;o2@02o`H00_l800;o1P02o`d00ol600;o0P02o`P00_l600;o
0`02o`D00_l700;o1P02o`<00_l200;o5`09oaL00_l900Wo1P02o`L00_l300;o0`03o`H00_l200;o
1`02o`T00_l@00004`02o`h00_l=00;o3@02oaH00_l200?o00<0ool01006o`L00_l900;o0`07o`/0
0_l700;o2@02o`<01_l700;o2@02o`<00ol200?o2P02o`L00_l900;o1P03o`l00_l800Oo1P03o`80
0ol700;o2`02o`D00_l700;o2`06oaL00_l500;o5`03o`P00_l500;o1P02o`L00_l300Oo1`06o`L0
0_l900;o400001<00_l>00;o3@02o`d00_lF00;o0P02o`800_l400Ko1`02o`T00_l300Go3@02o`L0
0_l900;o0`06o`L00_l900;o0`02o`@00_l:00;o1`02o`T00_l500Co3`02o`H01ol800;o1002o`L0
0_l;00Wo1`02o`/01_lH00;o0`02oaL01?l900;o0`02o`L00_l700;o0`09o`D01_l700;o2@02oa00
000D00;o3@02o`h000?o00002P02oaL00_l00`3oo`0300;o1002o`800_l700;o2@02o`<00_l0103o
ool<00;o1`02o`T00_l300;o0P02o`L00_l900;o0`02o`@00_l:00;o1`02o`T00_l400Ko3P02o`D0
0ol=00;o1002o`L00_l;00Wo1`02o`/00_l200;o6002o`<00_lF00Ko2002o`<00_l700;o1`02o`<0
0_l500?o1002o`800_l700;o2@02oa00000D00;o3@02o`h00_l;00;o5`05o`<00_l400;o0P02o`80
0_l300?o2002o`<00_l200?o2`02o`L00_l900;o0`02o`800_l200;o0`03o`P00_l200;o1P02o`T0
0_l700?o2002o`@00_l200;o3P02o`D00_l70003o`0000<00_l600;o1P02o`/00_l500;o1`02o`/0
0_l200;o0P02oaD00_l0103ooolF00;o0P02o`T00_l0103oool700;o1`02o`<00_l600;o1002o`80
0_l200;o0`02o`T00_l@00005003o``00_l>00;o2`02oaL01?l400;o1002o`H00_l400;o1`02o`@0
0_l300?o2P02o`P00_l700;o1002o`H00_l400;o1`02o`<00_l600;o2@02o`P00_l700;o1003o`<0
0_l=00;o1@02o`H00_l500;o1P02o`H00_l;00;o1@02o`L00_l;00;o1P02oaD00_l00`3oo`0F00?o
0`02o`P00_l00`3oo`0800;o1P02o`@00_l600;o1002o`H00_l400;o1`02oa40000E00;o3002o`l0
00?o00002002oaP01?l400;o1002o`H00_l500;o1@02o`D00_l400?o2@02o`P00ol500?o1002o`H0
0_l500;o1@02o`<00ol600?o2002o`T00_l500;o1@02o`@00_l=00;o1@03o`@00ol400?o1P03o`D0
0_l;00;o1@02o`L00_l;00;o1P02oaD01OlF00;o1002o`P01Ol800;o1004o`@00_l500?o1002o`H0
0_l400?o1@03oa40000F00;o1`03o`030?oo00P00_l500;o2002oaP01?l200Ko00<0ool02_l500Wo
0`05o`<01Ol300[o1@09o`<03?l500Wo0P06o`801_l300[o1@09o`<01Ol200Go1P0:o`<02Ol300Ko
0P06o`030?oo00Ko1`04o`<01?l300So1P0<oa801olE00Go0P05o`<01ol800[o0`0;o`<03?l500Wo
4P0001L000?o00001@06o`P02Ol80003o`0001L00ol300Ko00<0ool02_l700Go1@05o`<01Ol300[o
1`05o`D03?l700Go1006o`801_l300[o1`05o`D01Ol200Go1P0:o`D01Ol00`3o000200Ko0P06o`03
0?oo00Ko1`04o`<01?l300So1P0<oa801olE00Go0P05o`<01ol800So1@09o`D03?l700Go50000280
0ol800Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(18\\) JAQKIOFP IVYJTVJHJF A YCCUFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?oo`1j00005@02obP00_lf00[o
o`1i00005002obX00_lf00Go0P02ool0N@0001@00_lZ00;o=P000ol0003o07l0000D00;o2@09o`P0
1?l<00;o5`06o`D01_l300Ko1@05o`D01Ol600;o0`0:o`L01Ol500Oo2008oaH02_l800;o2@08o`L0
1_l800So2P02o`T01_l700Co0`04o`D01_l600Oo5@06o`<01_lA00So2005o`X01Ol:00Co1@07o`T0
1_l300;o4@0001<00_l:00Wo1P08o`/00_lD00Wo1006o`<01_l300Wo0`05o`D00ol300[o1@09o`<0
1ol800So5P0:o`L01?l800So1@09o`L02?l900Co1P09o`H01?l300Co0`09o`D01olE00Ko0`06oa40
2?l600Wo1P09o`H02?l300Oo2@06o`800olA00004`02o`h00_l800?o1003o`X00_lD00?o1003o`D0
0_l700;o1003o`D00ol400;o1@03o`P00_l800?o1@03o`@00_l=00;o7P02o`/01?l;00;o2003o`@0
0ol900;o3004o`H00ol400?o1P02o`D00_l400?o1003o`H00_lJ00;o1`02oaH00_l800?o1@03o`@0
0ol500?o1@02o`@00_l500;o3@02o`@01?lA00004`02o`h00_l800;o1P02o`X00_lD00;o1P02o`D0
0_l700;o1002o`L00_l400;o1@02o`T00_l800;o1`02o`@00_l=00;o7P02o`/01?l;00;o2002o`H0
0_l900;o3004o`H00_l600;o1P02o`D00_l400;o1P02o`H00_lJ00;o1`02oaH00_l800;o1`02o`@0
0_l700;o1002o`H00_l400;o3@02o`@01?lA00004`02o`h00_l800;o1P02o`X00_lD00;o1P02o`D0
2ol300;o2@02o`<00_l400;o2P02o`L00_l900;o0`02o`800_l900;o7P02o`X00_l200;o2P02o`P0
0_l600;o2@02o`/00_l200;o1@02o`H00_l600;o1@02o`@00_l600;o1P02o`800_lF00_o5P02o`L0
0ol<00?o3@02o`H00_l400;o0P02o`T00_l300Go4@0001<00_l>00;o2002o`H00_l:00;o5002o`H0
0_l600Wo1002o`T00_l300?o0P03o`X00_l700;o2@02o`<00_l200;o2@07oaT00_l:00;o0P02o`X0
0_l800;o1P02o`T00_l;00;o0P02o`D00_l600;o1P02o`D00_l400;o1P02o`H00_l200;o5`09oaL0
0_l700;o3@02o`h00_l600;o1002o`800_l900;o0`02o`030?oo0140000C00;o3P02o`T00_l400;o
2`02oa`00_l600;o1@02o`@00_l900;o0`07o`/00_l700;o2@02o`<01_l900Wo5`02o`T00ol200?o
2@03o`l00_l900;o2P03o`800ol<00;o1P02o`D00_l<00;o1P06oaL00_l500;o5`03o`H00_l=00;o
3P02o`H00_l400Ko2@02o`800ol00`3oo`0A00004`02o`h00_l:00Oo2`02oa`00_l700;o0`02o`D0
0_l900;o0`05o`d00_l700;o2@02o`<01_l900;o1@03oaH00_l900;o1002o`P01?l?00;o2@02o`X0
0_l400;o3002o`H02Ol<00;o1P06oaP00_l300;o5`04o`H00_l=00;o3P02o`H00_l400Ko2@02o`80
0_l200;o4@0001@00_l=00;o2P06o`/00_lM00;o1`02o`<00_l500;o2@02o`<00_l0103oool<00;o
1`02o`T00_l300;o0P02o`T00_l600;o5P02o`T00_l400;o1`06o`h00_l400;o0`02o`<00_l500;o
1002o``00_l600Wo3002o`H00_l200;o6002o`<00_lF00Ko1@02o`d00_l>00;o1P02o`@00_l200;o
2@02o`030?oo00<00_lA00005002o`d00_l900;o1002o`X00_lM00;o2002o`040?ooo`D00ol800;o
0`02o`800ol;00;o1`02o`T00_l300;o0P02o`800_l500;o1P02oaH00_l800;o1P02o`H00_l200;o
3P02o`@00_l300;o0`02o`@00_l600;o2`02o`H00_l500;o3002o`H00_l200;o0P02oaD00_l0103o
oolF00;o0P02o`D00ol700;o0`03o`L00_l400;o1P02o`@00_l200;o0P02o`D01Ol300;o4@0001@0
0ol<00;o2002o`H00_l900;o7@02o`P00_l00`3oo`0700;o1`02o`@00_l300?o2P02o`P00_l700;o
1002o`H00_l500;o1P02oaH00_l800;o1P02o`D00ol300;o3@02o`@00_l300;o0`02o`@00_l600;o
2`02o`H00_l500;o3002o`H00_l600;o5@02o`030?oo01H00ol300;o1@02o`L00_l400;o1`02o`@0
0_l600;o1002o`H00_l500Co1002oa40000E00;o3002o`P00_l600;o2002oah00_l800Go2002o`D0
0_l500;o1003o`T00_l800?o1@03o`@00_l600;o1@02o`D00olF00;o1`03o`H00ol400;o1002o`d0
0_l400;o0`02o`<00_l300?o1P03o`X00_l600;o1@02o``00_l600;o1P02oaD01OlF00;o1002o`D0
0ol500?o1003o`D00ol400;o1P02o`@00_l600;o1@04o`@00_lA00005P02o`L00ol00`3oo`0800?o
1003o`L00_lJ00[o0P07o`T02Ol300Go0`05o`<02_l500Wo0`0<o`<02olC00[o0P06o`801_l00`3o
o`03o`801Ol600[o00<0ool02_l200Ko0P06o`@02_l200Co0`04o`H02_l00`3oo`0:oa801olE00Go
0P05o`@02_l500[o0`04o`@01?l00`3oo`0:o`@01?l200Ko400001L000?o00001@06o`T02?l80003
o`0001T02_l200Oo2`05o`D01Ol300Go0`0:o`L01Ol500co0`09oaD02_l200Ko0P06o`030?oo00?o
0P05o`H02_l00`3oo`0:o`801_l200Ko100:o`801?l300Co1P0:o`030?oo00[o4P07oaD01Ol200Go
1P05o`030?oo00L01Ol00`3oo`0300Co1004o`030?oo00[o1003o`<01_l@00008P03o`X01_oo0<D0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(19\\) NAQKJMJQ ISYJTVMHJF A WCBRDN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ocL00_l400?o?`02o`@00ooo0380000E00;o
:002ocH02_ln00[oo`0a00005002obX00_lf00Go0P02ocl01Ol200;oo`0a00005002obX00_lf0003
o`0004D000?o0000o`0g00005002o`T02Ol500Go3P02oaH01_l300;o00<0ool01?l300Ko1@05o`D0
1Ol600;o1006o`H01Ol300Go0`06o`/01OlE00[o1002o`030?oo00?o1`08o`L01_l800So2P02o`L0
1Ol300Go0P04o`<01?l500Ko1P07oaD01_l300Ko4@02o`@00_l800Go1P0:o`@01Ol600?o00<0ool0
1_l700Ko0`02oa40000C00;o2P09o`D01ol=00;o5@06o`800ol00`3oo`04o`<01_l300Wo0`05o`D0
0ol200Wo1@05o`<01Ol00`3oo`07o`P02OlC00[o100:o`D02?l500Wo1`08o`T01?l600Go0`05o`80
1?l300Co0`09o`D01olE00Ko0`06oa400_l400;o1P09o`@02ol300Go1@04o`030?oo00So1@06o`80
0olA00004`02o`h00_l=00?o3002oaH00_l400Co0`02o`L00_l400?o1@03o`@00_l500?o0`03o`@0
0ol500;o1`02o`800ol400?o1P03o`D00olF00;o2003o`D00ol700;o2003o`@00ol900;o3004o`L0
0_l700;o1002o`D00_l400?o1003o`H00_lJ00;o1`02oa800ol400?o1003o`D00ol500;o1@03o`@0
0_l500?o1002o`@01?l500;o1004oa40000C00;o3P02o`h00ol;00;o5P02o`@01?l300;o1`02o`@0
0_l700;o1002o`D00_l400;o1P02o`D00_l700;o0P02o`H00_l600;o1`02oaH00_l800;o1`02o`L0
0_l800;o1P02o`T00_l<00Co1`02o`L00_l400;o1@02o`@00_l600;o1P02oaX00_l700;o4P04o`<0
0ol400;o1`02o`D00_l600;o1002o`D00_l500;o1P02o`D00_l400Co4@0001<00_l>00;o3`02o`/0
0_lF00;o0`05o`<02ol300;o2@02o`<00_l400;o1@02o`H00_l500;o0`02o`800_l200;o1P02o`D0
0_l900;o5@02o`P00_l700;o1`02o`P00_l600;o2@02o`/00_l200;o1P02o`<00_l200;o1002o`D0
0_l400;o1P02o`H00_l200;o5P0;oa801?l200Co0`03o`h00_l600;o1002o`@00_l600;o1`02o`@0
0_l300Go4@0001<00_l>00;o2`04o`030?oo00X00_lF00;o0`02o`030?oo00@02Ol400;o2@02o`<0
0ol200?o1@02o`H00_l500;o0P03o`800_l200;o1P02o`D00_l900;o5@02oa000ol700;o2002o`H0
0_l900;o2`02o`800_l600;o0P03o`800_l400;o1@02o`@00_l600;o1P02o`800_lG00Wo4`02o`04
0?l000Co0`02o`l00_l600;o1002o`<00ol600;o1`02o`@00_l300;o00<0ool04@0001<00_l>00;o
2@09o`X00_lF00;o0P03o`030?oo00@00_l500;o1002o`T00_l300Oo3P02o`D00_l20003o`3o0080
0_l:00;o1@02o`T00_lE00;o2`07o`P00ol?00;o2@02o`X00ol200?o1@02o`8000?o0?l00P02o`@0
0_l500;o3002o`H01_lG00;o1@02oa<00_l01P3o003o00;o0`02o`l00_l500?o1007o`L00_l700;o
1002o`800ol00`3oo`0A00004`02o`h00_l900;o1003o`X00_lF00;o0P02o`800_l500;o0`02o`D0
0_l900;o0`05oa000_l500;o00@0ool00_l00`3oo`0:00;o1@02o`T00_lE00;o2@07o`T01?l?00;o
2@02o`X00_l400;o1@02o`040?oo00;o00<0ool01009o``00_l600Ko6002o`<00_lD00;o00<0ool0
0_l00`3oo`0300;o3`09o`D02Ol500;o1`02o`@00_l200;o0P02oa40000D00;o3@02o`P00_l600;o
2@02oaL00_l00`3oo`0300;o1@02o`<00_l500;o2@02o`<00_l0103oool?00;o1@02o`030?oo0080
00Co0?oo2P02o`D00_l900;o5@02o`P00ol=00Ko3P02o`@00_l300;o0`02o`D00_l400;o1@02o`03
0?oo008000Co0?oo1009o``00_l600;o0P02oaP00_l300;o5002o`030?oo00;o00<0ool00`02o`l0
2?l600;o1@03o`@00_l700;o1002o`030?oo00<00_lA00005002o`d00_l800;o1P02o`T00_lG00Go
0`02o`H00_l0103oool500?o2002o`<00_l200?o3P02o`D00_l00`3o00020004o`3oo`X00_l500?o
2002oaD00_l800;o1`000ol0000400;o0P02o`h00_l400;o0`02o`<00_l400;o1P02o`@00_l00`3o
00020004o`3oo`@00_l500;o3002o`H00_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l200?o
1`02o`D00_l400?o1@02o`H00_l400;o1`02o`@01Ol300;o4@0001@00ol<00;o2002o`H00_l900;o
5`04o`@00_l600;o00<0ool01`02o`L00_l400;o0`03o`d00_l500Co0`04o`X00_l600;o1`02oaH0
0_l800;o1P02o`D00ol300;o3@02o`@00_l300;o0`02o`@00_l600;o1004o`<01?l400;o1@02o``0
0_l600;o1P02oaD00_l00`3oo`0D00;o0`02o`<00_l300;o1`02o`D00_l500;o1@02o`H00_l400;o
1P02o`D01?l400;o4@0001D00_l<00;o2002o`H000?o00001`02oaP01?l400;o1P05o`P00_l500;o
1@02o`@00ol<00;o1@04o`@00ol:00;o1`02o`D00_lG00;o2003o`@00ol500;o1002o`d00_l400;o
0`02o`<00_l300?o1P03o`<01?l400?o1002o`D00_l<00;o1P02o`H00_lE00Go5002o`P00_l300?o
1@03o`D00_l400?o1@02o`D00ol400;o1004o`D01?l400;o4@0001H00_l700?o00<0ool02@02o`@0
0_l800;o6004o`801_l200Oo2@09o`<01Ol300Go1@0:o`030?oo00;o1@04o`@02_l400Wo4`0:o`D0
2Ol300Go0P05o`H02_l00`3oo`0:o`801_l200Ko00<0ool00_l500Co0P04o`<01?l600[o00<0ool0
2_lB00Oo5006o`801_l300[o0`0:o`@02ol400[o1@04o`801_l@00005`000ol0000500Ko2@07o`T0
00?o00005`03o`<01_l200Oo2`05o`D01Ol300Go1@0:o`030?oo00;o1@04o`@02_l600Go5@0:o`L0
1Ol00`3o000200Go0P05o`H02_l00`3oo`0:o`801_l200Ko00<0ool00_l500Co0P04o`<01?l600[o
00<0ool02_lB00Oo5006o`801_l500Go00<0ool00`09o`D02Ol600So1`03o`<01_l@00008P03o`/0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(20\\) PASKIMGO KS HTVOGIF A XCBRDI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o2004o``00_lE00So1@06o`<01_l200;o00<0ool0
0ol500Go1P02o`<02_l300Go0`05o`D01_l900Go5005o`H00_l200;o00<0ool00olE00Co0`04o`@0
2?l:00;o2`05o`T01_l600[o0`07oaD01_l300Ko3`05o`801Ol600Go1P0:o`@01Ol600?o00<0ool0
1_l700[o4P0001<00_l900[o1`06o``00_lD00So1@06o`<01_l200[o0`05o`D00ol300[o0`05o`<0
1Ol300[o1@09oa801Ol500?o0P0:oa<01?l300Co1008o`T01?l800Wo1@0:o`@02_l300Oo5@06o`<0
1_l?00Go0P05o`@02Ol400_o0`05o`D01?l00`3oo`08o`D02_lB00004`02o`X00_l500;o1P03o`80
0ol;00;o5P02o`/00_l700;o1003o`D00ol400;o1@03o`P00_l800;o1`02o`<01?l500;o1003o`D0
0olC00;o1@03o`<00ol500?o4`02o`D00_l800;o3004o`L00ol500?o0`04o`D00_l800;o2@02oaX0
0_l700;o4P03o`@00ol400?o1@03o`D00_l500?o1002o`D00ol400;o1004o`P00_lF00004`02o`/0
0ol;00;o1002o`/00_lF00;o2`02o`L00_l400;o1`02o`@00_l500;o2@02o`P00_l700;o0`02o`L0
0_l400;o1`02oa<00_l500;o1002o`L00_lC00;o1@02o`P00_l<00Co1`02o`L00_l300;o1`02o`P0
0_l900;o6P02o`L00_lC00?o0P03o`D00_l700;o1@02o`H00_l400;o1@02o`D00_l600;o2002oaH0
000C00;o3003o`T00_l600;o2P02oaH00_l;00_o1002o`L00_l400;o1002o`X00_l800;o0`02o`80
0_l200?o1`02o`<00_l900;o4P02o`@00_l500;o1`02oa<00_l500;o2002o`/00_l200;o1@02o`T0
0_l0103oool700;o2002o`T00_l200;o5P0;oa@00_l200;o1@03o`h00_l600;o1002o`@00_l600;o
1`02o`L00_lF00004`02o`d00ol800;o1P02o`X00_lF00Oo1`09o`d00ol400?o0P03o`X00_l800;o
0P03o`800_l200;o1007o`800_l900;o4P03o`800ol=00?o4`02o`D00_l800;o2`02o`800_l500;o
2@02o`030?oo00@01ol700;o2@02o`800_lG00Wo5P04o`H00_l?00;o1P02o`@00_l300?o1P02o`L0
0_l700;o5P0001<00_l>00?o1`02o`H00_l:00;o5P09o`D00_l500;o2007o`D01ol;00;o2002o`80
00?o0?l00P02o`800_l400Oo0P02o`T00_lB00Oo2@07oa@00_l500;o2002o`X00ol200?o1002o`T0
0_l00`3oo`0400Oo1`02o`T01_lG00;o1@02oaH01?l600;o3`02o`D00ol400Oo1`02o`L00_l700;o
5P0001<00_l?00?o1P02o`H00_l:00;o5P02o`D00ol500;o0`02o`L01ol700Go3@02o`P00_l0103o
o`02o`030?oo00800_l=00;o2@02oa801Ol900Oo5P09o`P00_l:00;o1002o`@00_l900;o00<0ool0
4P02o`T01_lH00;o0`02oaL00ol700;o3`09o`D02Ol500;o1`02o`L00_lF00005002o`l00_l600;o
1P02o`T00_lG00;o1P02o`D00_l300;o1P03o``00_l0103oool<00;o2002o`030?oo008000Co0?oo
0P02o`d00_l900;o4P02o`040?ooo`L00olK00Wo0`02o`<00_l300;o1@02o`@00_l400;o2@02o`03
0?oo01800_l900;o0P02oaP00_l300;o5`04o`H00_l?00So1P02o`D00ol400;o1`02o`L00_lF0000
5002oa000_l500;o1P02o`T00_lG00;o1P02o`H00_l0103oool600;o1`000ol0000300;o0P03o`/0
0_l800;o00<0o`000P001?l0ool200;o2002o`<00_l900;o4P02o`800ol600;o1`000ol0000B00;o
1@02o`<00_l300;o0`02o`@00_l600;o0`02o`T00_l00`3oo`0800;o2002o`T00_l200;o0P02oaD0
0_l0103ooolF00Ko1@03o`L00_l500;o1003o`D00_l600;o1002o`L00_l700;o5P0001@00ol?00;o
1@02o`H00_l900;o5`02o`H00_l600;o00<0ool01`02o`H00_l500;o0`03o`X00_l800Co0`04o`<0
0_l600?o1002o`L00_lC00;o0`03o`D00_l600;o5002o`D00_l300;o0`02o`<00_l400;o1P02o`@0
0_l700;o0`02o`H00ol800;o2@02o`H00_lE00;o00<0ool05P03o`800ol500;o1`02o`D00_l500;o
1@02o`H00_l400;o1P02o`P00_lF00005@02o`P00_l500;o1P02o`@00_l900;o6002o`D00ol600Go
1`03o`@00ol500;o1003o`T00_l800Co1003o`<00ol400Co1003o`D00olC00;o1003o`@00ol400?o
5002o`D00_l300;o0`02o`<00_l300?o1P03o`<00ol500?o0`03o`@01?l800;o2@02o`H00_lE00Go
5P02o`@00_l500?o1@03o`D00_l400?o1@02o`D00ol400;o1004o`P00_lF00005P02o`L00ol300?o
1P03o`800ol800;o5`0;o`@01ol900Wo0`05o`<01Ol300[o0`04o`D01?l300[o1@09oa801Ol300Go
0`09oa<01?l300Co0P0<o`801_l200Ko0`09o`D02_l400[o0`0<oa801olE00Go0P05o`@02_l300[o
100;o`@02_l500[o4P0001L000?o00001P07o`P01_l90003o`0001H02Ol600Oo2`05o`030?l00080
1Ol300Go0`0:o`<01?l500Co1@05o`030?oo00L01OlD00Go0`05o`D01Ol00`3o000B00Co0`04o`80
3?l200Ko0P06o`D01Ol900Go00<0ool0100:o`<03?lB00Oo5@05o`801Ol600Go00<0ool00`09o`D0
2Ol600So1`0:oa80000Q00Go2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(21\\) OAVHIMGO KU KTVNGIF AYXCBRDJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1P09o`T00_lI00Go1006o`<01_l600;o2004o`<0
1?l400[o0`05o`<01Ol500Ko2@05oa@01Ol600;o1P04oa@01Ol600;o0`08o`X00_l800Ko0`02o`H0
1_l600[o0`07oaD01_l300Ko0P08o`D01Ol200Go1P05o`H02_l400Go1P03o`030?oo00Ko2006oaD0
000C00;o2@0:o`H02Ol:00;o5P09o`801_l300Ko1@04o`L01?l300Co100:o`<01Ol300Go0`0:o`D0
2OlB00Go1@03o`@02?lB00Go1@03o`<02?l900Co1`06o`800ol400[o100:o`<01olE00Ko0`06o`80
2?l500Go0P05o`@02Ol400_o0`05o`D01?l00`3oo`08o`@02OlD00004`02o`X00_l500;o2P02o`d0
0_lE00?o1@03o`<00_l700;o1`04o`P00_l500;o2@02o`P00_l700;o0`04o`D00_l400?o1@03oa<0
0_l500?o1@02o`@00_lD00;o1@03o`L00_l<00Co2002o`@01?l300Co1@02o`P00_l900;o6P02o`L0
0_l700;o2@03o`@00ol400?o1@03o`D00_l500?o1002o`D00ol400;o1004o`<00ol400?o4`0001<0
0_l;00?o3`02o`d00_lE00;o1`02o`<00_l700;o1`04o`P00_l500;o2@02o`P00_l700;o0`02o`L0
0_l400;o1`02oa<00_l500;o1@02o`H00_lC00;o1@02o`P00_l<00Co2002o`@01?l300;o1`02o`P0
0_l900;o6P02o`L00_l700;o2P03o`800ol500;o1`02o`D00_l600;o1002o`D00_l500;o1P02o`<0
0_l600;o4`0001<00_l<00?o3P02o`d00_lD00;o2@02o`802ol600;o0P02o`L00_l500;o2@02o`P0
0_l300;o0P02o`800ol700;o0`02o`T00_lB00;o1002o`H00_l600;o4`02o`@00_l900;o2`02o`80
0_l700;o0`05o`800ol700;o2002o`T00_l200;o5P0;o`L00_l;00;o0P02o`D00ol>00;o1P02o`@0
0_l400;o1P02o`L00_l200;o1P02oa<0000C00;o3@03o`d00_l=00;o5002o`T00_l300Wo1`02o`80
0_l700;o1@02o`T00_l800;o0P03o`800_l200;o1007o`800_l900;o4P03o`800ol600;o1P02oa<0
0ol200?o2@02o`/00_l200;o1`02o`<00_l00`3oo`0200;o1007o`L00_l900;o0P02oaL02Ol800;o
3004o`H00_l?00;o1P02o`@00_l300?o1P02o`L00_l200;o1P02oa<0000C00;o3P03o``00_l=00;o
5002o`T00_l300;o1@02o`H00ol200?o1P02o`D00_l900;o2002o`8000?o0?l00P02o`800_l400Oo
0P02o`T00_lB00Oo1`02o`H00_lC00Oo2P02o`X00ol200?o1P02o`800ol00`3oo`0200;o1007o`L0
0_l900Ko5`02o`D00_l800?o2`04o`H00_l?00;o1@03o`@01ol700;o1`02o`X00_lC00004`02o`l0
0ol;00;o3@02oa@00_l900;o1002o`<00_l700;o1002o`H02Ol900;o2002o`040?oo00;o00<0ool0
0P02o`d00_l900;o4P05o`T00_l600;o4`05o``00_l:00;o1002o`H00_l200;o0P02o`800_lB00;o
2@06oaP00_l300;o2004o`/00ol700;o3`09o`D02Ol500;o1`02o`X00_lC00005002o`l00_l;00;o
3002oaD00_l900;o1002o`<00_l700;o1002o`H02Ol900;o2002o`030?oo008000Co0?oo0P02o`d0
0_l900;o4P02o`040?ooo`P00_l600;o4`02o`040?ooo`H00_l300;o0`02o`D00_l400;o1P02o`03
0?oo00<00_l200;o4P02o`T00_l200;o6002o`<00_l700Ko2P04o`H00_l?00So1P02o`D00ol400;o
1`02o`X00_lC00005002oa000_l:00;o3002oaD00_l900;o1@02o`040?ooo`H00_l600;o1@02o`D0
0_l900;o2002o`030?l0008000Co0?oo0P02o`P00_l300;o2@02oa800_l200?o1`02o`H00_lC00;o
0P03o`D00_l300;o0`02o`@00_l600;o1@05o`<00_l200;o2002o`P00_l900;o0P02o`800_lE00;o
00@0oooo1`02o`800_l900Ko1@03o`L00_l500;o1003o`D00_l600;o1002o`L00_l:00;o4`0001@0
0ol?00;o2P02o``00_lF00;o1`02o`H00_l00`3oo`0700;o1P02o`D00_l500;o2@02o`P01?l300Co
0`02o`H00ol400;o1`02oa<00_l300?o1P02o`H00_lC00;o0`03o`@00_l300;o0`02o`@00_l600;o
1@04o`@00_l300;o1P03o`P00_l900;o1P02oaD00_l00`3oo`0700?o0`02o`L00ol200?o1@02o`L0
0_l500;o1@02o`D00_l600;o1002o`H00_l;00;o4`0001D00_l800;o1@02o`X00_l;00;o5`03o`D0
0ol600Go1P03o`H00ol400;o1@02o`T00_l800Co1003o`<00ol400Co1003o`D00olC00;o1003o`D0
0_l600;o4`02o`@00ol300;o0`02o`<00_l300?o1P03o`@01?l400;o0`03o`@01?l800;o2@02o`H0
0_lE00Go1`02o`@00_l700;o1002o`D00ol500?o1@02o`@00ol500;o1@03o`@00_l400Co2`02oa<0
000F00;o1`03o`<00ol600?o00<0ool02P02oaT02Ol400Oo1P06o`801_l200Co0`04o`@02_l300Co
1@04o`<02_l500Wo4P05o`<01Ol200Co1004oa001Ol300Go00<0ool02_l200Ko0P06o`801?l200Ko
0`0:o`@02_l300co4P07o`H01Ol200Go0`05o`801Ol400[o0`0:o`@02ol400[o1`0:oa00000G0003
o`0000H01ol700Ko2P000ol0000J00Go1P07o`H01_l200Ko0P04o`<01?l400[o0`04o`D01?l500Go
00<0ool01`05oa@01Ol300Go0P04o`@01?l@00Go0`05o`030?oo00[o0P06o`801_l200?o0`06o`D0
1Ol00`3oo`0400[o0`0<oa801ol600Go0P05o`<01Ol200Go1P05o`030?oo00<02Ol500Wo1P08o`T0
2_l@00008@05o`/00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(22\\) OFVHGMKN IV KUVJGIF BZXABRDM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1@0:o`T00_lI00Go1@07o`d00_l800Co0`04o`L0
1_l400Go0`05o`030?oo00?o1P02o`<01_l300;o4P0:o`P00_lF00Go1P02o`H01?l;00;o2@06o`X0
1_l600[o0`07oaH02_l500[o1005o`801Ol00`3oo`04o`<01_l00`3oo`08o`@01Ol600?o00<0ool0
1_l600Go0`05oa00000C00;o2@0:o`D02_l:00;o5P09o`<01ol<00Co1`04o`<01?l500[o0P05o`<0
1Ol00`3oo`03o`D00ol300Ko0P03oa802_l700Co5@05o`D00ol400So2004o`H02Ol700[o100:o`<0
1olF00_o100:o`@01Ol200Go00<0ool01?l300Ko00<0ool02Ol300Go1@04o`030?oo00So1005o`<0
1Ol@00004`02o`X00_l500;o1P02o`D00_l:00;o5@03o`D00ol400;o3`04o`P00_l500;o1@04o`D0
0_l300;o1`02o`@00_l500?o1@02o`@01?lF00;o2`04oaL00_l500?o1@02o`@00_l800Co1P03o`@0
0ol500Co1@02o`P00_l900;o6`02o`D00ol400;o1@02o`D00ol400?o1002o`L00_l500;o1@03o`@0
0_l500?o1002o`@01?l400;o1`02oa40000C00;o2`03o``00ol?00;o5@02o`L00_l400;o3`04o`P0
0_l500;o1@02o`L00_l300;o1`02o`@00_l500;o1P02o`@01?lF00;o2`04oaL00_l500;o1@02o`H0
0_l700Co1P02o`H00_l500;o1`02o`P00_l900;o6`02o`H00_l400?o1002o`H00ol200?o1@02o`L0
0_l500;o1P02o`@00_l500;o1@02o`H00_l400;o1`02oa40000C00;o3003o``00ol>00;o5002o`T0
0_l300;o0P02o`X00_l200;o1`02o`D00_l400?o1`02o`<00_l300;o0P02o`@00_l400;o1`02o`<0
1OlF00;o2P02o`800_lF00;o1002o`H00_l600;o1P02o`800_l500;o1P02o`@00ol700;o2002o`T0
0_l200;o5`02o`H00_l500?o0`02o`L00_l200;o1P0;o`D00_l600;o1002o`@00_l600;o1`02o`<0
0_l300;o0P02oa40000C00;o3@03o``00ol=00;o5002o`T00_l300;o0P02o`X00_l200;o1`02o`D0
0_l400;o1007o`800_l200?o0P02o`@00ol200?o1`02o`<00_l00`3oo`0F00;o2P02o`800_lF00?o
0P03o`H00_l600;o1P02o`800_l500;o1P02o`@00_l400Oo1`02o`T00_l200;o5`02o`H00_l600;o
0`02o`P01?l800Wo1P02o`H00_l400;o0`03o`H00_l700;o0`02o`800ol200;o4@0001<00_l>00?o
3003o``00_lD00;o2@02o`<01_l900?o0P03o`H00_l500;o1002o`@01ol200;o0P000ol0o`0200;o
1007o`P00_l200?o00<0ool05P02o`T00ol200?o5@07o`L00_l600;o1@03o`800ol<00;o1002o`@0
1ol700;o2@06oaL00_l500?o1P03o``01?l800;o1@02o`H00_l500?o1007o`L00_l700;o0`02o`80
00?o0?l00P02oa40000C00;o3`03o``00ol;00;o5002o`T00_l300Ko2@02o`@00_l600Wo1002o`d0
0_l0103oo`02o`030?oo00@01Ol:00;o0P02o`800_lF00;o2@02o`@00_lE00Go2@02o`H00_l500;o
1002o``00_l400;o4P02o`T01_lG00Wo2003o`/00ol:00;o0`02o`L02Ol500Wo1@02o`L00_l300;o
00@0ool00_l00`3oo`0A00005002o`l00_l=00;o2P02oaD00_l900;o0`02o`800_l900;o1002o`H0
2Ol400;o3@02o`030?oo008000Co0?oo1002o`040?ooo`T00_l00`3oo`0300;o5P02o`T00_l400;o
5@02o`040?ooo`P00_l600;o1@02o`@00_l<00;o1002oa800_l900;o0P02oaL02?l500;o0`02o`/0
1?l900;o0`02o`L02?l600;o1@03o`@00_l700;o0`02o`030?oo008000Co0?oo4@0001@00_l@00;o
3@02o`T00_lE00;o2@02o`<00_l200;o0P02o`@00_l600;o1@02o`D00_l400;o2002o`<00_l00`3o
00020004o`3oo`@00_l200?o2005o`<00_lF00;o2002o`H00_lD00;o0P03o`L00_l600;o1002o`H0
0_l;00;o1002o`P00_l800;o2@02o`800_l200;o4`02o`@00ol400;o0`03o`T01_l900;o00@0oooo
1`02o`@00ol500;o1P02o`@00_l700;o0`02o`030?l0008000Co0?oo4@0001@00ol?00;o3@02o`T0
0_lF00;o1`02o`@00_l600;o1002o`H00_l500;o1@02o`D00_l600?o0`04o`<01?l400;o0`03o`L0
1?l400;o5P02o`P00_l600;o5002o`<00ol600;o1P02o`@00_l600;o2`02o`D00_l600?o2002o`T0
0_l600;o4`02o`D00_l400;o1003o`L00ol200?o2002o`030?oo00P00_l500;o1@02o`H00_l400;o
1P02o`@01?l300Co4@0001D00_l800;o1@02o`H00_l500;o2002oaL00ol500?o1002o`H00_l300?o
1P03o`@00_l500;o1@03o`@01?l300Co1003o`@00_l400?o1P04o`@00_lF00;o1`03o`H00olC00;o
1003o`D00_l600;o0`03o`H00ol:00;o1@03o`@01?l800;o2@02o`H00_lC00;o1003o`@00_l500;o
1`02o`@00_l800Go2002o`@00ol500;o1@03o`@00_l400Co1004o`@00olA00005P02o`L00ol300?o
1P03o`<00ol700;o6@09o`<03?l200Ko0P06o`801?l300Co1@0:o`801?l500Co00<0ool00ol300Go
0`04o`801_lA00[o0P06o`801_l@00Go0`05o`801?l400Co00<0ool01?l200Ko100:o`<02_l400[o
0`0<oa402_l500[o1005o`801Ol300Oo1`0:o`@02ol400[o1004o`D01?l@00005`000ol0000600Oo
2007o`P000?o00006P05o`D03?l200Ko0P06o`801?l300Co1`05o`030?oo00801?l500Co00<0ool0
0ol300Go0`03o`<01_lA00[o0P06o`801_l@00Go0`05o`801?l400Co00<0ool01?l200Ko100:o`D0
1Ol00`3oo`0400[o0`0<oa402Ol600[o1005o`801Ol300Oo1`09o`D02Ol600So1P04o`D01?l@0000
8@05o`X01Ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(23\\) PFVJGNKN IV KVZJGIF B XEAWFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1`05o``00_lE00So1P07o`d00_l900Ko2`06o`D0
1_l300;o0P05o`H00_l300Ko0`02oa802_l800;o5P05o`H00_l600;o2@0:o`D01_l:00Ko1P0:o`<0
1olF00[o4`05o`801Ol200co0P06o`<01_l200;o1002o`@01ol900Ko0`02oa40000C00;o2@0:o`D0
2Ol;00;o5008o`H01ol<00Co1P09o`P02_l300Ko0P03o`801Ol500?o0`06o`800olB00[o1`04oaD0
1Ol500?o1@04o`P02_l300Wo1`0:o`@02_l300Oo5P0;oa801Ol200Go0P0<o`801_l300Ko0P02o`@0
0_l400Oo2@06o`800olA00004`02o`X00_l500;o1@02o`D00_l;00;o5P02o``00_l?00Co1P03o`@0
0ol600Co1@02o`@00_l400Co1002o`D00ol500;o1004oaH00_l;00Co5`02o`D00ol600Co2@02o`D0
0_l300?o1003o`D01?l500;o2002o`T00_lK00;o1@03oa800ol400?o1@02o`H00_l400;o1`02o`<0
0ol400?o1@02o`d00_l400Co4@0001<00_l;00?o4P02o`X00_lF00;o3002o`l01?l600;o1P02o`H0
0_l700;o1002o`@01?l400;o1@02o`H00_l400Co5P02o`/01?lG00;o1@02o`L01?l900?o1002o`<0
0_l600;o1@02o`L00_l800;o2@02oa/00_l600;o4`03o`800ol600;o1P02o`@00_l700;o0`04o`<0
0ol500;o3@02o`@01?lA00004`02o``00olA00;o2P02oaH00_l<00;o0P02o`X00_l200;o1@02o`H0
0_l500?o1`02o`@00_l300Go1002o`@00_l700;o0`05oaH00_l:00;o0P02oaH00_l400;o1`02o`80
0_l900?o0`02o`<00_l600;o1003o`L00_l800;o2@02o`800_lG00;o1P02oa@00_l200;o1`02o`80
0_l200;o100;o`<01?l200Co1@02o`800_l900;o0`05oa40000C00;o3@03oa000_l:00;o5P07o`L0
0_l200;o2P02o`800_l500;o1P02o`D00_l400Oo0`02o`<00_l00`3oo`0400?o0P03o`L00_l300;o
00<0ool05P02o`X00_l200;o5P03o`800ol700;o0P02o`X00_l300;o0`02o`H00_l400;o1007o`L0
0_l900;o0P02oaL00_l600;o5@04o`P00_l200;o2@09o`@00_l0103o0004o`D00_l200;o2@02o`<0
0_l00`3oo`0A00004`02o`h00ol>00;o2`02oaH02Ol500Ko2@03o`800ol<00;o1@02o`@01ol300;o
0P03o`030?oo00@01ol800;o0P03o`030?oo01H00_l900?o0P03oaD01ol700?o0P03o`T00ol?00;o
1002o`@01ol700;o2@06oaL00_l500?o5@04o`P01_l900;o1@02o`@00_l01P3o003o00;o1@06o`T0
0_l200?o00<0ool04@0001<00_l?00?o2P04o``00_lF00;o1@03o`@01_l900;o1002o``00_l500;o
3P02o`800_l200;o1005o`X00_l200;o0P02oaH00_l900;o1002oaD01Ol900;o1002o`X00ol>00;o
1002oa800_l900Ko5`09oaH00ol900Ko2P02o`<00_l500;o00<0ool00_l00`3oo`0500Ko2@02o`80
0_l200;o4@0001@00_l?00;o2P03o``00_lG00;o1P02o`@00_l200;o2@02o`@00_l<00;o1@02o`h0
0_l00`3oo`0300;o1002o`040?ooo`T00_l00`3oo`0300;o5P02o`T00_l400;o5@02o`040?ooo`P0
0_l400;o1P02o`<00_l>00;o1002oa800_l900;o0P02oaL02?lG00Co2002o`800_l:00;o0`02o`D0
0_l00`3oo`02o`030?oo00D00_l200;o2@02o`030?oo00<00_lA00005002oa000_l;00;o2`02oaL0
0_l600;o1002o`800_l200;o1002o`H00_l;00;o1@02o`P00_l400Go0`02o`@00_l200?o2005o`<0
0_lF00;o2002o`H00_lD00;o0P03o`H00_l600;o1@02o`<00ol=00;o1002o`P00_l800;o2@02o`80
0_l200;o4`02o`@00olE00Ko1`02o`800_l200;o1`02o`040?ooo`@00_l300;o0`02o`@00_l200;o
0P02o`D01Ol300;o4@0001@00ol?00;o3002o`X00_lG00;o1P02o`@00_l600;o1002o`H00_l;00;o
1P02o`H00ol400Co1002o`@00_l300?o1`04o`@00_lF00;o2002o`H00_lD00;o0`03o`D00_l600;o
1@02o`@00ol<00;o1@02o`H00ol800;o2@02o`H00_lC00;o1@02oa@00ol200?o1P02o`H00_l700;o
00<0ool01@02o`<00_l300;o1002o`H00_l500Co1002oa40000E00;o2002o`D00_l<00;o2@02oaP0
0_l500?o1002o`H00_l300?o1P03o`X00_l600?o1004o`@01?l400;o1002o`@00ol600Co1002oaH0
0_l700?o1P03oa<00_l400?o0`03o`H00ol400;o1@02o``00_l500?o1004o`P00_l900;o1P02oa<0
0_l400?o5002o`@00_l600;o1P02o`L01Ol500;o2002o`@00_l600;o1@04o`@00_lA00005P02o`L0
0ol300?o1P02o`<00ol800;o5`0;o`<03?l200Ko0P06o`@02_l400[o0`04o`801_l00`3oo`03o`<0
1Ol300Co0P06oa402_l200Ko0P06oa001Ol300_o0P06o`<02_l600[o0`0:o`@02_l300co4@0:oa<0
1Ol200Go0P0<o`@01ol500Ko0P06o`030?oo00[o1004o`801_l@00005`000ol0000600Oo1`07o`T0
00?o00005P09o`D03?l200Ko0P06o`@02_l600Go00<0ool00`03o`<01_l00`3oo`03o`<01Ol300?o
0`06oa402_l200Ko0P06oa001Ol300_o0P06o`<02_l600[o1@05o`030?oo00@02_l300co4@09oa@0
1Ol200Go0P0<o`@01ol500Ko0P06o`030?oo00[o1003o`<01_l@00008@05o`X01?oo0<H0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(24\\) RFVHGPKS HV KVZKFNHZB XEAXFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o2@06o`T00_lE00Go1P0:o`d00_l800Co0`04o`L0
1_l400So1P05o`H00_l300;o00<0ool00olE00Co0`04o`L00_lF00Go1P02o`H00_l900[o0`05o`H0
0_l00`3oo`05o`T01_l300;o0`04o`<01?l400[o0`0:oa<01Ol200Go0P0<o`801_l300_o0P05o`80
1ol900Ko0`02oa40000C00;o2@0:o`T01_l:00;o5005o`D02ol<00Co1`04o`<01?l500[o0P08o`H0
1Ol500?o0`0:oa<01?l300Co1P04oaD01Ol500?o1@04o`P02_l300Go1@03o`030?oo00Go2@06o`80
0ol300Co0`04o`@02_l300_o4P05o`801Ol200co0P06o`<02ol200Go0P07o`T01_l200?o4@0001<0
0_l:00;o1@02o`/00_l<00;o5P02o`D00ol400;o3`04o`P00_l500;o1@04o`D00_l400;o3002o`D0
0ol400?o1@03oa<00_l500;o1`04oaL00_l500?o1P04o`T00_l500;o1@02o`D00ol400;o3@02o`@0
1?l400;o1@02o`H00_l500;o1@02o`D00olB00?o1003o`D00_l600;o1002o`L00_l300?o1003o`D0
0_l=00;o1004oa40000C00;o2`03oa000_l<00;o5P02o`D00_l500;o3`04o`P00_l500;o1@02o`L0
0_l400;o3002o`D00_l500;o1`02oa<00_l500;o1`04oaL00_l500;o1`04o`T00ol400;o1@02o`D0
0_l500;o3@02o`@01?l400;o1@02o`H00ol400;o1@02o`H00_lC00?o0P03o`H00_l600;o1002o`L0
0_l400?o0P03o`H00_l=00;o1004oa40000C00;o3003o`T02_l:00;o5P02o`@00_l600;o0P02o`X0
0_l200;o1`02o`D00_l400?o1`02o`@00_l<00;o1002o`H00_l700;o4`02o`D00_l600;o0P02oaH0
0_l400;o1`02o`800_l900?o0`02o`D00_l400;o1P02o`800_l900;o0`05o`@00_l500;o1`03o`<0
0_l500;o1P02oa@00_l200;o1`02o`800_l200;o100;o`D00_l200;o1`02o`800_l900;o0`05oa40
000C00;o3@03o`P02_l:00;o5P02o`<00ol600;o0P02o`X00_l200;o1`02o`D00_l400;o1007o`<0
1ol700?o0P03o`h00olC00;o1@02o`H00_l200;o5P03o`800ol700;o0P02o`X00_l300;o1@03o`80
0ol600;o0P02o`T00_l300;o00<0ool01002o`D00_l800;o0`02o`D00_l600;o5@04o`P00_l200;o
2@09o`L01?l800;o0P02o`T00_l300;o00<0ool04@0001<00_l>00?o1`02o`@00_l<00;o5P07o`L0
1_l900?o0P03o`H00_l500;o1002o`@01ol300Wo1@07o`X01olD00;o1@02o`D00ol200?o5@07o`L0
0ol200?o2@03o`T01ol700Ko2@02o`800ol00`3oo`0400;o1@02o`P00ol900;o1@03oaD01?l800Ko
2@02o`D00_l700Co2006o`T00_l200?o00<0ool04@0001<00_l?00?o1`02o`<00_l<00;o5P09o`D0
1_l900;o1002o`H02Ol400;o3P02o`D00ol400Go2P07oaH02Ol500;o1002oaD01Ol900;o1002o`X0
0ol800Go2@06o`T00_l200;o0P02o`@02Ol900?o2009oaH00ol900Ko2P02o`<00_l800?o2@06o`T0
0_l200;o0P02oa40000D00;o3`02o`P000Co00000_l;00;o5`02o`D00ol400;o0P02o`T00_l400;o
1P09o`@00_l>00;o1P02o`@00_l0103oool800?o6`09o`D00_l400;o5@02o`040?ooo`P00_l400;o
1P02o`<00_l800;o00@0oooo2002o`800_l900;o00<0ool00`02o`@02Ol500;o0`02o`P02?lG00Co
2002o`800_l:00;o0`02o`P01?l800;o0P02o`T00_l00`3oo`0300;o4@0001@00_l@00;o1`02o`80
0_l;00;o5`02o`H00_l400;o0P02o`800_l400;o1P02o`D00_l500;o1002o`P00_l400;o1P02o`@0
0_l200?o1`02o`L000?o00004P02o`D00_l400;o1P02oa@00_l200?o1P02o`H00_l500;o0`03o`L0
0_l200?o1`02o`800_l200;o1@05o`<00_l400;o1@02o`D00_l300?o1`02o`@00olE00Ko1`02o`80
0_l200;o1`02o`040?ooo`L01_l700;o0P02o`800_l500Go0`02oa40000D00?o3`02o`P000?o0000
0_l;00;o5`02o`H00_l400;o1P02o`@00_l600;o1@02o`D00_l500;o1P03o`@00_l600;o1002o`<0
0ol600;o1P02oa@00_l500;o1002o`H00_lD00;o0`03o`D00_l600;o1@02o`@00ol600;o0`03o`H0
0_l600;o1@04o`@00_l400;o1@02o`D00_l400?o1P02o`D00_lD00?o0P03o`H00_l600;o1`02o`03
0?oo00L00ol200?o1P02o`H00_l500Co1002oa40000E00;o2002o`D00_l90004o`3oo`X00_lH00;o
1@03o`@00_l600;o0`03o`H00ol400;o1@02o`D00ol400Co1002o`D00ol400;o1003o`D00ol400?o
5002o`D00_l300?o1P03oa<00_l400?o0`03o`H00ol400;o1@02o`H00_l400?o1@02o`H00_l500Co
1002o`@00_l500;o1@02o`D00_l600;o1003oa@00_l400;o1P02o`H00_l700Go1`02o`@00_l600;o
1P02o`D01?l400;o4@0001H00_l700?o0`03o`T01?l900;o5`0;o`<03?l200Ko0P06o`801?l300Co
1@0:o`802ol300Go0`05o`@02OlC00Co0`04o`030?oo00Co0P06oa001Ol300_o0P06o`<02_l300Go
0`05o`030?oo00[o1004o`801_l200Co0`04o`@02_l300[o4`05o`801Ol200co1007o`H01Ol200Go
0P0<o`@01?l200Ko400001L000?o00001P07o`/00ol90003o`0001H02Ol500co0P06o`801_l200Co
0`04o`L01Ol00`3oo`0200Wo1@05o`<01Ol600Go00<0o`004P04o`<01?l00`3oo`04o`801_l@00Go
0`0;o`801_l300[o0`05o`<01Ol00`3oo`0:o`@00ol300Ko0P04o`<01?l400[o0`09oa@01Ol200Go
0P0<o`@01ol600Go0P05o`803?l400?o0`06oa00000Q00Go3003ool0a@000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(25\\) RFVIKPKS FV KVZKFNHZAWXEAVFP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o1`05o``00_lE00Go1P0:o`d00_l800[o1005o`H0
0_l00`3oo`06o`H01Ol600;o0`02o`030?oo00?o5007o``00_lF00Go1P02o`H00_l900[o0`05o`H0
0_l00`3oo`05o`T01_l300;o0`04o`<01?l400[o0P06o`<01_l200;o1002o`D01Ol200Go0P0<o`80
1_l300Ko1@02o`L01ol800So5@0001<00_l900[o1@09o`/00_lD00Go1@0;o``01?l700[o1005o`D0
0ol00`3oo`06o`H01Ol500?o0`0:oa801ol;00Co5@05o`D00ol500Co200:o`<01Ol500?o00<0ool0
1Ol900Ko0P03o`<01?l300Co100:o`801_l300Ko0P02o`@00_l500Go0P05o`803?l200Ko0`06o`@0
1?l600Oo2008oaD0000C00;o2P02o`D00_l500;o1@02o`/00_lF00;o1@03o`@00_l?00Co2`02o`X0
0_l500?o1002o``00_l500?o1003o`D00olC00;o3P04oaL00_l500?o1P04o`T00_l500;o1@02o`D0
0ol400;o3@02o`@01?l400;o1@02o`H00_l500;o1002o`L00_l300?o1003o`D00ol400?o1@02o`H0
0_l400;o1`02o`H01?l800;o3@02oaT0000C00;o2`03oa800_l:00;o5P02o`D00_l500;o3`04o`/0
0_l:00;o1@02o`D00_l<00;o1@02o`D00_l700;o4`02o`h01?lG00;o1@02o`L01?l900?o1002o`D0
0_l500;o1@02o`d00_l400Co1002o`D00_l600?o1002o`@00_l700;o0`04o`<00ol600?o0P03o`H0
0_l600;o1002o`L00_l600Co2002o`d00_lI00004`02o``00olA00;o2P02oaH00_l400;o1P02o`80
0_l:00;o0P02o`X00_l:00;o1002o`H00_l<00;o1002o`H00_l700;o4`02o`800_l900;o0P02oaH0
0_l400;o1`02o`800_l900?o0`02o`D00_l400;o1P02o`800_l900;o0`05o`@00_l500;o1`03o`<0
0_l400_o0`04o`801?l700;o0P02o`L00_l200;o0P02o`@02ol500;o0P02o`L00_l200;o2@02oaT0
000C00;o3@03oa000_l:00;o5P02o`<00ol600;o0P02o`X00_l200;o2P02o`X00ol200?o1P07o`L0
0ol200?o3P03oa<00_l200;o2@02o`800_lF00?o0P03o`L00_l200;o2P02o`<00_l500?o0P03o`H0
0_l200;o2@02o`<00_l00`3oo`0400;o1@02o`P00_l300;o1@09o`@00_l0103o0004o`P01?l800;o
0P02o`T02Ol600;o0P02o`L00_l200;o2@07oa@0000C00;o3P03o`l00_l:00;o5P07o`L01_l900?o
0P03o`T00_l:00Oo1`09o`D01ol:00Oo5006o`P00ol200?o5@07o`L00ol200?o2@03o`T01ol700Ko
2@02o`800ol00`3oo`0400;o1@02o`P00ol900;o1@02o`@00_l01P3o003o00;o2004o`P01_l900;o
1@02o`D00ol200?o1P06o`T02OlB00004`02o`l00ol700;o1002o`/00_lF00Wo1@06o`T00_l400;o
2@02o`X01Ol900;o1@03o`@01Ol:00Oo5P06o`P00_l400;o5@05o`T00_l400;o2P03o`P01Ol900Ko
2@02o`800_l200;o1009o`T00ol900;o0`02o`D00_l00`3oo`02o`030?oo00P00ol900Ko2P02o`<0
0_l600;o1002o`H01_l900;o1@03oa40000D00;o3`02o`L02?l:00;o5`02o`D00ol400;o0P02o`T0
0_l400;o2@02o`X00_l0103oool800;o1P02o`@00_l0103oool800?o6`02o`800_l800;o1002oaD0
0_l0103oool800;o1002o`H00_l300;o2002o`040?ooo`P00_l200;o2@02o`030?oo00<00_l400Wo
1@02o`<00_l900;o0`02o`D00_l00`3oo`02o`030?oo00P01?l800;o0P02o`X00_l300;o1P02o`@0
0_l600;o0P02o`T00_l600;o4@0001@00_l@00;o1P07o`/00_lG00;o1P02o`@00_l200;o0P02o`@0
0_l600;o2002o`X00_l200?o1`02o`H00_l400;o0P03o`L00_l70003o`0001800_l200;o0P02o`<0
0_l600;o5002o`800ol600;o1P02o`D00_l300?o1`02o`800ol700;o0P02o`800_l500Go0`02o`@0
0_l500;o1@02o`<00ol900;o00@0oooo1002o`<00_l300;o1P06o`L00_l200;o0P02o`L00_l0103o
ool500;o1P02o`D00_l200;o0P02o`D00_l600;o4@0001@00ol?00;o1P02oa000_lG00;o1P02o`@0
0_l600;o1002o`H00_l800;o2P02o`<00ol600;o1P02o`@00_l300?o1P02o`H00_lD00;o1P02o`<0
0_l600;o5002o`<00ol500;o1P02o`D00_l400?o1P02o`<00ol600;o1P02o`D01?l400;o1002o`D0
0_l500;o1003o`P00_l00`3oo`0500;o0`02o`<00_l500?o0P03o`H00_l600;o1`02o`030?oo00H0
0_l600;o1@02o`H00_l500;o1P02oa40000E00;o2002o`D00_l600;o3`02oaP00_l500?o1002o`H0
0_l300?o1P03o`L00_l:00;o1003o`D00_l500?o1002o`@00ol500?o1003oa@00_l600;o0P03o`H0
0olC00;o1003o`<00ol600?o1002o`D00_l600;o1003o`D00_l600;o1@04o`@00_l400;o1@02o`D0
0_l500;o2005o`D00_l800;o1@02o`@00_l600;o1P02o`L01Ol500?o1P03o`@00_l600;o1@02o`D0
0olA00005P02o`L00ol300?o1P02o`h00_lG00_o0`0<o`801_l200Ko0P0:o`@01Ol300Go00<0ool0
2Ol300Go0`05o`@02OlB00co00<0ool01?l200Ko4005o`<02ol200Ko0`0:o`<01Ol300Go00<0ool0
2_l400Co0P06o`801?l300Co100:o`@01ol500Ko0P06o`801Ol200Go0P0<o`@01ol500Ko0P06o`03
0?oo00[o0`0;oa80000G0003o`0000H01ol700So20000ol0000F00Wo1@0<o`801_l200Ko0P0:o`@0
1Ol300Go00<0ool01ol500Go0`05o`H01Ol00`3o000A00co00<0ool01?l200Ko4005o`<02ol200Ko
0`0:o`<01Ol300Go00<0ool02_l400?o0`06o`801?l300Co100:o`@01ol500Ko0P06o`801Ol200Go
0P0<o`@01ol500Ko0P06o`030?oo00[o0`09oa@0000Q00Go2008ool0a0000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(26\\) RFUIKPLS IV FVZKFIHYAWXEBSFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o2004o``00_lE00Go1P0:o`d01?l600[o1005o`H0
0_l00`3oo`06o`H03Ol300;o00<0ool00olE00[o2002oaH01ol<00;o2@0:o`<01Ol600;o00<0ool0
1Ol900[o1004o`<01?l500So0`06o`<01_l200;o1002o`D01Ol200Go0P0<o`<02_l500;o00<0ool0
0ol500Oo3005oa@0000C00;o2@0:o`L01ol;00;o5005o`D02ol;00So100:o`@01Ol500?o00<0ool0
1_l600go0`0:oa<02_l700Co5@07o`/01?l800[o0`05o`D00ol00`3oo`05o`T02_l400Co0`04o`D0
2?l300Ko0`06o`800_l400;o1@05o`801Ol200co0`0;o`@02_l300Oo2P09oa80000C00;o2P02o`D0
0_l600;o1002o`/00_lF00;o1@03o`@00_l>00;o1002o`P00_l:00;o1@03o`@00_l=00;o1P02o`<0
0ol500?o5P02o`/01?lG00;o3P04o`T00_l500;o1@02o`D00ol400;o4002o`T00_l500;o2@02o`P0
0_l700;o0`03o`@00ol500?o1003o`D00_l600;o1@02o`D00ol300?o1@03o`@00_l<00?o1@03oa40
000C00;o2`03o`X00_l600;o2P02oaH00_l500;o1@02o`d00_l600;o1`02o`X00_l500;o1@02o`d0
0_l600;o0`02o`L00_lF00;o2`04oaL00_l>00Co2@03o`@00_l500;o1@02o`D00_l@00;o2@02o`D0
0_l900;o2002o`L00_l300Co0`03o`H00ol200?o1P02o`H00_l500;o1P02o`<00_l700;o1002o``0
0_l700;o4@0001<00_l<00?o2@02o`H00_l:00;o5P02o`@00_l600;o0P02o`T00_l600;o1`02o`X0
0_l400;o1P02o`d00_l600;o0`02o`L00_lF00;o2P02o`800_lF00;o0P02o`T00_l200;o2@03o`<0
0_l500;o1002o`H00_l200;o3002o`T00_l500;o2@02o`P02ol300Co0P04o`L00_l200;o1`02o`80
0_l200;o1@02o`H00_l300;o1`02o`@00_l200;o1`02o`T00_l@00004`02o`d00ol800;o1P02o`X0
0_lF00;o0`03o`H00_l200;o2@02o`H00_l700;o2P03o`800ol600Oo2002o`H00_l;00?o5P02o`X0
0_l200;o5P02o`800_l900;o0P02o`X00_l300;o1@03o`800ol600;o0P02o``00_l900;o1@02o`T0
0_l900Wo1002o`040?l000Co2004o`P00_l200;o2@02o`H00_l;00?o1002o`800_l700;o2@02oa00
000C00;o3P03o`L00_l600;o2P02oaH01ol700Ko2@02o`H00_l700;o2P07o`L02Ol600;o3P07oaL0
0_l900?o0P03oaD01_l800?o0P03o`T00ol900Oo1`06o``00_l900;o1@02o`T00ol800;o1@02o`@0
0_l01P3o003o00;o2004o`P01_l900;o1@03o`H01ol500Ko1`02o`T00_l@00004`02o`l00ol600?o
1002o`/00_lF00Wo1@06o`T00_l600;o1`02o`X01Ol900;o1@03o`D00_l<00Oo6@02o`T00_l400;o
5@06o`P00_l400;o2P03o`P01Ol900Ko3002o`T02Ol800Co2@02o`<00_l500;o00<0ool00_l00`3o
o`0800?o2@06o`T02Ol500Oo1`06o`L00_l900;o400001@00_l?00;o1P09o`X00_lG00;o1@03o`@0
0_l200;o2@02o`H00_l700;o2P02o`040?ooo`P00_l600;o1@02o`/00olN00;o2@02o`@00_lE00;o
0P02o`P00_l400;o1P02o`<00_l800;o00@0oooo2002o`800_l<00;o2@09o`L01_l800;o0`02o`D0
0_l00`3oo`02o`030?oo00P01?l800;o0P02o`T02?l500?o3002o`800_l700;o2@02oa00000D00;o
4002o`D00_l00`3oo`02o``00_lG00;o1P02o`@00_l200;o0P02o`D00_l600;o1`02o`X00_l200?o
1`02o`H00_l500;o2`02o`L000?o00005@02o`P00_l600;o5002o`800_l200;o0`02o`H00_l500;o
0`03o`L00_l200?o1`02o`800_l200;o2002o`T00_l500;o1`02o`800_l900;o00@0oooo1002o`<0
0_l300;o1P06o`L00_l200;o0P02o`D00_l400?o1002o`L000?o00000`02o`800_l200;o0`02o`T0
0_l@00005003o`l00_l600;o4002oaL00_l600;o1002o`H00_l500;o1P02o`L00_l:00;o0`03o`H0
0_l600;o1@02o`/00_l600;o5`02o`P00_l600;o5002o`H00_l300;o1P02o`D00_l400?o1P02o`<0
0ol600;o1P02o`P00_l900;o1@02o`H00ol300;o2002o`030?oo00D00_l300;o0`02o`D00ol200?o
1P02o`H00_l500;o1@02o`@00_l600;o1@02o`H00_l400;o1`02oa40000E00;o2002o`D00_l600?o
3P02oaP00_l500?o1002o`H00_l500;o1P02o`L00_l:00;o1003o`D00_l500?o1@02o`/00ol400?o
5`02o`L00ol600?o4`02o`H00_l200?o1P03o`@00_l500;o1P02o`@00ol500;o1P02o`P00_l900;o
1@02o`H00_l400;o2005o`D00_l800;o1@02o`@00_l600;o1P02o`D00_l400?o1003o`@00ol500;o
1P02o`@00ol500?o4@0001H00_l700?o0`03o`L00ol<00;o5`0;o`<03?l400Co1004o`802_l400Go
0`05o`030?oo00Wo0`08o`T02OlC00[o0P06o`801_l@00co00<0ool01?l200Ko0`0:o`<01Ol300Go
00<0ool02_l400[o1004o`<01?l300Go0P05o`<01ol500Ko0P06o`801Ol200Go0P0<o`<02_l600Wo
0`0<o`D02OlB00005`000ol0000600Oo2@07o`L000?o00005P09o`D03?l400Co1004o`802_l400Go
0`05o`030?oo00Oo1@08o`/01Ol00`3o000B00[o0P06o`801_l@00co00<0ool01?l200Ko0`0:o`<0
1Ol300Go00<0ool02_l400[o1004o`<01?l300Go0P05o`<01ol500Ko0P06o`801Ol200Go0P0<o`<0
2Ol900Go00<0o`000P0<o`L01OlD00008@05o``01Ooo0<<0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(27\\) RFUIKOLS GV KTZJFIHZAWWEAXBO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800[o2002o`h00_lE00Go1P0:o`d01?l600[o1005o`H0
0_l500Go1@0=o`<00_l00`3oo`03oaP01_l900;o5P05o`H00_l300So1P0:o`D01_l600Oo2@0:o`@0
1?l300Co100:o`801_l300Ko0P02o`@00_l700;o1002o`@03?l200Ko0`0;o`801Ol200[o2@05oa@0
000C00;o2@0:o`P00_l?00;o5005o`D02ol;00So100:o`@01Ol500?o0`09o`<03Ol300[o500:o`H0
1?lE00Go1@03o`<02?l600[o0`09o`D01ol900[o1004o`<01?l400[o0P06o`<01_l200;o1002o`L0
0_l400;o100<o`801_l300_o0P05o`802ol600Wo4P0001<00_l:00;o1@02o`T00_l>00;o5P02o`D0
0ol400;o3P02o`@00_l800;o2P02o`D00ol300?o1@03o`D00_l600;o0`03o`D00olB00Co1@02o`H0
1?lG00;o1@03o`L00_l:00;o1@02o`<00ol400?o1P02oa000_l900;o1@02o`H00_l500;o1002o`L0
0_l300?o1003o`D00ol400?o1@02o`H00_l400;o1`02o`<00ol400?o1@02o`D00ol400?o1@03oa40
000C00;o2`03o`h00_l>00;o5P02o`D00_l500;o3@02o`H00_l700;o2P02o`D00_l400;o1`02o`D0
0_l600;o0`02o`L00_lB00;o1`02o`H01?lG00;o1@02o`P00_l:00?o1002o`<00_l600;o1P02oa00
0_l900;o1@02o`H00ol400;o1002o`L00_l300Co0`03o`D01?l300?o1@02o`H00_l400;o1`02o`@0
0ol200?o1P02o`H00_l400;o1`02oa40000C00;o3003o`d00_l>00;o5P02o`@00_l600;o0P02o`T0
0_l600;o1`02o`X00_l400;o1002o`T00_l400;o1P02o`<00_l700;o4@03o`L00_l500;o0P02oaH0
0_l400;o2@02o`/00ol300;o0`02o`H00_l600;o0P02o``00_l900;o1@02o`L00ol300;o100;o`<0
1?l200Co1@04o`801?l500;o0P02o`800_l400_o1@02o`800_l700;o1P02o`<00_l900;o400001<0
0_l=00?o3@000ol0000<00;o5P02o`<00ol600;o0P02o`T00_l600;o1`02o`X00ol200?o1002o`T0
0_l400;o1P02o`/00olA00;o1007o`@00_l200;o5P03o`800ol900;o3002o`<00_l300;o1P02o`H0
0_l200;o3002o`T00_l500;o2002o`<00_l500Wo1002o`040?l000Co1@02o`040?l000Co1@02o`80
0_l900Wo1`04o`P00_l600;o0`02o`T00_l@00004`02o`h00ol<00;o3@02oaH01ol700Ko2@02o`H0
0_l700;o2P07o`D00_l900;o1002o`h01olB00;o1007o`<00ol200?o5@07o`X00_l<00?o3`02o`H0
1_l<00;o2@02o`D00_l800?o2@02o`D00_l400;o00H0o`00o`02o`D00_l01P3o003o00;o1@06o`T0
0_l500;o1`04o`P00_l500?o0`02o`T00_l@00004`02o`l00ol;00;o3@02oaH02Ol500Ko2@02o`H0
0_l700;o2P05o`L00_l900;o1002o``01olD00;o3P02o`@00_lE00Go3002o`d00ol>00;o1P06o``0
0_l900Wo2@03o`T00_l300;o1@02o`030?oo00;o00<0ool01@02o`030?oo00;o00<0ool01@06o`X0
0_l300;o2003o`T02Ol400;o2@02oa00000D00;o3`02o``000?o00002P02oaL00_l500?o1002o`80
0_l900;o1P02o`L00_l:00;o00@0oooo1P02o`T00_l400;o2`03oaT00_l>00;o1002oaD00_l0103o
ool600;o0`02o`<00_l400;o0`02o`h00_l600;o0P02o``00_l900Wo1@02o`<00_l900;o0`02o`D0
0_l00`3oo`02o`030?oo00D00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l800Co2008o`D0
0_l900;o400001@00_l@00;o2`02o`/00_lG00;o1P02o`@00_l200;o0P02o`D00_l600;o1`02o`X0
0_l200?o1@02o`T00_l400;o2`02o`L000?o00004002o`P00_l300;o1P02oa@00_l200?o1@02o`<0
0_l300;o1002o`<00ol=00;o1P02o`800_l200;o2002o`T00_l500;o1@02o`<00ol900;o00@0oooo
1002o`<00_l300;o0`02o`<00_l300;o1002o`800_l200;o1`02o`040?ooo`L01_l700;o1003o`@0
0_l900;o400001@00ol?00;o2`02o`/00_lG00;o1P02o`@00_l600;o1@02o`H00_l700;o2P02o`<0
0ol500;o1`02o`D00_l;00;o1P02oa<00_l600?o0`02o`H00_lD00;o0`03o`@00_l300;o0`02o`@0
0_l400?o3002o`H00_l600;o2002o`T00_l500;o1@02o`@00ol800;o00<0ool01@02o`<00_l300;o
0`02o`<00_l300;o1002o`H00_l700;o00<0ool01`03o`800ol600;o1@02o`D00_l700;o4@0001D0
0_l800;o1@02o``000?o00002002oaP00_l500?o1002o`H00_l500;o1P02o`L00_l:00;o1003o`@0
0ol500?o1@02o`/00ol400?o4`03o`@01?l200?o1P03oa<00_l400?o0`02o`<00_l300;o1002o`D0
0_l<00;o1P02o`H00_l800;o2@02o`D00_l500;o1@02o`P01Ol500;o2002o`<00_l800;o1002o`H0
0_l700Go1`02o`@00_l600;o1003o`D00ol500?o4@0001H00_l700?o0`03o`D00_l500;o2002oaL0
2ol300co1004o`@01?l200[o1005o`<01Ol300Wo0`08o`T02OlD00[o00<0ool01?l200Ko4005o`<0
1Ol00`3oo`0:o`@02_l600[o00<0ool02_l400[o1004o`<01?l400[o1007o`D01_l200Ko00<0ool0
1?l200Ko00<0ool02_l400Oo1P05o`801Ol200[o1`09oa80000G0003o`0000H01ol600Wo20000ol0
000F00Wo1@0<o`@01?l400Co0P0:o`@01Ol300Go1@05o`D02?l;00Go00<0o`005@05o`040?oo00Ko
0P06oa001Ol300Go00<0ool02_l400[o1P0:o`030?oo00[o100:o`@01?l300Co100:o`@01ol500Ko
0P06o`030?oo00Co0P06o`030?oo00[o1007o`H01Ol200Go0P09o`X01OlD00008@05o`L02Ooo0<@0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(28\\) RFTEGPLS FX KQZMFIHZA YEAUBO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`P02_l800Co3002oaD0
1Ol600[o2P08o`@03?l700Ko1008o`H03Ol300;o00<0ool00olD00Oo1`05o`801OlA00Go1P02o`D0
1Ol700[o0`05o`<01Ol00`3oo`05o`T02_l400Co0`04o`@02_l200Ko0`06oa402?l400co0P06o`<0
1_l500Co1@0:o`T01OlD00004`02o`T02_l600So2`02oa@01Ol500_o2P08o`@03?l500[o0P08o`H0
3Ol300[o4P07o`L01Ol200Go4@05o`D00ol300Wo1@0:o`<01Ol300Go00<0ool01Ol900[o1004o`<0
1?l400[o0P06o`<01_lA00So100<o`801_l300Ko0`08o`<02ol600Wo4P0001<00_l:00;o1@02o`D0
0ol400?o2P02oaH00_l500?o1002oa000_l900;o1P02o`@01?l500;o1002o`d00_l600;o0`03o`D0
0olC00;o2`03o`@00olD00;o1@03o`<00ol500?o1@02o`D00_l400;o1`02o`@00_l@00;o2@02o`D0
0_l600;o1@02o`@00_l700;o5P02o`T00_l600;o1002o`L00_l500;o1002o`D00_l500?o1003o`D0
0olA00004`02o`/00ol:00;o1P02o`X00_lF00;o1@02o`D00_l@00;o2@02o`H00_l400;o1`02o`@0
0_l=00;o1P02o`<00_l700;o4`02o``00ol200?o5@02o`D00_l400;o1`02o`D00ol400;o1002o`L0
0_l400;o4002o`T00_l500;o1P03o`@00_l400;o1`02oaH00_l900;o1P02o`@00_l700;o1002o`H0
0_l400;o1P02o`@00_l700;o4@0001<00_l<00?o2@02o`H00_l:00;o5P02o`@00_l600;o0P02o``0
0_l900;o0P02o`800_l300?o1`02o`@00_l=00;o1P02o`<00_l700;o4`02o`800_l900;o0P02oaH0
0_l400;o1002o`T00_l500?o0`02o`@00_l300;o0P02o`@00_l200;o3002o`T00_l500;o1`03o`<0
0_l400_o5P02o`T00_l200;o0P02o`@02ol400;o1P02o`@00_l600;o0`02o`T00_l@00004`02o`d0
0ol800;o1P02o`X00_lF00;o0`03o`H00_l200;o3002o`T00_l200;o1`02o`@01ol300Oo2002o`H0
0_l;00?o4`02o`800_l:00Co5`03o`800ol400;o2@02o`H00_l300;o1002o`800ol200;o1002o`80
0_l<00;o2@02o`D00_l800;o0`02o`D02OlG00;o2@02o`800_l900Wo1@02o`H00_l400;o1P02o`<0
0_l900;o400001<00_l>00?o2002o`@00_l;00;o5P07o`L01_l<00;o2@06o`L00_l400Oo0`09o`H0
0_l>00Oo5006o`X01?lG00Oo1@02o`T00_l600?o2002o`8000?o0?l00P02o`@01_l<00;o2@02o`D0
0_l800?o2@02o`D00_lG00?o2006o`T00_l500;o1@02o`H00_l400;o1@03o`<00_l900;o400001<0
0_l?00?o2007o`/00_lF00Wo1@06o``00_l900Ko1`02o`h00_l500?o1@02o``01olF00Ko2P03oaP0
1Ol700;o2@02o`L00ol700;o00@0ool00_l00`3oo`0400Ko3002o`T02Ol900?o2@02o`<00_lG00Co
2006o`X00_l300;o1P02o`H00_l400Wo1002o`T00_l@00005002o`l00_l800Ko2`02oaL00_l500?o
1002o`800_l700;o0`02o`<00_l400;o0P02o`L00_l>00;o1P02o`D00_l;00?o6`02o`800_l:00Co
5`02o`040?ooo`H00_l900;o0`02o`<00_l700;o00<0ool00P001?l0ool400;o0P02o``00_l900Wo
1@02o`<00_l900;o0`02oaH01_l700;o0P02o`X00_l300;o1P02o`H00_l400So1@02o`T00_l@0000
5002oa000_l600;o1002o`X00_lG00;o1P02o`@00_l200;o0P02o`<00_l300;o0`02o`@00_l200;o
0P02o`<00_l800;o1002o`H00_l500;o2`02o`L000?o00004P02o`800_l200;o1@06oaH00_l200?o
1@03o`P00_l300;o0`03o`H00_l00`3o00020004o`3oo`@00_l200;o0P02o`P00_l900;o1@02o`D0
0_l300?o2@02o`040?oooaH00_l200;o1`02o`800_l200;o1`02o`040?ooo`H00_l600;o1002o`@0
0ol400;o2@02oa00000D00?o3`02o`D00_l600;o2@02oaL00_l600;o1002o`H00_l300;o0`02o`<0
0_l400;o1P02o`@00_l600?o1002o`H00_l500;o2`02o`H00_lD00;o1P02o`@00ol200?o5@02o`<0
0ol500;o1`02o`@00_l400?o1@04o`<01?l400;o1P02o`P00_l900;o1@02o`D00_l400?o2002o`03
0?oo01H00ol300;o1P02o`H00_l700;o00<0ool01`02o`H00_l400;o1@02o`D00_l700;o4@0001D0
0_l800;o1@02o`D00_l600;o2002oaP00_l500?o1002o`H00_l300;o0`02o`<00_l400;o1P02o`@0
0ol400Co1002o`D00ol500;o2`03o`@00olD00;o1P02o`@00_l400;o5@02o`@00ol500;o1@02o`D0
0_l500;o1@04o`@00ol400;o1P02o`P00_l900;o1@02o`D00_l500;o2005oaH00_l400;o1P02o`H0
0_l700Go1`02o`H00_l400;o1003o`D00ol500?o4@0001H00_l700?o0`03o`D00ol400?o1`02oaL0
2ol300co0`0<o`803?l500[o0P0;o`<02?l900Wo4P0<o`801Ol200Go4@05o`<01Ol300Wo1@0:o`<0
1?l500Co00<0ool02_l400[o1004o`<01?l400[o1007oaD01Ol200Go0P0<o`@01ol700Co1004o`03
0?oo00So1`09oa80000G0003o`0000H01ol700So20000ol0000F00Wo1@0<o`<03?l200co1`05o`03
0?oo00802Ol500So2`05o`030?l001403?l200Go0P05oa401Ol300Go1@05o`L02_l300Co1@04o`03
0?oo00[o100:o`@01?l300Co100:o`@01olE00Go0P05o`803?l400Oo1`04o`@01?l00`3oo`07o`X0
1OlD00008@05o`T01_oo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(29\\) MGUEGPLS FT IQZRFIHZA  EDSAO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`P02_l500Go3P02oaD0
1Ol300Go1@06o`X01?l500co1`06o`@02?l600go0`02o`030?oo00?o5007o`T02?lD00[o1`05o`L0
2_l300Go1P0:o`T02_l400Co0`04o`@02_l200Ko0`06oad03?l400So1P02o`030?oo00?o1006o`<0
1_l500Go500001<00_l900[o1@07o`d00_lD00Go0`05o`<02_l600So0`0<o`D02_l200So1P0=o`<0
2_lB00Oo2@08oa@02_l500Wo1@0:o`<01Ol500_o2@0:o`@01?l300Co100:o`801_l300Ko7@0<o`@0
2_l400[o0P06o`<01_l300Wo4P0001<00_l:00;o1@02o`X00ol<00;o5@02o`L00_l300Co1@02o`H0
0_l400;o1@02o`H00_l400Co1@02o`@00_l=00;o1P02o`<00ol500?o4`02o`l00_lK00;o2003o`D0
0ol500;o1@02o`D00_l500?o1002oa000_l900;o1@02o`H00_l500;o1002o`L00_lQ00;o1P02o`D0
0_l400Co0`03o`D00ol300;o1`02o`@00ol500?o4@0001<00_l;00?o4003o`/00_lE00;o1`02o`<0
0_l700;o1@02o`H00_l400;o1P02o`@00_l700;o1002o`d00_l600;o0`02o`L00_lC00;o3`02oa/0
0_l800;o1`02o`D00ol400;o1@02o`D00_l500;o4002o`T00_l500;o1P03o`@00_l400;o1`02ob40
0_l600;o1@02o`H00_l300;o1`02o`<00_l700;o1002o`L00_lA00004`02o``00ol@00;o2`02oaD0
0_l300;o0P02o`800ol700;o1@02o`H00_l400;o0P02o`800_l300?o1`02o`@00_l=00;o1P02o`<0
0_l700;o4`02o`800_l;00;o6`02o`L00_l900;o1@03o`<00_l500;o1002o`H00_l200;o3002o`T0
0_l500;o1`03o`<00_l400_o8@02o`800_l200;o1@02o`L00_l200;o1`02o`<02ol300;o2@02oa00
000C00;o3@03o`/01?l00`3oo`0:00;o5@02o`800ol200;o0P02o`@01ol400;o1P02o`@00_l200;o
1`02o`@01ol300Oo2002o`H00_l;00?o4`02o`800_l;00;o6`02o`L00_l900;o1P02o`<00_l500;o
0`03o`H00_l200;o3002o`T00_l500;o2002o`<00_l500Wo8P02o`800_l900;o1`02o`X00ol400Wo
1002o`T00_l@00004`02o`h00ol800Wo2P02oaD00_l20003o`3o00800_l200;o1007o`@00_l600;o
1006o`L00_l400Oo0`09o`H00_l>00Oo5006o`/00_lK00;o1`02o`T00_l600?o2@07o`L01_l<00;o
2@02o`D00_l800?o2@02o`D00_lR00Ko2@02o`L00_l500Oo1@02o`D00_l400;o2@02oa00000C00;o
3`03o`L00_l400?o2P02oaD00_l0103oo`02o`030?oo00800_l?00;o1P02o`@01_l700;o3P02o`D0
0ol500;o3007oaH01_l;00;o6`02o`L00_l900;o1`03o`P02Ol500Ko3002o`T02Ol900?o2@02o`<0
0_lS00Ko2@02o`L00_l300Oo2002o`<00_l500;o2@02oa00000D00;o3`02o`H00_l600;o2@02oaH0
0_l00`3oo`020004o`3oo`800_l?00;o1P02o`@00_l200;o1`02o`h00_l600;o1@02o`/00olK00;o
0P02o`H00_l300;o0`02oaH00_l700;o2@02o`<00_l300;o2002o`D00ol400;o0P02o``00_l900Wo
1@02o`<00_l900;o0`02ob<00_l200;o2@02o`L00_l200?o3@02o`<00_l500;o2@02oa00000D00;o
4002o`D00_l600;o2@02oaH00_l00`3o00020004o`3oo`800_l800;o1@02o`H00_l400;o0P02o`80
0_l300;o2002o`@00_l600;o1@02o`/00_l70003o`0001800_l200;o0P02o`800_l300;o0`02oaH0
0_l700?o2002o`<00_l300?o1`02o`H00_l400;o0P02o`800_l800;o2@02o`D00_l500;o0`03o`T0
0_l0103ooolS00;o0P02o`800_l500;o1`02o`800_l70003o`0000D00_l0103oool500;o2@02oa00
000D00?o3`02o`D00_l600;o2@02oaH01?l300Co0`02o`H00ol500;o1P02o`@00_l600;o1002o`H0
0ol400;o1P02o`D00_l;00;o1P02oa@00_l600;o0P02o`<00_l300;o5P02o`P00_l700;o1002o`@0
0ol600;o1P02o`@00_l600;o2002o`T00_l500;o1@02o`@00ol800;o00<0ool09002o`H00_l500;o
1P02o`<00_l600;o1`02o`030?oo00L00_l700;o4@0001D00_l800;o1@02o`D00_l60003o`0000L0
0_lG00Co1003o`<00ol400Co1@02o`H00_l400;o1P02o`@00ol400Co1002o`D00ol500;o2`03o`@0
0olD00;o1P02o`800_l300;o0`02oaH00_l900;o1@02o`D00_l500;o1P02o`D00ol400;o1P02o`P0
0_l900;o1@02o`D00_l500;o2005ob@00_l600;o1@02o`@01?l300?o1003o`L01Ol700?o1@03oa40
000F00;o1`03o`<00ol600;o1002o`P00_lG00Co1@04o`<02_l400Co1004o`030?oo00[o1@0:o`80
2ol300So2@09oa803?l200co4P0:o`D02Ol500[o0`0;o`<03?l400[o1004o`<01?l400[o1007ob<0
3?l400[o1@09o`@01ol900Wo4P0001L000?o00001P07o`L01ol90003o`0001H01?l500Co1@05o`03
0?oo00@01?l400Co00<0ool02_l700Go00<0ool00P09o`D02?l;00Go00<0o`004@0<o`803?lB00[o
1`05o`L02_l300Wo1@0<o`@02_l400Co0`04o`@02_l400Oo8`0<o`@02?l900Go00<0o`000`07o`/0
1OlD00008@05o`X01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(30\\) MFUFKPLPWJT IQYRIHGZA WIDSEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`X01Ol;00Co3002oaD0
1Ol300Go00<0ool01Ol=00Co1@07o`P01Ol600;o00<0ool01_l600go0P08o`P00_l400;o1`06o`P0
2?lD00[o1`05o`P02?l400Go1P03o`030?oo00So1@04o`<01?l600Ko1P0:o`801_l300Ko4@02o`@0
0_l500[o1@08o`H00_l00`3oo`03o`D03?l300Go1P02oa00000C00;o2@09o`P01_l<00;o5005o`<0
1Ol00`3oo`05o`/02?l300Oo2005o`D00ol00`3oo`06o`H03Ol200So2002o`@00_l500Wo1`08oa@0
2_l500Wo1P08o`@01Ol500Co00<0ool02?l500Co0`04o`@02_l400[o0P06o`<01_lA00;o1002o`D0
2_l500[o100:o`<03?l300Go1@03oa00000C00;o2@02o`D00_l700?o0P03o`/00_lE00;o1`02o`@0
0_l>00;o1002o`D00_l=00;o1@03o`@00_l=00;o1P02o`@00_l;00?o1003o`@00ol400?o2@02oa/0
0_l800?o1@03o`P00_l900;o1@03o`L00_l:00;o1@02o`@01?l500;o1@02o`D00_l400;o1`02oa80
0ol400?o2002o`X00_l400Co0`03o`D00ol400;o1P02o`D00_l500?o4@0001<00_lA00;o1P02o`@0
0_l;00;o5@02o`L00_l400;o3@02o`H00_l400;o3@02o`D00_l500;o3@02o`H00_l400;o2`04o`<0
0ol400;o1P02o`T00_lK00;o2002o`L00_l800;o2@02o`D00_l800;o2P02o`D00_l400;o1`02o`D0
0ol400;o1002o`L00_lB00Co0`03o`P00_l:00;o1P02o`<00_l700;o1002o`H00_l500;o1@02oa80
000C00;o4@02o`D00_l600;o2P02oaD00_l300;o0P02o`@00_l200;o2@02o`H00_l400;o0P02o`T0
0_l400;o1P02o`d00_l600;o1002o`/01?l200Co1002o`H00_l900;o6`02o`L00_l900;o1`02o`T0
0_l400;o2@02o`X00_l500;o0`03o`L00_l600?o0`02o`@02olB00Co0P04o`P00_l:00;o1`02o`80
0_l700;o1002o`800_l200;o1@02o`@00_lC00004`02oa400_l500;o1P02o`X00_lE00;o0P03o`80
0_l400;o0P02o`T00_l600;o1002o`800_l900?o0P03o`H01ol800;o1P02o`@01ol600;o00@0o`00
1?l400;o1P02o`T00_lK00;o1`02o`T00_l700;o2@02o`<00ol900;o2P02o`D00_l300;o1007o`H0
0_l300;o1@09oa<00_l0103o0004o`P00_l:00;o1`02o`X00ol400;o0P02o`T00ol200?o4`0001<0
0_l@00;o1P02o`H00_l:00;o5@02o`8000?o0?l00P02o`@01_l900;o1P02o`@01_l900Oo1`09o`H0
0_l<00Wo1002o`060?l00?l00_l<00;o2@02oa/00_l700;o2@02o`L00ol800Oo2P02o`X00_l500;o
0`02o`@01ol600?o2@02o`D00_lC00;o00H0o`00o`02o`P00_l:00;o1`02o`D01ol500Ko2@07oa@0
000C00;o3@04o`L00_l600;o2P02oaD00_l0103oo`02o`030?oo00@01_l900;o1P02o`@01_l900Go
2@02o`D00ol500;o3002o`D00ol300;o00<0ool00_l00`3oo`0<00;o2@02oa/00_l700;o2@02o`H0
1?l800Wo2002o`X02Ol300;o4P03o`T00_l300;o5002o`030?oo00;o00<0ool02002o`X00_l700;o
0`07o`L01_l900Go5P0001@00_l<00?o2002o`H00_l900;o5P02o`030?oo008000Co0?oo1002o`80
0_l900;o1P02o`@00_l200;o2@02o`040?ooo`P00_l600;o1@02o``00_l600;o0`02o`030?oo00;o
00<0ool03002o`@00_l300;o0`02oaH00_l700;o2@02o`D01_l700;o1@03o`L00_l:00Wo0`02o`h0
0_l300;o2@02o`<00_lD00;o00<0ool00_l00`3oo`0800;o2P02o`L00_l200?o3002o`800_l900;o
00@0oooo5@0001@00_l>00;o1`02o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`800_l200;o
1@02o`H00_l400;o0P02o`800_l500;o0P03o`L00_l600;o1@02o``00_l600;o0P02o`<00_l300;o
2`02o`@00_l300;o0`02oaH00_l700?o2002o`D00_l200;o1`02o`H00_l700;o2P02o`D00_l300;o
2002o`@00_l300?o2@02o`040?oooa<00_l300;o0`02o`L00_l:00;o1`02o`800_l70003o`0000<0
0_l200;o0P02o`D00_l200?o500001@00ol>00;o1P02o`H00_l900;o5P04o`<01?l400;o1P02o`D0
0_l600;o1002o`H00_l500;o0`03o`H00_l600;o1@02o``00_l600;o0P02o`<00_l300;o2`02o`@0
0_l300;o0`02oaH00_l800;o1`02o`D00ol300;o1P02o`H00_l700;o2P02o`D00_l400;o1P03o`@0
0_l400?o2002o`030?oo01@00_l300;o0`02o`L00_l:00;o1P02o`<00_l600;o1@02o`H00_l500;o
0`03oa<0000E00;o3P02o`L00_l400;o2@02oaL01?l400?o1002o`H00_l500;o1P02o`@00_l600;o
1@02o`@00ol500;o1@03o`D00_l<00;o1@03o`800_l800;o2`02o`@00_l300;o0`02oaH00_l900;o
1@02o`H00_l400;o1P02o`D00ol700;o2P02o`D00_l400?o1004o`@00_l500;o2005oa@00_l800;o
1`02o`X00_l400Co0`03o`@00ol500;o1P02o`D00_l400?o4P0001H00_l700;o0`03o`L00ol200?o
2002oaL01?l500Co00<0ool02_l400Co1004o`030?oo00[o0`05o`<01Ol00`3oo`09o`<02?l700_o
0P06o`801_l500[o00<0ool02_lB00[o1@09o`@01Ol200Go0P0;o`@02_l500Co0`04o`@02_l400[o
1007oa@01_l200Ko0P0:o`D02_l500Wo0`0<o`<01Ol300Go400001L000?o00001@07o`T01_l90003
o`0001H01?l500Co00<0ool02_l400Co1004o`030?oo00[o0`05o`<01Ol00`3oo`07o`D02?l700Wo
1006o`801_l500[o00<0ool02_lB00[o1`05o`H01Ol200Go0P09o`H02_l500Co0`04o`H01Ol00`3o
o`0400[o1007oa@01_l200Ko0P0:o`D02?l900Go00<0o`000P0<o`<01Ol300Go400002401?l;00Co
o`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(31\\) MEUHKPLPWHTWGTYRIMF D WIDSEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2@09o`T00_lE00Go0`05o`030?oo00[o2004o`H0
1?l300Co0`05o`H00_l00`3oo`06o`H03Ol200So2002o`@00_l600Co0`04o`@02?l600;o1002o`T0
1_l600So1`08o`@01Ol600?o00<0ool02?l400Go0`05o`030?oo00Go5`08oaH00_l400;o1@0:o`D0
2?l600;o00<0ool00ol500co0`05o`H00_l@00004`02o`T02Ol700Wo2P02oa@01Ol300Go00<0ool0
2_l600So1004o`<01?l300Go1@03o`030?oo00Ko1P0=o`802?l800;o1002o`H01?l300Co1008o`H0
0_l400;o1`0:o`@02?l700So1005o`D01?l00`3oo`08o`@01Ol300Go00<0ool01OlG00[o5002o`@0
0_l500[o1@0:o`@02_l300co0`05o`D00ol@00004`02o`T00_l500;o2`02o`d00_lE00;o1`02o`@0
0_l600;o1P02o`@00_l500;o1@02o`H00_l500?o1002o`d00_l600;o1002o`/00ol400?o1P02o`D0
0_l800;o2003o`@00ol500Co1@02o`L00_l=00;o2@02o`D00ol700;o2@02o`L00_l400;o6`02o`@0
1?lB00?o1003o`P00_l:00;o1004o`<00ol500?o1002o`H00_l500;o1@03oa40000C00;o4@02o`X0
0_l=00;o5@02o`L00_l400;o1P02o`D00_l600;o1002o`D00_l600;o1@02o`D00_l=00;o1P02o`@0
0_l;00Co0`03o`H00_l500;o2002o`P01?l300?o1@02o`L00_l700;o3@02o`T00_l500;o2002o`T0
0_l700;o1002oa/00_l600;o4P04o`<00ol800;o2P02o`H00_l300;o1`02o`@00_l600;o1@02o`D0
0_lB00004`02oa400_l:00;o3@02oaD00_l300;o0P02o`@00_l200;o0P02o`D00_l600;o1002o`D0
0_l600;o1002o`H00_l=00;o1P02o`@00_l;00Co0P04o`H00_l500;o2002o`P01?l200Co1003o`L0
0_l700;o3@02o`T00_l400;o2@02o`T00_l300;o0P02o`@00_l200;o5`02o`L00_lA00Co0P04o`P0
0_l:00;o1`02o`800_l700;o1002o`800_l200;o1@02o`@00_lC00004`02oa400_l:00;o3@02oaD0
0_l200?o0P02o`@00_l200;o2@02o`H00_l400;o1@02o`H00ol200?o1P07o`P00_l600;o1007o`H0
0_l0103o0004o`H00_l500;o2002o`P00_l0103o0004o`@00_l400Oo1P02o`d00_l900;o0`03o`T0
0_l900;o0P03o`800_l400;o0P02oaL00_l700;o4@02o`040?l000Co2002o`X00_l700;o2P03o`@0
0_l200;o2@03o`800olC00004`02oa000_l;00;o3@02oaD00_l20003o`3o00800_l400Ko2@02o`H0
0_l400;o1@02o`H01ol700Wo1P02o``02Ol400;o00H0o`00o`02o`H00_l500;o2002o`P00_l01P3o
003o00;o1002o`@01ol600;o3@03o`P01ol:00;o2@02o`8000?o0?l00P02o`@01_lG00;o1`02oa40
0_l01P3o003o00;o2002o`X00_l700;o1@07o`D01_l900Oo500001<00_l=00Co3002o`d00_lE00;o
00@0ool00_l00`3oo`0400Ko2@02o`H00_l400Wo1P05o`T00_l500?o1@02o``00_l500?o0`02o`03
0?oo00;o00<0ool01P09o`P00_l800;o00<0ool00_l00`3oo`0400;o4@02o``01?l800Wo2002o`T0
0_l0103oo`02o`030?oo00@01_lG00;o1`02oa400_l00`3oo`02o`030?oo00P00_l:00;o1`02o`<0
1ol700Ko2@05oaH0000D00;o3003o`d00_l<00;o5P02o`030?oo008000Co0?oo1002o`800_l900;o
1P02o`@02Ol600;o00@0oooo2002o`H00_l500;o3002o`H00_l300;o00<0ool00_l00`3oo`0600Wo
0`02o`<00_l300;o0`02o`030?oo00;o00<0ool01002o``00_l300;o0`02o`H01_l700;o1@03o`L0
0_l900;o00<0ool00P001?l0ool400;o0P02oaL00_l700;o4@02o`030?oo00;o00<0ool02002o`X0
0_l700;o0P03o``00_l200;o2@02o`040?oooaD0000D00;o3P02o``00_l<00;o5P02o`030?l00080
00Co0?oo1002o`800_l200;o1@02o`H00_l400;o1@02o`H00_l200?o1`02o`H00_l500;o3002o`H0
0_l200;o0`02o`<00_l500;o1@02o`<00_l300;o0`02o`800_l300;o0`02o`<00_l800;o0P02o`<0
0_l300;o1P02o`800_l700;o1P02o`L00_l900;o00<0o`000P001?l0ool400;o0P02o`800_lC00;o
1`02oa000_l300;o0`02o`L00_l:00;o1`02o`800_l70003o`0000<00_l200;o0P02o`D00_l200?o
500001@00ol>00;o2`02o``00_lF00Co0`04o`@00_l600;o1@02o`H00_l400;o1@02o`H00_l300?o
1P02o`H00_l500;o3002o`H00_l200;o0`02o`<00_l500;o1@02o`<00_l300;o0`02o`800_l300;o
0`02o`@00_l600?o0P02o`<00_l300;o1@03o`<00_l600;o1P02o`L00_l900Co0`04o`@00_l600;o
4`02o`H00_lA00;o0`02o`<00_l700;o2P02o`H00_l300;o1P02o`D00_l600;o1@02o`<00olC0000
5@02o`h00_l;00;o2`02oaL01?l400?o1002o`H00_l500;o1P02o`@00_l500;o1P02o`@00ol500;o
1@03o`D00_l<00;o1@03o`800_l800;o1@02o`D00_l300;o0`02o`<00_l200;o2002o`@00ol400Co
0P02o`<00_l300;o1@02o`@00_l600;o1@03o`L00_l900Co1003o`@00_l600;o4`02o`@01?lA00;o
2002o`L00_l:00;o1004o`<00ol400?o1@02o`H00_l500;o1003oa80000F00;o1`02o`<00ol700?o
00<0ool02P02oaL01?l500Co00<0ool02_l400Co1004o`801?l300Co0`05o`<01Ol00`3oo`09o`<0
2?l700_o0P06o`801_l300Co0`04o`803?l00`3oo`04o`801_l400[o0P0<o`<01Ol200Go0P0;o`@0
2_l400Co1@04o`030?oo00[o4P0:oa401_l200Ko0P0:o`D02_l500Wo0`0<o`<01Ol300Go400001L0
00?o00001@07o`P01_l:0003o`0001H01?l500Co00<0ool02_l400Co1004o`801?l300Co0`05o`<0
1Ol00`3oo`07o`D02?l700Wo1006o`801_l300Co0`04o`803?l00`3oo`04o`801_l600Go00<0ool0
0P0<o`<01Ol200Go0P09o`H02_l400Co1@04o`030?oo00[o4P08oa<01_l200Ko0P0:o`D02?l900Go
00<0o`000P0<o`<01Ol300Go400002401?l<00?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(32\\) LEUHFLLPWHTXJTYMIOF D WIDSEI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go200:o`T00_lE00go00<0ool02_l800Co1P04o`<0
1?l300Oo1`0=o`030?oo00_o0P08o`P00_l400;o1P04o`<01?l400So1005o`801Ol500Ko2008o`L0
2?l400Go0`05o`802_l800Go1@07oaL02?lF00;o1002o`D02_l500So1P02o`030?oo00?o1@0<o`@0
2_lB00004`02o`T02Ol600[o2P02oa@03Ol00`3oo`0:o`H02?l400Co0`04o`<01ol700go00<0ool0
2ol200So2002o`@00_l600Co0`04o`@02?l400Go0P05o`<02Ol700So1`08o`@01Ol300Go0P0:o`H0
2Ol300Oo5`0:oa@00_l400;o1@0:o`D02_l400[o0`0<o`@02_lB00004`02o`T00_l500;o1`02o`D0
0_l:00;o5`02o`H00_l300;o1P02o`H00_l400;o1@02o`D00_l600;o3@02o`H00_l400;o1P02o`@0
0_l;00?o1003o`H00_l500;o2002o`P00ol400?o1003o`@00ol900;o3@02o`P00_l700;o1`02o`T0
0ol500?o1002oa/00_l400Co4P03o`@00ol800;o2P02o`@01?l300?o1@03o`@00_l600;o2002oaH0
000C00;o4@02o`L00ol?00;o5`02o`H00_l300;o1P02o`D00_l600;o1002o`D00_l600;o3@02o`H0
0_l400;o1P02o`@00_l;00Co0`03o`H00_l500;o2002o`T00ol200?o1@02o`H00_l900;o3@02o`P0
0_l700;o1`02o`T00_l700;o1002oa/00_l600;o4P04o`<00ol800;o2P02o`H00_l300;o1`02o`@0
0_l600;o2002oaH0000C00;o4@02o`P00ol>00;o5`02o`H00_l300;o0P02o`800_l500;o1P02o`@0
0_l500;o1P02o`800_l900;o1P02o`@00_l600;o1002o`/01?l200Co1P02o`D00_l800;o2P02o`80
0_l600;o1P02o`T00_l=00;o2002o`<00_l200;o1`02o`P00_l900;o0`02o`800_lG00;o1`02oa40
1?l200Co2002o`X00_l700;o0P02o`L00_l400;o0P02o`800_l800;o5P0001<00_lA00;o2@03o`d0
0_lG00;o1P02o`<00_l200;o2@02o`H00_l400;o1@02o`H00_l200;o2@02o`H00_l400;o1P02o`@0
1ol600;o00@0o`001?l600;o1@02o`P00_l;00Co1`02o`H00_l900;o3@02o`P00_l200?o0P02o`L0
0_l800;o2@02o`<00_l200;o5`02o`L00_lA00;o00@0o`001?l800;o2P02o`L00_l:00?o1002o`80
0_l<00;o5P0001<00_l@00;o2`03o``00_lG00;o2`06o`T00_l600;o1002o`D00_l600Ko2@02o``0
0_l<00Wo1002o`060?l00?l00_l600;o1@02o`P00_l;00Co3`02o`T00_l=00?o1`02o`8000?o0?l0
0P02o`L00_l800;o2@02o`<01_lG00;o1`02oa400_l01P3o003o00;o2002o`X00_l700;o1@07o`D0
1_l<00;o5P0001<00_l=00Co3@03o`/00_lG00;o2`06o`T00_l600;o1009o`H01_l900;o3002o``0
0_l500?o0`02o`030?oo00;o00<0ool01P09o`P00_l;00?o4002o`T00_l<00Co1`02o`040?oo00;o
00<0ool01`02o`P00_l900;o0`06oaL00_l700;o4@02o`030?oo00;o00<0ool02002o`X00_l700;o
0`07o`L01_l<00;o5P0001@00_l<00?o3`02o`X00_lH00;o2`02o`800_l900;o1P02o`@02Ol600;o
0P02o`T00_l<00;o3002o`H00_l300;o00<0ool00_l00`3oo`0600Wo0`02o`<00_l300;o1P04o`l0
0_l400;o0`02o`<00_l600Ko1P02o`030?oo008000Co0?oo1`02o`P00_l900;o0`02o`800_lG00;o
1`02oa400_l00`3oo`02o`030?oo00P00_l:00;o1`02o`800ol<00;o0P02o``00_lF00005002o`h0
0_l?00;o2@02oaP00_l;00;o0P02o`800_l500;o1P02o`@00_l500;o1P02o`800_l200;o1@02o``0
0_l<00;o1P02o`800_l300;o0`02o`D00_l500;o0`02o`<00_l300;o1@06o`h00_l400;o0`02o`<0
0_l600;o0P02o`H00_l00`3o00020004o`3oo`L00_l800;o2@02o`<00_l200;o0P02oa<00_l700;o
4002o`<00_l300;o1`02o`X00_l700;o0P02o`L000?o00000`02o`800_l200;o2002oaH0000D00?o
3P02o`h00_l900;o6002o`/00_l600;o1@02o`H00_l400;o1@02o`H00_l600;o1@02o``00_l<00;o
1P02o`800_l300;o0`02o`D00_l500;o0`02o`<00_l300;o1003o`800ol=00;o1002o`<00_l300;o
1@03o`<00_l500Co0`04o`L00_l900;o1`02o`@00_l600;o4`02o`H00_lA00;o0`02o`<00_l700;o
2P02o`H00_l300;o1P02o`D00_l600;o2002oaH0000E00;o3P02o`L00_l500;o2002oaT00_l;00;o
1P02o`D00_l600;o1002o`D00_l600;o1P02o`D00_l<00;o3002o`D00ol200;o2002o`D00_l500;o
0`02o`<00_l300;o1002o`@00_l=00;o1002o`<00_l300;o1@02o`@00_l500Co1003o`L00_l900?o
1@03o`@00_l600;o4`02o`@01?lA00;o2002o`L00_l:00;o1004o`<00ol400?o1@02o`H00_l800;o
5P0001H00_l700;o0`03o`L00ol300?o1`02oaL02?l600co1004o`@01?l200Co0`04o`<03?l200So
1P08o`L02ol200Ko0P06o`<01?l300Co0P0<o`801Ol200Go1P0:o`030?oo00[o0`05o`801Ol200Co
1@04o`802_l600Wo0`0<oa802_lA00Ko0P06o`802_l500[o1@09o`<03?l400[o4P0001L000?o0000
1@07o`T01ol80003o`0001H02?l600co1004o`@01?l200Co0`04o`<03?l200So1P08o`L02Ol400Ko
0P06o`<01?l300Co0P0<o`801Ol200Go1P0:o`030?oo00[o0`05o`801Ol200Co1@04o`802_l800Go
1@0<oa802?lC00Ko0P06o`802_l500So2@05o`030?l000803?l400[o4P0002401?l;00Goo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(33\\) LEUHFNLRYHSXJTZMIOF EXWKDSHI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lE00go00<0ool02_l800Co1P04o`<0
1?l300Oo2006o`<00_l200go0P05o`H00ol200So1P04o`<01?l300;o00<0ool00ol500Go0P05o`D0
1_l800So1P0:o`<01Ol300Go0P0:o`P01Ol500Oo5P0<o`801Ol200Go1@02o`@00_l400Go1P02o`<0
2?l600;o00<0ool00ol600Co0`04o`@02_lB00004`02o`T02Ol600Wo2`02oa@03Ol00`3oo`0:o`H0
2?l400Co0`04o`<01ol800Ko0P03o`803Ol200Go1@04o`802?l600Co0`04o`<02_l300Go0P05o`<0
2Ol700So1P0:o`<01Ol300Go0P0:o`H02Ol300Oo5P0<o`801Ol200Go1@02o`@00_l400Go1@03o`<0
2_l400[o1004o`<01?l400[o4P0001<00_l900;o1@02o`H00_l500;o2`02oaL00_l600;o0`02o`H0
0_l600;o1002o`D00_l500;o1P02o``00_l400Co1@02o`H00_l400;o1@03o`L00_l:00;o1@02o`@0
0ol500?o0`03o`@00ol400?o1003o`T00_l:00;o1@02o`@00_l700;o1`02o`T00ol500?o1002oa/0
0_l600;o0`03o`@00ol500?o1003o`D00_l500?o1@02o`@01?l300?o1@03o`@00_l500;o2@02oaH0
000C00;o4@02o`d00_l:00;o5`02o`H00_l300;o1P02o`D00_l600;o1002o`D00_l600;o3002o`@0
1?l500;o1P02o`@00_l500;o2002o`X00_l500;o1002o`L00_l400?o0P03o`D00_l600;o2@02o`X0
0ol400;o1002o`L00_l700;o2@02o`L00_l400;o6`02o`H00_l400?o0P03o`H01?l300?o1@02o`D0
0_l600;o1P02o`<00_l700;o1002o`D00_l900;o5P0001<00_lA00;o3@02o`X00_lG00;o1P02o`<0
0_l200;o0P02o`D00_l600;o1002o`D00_l600;o0P02o`P00_l300Go1@02o`H00_l400;o1002o`T0
0_l:00;o1@02o`@00_l700;o1@02o`800_l600;o1P02o`T00_l;00?o0`02o`@00_l300;o0P02o`L0
0_l800;o2@02o`<00_l200;o5`02o`800_l200;o1@02o`800_l700Co0P04o`D00_l400;o1`02o`L0
0_l200;o1`02o`@00_l500;o2@02oaH0000C00;o4@02o`d00_l:00;o5`02o`H00_l300;o0P02o`T0
0_l600;o1002o`D00_l600;o0P02o`P00_l300;o00<0ool01@02o`H00_l400;o0`03o`T00_l:00;o
1@02o``00ol600Co1`02o`H00_l900;o3002o`<00_l400;o0P03o`800_l700;o2002o`T00_l300;o
0P02oaL00_l200;o2P04o`P00_l0103o0004o`D00ol200?o1`02o`L00_l:00?o1002o`D00_l900;o
5P0001<00_l@00;o3@02o`/00_lG00;o2`06o`T00_l600;o1002o`D00_l600Ko2002o`800ol00`3o
o`0500;o3007o`X00ol900;o1@02o`L01ol700Co3`02o`T00_l<00?o2002o`8000?o0?l00P02o`L0
0_l800;o2@02o`<01_lG00Ko2P04o`P00_l01P3o003o00;o1@07o`P00_l700;o1@07o`D00_l500;o
2@02oaH0000C00;o3@04o`/01?l<00;o5`02o`/01_l900;o1P02o`@02Ol600Ko2002o`800_l200;o
1@02o``02Ol700Co2@09o`D01ol900?o4002o`T00_l=00?o1`02o`040?oo00;o00<0ool01`02o`P0
0_l900;o0`06oaL01_l:00?o2@02o`030?oo00;o00<0ool01@05o`X00_l700;o0`07o`L02Ol900;o
5P0001@00_l<00?o3003o``00_lH00;o2`02o`800_l900;o1P02o`@02Ol600;o0P02o`P00_l00`3o
o`0300;o1@02o``00_l500?o1@06o`P02Ol400?o3P04o`l00_l400;o0`02o`<00_l400;o0`02o`L0
0_l00`3oo`020004o`3oo`L00_l800;o2@02o`<00_l200;o5`02o`800_l:00Co2002o`030?oo00;o
00<0ool01@02o`040?ooo`T00_l700;o0P03o``02Ol900;o5P0001@00_l>00;o3@02o`/00_lH00;o
2`02o`800_l200;o1@02o`H00_l400;o1@02o`H00_l200;o0P02o`@01Ol300;o1@02o``00_l600;o
1@02o`800_l800;o1@02o`@00_l70003o`0000@01_l>00;o1002o`<00_l300;o1002o`<00ol600;o
00<0o`000P001?l0ool700;o2002o`T00_l300;o0P02o`800_lC00;o0P02o`800_l500Ko1P02o`<0
0_l300;o1002o`800ol800;o1`02o`800_l70003o`0000<00_l500;o2@02oaH0000D00?o3P02o`d0
0_l:00;o6002o`/00_l600;o1@02o`H00_l400;o1@02o`H00_l600;o1004o`@00_l500;o3002o`H0
0_l400?o0`02o`L00_l500;o1002o`H00_l500?o0P03o`d00_l400;o0`02o`<00_l400;o1003o`D0
1?l300Co1`02o`T00_l700;o1002o`H00_lC00;o1P02o`@00ol200?o1@02o`<00_l300;o1002o`<0
0ol700;o1P02o`<00_l600;o1@02o`D00_l900;o5P0001D00_l>00;o3@02o`T00_lI00;o2`02o`H0
0_l500;o1P02o`@00_l500;o1P02o`H00_l400Co1002o`D00_l<00;o1@03o`@00_l400;o1`02o`D0
0_l400?o1003o`D00_l400;o3@02o`@00_l300;o0`02o`@00_l500;o1@04o`@00ol700;o2@03o`D0
0ol400;o1P02oa<00_l600;o1002o`@00_l500;o2002o`@00_l400?o1P02o`@01?l300?o1003o`D0
0_l500;o2@02oaH0000F00;o1`02o`<00ol700;o0`03o`P00_lG00So1P0<o`@01?l400Co0P04o`<0
1?l300co0`04o`801_l00`3oo`06o`L02ol300Go0P05o`@01?l300Co1009o`<01Ol200Go1P0:o`03
0?oo00[o100:o`<01?l500Co0P0:o`H02Ol300co4@0<o`801Ol200Go0P06o`801_l00`3oo`03o`<0
1Ol300[o1@09o`@01?l300Co100:oa80000G0003o`0000D01ol800Oo2@000ol0000F00So1P0<o`@0
1?l400Co0P04o`<01?l300co0`03o`<01_l00`3oo`06o`L02Ol500Go0P05o`@01?l300Co1P05o`03
0?l000801Ol200Go1P0:o`030?oo00[o100:o`<01?l500Co0P0:o`P01Ol500co4@0<o`801Ol200Go
0P06o`801_l00`3oo`03o`<01Ol300So2@05o`030?l000<01?l300Co100:oa80000Q00Co2`04ool0
aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(34\\) OIUGHMLRYJUXJUZLFOF EXWHASHI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go3006o`T00_lI00Go1P0:o`T01?l900Ko1P04o`<0
1?l200Go0`05o`030?oo00_o0P05o`H00ol200So1`06o`/01?l500Go0P05o`D01_l;00Co1`0:o`<0
3Ol00`3oo`05o``01Ol500Oo5P0<o`801Ol200Go1@02o`@00_l500Co0`04o`801_l300Ko00@0ool0
1Ol600Co0`04o`@02_lB00004`02o`T02Ol:00Ko2P02oaH02Ol400[o1`08o`D02_l400Co0`04o`80
1Ol300Go00<0ool02ol200Go1@04o`802?l500Wo2008o`<01Ol200Go0`09o`P02?l500[o0`0=o`03
0?oo00Go2P09o`<01olF00co0P05o`801Ol500;o1002o`D01?l300Co0P06o`<01_l00`3oo`08o`@0
1?l300Co100:oa80000C00;o2@02o`D00_l<00;o3002oaD00ol500?o1`02o`/00_l400;o1004o`D0
0_l500;o1@02o`@00_l700;o1@02o`H00_l400;o1@03o`L00_l800?o1003o`L00_l400;o1003o`@0
0ol400?o1003o`L00_l400;o1P02o`D00_l600;o1P02o`<00_l<00?o1@03o`@00_lK00;o1P02o`<0
0ol400?o1@03o`@00ol500;o1@02o`D00_l700;o0`03o`D00ol400;o1@02o`T00_lF00004`02oa40
0_l;00;o3002oaD00_l700;o1`02o`X00_l600;o0`02o`L00_l500;o1@02o`@00_l700;o1@02o`H0
0_l400;o1@02o`P00_l800;o1P02o`H00_l600;o1003o`800ol500;o1P02o`H00_l600;o1@03o`@0
0_l600;o1P02o`<00_l<00;o1`02o`@00_lK00;o1P02o`@00ol200?o1P04o`<00ol500;o1@02o`D0
0_l700;o0`02o`L00_l400;o1@02o`T00_lF00004`02oa400_l500[o2P02oa@00_l900;o1P02o`X0
0_l600;o0P03o`L00_l500;o1@02o`@00_l300;o0P02o`D00_l600;o1002o`@00_l900;o2002o`H0
0_l600;o1P02o`D00_l200;o1P02o`H00_l600;o1P02o`H00ol300;o1P02o`H00_l300;o0P02o`L0
0_l900;o0`02o`800_lG00;o0P02o`800_l500;o0P02o`L01?l200Co1@02o`D00_l500_o0`02o`L0
0_l400;o1@02o`T00_lF00004`02oa400_l500[o2P02oa@00_l900;o1P02o`X00_l600;o0P02o`@0
1ol400;o1@02o`@00_l200?o0P02o`D00_l600;o1002o`<00ol900;o2002o`H00_l600;o1P02o`H0
1?l700;o1P02o`H00_l600;o1`02o`<00_l600;o1P02o`<00_l200;o1`02o`T00_l300;o0P02oaL0
0_l200;o2P04o`P00_l0103o0004o`D00_l500;o1P09o``00ol400;o1@02o`T00_lF00004`02oa00
0_l600;o1002o``00_lD00;o2@02o`H00_l:00;o1P02o`800_l400Oo1002o`D00_l400;o0P000ol0
o`0200;o1@02o``01ol:00?o3`02o`H00_l600;o1P04o`l00_l600;o1P02o`L00ol:00;o2`06o`L0
0_l900;o0`06oaL01_l:00Co2002o`060?l00?l00_l500;o1@02o`H00_l500;o1`07o`D00_l500;o
2@02oaH0000C00;o3@04o`P00_l300;o3002oa@00_l900;o1P02o`X00_l600;o0P02o`l02Ol400;o
00@0ool00_l00`3oo`0500;o3009o`L01?l?00;o1P02o`H00_l600?o4002o`H00_l600;o2003o`T0
0_l;00Ko1`02o`T00_l300Ko5`06o`X00ol900;o00<0ool00_l00`3oo`0500Wo1`02o`<00_l600Oo
1`09o`T00_lF00005002o``00ol:0004o`0000;o2`02oaD00_l900;o1P02o`X00_l600;o0P02o`l0
2Ol400;o00<0ool00P001?l0ool500;o3002o`D00ol500Ko3P02o`H00_l600;o1P04o`l00_l600;o
1P02o`@00_l300;o2@02o`/00_l200;o1`02o`T00_l300;o0P02oaL00_l200;o2P04o`P00_l00`3o
o`02o`030?oo00D02Ol700;o0`02o`D00ol<00Wo2@02oaH0000D00;o3P02o`T00_l200;o2`02oaD0
0_l900;o1P02o`X00_l600;o0P02o`P00_l500;o1@02o`@00_l00`3o00020004o`3oo`D00_l<00;o
1P02o`D00_l200;o3P02o`H00_l600;o1@06o`h00_l600;o1P02o`@00_l300?o2002o`/00_l200;o
0P02o`<00_l900;o0`02o`800_l200;o4`02o`800_l200;o1@06o`H00_l300;o0`02o`@00_l500;o
2002o`040?ooo`D00_l70003o`0000<00_l500;o2@02oaH0000D00?o3P02o`T000?o00000_l;00;o
5P02o`L00_l700;o2P02o`H00_l300;o1P03o`D00_l500;o1004o`<01?l500;o3002o`H00_l400?o
0`02o`d00_l600;o1P02o`@00ol200?o3@02o`H00_l600;o1002o`@00ol700;o2`02o`H00_l400;o
1`02o`@00_l600;o4`02o`H00_l400?o0P03o`D00_l300;o0`02o`@00_l500;o2002o`030?oo00H0
0_l600;o1@02o`D00_l900;o5P0001D00_l>00;o2P001?l0ool:00;o5`03o`D00ol700;o2P02o`H0
0_l300?o1004o`D00_l500;o1004o`@00ol500;o3002o`D00ol400;o1002o`d00_l600;o1P02o`@0
0_l400;o3@02o`H00_l600;o1002o`D00_l700;o2`02o`H00_l400?o1@03o`@00_l600;o4`02o`H0
0_l400;o1002o`D00_l800;o1002o`D00_l800Go1P03o`@00ol500;o1@02o`T00_lF00005P02o`L0
0_l300?o2P04o`T00_lI00Wo100:o`D01?l400Co0`0:o`@01?l300Co0P04o`D01?l00`3oo`06o`L0
2ol300Go0P05o`H02_l200Co1004o`030?oo00?o0P05o`H02_l200Co1004o`<02_l300So1P0<o`D0
2Ol300co4@0<o`801Ol200Go0P06o`801_l200Co0`04o`@01ol800Wo1004o`<01?l400[o4P0001L0
00?o00001@07o``00ol90003o`0001X01Ol600[o1@04o`@01?l500Go00<0ool01004o`<01?l200Co
1@04o`030?oo00Ko1`09o`D01Ol200Go1P0:o`801?l400Co00<0ool00ol200Go1P0:o`801?l400Co
0`0:o`<02?l600co1`05o`D03?lA00co0P05o`801Ol200Ko0P06o`801?l300Co1007o`X01Ol00`3o
000300Co0`04o`@02_lB00008@04o`d00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(35\\) OIUGHMLRYJU JU LJMF E WHASCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lI00Go1P0:o`T01?l900Ko1P04o`<0
1?l200Go0`05o`030?oo00_o0P05o`H00ol200So1`06o`/01?lF00Ko2`04oa@03Ol300Ko1`05o`<0
1Ol00`3oo`05oaH03?lC00;o1002o`D01?l300Co0P06o`<01_l0103oo`05o`T01Ol700[o4P0001<0
0_l900Wo1P09o`/00_lF00Wo100:o`L02?l500[o1004o`<01?l200Go0`05o`030?oo00_o0P05o`D0
1?l200So1@09o`P02?lB00Wo2008oa803Ol00`3oo`07o`H01Ol300Go00<0ool01OlF00co4`02o`@0
0_l500Co0`04o`801_l300Ko00<0ool02?l500Wo1@0:oa80000C00;o2@02o`D00_l600;o1@02o`/0
0_lE00?o1@03o`L00_l;00;o1002o`@01?l500;o1@02o`D00_l400;o1`02o`D00_l600;o1002o`D0
0ol700;o2003o`@00ol700;o1002oa800ol400?o1`02o`@00_lE00;o1P02o`040?ooo`@00ol600;o
1`02o`@00_lK00;o1P02oa800ol400?o1@02o`D00_l500;o1`02o`<00ol500?o0`03o`D00ol800;o
5P0001<00_lA00;o3@02o`X00_lE00;o1`02o`L00_l:00;o1P02o`<00_l700;o1@02o`D00_l400;o
1`02o`D00_l600;o1002o`D00_l800;o2002o`H00_l600;o1P02oa400_l600;o1P02o`H00_lD00;o
1P02o`030?oo00H00_l600;o1`02o`@00_lK00;o1P02oa801?l300?o1@02o`D00_l500;o1`02o`<0
0_l700;o0`02o`L00_l800;o5P0001<00_lA00;o3@02o`X00_lD00;o2@02o`H00_l:00;o1P02o`80
0ol700;o1@02o`D00_l400;o0`02o`800_l500;o1P02o`@00_l400;o2@02o`P00_l600;o1P02o`H0
0_lA00;o1P02o`H00_l600;o5002o`H00_l00`3oo`0600;o1P02o`<00_l200;o1002o`800_lG00;o
0P02o`800_lB00Co0P04o`D00_l500;o1@0;o`<00_l700;o0P03oa400_lF00004`02oa400_l=00;o
2P02oa@00_l900;o1P02o`X00_l600;o0P02o`@01ol400;o1@02o`@00_l200?o0P02o`D00_l600;o
1002o`<00ol900;o2002o`H00_l600;o1P02oa400_l600;o1P02o`H00_lD00;o1P02o`030?oo00H0
0_l600;o0P03o`800_l400;o0P02oaL00_l200;o5P02o`040?l000Co1@02o`D00_l600Wo3003o`80
0_lB00;o5P0001<00_l@00;o3P02o`X00_lD00;o2@02o`H00_l:00;o1P02o`800_l400Oo1002o`D0
0_l400;o0P000ol0o`0200;o1@02o``01ol:00?o3`02o`H00_l600;o6@02o`H00_l600;o5002oa40
0_l600;o0P000ol0o`0200;o1006oaL01_lF00;o00H0o`00o`02o`D00_l500;o1P02o`D00_l700Oo
0`02oa800_lF00004`02o`d01?l800;o1002o`/00_lD00;o2@02o`H00_l:00;o1P02o`800_l?00Wo
1002o`040?oo00;o00<0ool01@02o``02Ol700Co3`02o`H00_l600;o6@02o`H00_l600;o5002oa40
0_l600;o00@0ool00_l00`3oo`0400Ko5`06oaH00_l00`3oo`02o`030?oo00D02Ol700;o0`02o`H0
1ol500;o4P02oaH0000D00;o3003o`T02?l:00;o5@02o`T00_l600;o2P02o`H00_l200;o3`09o`@0
0_l00`3oo`020004o`3oo`D00_l<00;o1@03o`D01_l>00;o1P02o`H00_lI00;o1P02o`H00_lD00;o
4@02o`H00_l00`3oo`020004o`3oo`@00_l200;o5`02o`800_lF00;o00<0ool00_l00`3oo`0500Wo
1`02o`<00_l500?o2P02oa800_lF00005002o`h00_l800Oo2`02oaD00_l900;o1P02o`X00_l600;o
0P02o`P00_l500;o1@02o`@00_l00`3o00020004o`3oo`D00_l<00;o1P02o`D00_l200;o3P02o`H0
0_l600;o6@02o`H00_l600;o5002oa400_l600;o00<0o`000P001?l0ool400;o0P02o`800_lC00;o
0P02o`800_lA00;o0`02o`<00_l400;o1@02o`P00_l0103oool500;o1`001?l00003o`L00_l800;o
5P0001@00ol>00;o1`02oa000_lF00;o1`02o`L00_l:00;o1P02o`<00_l600?o1@02o`D00_l400Co
0`04o`D00_l<00;o1P02o`@00ol300;o3@02o`H00_l600;o6@02o`H00_l600;o5002oa400_l600Co
0`04o`@00_l600;o4`02o`H00_lA00;o0`02o`<00_l400;o1@02o`P00_l00`3oo`0600;o1P02o`@0
0_l700;o2002oaH0000E00;o3P02o`L00_l?00;o5`03o`D00ol700;o2P02o`H00_l300?o1004o`D0
0_l500;o1004o`@00ol500;o3002o`D00ol400;o1002o`d00_l600;o1P02oaT00_l600;o1P02oa@0
0_lA00;o1P04o`@00ol400;o1P02oa<00_l600;o4@02o`P00_l400;o1@02o`P01Ol600?o1003o`@0
0ol500?o2002oaH0000F00;o1`02o`<00ol700;o3P02oaT02Ol400[o1@04o`@01?l300[o1004o`<0
1?l200Co1@04o`030?oo00Ko1`0;o`<01Ol200Go1P0:o`801?l400Co4`0:o`801?l400Co4008o`T0
2_l200Co1@04o`030?oo00[o4@0<oa001_l200Ko0P04o`<01?l400Oo2009o`D02_l400[o4P0001L0
00?o00001@07o`P02?l80003o`0001X01Ol600[o1@04o`@01?l500Go00<0ool01004o`<01?l200Co
1@04o`030?oo00Ko1`09o`D01Ol200Go1P0:o`801?l400Co4`0:o`801?l400Co4008o`T02_l200Co
1@04o`030?oo00[o4@0<oa001_l200Ko0P04o`<01?l400Oo2P05o`030?l000H01Ol00`3oo`0400[o
4P0002401?l900Soo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(36\\) OIUGLMLR JU JU LLMF A VCASCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lI00Go1P0:o`T01?l900Ko1@0=o`03
0?oo00?o0`05o`030?oo00_o0P05o`H00olA00Ko2`04oaH01_l;00Co500=o`030?oo00_o0P05o`<0
1Ol00`3oo`05oaD01_l300Ko5002o`/01Ol500Ko0`06o`040?oo00Go2@05o`L02_lB00004`02o`T0
2Ol800Oo2`02oaH02Ol400[o1`08o`D02_l300go00<0ool00ol300Go00<0ool02ol200Go1@04o`l0
2Ol800So4P09o`P02?lB00go00<0ool02ol200Go0`05o`030?oo00Go5@06o`<01_lC00Co2009o`<0
1_l300Ko00<0ool02?l500Wo1@0:oa80000C00;o2@02o`D00_l700;o1002o`/00_lE00?o1@03o`L0
0_l;00;o1002o`@01?l500;o1P02o`H00_l200;o1`02o`D00_l600;o1002o`D00olA00?o1003o`L0
0_l400;o4P03o`@00ol700;o1002oaD00_l600;o1002o`H00_l300;o1`02o`@00_lJ00;o1`02oaD0
1?l700?o1@03o`@00_l700;o0`03o`D00ol300?o1@03o`P00_lF00004`02oa400_l500;o1P02o`X0
0_lE00;o1`02o`L00_l:00;o1P02o`<00_l700;o1P02o`H00_l200;o1`02o`D00_l600;o1002o`D0
0_lB00;o1P02o`H00_l600;o4@02o`H00_l600;o1P02oa@00_l600;o1002o`H00_l300;o1`02o`@0
0_lJ00;o1`02oaD01?l700;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`P00_lF00004`02oa40
0_l500;o1P02o`X00_lD00;o2@02o`H00_l:00;o1P02o`800ol700;o1P02o`H00_l200;o0`02o`80
0_l500;o1P02o`@00_l400;o4`02o`H00_l600;o1P02oa400_l600;o1P02o`H00_lD00;o1P02o`@0
0_l600;o0`02o`<00_l200;o1002o`800_lF00_o5002o`800_l500?o3@0;o`<00_l700;o0P03oa40
0_lF00004`02oa400_l500;o1P02o`X00_lD00;o2@02o`H00_l:00;o1P02o`800_l400Oo1@02o`H0
0_l200;o0P03o`800_l500;o1P02o`@00_l300?o4`02o`H00_l600;o1P02oa400_l600;o1P02o`H0
0_lD00;o1P02o`@00_l600;o0`02o`800ol200;o1002o`800_lG00Wo5@02o`800_l500;o3`09o``0
0ol200;o4P02oaH0000C00;o4002o`H00_l600;o2P02oa@00_l900;o1P02o`X00_l600;o0P02o`@0
1ol500;o2P02o`8000?o0?l00P02o`D00_l<00Oo7002o`H00_l600;o6@02o`H00_l600;o5002o``0
0_l;00;o0P000ol0o`0200;o1006oaL00_l500;o5003o`800ol400;o3`02o`D00_l700Oo0`02oa80
0_lF00004`02o`d01?l700?o1002o`/00_lD00;o2@02o`H00_l:00;o1P02o`800_l@00;o2P02o`04
0?oo00;o00<0ool01@02o``02OlJ00;o1P02o`H00_lI00;o1P02o`H00_lD00;o3002o`/00_l0103o
o`02o`030?oo00@01_lH00;o0`02oaD00_l400;o1002oa000_l300;o1P07o`D00_lB00;o5P0001@0
0_l<00?o2009o`X00_lE00;o2@02o`H00_l:00;o1P02o`800_l@00;o2P02o`030?oo008000Co0?oo
1@02o``00_l500?o6@02o`H00_l600;o6@02o`H00_l600;o5002o``00_l;00;o00<0ool00P001?l0
ool400;o0P02oaP00_l300;o5@02o`@00_l400;o4002o`<00_l500?o2P02oa800_lF00005002o`h0
0_l700;o00<0ool00_l<00;o5@02o`T00_l600;o2P02o`H00_l200;o2002o`H00_l:00;o00<0o`00
0P001?l0ool500;o3002o`H00_lI00;o1P02o`H00_lI00;o1P02o`H00_lD00;o3002o`/00_l00`3o
00020004o`3oo`@00_l200;o0P02oaD00_l0103ooolD00;o1P02o`<00ol700;o1`02o`040?ooo`D0
0_l70004o`0000?o1`02o`P00_lF00005003o`h00_l700;o4002oaH00_l700;o1`02o`X00_l600;o
0`02o`H00ol600;o2P04o`<01?l500;o3002o`H00_lI00;o1P02o`H00_lI00;o1P02o`H00_lD00;o
3002o`/01?l300Co1002o`H00_lE00;o00<0ool05@02o`H00_l400;o1`02o`L00_l00`3oo`0600;o
1P02o`@00_l700;o2002oaH0000E00;o3P02o`L00ol>00;o5`03o`D00ol700;o2P02o`H00_l300?o
1004o`H00_l:00Co1003o`D00_l<00;o1@03oaT00_l600;o1P02oaT00_l600;o1P02oa@00_l<00;o
2`04o`@00ol400;o1P02oaD01OlD00?o1P03o`<00ol500?o1`05o`H00ol400?o1003o`D00ol800;o
5P0001H00_l700;o0`03o`P00ol<00;o6@09o`@02_l500Co1004o`<02_l300So1P04o`D01?l00`3o
o`06o`L02olE00[o0P04o`@01?lC00[o0P04o`@01?l@00So1P08o`L01?l500Co00<0ool02_lB00Oo
5006o`801_l300[o1007o`P02Ol500[o100:oa80000G0003o`0000D01ol:00Oo1`000ol0000J00Go
1P0:o`D01?l400Co1@05o`030?oo00<02?l600Co1@04o`030?oo00Ko1`09oaL02_l200Co1004oa<0
2_l200Co1004oa002?l600So1`04o`D01?l00`3oo`0:oa801olD00Ko0P06o`D01Ol00`3oo`0400Oo
2P05o`030?l000H01Ol00`3oo`0400[o4P0002401?l=00Goo`330000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(37\\) KETJKLGS JT JT LLMF B ZCAOCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`02o`h00_lE00Go1P02o`030?oo00[o1@08o`H0
1_l700Go1P02o`030?oo00_o1@06o`H00_l00`3oo`03oaH01_l800So5@06o`P02?lC00go00<0ool0
2ol200Go0`05o`030?oo00Go5P0:oa@02_l700Go1@06o`<01_l400Go2@05o`H01Ol600;o400001<0
0_l900Wo2@02o`l00_lD00Go1@03o`030?oo00[o1@08o`@02Ol600Go1@03o`030?oo00_o0`0:o`@0
2_lB00Wo1`08oa<02Ol700So4`0=o`030?oo00_o0P05o`<01Ol00`3oo`05oaH02olC00[o1@09o`<0
1_l300Ko0P09o`D02Ol400Go1@03oa00000C00;o2@02o`D00_l:00;o3P02oaH00_l500?o1002o`H0
0_l800;o1`03o`@00ol700;o1@03o`D00_l600;o0P04o`D00_l400?o1@03oa400ol400?o2@02oaH0
0ol400?o2@02oaT00_l600;o1002o`H00_l300;o1`02o`@00_lK00;o1@03oa<00_l500;o1003o`D0
0ol400;o1`02o`<00ol500?o0`03o`D00ol500;o1@03oa40000C00;o4@02o`T00_l>00;o5P02o`D0
0_l500;o1P02o`P00_l700;o1P02o`L00_l500;o1P02o`H00_l200;o1`02o`@00_l700;o4@02o`H0
0_l900;o5P02o`H00_l900;o6@02o`H00_l400;o1P02o`<00_l700;o1002oa/00_l600;o4`03o`@0
0_l400;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`D00_l500;o4P0001<00_lA00;o2@02o`h0
0_lF00;o1002o`H00_l200;o0P02o`P00_l700;o1P02o`L00_l400;o1`02o`H00_l0103oool700;o
1002o`L00_lA00;o1P02o`T00_lF00;o1P02o`T00_lI00;o1P02o`@00_l600;o0`02o`<00_l200;o
1002o`800_lG00;o1P02oa@00ol300;o0`03o`d02ol200;o2@02o`040?ooo`h00_l400;o4`0001<0
0_lA00;o2P000ol0000<00;o5P03o`800ol600;o0P02o``00_l700;o1P02o`L00ol200?o1`02o`H0
0_l00`3oo`0400Oo2`03oa400_l600;o2@02oaH00_l600;o2@02oaT00_l600;o1002o`H00_l300;o
0P03o`800_l400;o0P02oaL00_l600;o5@02o`<00_l300;o3`09o`<00_l900;o00<0ool03`03o`80
0olC00004`02oa000_l;00;o3@02oaH01ol700Ko3002o`l00_l700Oo2002o`T00_l400Oo1P07oaX0
0_l900;o7P02o`T00_lI00;o3002o`/00_l20003o`3o00800_l400Ko5`02o`D00olE00?o1`02o`l0
0_l500;o0`02o`T00_l00`3oo`0?00Oo500001<00_l=00Co3002o`d00_lF00Go2@06o``00_l?00;o
1`05o`X00_l900;o3`07oa`00_l900;o7P02o`T00_lI00;o3002o`/00_l0103oo`02o`030?oo00@0
1_lG00Wo5`03o`H00_l@00;o0`02o`@00_l900;o00<0ool03`05oaH0000D00;o3003o`h000?o0000
2P02oaL00_l0103oool800;o0P02o`L00_l300;o0`02o`X00_l700;o00@0oooo2@02o`T00_l>00?o
8@02o`@00_l300;o0`02oaT00_l400;o0`02o`<00_lD00;o3002o`/00_l00`3oo`020004o`3oo`@0
0_l200;o5`08oa@00_l300;o1P02oa000_l300;o1002o`T00_l00`3oo`0?00;o00@0oooo5@0001@0
0_l>00;o3@02o`/00_lG00;o0P03o`L00_l200;o0P02o`<00_l300;o0`02o`X00_l700;o0P03o`P0
0_l900;o2002o`@00_l70003o`0001P00_l400;o0`02o`<00_lI00;o1002o`<00_l300;o5002o``0
0_l;00;o00<0o`000P001?l0ool400;o0P02o`800_lC00;o1003oa<00_l300?o1@03o`L00_l700;o
00@0oooo1002o`T00_l0103oool700;o1@02o`800olD00005003o`h00_l<00;o2`02oaL00_l300?o
1P02o`H00_l300;o0`02o`<00_l:00;o1`02o`<00ol700;o2P02o`H00ol400;o1P02oaX00_l400;o
0`02o`<00_lI00;o1002o`<00_l300;o5002o``00_l;00Co0`04o`@00_l600;o4`02o`D00_lC00;o
1003o`D00_l700;o1`02o`030?oo00H00_l700;o0`02o`L00_l500;o0`03oa<0000E00;o3P02o`d0
00?o00002002oaP00_l400?o1@02o`H00_l300;o0`02o`<00_l:00;o1`02o`@00ol600;o2P03o`@0
1?l400?o1003oaX00_l400;o0`02o`<00_lI00;o1002o`<00_l300;o5002o``00_l;00Co1003o`@0
0_l600;o4`02o`@00olC00;o1@02o`D00ol500?o1`05o`H00ol500?o0`03o`D00ol500;o1003oa80
000F00;o1`02o`<00ol600;o1@02o`P00_lG00Go0`05o`030?oo00[o0`0<o`D02_l200Go0`05o`03
0?oo00Ko200:o`D02OlE00[o00<0ool02_lD00[o00<0ool02_lA00So1P08o`L01?l500Co00<0ool0
2_lA00[o500:o`D02_l400Oo2009o`D02_l300Go0`05oa00000G0003o`0000D01ol700Wo20000ol0
000F00Go0`05o`030?oo00[o0`0<o`D02_l200Go0`05o`030?oo00Ko2P05o`030?oo00L01Ol00`3o
000D00[o00<0ool02_lD00[o00<0ool02_lA00So1P08o`L01?l500Co00<0ool02_lA00Wo5@0:o`L0
1Ol00`3oo`0400Oo2P05o`T01Ol00`3oo`0300Go0`05oa00000Q00Co2009ool0a0000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(38\\) MITJKNJPZJT IT LJJI B YCBQCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o2P05o`/0
1?l<00;o5@05o`<01Ol200[o1P08o`H01_l700Go1P02o`801_l300;o1006o`L02?l700[o1P06o`P0
2?lD00[o1@08oa<03Ol300Ko2@06o`L02_lB00[o5@08o`P01Ol600[o2005o`T01Ol600Go1P02oa00
000C00;o2@09o`L02?l;00;o5005o`<01Ol200[o1P08o`@02Ol600Go1@03o`801_l200?o0P09o`H0
2?l700[o1009o`L02?lD00[o1@08oa<03Ol00`3oo`07o`H02Ol600[o4P0;oa@02?l600Wo100;o`D0
2Ol500Wo1005o`D00ol@00004`02o`T00_l500;o1P03o`@00ol:00;o5@02o`L00_l700;o3@02o`L0
0ol400?o1`02o`D00ol400;o1004o`800ol400?o1`02o``00_l500;o1003o`@00ol900;o6`02o``0
0_lI00;o1P02o`040?ooo`@00ol500?o1003o`T00_lH00;o1@03oaH00_l800?o1@03o`D00_l500?o
0`03o`D00ol300?o1@03o`D00_l500?o4@0001<00_lA00;o1@02o`H00_l:00;o5@02o`L00_l700;o
3@02o`L00_l600;o1`02o`D00_l500;o1004o`800_l600;o1`02o``00ol400;o1002o`H00_l900;o
6`02o``00_lI00;o1P02o`030?oo00H00_l500;o1P02o`T00_lH00;o1P02oaH00_l800;o1`02o`D0
0_l600;o0`02o`L00_l300;o1`02o`D00_l500;o4P0001<00_lA00;o1@02o`H00_l:00;o5@02o`<0
0_l200;o1`02o`d00_l700;o1P02o`L00_l400;o1P02o`<01Ol200;o1P02o`L00_l=00?o0`02o`@0
0_l600;o2@02oa/00_l<00;o6@02o`H00_l00`3oo`0600;o1@02o`H00_l900;o6002o`H00_lF00;o
1`03o`h00_l600;o0P02o`T00_l0103oool>00;o1002oa<0000C00;o4@02o`D00_l600;o2P02oaD0
0_l200?o0P02o`L00_l=00;o1`02o`H00_l700?o0P03o`H00_l300;o00<0ool00P02o`H00_l700Oo
2@02o`<00_l400;o1P02o`T00_lK00;o3002oaT00_l600;o00<0ool01P02o`D00_l600;o2@02oaP0
0_l600;o5P02o`L00_l?00;o1P02o`800_l900;o00<0ool03`03o`800olC00004`02oa000_l700;o
1002o`/00_lE00;o0P000ol0o`0200;o1`02o`d00_l?00;o1`07o`L00_l200?o00<0ool02P02o`L0
2Ol700?o4002o`T00_lK00;o3002oaT00_lA00;o3@02o`T00_lH00;o1@03oaH00ol600;o3`02o`D0
0ol200;o2@02o`030?oo00l01olD00004`02o`d01?l900Oo2`02oaD00_l0103oo`02o`030?oo00L0
0_l=00;o3`02o`L01Ol900;o0P02o`800_l:00;o1`02o`D00ol700?o3`02o`T00_lK00;o3002oaT0
0_lA00;o3@02o`T00_lH00Wo5P04o`H00_l?00Wo0`02o`T00_l00`3oo`0?00Go5P0001@00_l<00?o
2P06o`/00_lF00;o00<0ool00P001?l0ool700;o2002o`<00_l300;o2P02o`L00_l0103oool800;o
00<0ool00`02o`X00_l700;o1P02o`<00_l300;o3`02o`@00_l300;o0`02oaH00_l700;o0`02o`<0
0_lD00;o4@02o`d00_l900;o6008oaH01_l500;o3`08o`@00_l900;o00<0ool03`02o`040?oooaD0
000D00;o3P02o`P00_l400;o2P02oaH00_l00`3o00020004o`3oo`L00_l800;o0`02o`<00_l:00;o
1`02o`800ol700Go0`02o`X00_l700;o1P02o`<00_l300?o3P02o`@00_l300;o0`02oaH00_l700;o
0`02o`<00_lD00;o4@02o`d00_l900;o6002o`@00olE00;o0P02o`D00ol700;o1@02o`@00ol300?o
2002o`040?ooo`L00_l500;o0P03oa@0000D00?o3P02o`H00_l600;o2@02oaH01?l300Co1`02o`P0
0_l300;o0`02o`X00_l700;o0`03o`H01?l400;o2P02o`L00_l600;o0`02o`@00ol=00;o1002o`<0
0_l300;o5P02o`L00_l300;o0`02oa@00_lA00;o3@02o`T00_lH00;o1@02oa@00ol300;o1@02o`L0
0_l500;o1@02o`@00_l700;o0`02o`L00_l500;o0`03oa<0000E00;o3P02o`H00_l600;o2002oaL0
1?l400?o1`02o`P00_l300;o0`02o`X00_l700;o1003o`D01?l400;o2P02o`L00_l500?o0`02o`D0
0_l=00;o1002o`<00_l300;o5P02o`L00_l300;o0`02oa@00_lA00;o3@02o`T00_lH00;o1003oa@0
0_l400;o1@03o`D00ol500;o1003o`D00_l500;o1003o`D00ol500;o1003oa80000F00;o1`02o`<0
0ol600?o1003o`L00_lG00Co1@04o`802_l400co1@0:o`801Ol300Go0P04o`801_l400[o0P0;o`@0
2_l700[o00<0ool02_lB00[o0`0<oa402?l900[o1@0:o`802_lB00[o4`05o`801Ol400[o0`0:o`H0
2Ol500[o0`05o`<01Ol@00005`000ol0000500Oo2008o`P000?o00005P04o`D01?l200[o100<o`D0
2_l200Go0`05o`800ol300Ko100:o`802Ol600[o1`0:o`030?oo00[o4P0:o`<03?lA00So2@0:o`D0
2_l200[o4P09oa@01Ol200Go1P05o`030?oo00<02Ol900Go2@05o`030?oo00<01Ol300Go40000240
1?l:00Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(39\\) MEXJKNJO HP KTZJJLG B YGBQDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o2P05o`P0
1Ol>00;o5@05o`<01Ol00`3oo`0:o`<01Ol200Go1006o`L01Ol600;o0P06o`<00_l400Ko2`05oaD0
1?l300Co0P08oaD01Ol600;o0`08o`H02_l500Ko2006o`L03Ol500Ko4`0:oaD02?l800Ko1@0:o`P0
1Ol600So1P05o`H00_l@00004`02o`T02Ol600Oo3@02oa@01Ol300Go00<0ool02_l300Go0P05o`80
2Ol600Go1@03o`801_l200?o0P09o`P02OlC00Co0`04o`802?lE00Go1@03o`<02?l600[o0`09o`D0
2Ol600go0`0:oa402olD00So1P0:o`<02ol500Wo100:o`@01Ol500?o400001<00_l900;o1@02o`/0
0ol<00;o5@02o`L00_l400;o1P02o`@00ol400?o0`03o`@00ol700;o1@03o`@00_l400Co0P03o`@0
0ol600?o1@03oa<00_l500;o1@02oa/00_l500?o1`02o`X00_l500;o0`03o`@00ol400?o1003o`P0
0_l600;o0P04o`D00_lC00;o1@03oaH00_l800Co1@02o`D00_l500?o0`03o`D00ol400;o1004o`D0
0_l500?o4@0001<00_lA00;o2`03o`/00_lE00;o1`02o`@00_l600;o1@03o`800ol400;o1P02o`L0
0_l500;o1@02o`@01?l200;o1P02o`H00_l700;o4`02o`D00_l500;o6`02o`D00_l800;o2P03o`@0
0_l300;o1P02o`@00_l600;o2002o`H00_l200;o1`02oa<00_l600;o5P02o`P00_l700;o1@02o`H0
0_l300;o1`02o`@00_l600;o1@02o`D00_lB00004`02oa400_l<00;o2`02oaD00_l300;o0P02o`@0
0_l200;o0P02o`H00_l200;o1@02o`H00_l700;o1002o`H00_l300Go0P02o`H00_l500;o2@02oa80
0_l500;o1@02oa/00_l400;o2@02o`/00ol300;o0`02o`H00_l400;o1P02o`P00_l600;o00@0oooo
1`02oa<00_l600;o5P02o`L00ol700;o1@02o`H00_l200;o2@02o`<00_l700;o1002o`@00_lC0000
4`02oa400_l800Co00<0ool02P02oaD00_l200?o0P02o`@00_l200;o2`04o`H00_l600;o1`03o`80
0ol600;o0`02o`030?oo00800_l600;o1@02o`T00_lB00;o1@02o`D01olF00?o0P03o`T00_l<00;o
0`02o`<00_l600;o1002o`H00_l800;o1P02o`030?oo00@01olB00;o1P02oaH00_l700;o1007o`@0
0_l600;o0P02o`T00_l300;o1`02o`@00ol200?o4`0001<00_l@00;o1`09o`X00_lE00;o0P000ol0
o`0200;o1006o`/01?l>00;o1`07o`L00_l200?o00<0ool02P02o`D00_l900;o4P02o`D00_l500Wo
5007o`X00_l<00?o3`02o``00_l800;o2@02o`@01olB00;o1@03oaH00ol600;o1007o`@00_l500?o
0P02o`T00_l300;o1`02o`@01olD00004`02o`d01?l800;o1003o`X00_lE00;o00@0ool00_l00`3o
o`0400Ko2`03o`l00_l700Go2@02o`800_l200;o2P02o`D00_l900;o4P09o`D00_l500?o4`05o``0
0_l=00?o3P02o``00_l800;o2@02oad02OlF00Co1P02o`l02Ol300;o2@02o`<00_l700;o1005oaH0
000D00;o3003o`P00_l600;o2@02oaH00_l00`3oo`020004o`3oo`@00_l200;o2`04o`h00_l700;o
00@0oooo2002o`030?oo00<00_l:00;o1@02o`T00_lB00Wo1@02o`H00_lC00;o00@0oooo1P02o`<0
0_l300;o1002o`<00_l>00;o3002o`P00_l900;o7@08oaH01_l500;o3`08o`@00_l900;o0`02o`L0
0_l400;o00@0oooo5@0001@00_l>00;o1`02o`H00_l900;o5P02o`030?l0008000Co0?oo1002o`80
0_l200;o1P06o`d00_l700;o0P03o`L01Ol300;o2P02o`D00_l900;o4P02o`D00_l500;o1P02oa<0
0_l200?o1@02o`<00_l300;o1002o`<00ol=00;o3002o`P00_l900;o2002oa<00_l400?o5@02o`80
0_l500;o2002o`D00_l400?o0`03o`P00_l300;o1`02o`@00_l200?o500001@00ol>00;o1P02o`H0
0_l900;o5P04o`<01?l400;o1P02o`D00ol200?o3002o`L00_l300?o1P04o`@00_l:00;o1P02o`L0
0_lC00;o1@02o`D00_l600;o4`02o`<00ol400;o0`02o`<00_l400;o1003o``00_l<00;o2002o`X0
0_l600?o4`02o`D00_lD00?o0`02o`D00_l600?o1@02o`D00_l400;o1`02o`@00_l600;o1@02o`<0
0olC00005@02o`h00_l600;o1P000ol0000700;o5`04o`@00ol400;o1P02o`D00_l400;o3002o`L0
0_l400?o1@04o`@00_l:00;o1P03o`D00olC00;o1@02o`D00_l500?o4`02o`@00ol300;o0`02o`<0
0_l400;o1@02o``00_l<00;o2002o`X00ol400Co4`02o`@00olD00;o1002o`D00ol400Co1@02o`@0
0ol500;o1@02o`D00_l400Co1@02o`@00olB00005P02o`L00_l300?o1`02o`@00_l800;o5`04o`D0
1?l00`3oo`0:o`<01Ol200Go1@0:o`801Ol300Go0P04o`801_l400[o1009oa<01?l300Co0P0;oa80
1Ol300Go00<0ool02_l400[o1P0:o`@02_l200So200:oa402_lC00Go0P05o`@02_l300[o1P09o`@0
2_l400Go0`05oa00000G0003o`0000D01ol800Oo2@000ol0000F00Co1@04o`030?oo00[o0`05o`80
1Ol500[o0P05o`<01Ol200?o0`06o`@02_l600Go5@04o`<01?l200Wo5005o`<01Ol00`3oo`0:o`@0
2_l600[o100:o`802?l:00Go00<0ool04@09oa@01Ol200Go1P05o`030?oo00<02Ol900Go1P08o`H0
1Ol300Go400002401?l;00Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(40\\) MEXJKNJO HP LWZJJLG A VGBQDN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o3006o`P0
1?l<00;o5@05o`<01Ol00`3oo`0:o`<01Ol200Go1006o`L01Ol600;o0P06o`<00_l400Ko2`05oaD0
1?l300Co0P08oaD03Ol300;o1002o`H02_l500Ko2006o`L03Ol500Ko4P06o`<01_lD00;o2`06o`D0
2_l800Go1P08o`L01_l300;o4@0001<00_l=00Ko1`06o``00_lD00Go0`05o`030?oo00[o0`05o`80
1Ol200Wo1P05o`D00ol200Ko0P03o`802Ol800Wo4`04o`<01?l200So5@0=o`<00_l400;o1P0:o`<0
2Ol500Wo1P0=o`<02_l@00Ko0`06oa<01?l800[o0`0;o`D02Ol400[o1@06o`800olA00004`02o`l0
0_l800?o0P03o`/00_lE00;o1`02o`@00_l600;o1003o`@00ol300?o1003o`L00_l500?o1002o`@0
1?l200?o1003o`H00ol500?o4`02o`D00_l500;o7002o`H00_l200?o1003o`H00_l500;o0`03o`@0
0ol400?o1003o`P00_l600;o0P04o`D00_lB00;o1`02oaD01?l700Co1@02o`D00_l500?o0`03o`D0
0ol400;o1004o`D00_l400Co4@0001<00_l?00;o2002o`@00_l;00;o5@02o`L00_l400;o1P02o`D0
0ol200?o1002o`H00_l700;o1@02o`D00_l400Co0P02o`H00_l600;o1`02oa<00_l500;o1@02oa`0
0_l600;o0P04o`<00ol600?o1002o`<00_l600;o1002o`H00_l800;o1P02o`800_l700;o4P02o`L0
0_lE00Co1`02o`L00_l500;o1P02o`<00_l700;o1002o`H00_l500;o1004oa40000C00;o2@0:o`D0
0_l600;o2P02oaD00_l300;o0P02o`@00_l200;o0P02o`H00_l200;o1@02o`H00_l700;o1002o`H0
0_l300Go0P02o`H00_l500;o2@02oa800_l500;o1@02oa`00_l600;o0P04o`801?l700?o0`02o`<0
0_l600;o1002o`H00_l800;o1P02o`040?ooo`L00_lB00_o5002o`800_l500?o1`02o`D00_l600;o
0P02o`T00_l300;o1`02o`@00_l300Go4@0001<00_l900[o1@02o`H00_l:00;o5@02o`800ol200;o
1002o`800_l;00Co1P02o`H00_l700?o0P03o`H00_l300;o00<0ool00P02o`H00_l500;o2@02oa80
0_l500;o1@07oaL00_l600;o0P02o`040?l000Co2002o`<00_l300;o1P02o`@00_l600;o2002o`H0
0_l00`3oo`0400Oo4P09oaD00_l200;o1@02o`@01ol400;o1P02o`800_l900;o0`02o`L00_l400;o
0`02o`030?oo0140000C00;o2@02o`@00_l700;o1P02o`X00_lE00;o0P000ol0o`0200;o1006o`/0
1?l>00;o1`07o`L00_l200?o00<0ool02P02o`D00_l900;o4P02o`D00_l500Wo5@02o`X00_l01P3o
003o00;o2003o`l00_l<00;o2002o`T00_l400Oo4P02o`D00_lD00?o0P03o`@00_l400Oo1002o`D0
0ol200;o2@02o`<00_l700;o1002o`800ol00`3oo`0A00004`02o`X00_l300;o1`02o`H00_l:00;o
5@02o`040?oo00;o00<0ool01006o`/00ol?00;o1`05o`T00_l200;o0P02o`X00_l500;o2@02oa80
2Ol500;o1@03oa@00_l:00;o00<0ool00_l00`3oo`0900?o3P02o``00_l800;o2@02oah00_l300;o
5@02o`@00_l400;o3`09o`<00_l900;o0`02o`L00_l400;o0P02o`800_lA00005002o`X000Co0000
0_l700;o1P02o`T00_lF00;o00<0ool00P001?l0ool400;o0P02o`/01?l>00;o1`02o`040?ooo`P0
0_l00`3oo`0300;o2P02o`D00_l900;o4P09o`D00_l600;o5002o`X00_l00`3oo`02o`030?oo00D0
0_l300;o3P02o``00_l800;o2@02oah00_l300;o5@02o`@00_l400;o3`08o`@00_l900;o0`02o`L0
0_l400;o00<0ool00`02oa40000D00;o2P02o`800_l700;o1P02o`T00_lF00;o00<0o`000P001?l0
ool400;o0P02o`800_l600Ko3@02o`L00_l200?o1`05o`<00_l:00;o1@02o`T00_lB00;o1@02o`D0
0_l600;o5002o`T00_l300;o0`02o`@00_l300?o3@02o``00_l800;o2@02o`P00_lE00;o00@0oooo
5002o`H00_l300;o2002o`D00_l400?o0`03o`P00_l300;o1`02o`@01Ol300;o4@0001@00ol:0003
o`0000;o1`02o`H00_l900;o5P04o`<01?l400;o1P02o`D00ol200?o3002o`L00_l300?o1P04o`@0
0_l:00;o1P02o`L00_lC00;o1@02o`D00_l600;o5002o`T00_l300;o0`02o`@00_l400?o3002o``0
0_l800;o2P02o`H00olE00;o00<0ool05@02o`H00_l400;o1P03o`D00_l500;o1002o`L00_l400;o
1P02o`D01?l400;o4@0001D00_l;0004o`3oo`P00_l400;o2@02oaL01?l400?o1002o`H00_l500;o
1002o``00_l700;o1003o`D01?l400;o2P02o`H00ol500?o4`02o`D00_l500;o1@03oa@00_l900;o
2002o`@00_l500;o3002o``00_l800;o2P03o`@01?lE00Go5003o`H00ol300?o1004o`D00_l400?o
1@02o`D00_l500;o1004o`D01?l400;o4@0001H00_l:00Co2003o`800ol800;o5`04o`D01?l00`3o
o`0:o`<01Ol200Go1@0:o`801Ol300Go0P04o`801_l400[o1009oa<01?l300Co0P0;oa802?l500Ko
0P06o`<02_l600[o100:o`802?l800[o4P07oa@01_l200Ko0`0:o`<02_l600Wo100:o`D01?l200Ko
400001L000?o00002@03o`T01_l90003o`0001H01?l500Co00<0ool02_l300Go0P05o`D02_l200Go
0`05o`800ol300Ko100:o`H01OlE00Co0`04o`802OlD00So1@06o`801_l300[o1P0:o`@02_l200So
2P05o`030?oo01801olD00Ko0P06o`D01Ol00`3oo`0300Wo2@05o`H02?l700?o0`06oa00000S00?o
2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(41\\) MDXJKNJQ HP LWZKJLD AYVGCNCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o3006o`H0
2Ol900;o5@05o`<01Ol200So1P05o`801Ol400Ko1`05o`H00_l200Ko0`02o`@01_l;00Go5@04o`<0
1?l200So5@0=o`<00_l400;o1P0:o`<01Ol600;o0`06o`L03Ol200So4`06o`<01_l200So2P02o`/0
1_l900Go1P06o`<00_l600Go1P05o`H00_l@00004`02o`d01_l600Wo2P02oa@01Ol300Go0P0:o`@0
1Ol200Go0P09o`H01Ol500?o0P06o`800ol200Wo2009oa<01?l300Co0P08oaD03Ol300;o1002o`H0
2_l300Go1@03o`030?oo00Oo1P0=o`802_lA00Ko0`06o`802?l900Co200:o`D02Ol400Ko0P03o`@0
2Ol400Go1@03oa00000C00;o3`02o``00_l=00;o5@02o`L00_l400;o1004o`@00ol400?o0`03o`@0
0ol700;o1@03o`@00_l400Co0P03o`@00ol600?o1@03oa<00_l500;o1@02oa`00_l600;o0P03o`@0
0ol600;o1@02o`D00_l500?o0P03o`@00ol800;o1P02o`<00_l400Co4P02o`L00_l700;o3004o`L0
1?l500;o1003o`D00ol400;o1004o`<00ol500?o1@02o`D00olA00004`02o`l00_l<00;o3@02oaD0
0_l700;o1002o`H00_l500?o0P03o`@00_l600;o1`02o`D00_l500;o1004o`800_l600;o1P02o`L0
0_lC00;o1@02o`D00_lL00;o1P02o`801?l300?o1P03o`@00_l500;o1@02o`<00_l600;o2002o`H0
0_l300;o1P02oa800_l700;o1`02o``01?l700;o1`02o`@00_l700;o1002o`@01?l300;o1`02o`D0
0_l500;o4P0001<00_l900[o2P02o`d00_lE00;o0`02o`800_l400;o1`02o`D00_l200;o1@02o`H0
0_l700;o1002o`H00_l300Go0P02o`H00_l500;o2@02oa800_l500;o1@02oa`00_l600;o0P04o`80
1?l700?o0`02o`D00_l400;o1002o`H00_l800;o1P02o`<00_l700;o4@0;o`L00_l;00;o0P02o`D0
0ol700;o0`03o`d00_l300Go0P03o`h00_l400;o4`0001<00_l900[o2P02o`d00_lE00;o0P03o`80
0_l400;o1`02o`H01?l600;o1P02o`L00ol200?o1P02o`<00_l00`3oo`0200;o1P02o`D00_l900;o
4P02o`D00_l500Oo5`02o`H00_l200;o00@0o`001?l800;o0`02o`D00ol200?o1002o`H00_l800;o
1P02o`<00_l700;o4P09o`P00_l;00;o0P02o`D00_l400Oo0P02o`h00_l300;o00<0ool00P02o`l0
0ol200?o4`0001<00_l900;o1002o``00_l=00;o5@02o`8000?o0?l00P02o`@00_l700;o1P04o`h0
0_l700Oo1`02o`800ol00`3oo`0:00;o1@02o`T00_lB00;o1@02o`D02OlE00;o2P02o`060?l00?l0
0_l800?o2@07o`d00_l800;o2`02o`L00_lB00;o1@02o`P00ol900?o0P03o`@00_l400Oo0P02o`h0
0_l200?o00<0ool00P02o`l01olD00004`02o`X00_l300;o3002o`d00_lE00;o00@0ool00_l00`3o
o`0400;o1`02o`H00ol?00;o1`05o`T00_l200;o0P02o`X00_l500;o2@02oa802Ol500;o1@03oa@0
0_l:00;o00<0ool00_l00`3oo`0900?o2005o`l00_l800;o2`02o`L00_lC00;o0`02o`P01?l900;o
1002o`@00_l=00;o3P02o`800_l200;o0P02o`l01OlF00005002o`X000Co00000_l<00;o3002oaH0
0_l00`3oo`020004o`3oo`@00_l700;o1P04o`h00_l700;o00@0oooo2002o`030?oo00<00_l:00;o
1@02o`T00_lB00Wo1@02o`H00_lD00;o2P02o`030?oo00;o00<0ool01@02o`<00_l800;o00@0oooo
3P02o`P00_l;00;o1`02oa<00_l300;o1`06o`P00_l400;o1002o`d00_l>00;o00<0ool00`02o`80
0_l?00;o00@0oooo5@0001@00_l:00;o0P02o``00_l<00;o5P02o`030?l0008000Co0?oo1002o`L0
0_l500Ko3@02o`L00_l200?o1`05o`<00_l:00;o1@03o`P00_lB00;o1@02o`D00_l600;o5002o`T0
0_l300;o0`02o`@00_l300?o1`02o`800ol=00;o2002o`/00_l700;o5002o`040?ooo`L00_l200;o
1`02o`H00_l300;o2002o`<00ol700;o1005o`<00_l200?o1`02o`D00_l200?o500001@00ol:0003
o`0000;o3002o``00_lF00Co0`04o`@00_l600;o1@03o`800ol<00;o1`02o`<00ol600Co1002o`X0
0_l600;o1`02oa<00_l500;o1@02o`H00_lD00;o2@02o`<00_l300;o1002o`@00ol600;o0`03o``0
0_l800;o2`02o`H00_lE00;o00<0ool01`03o`<00_l600;o1P02o`@00_l600?o1002o`L00_l400Co
1002o`<00_l700;o1@02o`<00olC00005@02o`/000Co0?oo3002o`/00_lG00Co1003o`@00_l400Co
1@02o`@00_l<00;o1`02o`@00ol500Co1002o`X00_l700;o1@02oa@00_l500;o1@02o`D00olD00;o
2@02o`P00_l400;o1@02o`H00_l400?o2`02o`P00_l;00;o1004oaD01Ol700;o1002o`D00ol600?o
0`03o`@01?l400?o1@03o`@01?l400;o0`03o`D00ol500;o1003oa80000F00;o2P04o`P00ol00`3o
o`0:00;o5`04o`D01?l200[o1005o`801Ol500[o0P05o`<01Ol200Co0P06o`@02_l400Wo4`04o`<0
1?l200_o4P08o`D01_l200Ko0`0:o`<01Ol300Go100:o`802?l700[o4`07o`H01Ol200Go0P06o`80
1_l300[o1@0:o`<01?l200Ko0`0:o`<01Ol300Go400001L000?o00002@03o`P01_l:0003o`0001H0
1?l500Co0P08o`H01Ol200Go1@0:o`801Ol300Go0P03o`<01_l400[o1P05oaD01?l300Co0P09oa@0
2?l500Ko0P06o`<02_l300Go0`05o`@02_l200So1`08oaD01ol600Go0P05o`801_l200Ko1@05o`03
0?oo00L01Ol00`3oo`0300?o0`06o`D01Ol00`3oo`0300Go0`05oa00000S00?o2`03ool0aP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(42\\) ODXJKNKT HR HU KILD DYWICSCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@0:o`T00_lI00Go1P08o`H01Ol200Go1006o`L0
1Ol600;o0P06o`<00_l200Go1P02o`@02?lD00Co0`04o`801Ol600?o4004o`<01?l700Co5005o`H0
0_l200[o100=o`802?lE00So1`08o`L00_l400;o1@0:o`P01Ol600;o00<0ool00ol900Go1P05o`H0
0_l@00004`02o`d01_l500[o2P02oaH02Ol400[o1005o`801Ol200Wo1P05o`D00ol200Ko0P03o`80
1Ol500?o1008oa@01?l300Co0P05o`D01?l@00Co0`04o`D02?lB00Go1@03o`802_l400go0P0:oa<0
2_l500So1`02o`@00_l500[o1P09o`@02_l500Wo1005o`D00ol@00004`02o`l00_l800;o1@02o`X0
0_lE00?o1@03o`@00_l400Co1003o`@00ol300?o1003o`L00_l500?o1002o`@01?l400;o1@03o`P0
0_lH00;o1@02o`D00_l500?o4`02o`D00_l600;o1002oa@00_l500?o1`02o`/00_l600;o0`02o`@0
1?lC00;o1004o`L00_l900?o1003o`P00_l900?o1@03o`<00ol500?o0`03o`D00ol500;o1@03oa40
000C00;o3`02o`T00ol?00;o5@02o`L00_l400;o1P02o`D00ol200?o1002o`H00_l700;o1@02o`D0
0_l400Co1002o`D00_l900;o6002o`D00_l500;o1@02oa@00_l500;o1@02o`H00_lC00;o1@02o`P0
0_l;00;o1P02o`<00_l600;o4`02o`H00_l700;o2@04o`<00ol800;o2@02o`L00_l300;o1`02o`<0
0_l700;o1@02o`D00_lB00004`02o`T02_l800?o3P02oa@00_l900;o0`02o`L00_l500;o0P02o`D0
0_l600;o1`02o`@00_l600;o0`05o`@00_l400;o2P02oaP00_l500;o1@02o`@00_lE00;o1@02o`D0
0_l600;o4`02o`@00_l900;o2`02o`H00_l300;o1`02oa800_l700;o1P02o`T01?l200Co2002o`P0
0ol<00;o1`02o`800ol>00;o1002oa<0000C00;o2@0:o`T00ol=00;o5002o`T00_l300;o1`02o`H0
1?l600;o1P02o`L00ol200?o1P02o`<00_l00`3oo`0400?o0P03o`X00_lH00;o1@02o`D00_l300?o
5@02o`D00_l500;o1P02oa<00ol200?o2@02o`/00_l600;o0`02o`L00_lB00;o1`02o`H00_l900;o
00@0o`001?l800;o2002oaD00ol200;o3`03o`800olC00004`02o`T00_l400;o3003o``00_lD00;o
2@02o`<00_l700;o1P04o`h00_l700Oo1`02o`800ol00`3oo`0400Oo2`02oaP00_l500;o1@07oaH0
0_l500;o1@02o`H00_lC00Oo2P02o`/00_l;00;o1`02oa800_l700;o1P03o`P00_l01P3o003o00;o
2002o`P00_l@00Oo0`02o`l01olD00004`02o`X00_l300;o3@03o`/00_lD00;o2@02o`<00_l700;o
1P03o`l00_l700Go2@02o`800_l200;o1005o`d00_lH00Wo1@09oa@02Ol500;o1P02oa<01Ol<00;o
2`02o`/00_l700;o4P02o`L00_l500Co2002o`030?oo00;o00<0ool02002o`P00_l>00Oo1@02o`l0
1OlF00005002o`X000Co00000_l>00;o2P02oaD00_l900;o0`02o`L00_l600Co3P02o`L00_l0103o
ool800;o00<0ool00`02o`@00_l0103oool700;o0`02o`<00_lC00Wo1@02o`D00olC00Wo1@02o`H0
0_lC00;o00@0oooo2`02o`/00_l;00;o1`02oa800_l700;o1006o`L00_l00`3oo`02o`030?oo00P0
0_l800;o3@03o`X00_l?00;o00@0oooo5@0001@00_l:00;o0P02o`l00_l900;o5@02o`T00_l300;o
1`02o`D01_l=00;o1`02o`800ol700Go0`02o`@00_l200?o1P02o`<00_l300;o4`02o`D00_l500;o
1P02oa<00_l500;o1@02o`H00_lC00;o0P03o`X00_l;00;o2`02o`L00_lB00;o1`02o`@00_l200;o
1P02o`<00_l300;o1`02o`P00ol700;o0`02o`L000Co00000ol700;o1@02o`800olD00005003o`X0
00?o00000_l?00;o2@02oaH00_l700;o1002o`H00_l500?o0P03o``00_l700;o0`03o`H01?l400;o
1002o`<00ol500;o0`02o`<00_lC00;o1@02o`D00_l600;o4`02o`D00_l500;o1P02oa<00_l300?o
2@02o`/00_l;00;o1P02oa<00_l600;o1003o`<00_l500;o0`02o`<00_l700;o2@02o`L00_l300;o
1P02o`@00_l700;o1@02o`<00olC00005@02o`/000Co0?oo2002o`D00_l800;o5`03o`D00ol400;o
1004o`D00_l400;o3002o`L00_l400?o1@04o`@00_l400;o1003o`@00_l300;o0`02oa<00_l500;o
1@02o`D00olC00;o1@02o`D00_l600;o4`02o`@00ol800;o2`02o`/00_l400Co4`02o`@01?l400;o
1002o`D00_l800;o1`02o`T00ol500?o0`03o`@00ol400?o1@03o`D00_l400?o4P0001H00_l:00Co
2003o`<00ol700;o6@09o`@02_l400Go0P05o`D02_l200Go0`05o`801?l200Ko00<0ool00ol300Go
0P0<oa801?l300Co0P0;oa<01?l300Co0`04o`@01?l@00Go0`05o`802_l400So1`0:oa<02_l300Go
0P05o`801_l200Ko0P0:o`H02_l400Wo1@0:o`<01Ol300Go400001L000?o00002@03o`T01ol80003
o`0001X01Ol600So1P05o`801Ol500[o0P05o`<01Ol200?o0`06o`030?oo00?o0`05o`803?lB00Co
0`04o`802OlE00Co0`04o`<01?l400Co4005o`<01Ol200[o1008o`L02?lE00So1@05o`801Ol200Ko
0P06o`802_l800Go00<0ool01P05o`030?l000H01Ol00`3oo`0300Go0`05oa00000S00?o2P05ool0
a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(43\\) ODXEJNKT HRZKUYKMLD BYVJCSCJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1`05o``00_lI00Go1P08o`H01Ol200Go0P0<o`D0
1_l700Ko0`02o`801Ol600;o1008oa@01?l300Co0P05o`H00ol00`3oo`08o`@01Ol600;o1P04o`P0
2?l400Go1P02o`030?oo00?o0`05o`803Ol200So500:o`H02?l:00;o2@06o`/01Ol600;o00<0ool0
0ol900Go2006oaD0000C00;o3@06o`D02Ol;00;o5P09o`@02_l400Go0P05o`803?l300Wo1P06o`80
0ol200Go1@03o`@02?lD00Co0`04o`801Ol500Co00<0ool02?l400Go1@03o`@02?l600So1005o`D0
0ol00`3oo`03o`<01Ol200go0P0:oa802ol500So2@04o`H02Ol800Wo100:o`D02Ol400Wo500001<0
0_l?00;o1`02o`D00_l;00;o5@03o`D00ol400;o1004o`@00ol400?o1@02o`H00_l300?o1003o`H0
0_l400Co1002o`D00ol800;o6002o`D00_l500;o1@03o`@00_l500;o1P02o`D00ol500;o1002o`T0
0_l900;o1@03o`<00_l700;o1P02o`H00_l300;o1004oa<00_l500?o1`02o``01?l600?o1003o`H0
0ol500?o0`03o`D00ol300?o1@03o`<00ol400?o4`0001<00_l?00;o3`02o`X00_lE00;o1`02o`@0
0_l600;o1@03o`800ol600;o1P02o`<00_l600;o1P02o`@01?l400;o1@02o`T00_lH00;o1@02o`D0
0_l500;o1@03o`@00_l600;o1@02o`D00_l600;o2002o`T00_l500;o1002o`L00_l600;o1P02o`<0
0_l600;o4`02o`H00_l700;o3004o`H00_l600;o1P02o`L00_l300;o1`02o`<00_l700;o0`02o`H0
0_lC00004`02o`T02_l=00;o2P02oa@00_l900;o0`02o`L00_l500;o0P02o`L00_l200;o0P02o`<0
0_l600;o1P02o`<01Ol400;o1002o`X00_lH00;o1@02o`D00_l400;o1`03o`<00_l600;o1002o`H0
0_l600;o2002o`T00_l400;o1@02o`<00_l200;o1P02o`H00_l300;o1`02oa800_l600;o1`02o`/0
0_l200;o1@02o`H00_l500?o3002o`L00_l200?o3002o`H00_lC00004`02o`T02_l=00;o2P02oa@0
0_l900;o0`02o`L00_l600Co2002o`800_l700;o1P02o`H00_l300;o00<0ool01003o`800ol:00;o
6002o`D00_l500;o0`03o`P00_l300;o1P03o`800ol600;o1P02o`P00_l900?o0P03o`D00_l200?o
0P02o`H00_l600;o0`02o`L00_lB00;o1P02o`L00_l;00;o0P02o`D00_l600;o1@02oaD00ol200;o
3@02o`H00_lC00004`02o`T00_l400;o3P02o`/00_lD00;o2@02o`<00_l700;o1P04o`P01_l?00;o
1P02o`800ol00`3oo`0400Oo2`02oaP00_l500;o1@07o`T00ol:00Oo1`02o`H00_l800?o2007o`H0
0_l20003o`3o00800_l600;o2`02o`L00_lB00;o1@03o`L00ol900?o0P03o``00_l500;o4007o`<0
0_lE00;o4`0001<00_l:00;o0`02o`/01?l<00;o5002o`T00_l300;o1`02o`H00ol900Ko3`02o`H0
0_l200;o0P02o`@01Ol=00;o6009o`D02Ol800?o2@05o`T00_l600;o1`04o`P01Ol800;o00@0ool0
0_l00`3oo`0600;o2`02o`L00_lB00Wo1`04o`T00_l400;o3002o`D00_l>00Oo1@02oaD00_lC0000
5002o`X000Co00000_l;00?o3002oaD00_l900;o0`02o`L00_l600Co2002o`800_l?00;o1P02o`03
0?oo00<00_l400;o00@0oooo1`02o`<00_l300;o4`09o`D00_l500?o0`02o`<00_l900;o00@0oooo
2002o`H00_l600Ko1`02o`040?ooo`L00_l00`3oo`020004o`3oo`H00_l;00;o1`02oa802?l700Ko
2002o`@00_l<00;o1@02o`d00ol:00;o5@02oa<0000D00;o2P02o`800_l=00;o2`02oaD00_l900;o
0`02o`L00_l500Ko1`02o`800_l200;o2`02o`H01Ol300;o1002o`800ol600;o0`02o`<00_lC00;o
1@02o`D00_l600;o0`02o`<00ol800;o0P03o`L00_l600;o1P02o`800_l700;o0P03o`H00_l00`3o
00020004o`3oo`H00_l;00;o1`02oa800_l400?o1P02o`800_l700;o1P02o`/00_l500?o1`02o`<0
0_l70004o`0000?o1`02o`/00_lC00005003o`X000?o00000_l>00;o2P02oaH00_l700;o1002o`H0
0_l500?o0P03o`H00_l600;o2`02o`H01?l400;o1002o`<00ol500;o0`02o`<00_lC00;o1@02o`D0
0_l600;o0`02o`@00ol700;o0`03o`H00_l600;o1@03o`<00_l600;o0`03o`D01?l300Co1P02o`/0
0_l600;o4`02o`D00_l500?o0`02o`H00_l600;o2`02o`H00_l700;o0`02o`H00_l400;o1`02o`/0
0_lC00005@02o`/000Co0?oo3P02o`T00_lG00?o1@03o`@00_l400Co1@02o`@00_l600;o1P02o`/0
0_l600Co1002o`@00_l400?o1002o`<00_l300;o4`02o`D00_l500;o1@03o`<00_l500;o1`02o`@0
0ol500;o1P02o`D00_l400;o1P02o`@00ol400Co1003o`H00_l;00;o1004oa<00_l400?o1@02o`@0
0_l500?o1P03o`X00_l600?o1@03o`<00ol400?o1003o`D00ol;00;o4`0001H00_l:00Co2002o`<0
0ol800;o6@09o`@02_l400Go0P05o`803?l600[o0P04o`801_l00`3oo`03o`<01Ol200co4P04o`<0
1?l200_o100:o`@01Ol300Go0P04o`@01?l200Go0P05o`801Ol300Go00<0ool00_l500Co0P08o`L0
2_lB00[o1005o`801Ol200Ko0P06o`@02_l400[o1009o`D02_l600[o400001L000?o00002@03o`P0
1ol90003o`0001X01Ol600So1P05o`801Ol200co1P0:o`800ol300Ko00<0ool00ol300Go0P0<oa80
1?l300Co0P09o`H02_l400Go0`05o`801?l400Co0P05o`801Ol200Go0`05o`030?oo00;o1@04o`80
2?l700So5009o`D01Ol200Go0P06o`801_l400[o1P05o`030?oo00H01Ol00`3o000600Go00<0ool0
1P0:oa00000S00?o2P04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(44\\) MDWIJNKW HM KUZKMLD BYVJASCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2@06o`T00_lE00Go0`05o`802?l800;o1002o`D0
2_l600Ko1`06o`<00_l200Go1P02o`@00_l400;o5004o`<01?l200Go0`05oa001Ol600;o1P04o`L0
2_l300Go1P02o`030?oo00?o0`05o`803Ol200So500:o`H02?l:00;o2@06o`H01_l300Ko00@0ool0
1Ol900Go1P05o`H00_l@00004`02o`d01_l900Ko2P02oa@01Ol300Go0P0:o`H00_l400;o1@0:o`@0
2Ol600Ko0P03o`801Ol500?o1002o`@00_lD00Co0`04o`801Ol300Go4005o`D00ol400So1@0:o`<0
1Ol500?o00<0ool00ol300Go0P0=o`802_lB00_o1@08o`T01?l600Wo1@06o`<01_l00`3oo`08o`D0
2Ol400Go1@03oa00000C00;o3`02o`d00_l<00;o5@02o`L00_l400;o1004o`@00ol400?o2002o`P0
0ol400?o1P02o`@01?l400;o1@03o`@00ol400?o5002o`D00_l400;o1`02oa<00_l500?o1@02o`@0
0_l600;o1@02o`D00_l500?o0`02o`L00_l600;o1P02o`<00_l400Co4`02o`D00ol700;o3004o`H0
0ol400?o1P02o`L00_l300?o1@03o`<00ol500?o1@02o`D00olA00004`02o`l00_l=00;o3002oaD0
0_l700;o1002o`H00_l400Co0`03o`P00_l800;o1P02o`H00_l400Co1002o`D00_l500Co0`03oa@0
0_l500;o1002o`L00_lC00;o1@02o`D00_l600;o1@03o`@00_l500;o1@02o`@00_l700;o1P02o`H0
0_l300;o1P02oa<00_l600;o1`02o``01?l600;o1P02o`H00_l700;o0`02o`L00_l300;o1`02o`D0
0_l500;o4P0001<00_l900[o1@0:o`X00_lE00;o0`02o`800_l400;o1`02o`<01?l200Co2002o`P0
0_l600;o1P02o`<01Ol400;o1002o`H01?l200Co5002o`D00_l400;o0`02o`800_lC00;o1002o`H0
0_l600;o1P03o`<00_l500;o1002o`D00_l300;o0P02o`H00_l600;o0`02o`L00_lB00;o1P02o`L0
0_l;00;o0P02o`D00_l600;o1P0;o`<00_l700;o0P03o`h00_l400;o4`0001<00_l900[o1@0:o`X0
0_lE00;o0P03o`800_l400;o1`02o`<00_l0103o0004o`P00_l800;o1P02o`H00_l300;o00<0ool0
1003o`800ol600;o00@0o`001?lD00;o1@02o`@00_l200?o0P02oa<00ol200?o1P02o`H00_l700;o
0`02o`D00ol200?o1@02o`800ol200;o1P02o`H00_l300;o1`02oa800_l600;o1`02o`/00_l200;o
1@02o`H00_l700Wo3003o`800_l?00?o0P03oa<0000C00;o2@02o`@00_l700;o1002o``00_lE00;o
0P000ol0o`0200;o1002o`L00_l300;o00H0o`00o`02o`P00_l@00;o1P02o`800ol00`3oo`0400Oo
1`02o`060?l00?l00_lD00;o1@02o`@00_l20003o`3o00800_lC00Oo1`02o`H00_l700?o2@07o`H0
0_l20003o`3o00800_l600;o2`02o`L00_lB00;o1@03o`L00ol900?o0P03o``00_l700;o1@02o`L0
1ol300;o3`07oa@0000C00;o2P02o`<00_l800;o0`02o``00_lE00;o00@0ool00_l00`3oo`0400;o
1`02o`<00_l00`3oo`02o`030?oo00P00_l@00;o1P02o`800_l200;o1005o`T00_l00`3oo`02o`03
0?oo01@02Ol400;o00@0ool00_l00`3oo`0C00Go2@02o`H00_l800?o2005o`P00_l0103oo`02o`03
0?oo00H00_l;00;o1`02oa802Ol700Co2@02o`@00_l<00;o2002o`<00_l600Oo1@02o`l01OlF0000
5002o`X000Co00000_l90004o`0000;o2`02oaH00_l00`3oo`020004o`3oo`@00_l700;o0`02o`03
0?oo00;o00<0ool02002oa000_l600;o00<0ool00`02o`@00_l0103oool800;o00<0ool00_l00`3o
o`0D00Wo1002o`030?oo008000Co0?oo4`02o`040?ooo`P00_l600;o1002o`<00_l800;o00@0oooo
1`02o`030?oo008000Co0?oo1P02o`/00_l700;o4P08o`L01_l800;o1002o``00_l800;o0`02o`D0
0ol:00;o3`02o`040?oooaD0000D00;o2P02o`800_l900;o0P02o`/00_lF00;o00<0o`000P001?l0
ool400;o1`02o`800_l300;o0`02o`L00_l@00;o1P05o`<00_l400;o0P03o`H00_l300;o0`02oa<0
0_l500;o1002o`030?l0008000Co0?oo4`02o`800ol700;o1P02o`@00_l300?o1`02o`800ol600;o
00<0o`000P001?l0ool600;o2`02o`L00_lB00;o1003o`H00_l200;o1`02o`H00_l;00;o2@02o`04
0?ooo`D00_l70004o`0000?o1`02o`D00_l200?o500001@00ol:0003o`0000;o2P000ol00002o`/0
0_lF00Co0`04o`@00_l600;o0`02o`<00_l300;o1`02oa000_l600Co1002o`@00_l300?o1@02o`<0
0_l300;o4`02o`D00_l400Co0`04oa<00_l300?o1P02o`H00_l400;o1003o`H00_l300?o1@04o`<0
1?l600;o2`02o`H00_lC00;o1@02o`D00ol300;o1P02o`H00_l;00;o2@02o`030?oo00H00_l600;o
1002o`L00_l500;o0`03oa<0000E00;o2`001?l0ool;0004o`3oo`X00_lG00Co1003o`@00_l400Co
0`02o`P00_l700;o4002o`H01?l400;o1002o`@00ol400;o2002oa<00_l500;o1004o`@00olC00;o
1003o`D00_l600;o1002o`D00_l600;o1003o`@01?l400?o1P02o`/00_l400Co4`02o`@00ol500;o
1002o`D00ol600?o2P02o`T01Ol600?o1003o`@00ol500?o1@02o`@00olB00005P02o`X01?l;00Co
2@02oaL01?l500Co0P0:o`<01_l200Ko0P0:o`L02_l200Co0P06o`030?oo00?o0`05o`030?oo00Co
0P06oa401?l300Co0P04o`D01?l@00Go0`05o`801?l400Co0`0:o`<01Ol300Go00<0ool00_l500Co
0P08o`L02_lB00[o1005o`801Ol200Ko0P06o`@02_l300Oo2009o`D02_l300Go0`05oa00000G0003
o`0000T00ol<00?o2@000ol0000F00Co1@04o`802?l500Ko0P06o`802_l700[o0P03o`<01_l00`3o
o`03o`<01Ol00`3oo`04o`801_lA00Co0`04o`801?l500Co4005o`<01Ol200Co1004o`<02_l300Go
0`05o`030?oo00;o1@04o`802?l700So5009o`D01Ol200Go0P06o`801_l400[o0`07o`X01Ol00`3o
000600Go00<0ool00`05o`<01Ol@00008`03o``00ooo0<D0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(45\\) MBUGJPNWZHP KQ KMLD BY GAUCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o``01_l700Go3002oaD0
1Ol300Go00<0ool02?l:00Co2@06o`L01_l600So1`06o`<00_l500;o1002o`D02_l500Co0`04o`80
2?lE00Go1P02o`D01OlD00Go1P02o`030?oo00?o0`05o`803Ol200So500:o`H02?lG00Ko1006o`<0
1_l500Co2@05o`L02_lB00004`02o`d01_l500Wo2`02oa@01Ol300Go00<0ool02Ol700So1@0:o`<0
2Ol500So1`06o`800ol500;o1002o`D02_l500Co0`04o`802?lE00Go1@03o`<02OlB00Go1@03o`03
0?oo00?o0`05o`803Ol200[o4P0;o`D02?lE00[o0P06o`<01_l300So1@09o`D02_lB00004`02o`l0
0_l700;o1@02o`/00_lE00;o1`02o`@00_l500?o1P02o`@00_l400Co1@02o`<00ol400?o1P02o``0
0_l400Co1003o`@00ol500;o1@02o`H00_l500;o1@02oa/00_l500?o0`03o`D00olC00;o1@03o`<0
0_l700;o1P02o`H00_l300;o1004oa<00_l500?o1`02oaL01?l500;o1002o`L00_l500;o1002o`@0
0ol500?o2002oaH0000C00;o3`02o`l00_l:00;o5@02o`L00_l400;o1P02o`D00_l600;o0`02o`L0
0_l300;o1P02o`H00_l<00;o1004o`@01?l300?o1@03o`@00_l600;o1@02o`D00_lK00;o1@02o`@0
0_l700;o4`02o`D00_l400;o1`02o`H00_l600;o0`02o`H00_lC00;o1P02o`L00_lG00;o1`02o`@0
0_l700;o1002o`H00_l300;o1`02o`P00_lF00004`02o`T02_l=00;o2P02oaD00_l300;o0P02o`@0
0_l600;o1@02o`H00_l200?o1`02o`<00_l600;o1P02o``00_l300Go1004o`801?l600?o0`02o`H0
0_l500;o1@02oa/00_l400;o1002o`T00_lB00;o1002o`D00_l300;o0P02o`H00_l600;o0`02o`L0
0_lB00;o1P02o`L00_lF00?o1`02o`@02ol400;o1P02o`800olA00;o5P0001<00_l900[o3@02o`X0
0_lE00;o0P03o`800_l400;o1P02o`D00_l600;o0P02o`@01ol200;o1P02o`H01ol700;o0`02o`03
0?oo00@00_l0103o0004o`L00_l300;o1P02o`D00_l500Oo5P03o`800ol400;o2@02oa800ol200?o
1@02o`800ol200;o1P02o`H00_l300;o1`02oa800_l600;o1`02oaH00_l400Oo1009o`D00_l600;o
0P02oa800_lF00004`02o`T00_l400;o3`02o`X00_lE00;o0P000ol0o`0200;o1002o`D00ol500;o
1P02o`800_l400Oo2P02o`H02Ol500;o0P03o`030?oo00@00_l01P3o003o00;o1`03o`X00_l500;o
1@09oa@01ol500;o2@02oa801ol600;o0P000ol0o`0200;o1P02o`/00_l700;o4P02o`D00ol700?o
5@02o`@01ol400;o1@02o`D00_l600;o0P02oa800_lF00004`02o`X00_l300;o2002o`@00_l;00;o
5@02o`040?oo00;o00<0ool01009o`H00_l600;o0P02oaD00_l600;o1@03o`@00_l200;o0P02o`@0
0_l00`3oo`02o`030?oo00P00ol900Wo1@02o`D00olC00Go1`02o`T00_lB00Go2002o`040?oo00;o
00<0ool01P02o`/00_l700;o4P09o`L01?lE00;o4002o`<00_l600;o1P02o`800_lB00;o5P0001@0
0_l:0004o`0000;o2008o`X00_lF00;o00<0ool00P001?l0ool400So1`02o`H00_l200;o5@02o`H0
0_l600;o1002o`030?oo00<00_l400;o00<0ool00_l00`3oo`0400;o0`02o`T02Ol500;o1P02oa<0
0_l0103oool600;o2@02oa800_l0103oool700;o00<0ool00P001?l0ool600;o2`02o`L00_lB00So
1`06oa@00_l@00;o0`02o`H00_l600;o0P02oa800_lF00005002o`X00_l200;o2007o`/00_lF00;o
00<0o`000P001?l0ool400;o1003o`H00_l600;o0P02o`P00_l;00;o1P02o`H00_l400Go0`02o`<0
0_l300;o0`02o`<00_l300?o2002o`D00_l500;o1P02oa<00_l200?o1@03o`P00_lB00;o0P03o`H0
0_l00`3o00020004o`3oo`H00_l;00;o1`02oa800_l400?o1P02o`800_lD00;o2002o`L00_l0103o
ool600;o1P02o`800ol700;o2002oaH0000D00?o2P000ol00002o`P00_l@00;o5P04o`<01?l400;o
1@02o`H00_l600;o0`02o`H00ol;00;o1P02o`H00_l400Co1002o`<00_l300;o0`02o`<00_l400?o
1`02o`D00_l500;o1P02oa<00_l300?o1@02o`L00_lC00;o0`03o`D01?l300Co1P02o`/00_l600;o
4`02o`D00_l500?o0`02oa@00_l600?o1`02o`030?oo00L00_l600;o0`02o`L00_l800;o5P0001D0
0_l;0004o`3oo`P00_l?00;o5`04o`@00ol400;o1003o`H00_l600;o0`03o`@01?l;00;o1P02o`D0
0ol400Co1002o`<00_l800;o0`02o`D00_l700;o1@02o`D00_l500?o4`02o`@00ol500;o1@02oa@0
0_l400?o1004o`@00ol600;o2`02o`@01?lC00;o1003o`D00_l400;o5003o`@01?l700Go1`02o`H0
0_l300?o1@03o`P00_lF00005P02o`X01?l800;o3P02oaL01?l500Co00<0ool02?l600Co1004o`<0
2_l600[o00<0ool02Ol400Co0P06o`030?oo00Co0P06o`802_l500Co0`04o`802olB00Go0`05o`<0
2OlB00Go0`05o`030?oo00;o1@04o`802?l700[o4P0:o`@01Ol200Go4`0:o`@01ol700Co1004o`<0
2_l400[o4P0001L000?o00002@03o`P02?l80003o`0001H01?l500Co00<0ool01ol700Co1004o`D0
1Ol00`3oo`0600[o00<0ool01ol600?o0`06o`030?oo00Co0P06o`802_l500Co0`04o`802OlD00Go
0`05o`D01OlD00Go0`05o`030?oo00;o1@04o`802?l700So5009o`D01Ol200Go5@05o`030?oo00@0
1ol700Co1004o`D01Ol00`3oo`0400[o4P0002<00ol800Soo`340000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(46\\) MBUGJQMWZHPYMQ KMLD B WGAVCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oJP02o`@00ooK00005@02obP0
0_mQ00[oJ@0:omX0000D00;o:P02of401Ol200;oJP05o`800_oJ00005002obX00_mQ0003o`000700
00?o0000h00001@00_l<00Ko2004o``00_lE00Go0`05o`030?oo00So2P04o`T01_l700Ko2P05o`D0
1Ol300Go1002o`@00_l500[o1@04o`<01?l200So2008o`D01Ol300Go1@05oa@01Ol600;o00<0ool0
0ol300Go0P0=o`802?lD00[o5@02o`@00_l800Ko1006o`<01_l500;o2`05o`L02_lB00004`02o`d0
1_l700Oo2`02oa@01Ol300Go00<0ool02Ol700So1@0:o`<02Ol700Wo0`05o`<01Ol400;o1002o`D0
2_l500Co0`04o`802?l800So1@05o`<01Ol300Wo4P05o`D00ol00`3oo`03o`<01Ol200go0P0:oa80
2olD00;o1002o`H02_l200Ko0`06o`@01?l800Wo1@0:oa80000C00;o3`02o`P00_l400;o2`02oaD0
0_l700;o1002o`D00ol600;o1002o`@01?l500;o0`03o`@00ol500?o1@03o`<00_l700;o1003o`@0
0ol500;o1@02o`H00_l500;o1@02o`l00_l900;o1`02o`<00ol500?o4`02o`D00ol300;o1`02o`H0
0_l600;o0`02o`@01?lC00;o1@03oa800ol400?o1004o`D00_l400;o1`02o`H01?l700?o1@03o`P0
0_lF00004`02o`l00_l700;o1P02o`X00_lE00;o1`02o`@00_l600;o1@02o`H00_l300;o1`02o`<0
0_l600;o1@02o`L00_l300;o1`02o`@01?l300?o1@03o`@00_l600;o1@02o`D00_l?00;o2@02o`L0
0_l300;o1`02oa<00_l500;o1002o`L00_l600;o1P02o`<00_l600;o4`02o`H00_lB00Co0`03o`@0
0_l700;o1002o`L00_l600Co1`02o`L00_l800;o5P0001<00_l900[o1@02o`H00_l:00;o5@02o`<0
0_l200;o1002o`H00_l500;o1P02o`800ol700;o0`02o`H00_l400;o2@02o`800_l300;o0P02o`@0
1?l200Co1P03o`<00_l600;o1@02o`D00_l?00;o2@02o`<00_l200;o0P02o`T00_lB00;o1002o`D0
0_l300;o0P02o`H00_l600;o0`02o`L00_lB00;o1P02oa801?l200Co0`03o`L00_l400_o1@02o`80
0_l500?o4@02oaH0000C00;o2@0:o`D00_l600;o2P02oaD00_l200?o0P02o`@00_l600;o1@02o`H0
0_l200;o1007o`800_l600;o1002o`T00_l200;o0P03o`800_l400;o00@0o`001?l700;o0`02o`H0
0_l500;o1@07o`X00_l900;o0P03o`800_l200;o2@02oa800ol200?o1@02o`800ol200;o1P02o`H0
0_l300;o1`02oa800_l600;o4P02o`040?l000Co0`02o`@01ol400Wo1P02o`800_l500;o4P02oaH0
000C00;o2@02o`@00_l700;o1P02o`X00_lE00;o0P000ol0o`0200;o1002o`D00ol500;o1P02o`80
0_l400Oo2P02o`@00_l900;o0P02o`8000?o0?l00P02o`@00_l01P3o003o00;o1`03o`X00_l500;o
1@09o`P00ol800;o0P000ol0o`0200;o0P02o`T00_lB00Oo1P02o`8000?o0?l00P02o`H00_l;00;o
1`02oa800_l500?o4P02o`060?l00?l00_l300;o1007o`@00_l500;o1@03o`800ol400;o4P02oaH0
000C00;o2P02o`<00_l700?o1002o`/00_lE00;o00@0ool00_l00`3oo`0400Wo1P02o`H00_l200;o
5@02o`@00_l900;o0P02o`040?oo00;o00<0ool01002o`030?oo00;o00<0ool02003o`T02Ol500;o
1@03o`H01?l800;o00@0ool00_l00`3oo`0200;o2@02oa801Ol800;o00@0ool00_l00`3oo`0600;o
2`02o`L00_lB00Wo4`02o`030?oo00;o00<0ool00`02oa000_l300;o1P02o`@00_l400;o4P02oaH0
000D00;o2P001?l00002o`L02Ol:00;o5P02o`030?oo008000Co0?oo1008o`L00_l600;o0P02oaD0
0_l400;o2@02o`800_l00`3oo`020004o`3oo`@00_l00`3oo`02o`030?oo00@00_l300;o2@09o`D0
0_l600;o1@06o`L00_l00`3oo`020004o`3oo`800_l900;o4P02o`040?ooo`L00_l00`3oo`020004
o`3oo`H00_l;00;o1`02oa802?lD00;o00<0ool00_l00`3oo`0300;o4002o`<00_l600;o1002o`@0
0_lB00;o5P0001@00_l:00;o0P02o`L00_l00`3oo`02o``00_lF00;o00<0o`000P001?l0ool400;o
1003o`H00_l600;o0P02o`P00_l;00;o1003o`P00_l200;o00<0o`000P001?l0ool300;o0`02o`<0
0_l300;o0`03o`P00_l500;o1@02o`H00_l500;o0P02o`L00_l00`3o00020004o`3oo`800ol800;o
4P02o`800ol600;o00<0o`000P001?l0ool600;o2`02o`L00_lB00;o1003oa800_l300;o0`02o`80
0_l800;o1`02o`040?ooo`D00_l600;o0`03o`L00_l800;o5P0001@00ol:0003o`0000;o2002oa00
0_lF00Co0`04o`@00_l500;o1P02o`H00_l300;o1P03o`/00_l500;o1`02o`<01?l300Co0`02o`<0
0_l300;o0`02o`@00ol700;o1@02o`D00_l600;o1003o`<00_l600Co0`04o`<00_l700;o4`02o`<0
0ol500Co0`04o`H00_l;00;o1P02oa<00_l500;o4P02o`<00_l300;o0`02o`H00ol700;o00<0ool0
1P02o`H00_l400;o1`02o`P00_lF00005@02o`/000Co0?oo2003o`h00_lG00Co1003o`@00_l400?o
1P02o`H00_l300?o1004o`/00_l600;o1@02o`@01?l400?o0`02o`P00_l300;o1@02o`L00_l500;o
1@02o`D00ol400;o1002o`H01?l400?o1002o`D00_lD00;o1003o`@01?l400?o1P02o`/00_l400Co
4`02o`@00olB00;o2002o`<00ol400Co1`05o`D00ol600?o0`03o`D00ol800;o5P0001H00_l:00Co
2@03o``00_lG00Co1@04o`030?oo00So1P04o`@01?l300[o1P0:o`<02Ol300Co1@04o`030?oo00Co
0P06o`802_l500Co0`04o`802ol300Go0P05o`<01?l500Co0`09oa801Ol300Go00<0ool00_l500Co
0P08o`L02_lB00[o4P06o`801_l300[o1007o`D01_l200Ko0`0:o`@02_lB00005`000ol0000900?o
2P07o`L000?o00005P04o`D01?l00`3oo`07o`L01?l400Co1@05o`030?oo00H02_l500Go1@04o`D0
1?l00`3oo`04o`801_l200[o1@04o`<01?l200Wo1@05o`801Ol300Co1@04o`D01OlD00Go0`05o`03
0?oo00;o1@04o`802?l700So5009oa<01_l200Ko1@05o`030?oo00@01ol500Ko0P06o`D01Ol00`3o
o`0400[o4P0002<00ol<00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(47\\) HGUGJLNTZHPYMQ KHLFXB UFAVCM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o``01_l800;o3P02oaH0
1?l300Co1P06o`X01?l900Ko1`06o`H03Ol200Ko0`02o`D02?l500[o1@04o`<01?l200So2008o`D0
1Ol300Go1@05oa@01Ol600;o0P04o`<01?l300go00<0ool01Ol800Go0P05o`802_lH00Co1@07o`L0
1_l300Ko1@02o`/01Ol600Go0`05oa00000C00;o3@06o`P00_l?00;o5@04o`<01?l400[o1P08o`D0
2_l300Wo1@0=o`801_l200?o1@08o`D02_l500Co0`04o`802?l800So1@05o`<01Ol300Wo4P05o`D0
0ol200Co0`04o`<03Ol00`3oo`05o`P01Ol200Go0P0;oaD02?l300Oo1`06o`<01_l400Co2009o`@0
1Ol300Go400001<00_l?00;o2`02o`h00_lF00;o1@02o`@01?l500;o1P02o`@00_l400Co1@02o`<0
0ol400?o1`02o`H00_l300;o1004o`P00_l900;o1@02o`H00_l500;o1@02o`l00_l900;o1`02o`<0
0ol500?o4`02o`D00ol400;o1@02o`L00_l600;o0`02o``00ol400?o1@02o`D00olD00;o1002o`D0
0_l<00;o1`02o`H01?l700?o1@03o`@00_l700;o4@0001<00_l?00;o2`02o`h00_lF00;o1@02o`@0
0_l700;o1@02o`H00_l300;o1`02o`<00_l600;o1`02o`H00_l300;o1004o`P00_l900?o1002o`H0
0_l500;o1@02o`l00_l900;o1`02o`<00_l700;o4`02o`D00_l500;o1@02o`L00_l600;o0`02o`d0
0ol200?o1P02o`H00_lC00;o1P02o`@00_l<00;o1`02o`H01?l700;o1`02o`@00_l700;o4@0001<0
0_l900[o2@02o`h00_lF00;o1@02o`<00ol700;o1@02o`H00_l200?o1`02o`<00_l600;o1`02o`H0
0_l300;o0`05o`P00_l:00?o0`02o`H00_l500;o1@02o`l00_l900;o0`02o`800_l200;o2@02oa80
0_l400;o1P02o`D00_l700;o1P02o`<00_l200;o2P02o`800_l700;o1P02oa<00_l600;o1002o`80
0_l800_o1@02o`800_l500?o3@02o`<00_l200;o4@0001<00_l900[o2P000ol0000<00;o5P02o`D0
0_l300;o1007o`@00_l600;o0P02o`@01ol200;o1P02o`L00_l600;o0`02o`<00_l00`3oo`0800;o
2`02o`<00_l600;o1@02o`D01ol:00;o2@02o`800ol200;o0P02o`T00_lB00?o0P03o`H00_l500;o
1`02o`H00_l300;o0P02o`/01?l800;o1P02oa<00_l600;o1002o`800_l900Wo1P02o`800_l500;o
3P02o`800ol200;o4@0001<00_l900;o1002o``00_l=00;o5P02o`D00_l300;o1007o`@00_l600;o
0P02o`@01ol:00;o1`02o`/00_l200?o00<0ool02002o`/00ol:00;o1@02o`D02Ol800?o2002o`80
00?o0?l00P02o`800_l900;o4P07o`L00_l500;o1`02o`/01_l;00Co2002o`D00olC00;o1P02o`@0
1_l900;o1@02o`D00ol200?o1002o`h00_l20003o`3o00800_lA00004`02o`X00_l300;o3002o`d0
0_lF00Wo0`02o`l00_l600;o0P02oaD00_l700;o2`02o`800_l200;o2002o``00ol900Wo1@02o`D0
0ol600Co2002o`040?oo00;o00<0ool00P02o`T00_lB00Go2@09o`L00_l;00Ko2`03o`T02OlD00;o
1P02o`@01_l:00;o0`02o`H00_l400;o1002o`h00_l0103oo`02o`030?oo0140000D00;o2P001?l0
0002o`d000?o00002P02oaL02Ol300;o3`02o`H00_l200;o5@02o`L00_l;00;o00<0ool00`02o`<0
0_l300;o0`02o`<00_l300;o2@09o`D00_l600;o1@06o`L00_l00`3oo`020004o`3oo`800_l900;o
4P02o`040?ooo`P02Ol700;o2`02o`800_l;00Co2008oaD00_l600;o1002o`800_l:00;o0`02o`H0
0_l400;o1002o`h00_l00`3oo`020004o`3ooa40000D00;o2P02o`800_l=00;o2`02oaL00_l500;o
0`02o`P00_l500;o1P02o`800_l800;o2`02o`L00_l;00Go0`02o`<00_l300;o0`02o`<00_l300?o
2002o`D00_l500;o1P02o`D00_l200;o1`02o`030?l0008000Co0?oo0P03o`P00_lB00;o0P03o`L0
0_l500;o1`02o`/00_l200;o0P02o`H01_l700;o1003oa@00_l600;o1002o`800_l200;o1`02o`04
0?ooo`D00_l600;o0`03o`L00_l400;o00<0o`000P001?l0oolA00005003o`X000?o00000_l=00;o
2`02oaL00_l500;o1002o`H00ol500;o1P02o`<00_l600?o2`02o`L00_l;00Co1002o`<00_l300;o
0`02o`<00_l400?o1`02o`D00_l500;o1P02o`@00ol300;o1P04o`<01?l300;o1`02oa<00_l300?o
1P02o`D00_l700;o2`02o`H00_l500?o0P03o`H00_l500;o5002o`H00_l400;o1P02o`L00_l00`3o
o`0600;o1P02o`@00_l700;o1004o`<01?lA00005@02o`/000Co0?oo3P000ol0000800;o6002o`D0
0_l400?o1004o`D00_l600;o0`03o`@01?l;00;o1`02o`/01?l400;o0`02o`<00_l300;o0`02o`D0
0_l700;o1@02o`D00_l500?o1002o`@00_l600Co1003o`@00_l500;o5002o`@00ol500;o1@02o`L0
0_l;00;o1P02o`D00_l400;o1P02o`@00olD00;o1P02o`@00_l600;o1`05o`D00ol600?o0`03o`D0
0ol400Co1003oa40000F00;o2P04o`L00_l500;o2002oaP01?l300Co100:o`@01?l400Co0`0:o`H0
2_l00`3oo`06o`L01?l200Ko0P0<o`<02_l500Co0`04o`802ol300Go0P05o`<01?l500Co0`09oa80
1Ol300Go0P04o`<01?l300So1P0<o`<01Ol200Go0P0:oa@01?l400Co00<0ool02_l400Oo1@06o`80
1_l300[o0`04o`D01?l@00005`000ol0000900?o1`09o`P000?o00005`04o`<01?l600Go00<0ool0
1004o`@01?l500Go00<0ool01P0:o`030?oo00Ko1`03o`<01_l200co0`0:o`D01?l300Co0P09o`D0
1Ol200Go0`04o`D01?l500Go5005o`<01Ol200Co0`04o`<02?l600co0`05o`801Ol200Wo5@04o`@0
1?l00`3oo`0:o`@01ol500Ko0P06o`D01Ol00`3oo`0300Co1@04oa00000S00?o1`09ool0a0000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(48\\) HGSGILNTVHPYMT KHLCXCZUFAVCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko2004o``00_lF00Co0`04o`H01_l600;o00<0ool0
0ol900Ko1P0:o`<03Ol200Ko0`02o`D02?l900;o2@04o`<01?l200So2008o`D01Ol300Go0`08oa<0
1Ol600;o0P04o`<01?l300go1@05o`H01Ol200Go1P05o`H02_l900Co1@07o`L01_l300Ko1@02o`/0
1Ol600Go1P02oa00000C00;o3@06o`H02?l;00;o5@04o`<01?l400[o100:o`D02_l400[o0`0=o`80
1_l200?o1@08o`P01?l800Co0`04o`802?l800So1@05o`<01Ol300So4`05o`D00ol200Co0`04o`<0
3Ol300Wo1005o`801Ol400Wo100:o`L02?l300Oo1`06o`<01_l400Co2009o`@01Ol500?o400001<0
0_l?00;o1`03o`@00ol:00;o5P02o`D00_l400Co1@02o`@00ol500?o0`04o`D00_l800;o2P02o`H0
0_l300;o1004o`P00_l;00Co2@02o`D00_l500;o3`02o`T00_l700;o1`02oaP00_l500?o1002o`D0
0_l700;o1P02o`800ol500?o1003o`@00ol400?o1@03o`@00_l500;o1`02o`@00_l500;o3002o`L0
0_l600Co1`03o`D00ol500;o1@03oa40000C00;o3`02o`L00_l600;o2P02oaH00_l500;o1002o`L0
0_l400;o1`02o`<00_l700;o2002o`X00_l600;o0`02o`@01?l800;o2`04o`T00_l500;o1@02o`l0
0_l900;o1`02o`L00_lH00;o1@02o`D00_l500;o1`02o`H00_l200;o1`02o`D00ol200?o1@02o`L0
0_l400?o1002o`H00_l600;o1002o``00_l700;o1P04o`L00_l700;o1@02o`D00_lB00004`02o`T0
2_l500;o1P02o`X00_lF00;o1@02o`<00ol700;o1002o`L00_l200?o1`02o`P00_l:00;o1P02o`<0
0_l300Go2002o`X00_l200;o2002o`D00_l500;o3`02o`T00_l300;o0P02o`L00_lH00;o1002o`H0
0_l500;o1`02o`H00_l0103oool?00;o0P02o`D00ol>00?o0`02o`H00_l600;o1002o`800_l800_o
1@02o`800_l500?o3P02o`@00_lC00004`02o`T02_l500;o1P02o`X00_lF00;o1@02o`<00_l400Oo
2`03o`800_l400Oo1`02o`X00_l600;o0`02o`<00_l00`3oo`0800;o2P02o`800_l800;o1@02o`D0
1ol:00;o2@02o`800ol200;o1`02oaP00ol200?o1P02o`D00_l700;o1P02o`030?oo01401?l600;o
4002o`<00_l600;o1P02o`@00_l200;o2@09o`H00_l200;o1@02o`l00ol200?o4`0001<00_l900;o
1002o`P00_l400;o2`02oaH00_l500;o0`02o`@01ol600Oo0`02o`@01ol700;o2P02o`/00_l200?o
00<0ool02002o`T00ol200?o1`02o`D00_l500Wo2003o`P00_l20003o`3o00800_l700;o6007o`L0
0_l500;o1`02o`T00_lA00Co1P02oa000ol:00;o1P02o`@01_l900;o1@02o`D00ol200?o1002o`l0
1olD00004`02o`X00_l300;o2@07o`/00_lF00Wo0`02o`l01ol500;o4P02o`X00_l;00;o0P02o`80
0_l800;o2@02o`@00_l700Wo1@02o`D00ol600Co2002o`040?oo00;o00<0ool01`02oaP01Ol900Wo
1`02o`T00_lA00?o1`02oa400ol900;o1P02o`@01_l:00;o0`02o`H00_l400;o1002o`l01OlF0000
5002o`X000Co00000_l900Ko2`02oaL02Ol300;o3P03o`X00_lB00;o2P02o`/00_l00`3oo`0300;o
0`02o`<00_l300;o1002o`@00_l700Wo1@02o`H00_l500Ko1`02o`030?oo008000Co0?oo0P02o`<0
0_l300;o4`02o`040?ooo`P02Ol700;o2@02oa401?l600;o3@02o`<00_l900;o1P02o`@00_l200;o
2P02o`<00_l600;o1002o`@00_l?00;o00@0oooo5@0001@00_l:00;o0P02o`P00_l400;o2P02oaL0
0_l500;o0`02o`P00_l400;o1`001?l00002o`P00_l800;o2P02o`/01Ol300;o0`02o`<00_l300;o
0`02o`H00_l600;o1@02o`D00_l600;o1@02o`800_l700;o00<0o`000P001?l0ool200;o0`02o`<0
0_lC00;o0P03o`L00_l500;o1`02o`T00ol700;o1P06o`D00ol700;o0`02o`<00ol800;o1P02o`@0
0_l200;o0P02o`L00_l0103oool500;o1P02o`<00ol700;o1@02o`800olD00005003o`X000?o0000
0_l700;o1P02o`T00_lG00;o1@02o`@00_l600?o1002o`H00_l400;o1P03o`P00_l:00;o2`04o`@0
0_l300;o0`02o`<00_l300;o1P02o`H00_l500;o1@02o`H00_l400?o0`02o`H01?l300Co0P02o`<0
0_l300;o4`02o`<00ol600;o1@02o`L00_l:00;o1`02o`D00ol200?o1@02o`L00_l300;o1003o`L0
0_l600;o1002o`H00_l700;o00<0ool01P02o`H00_l400;o1`02o`D00_l300?o4`0001D00_l;0004
o`3oo`L00_l600;o2002oaP00_l500;o1003o`@01?l400?o1003o`@00ol400Co2002o`X00_l;00Co
1002o`<00_l300;o0`02o`800ol600?o1@02o`D00_l500;o1@03o`@00_l400;o1P04o`@00ol200;o
0`02o`<00_lC00;o1003o`D00_l500;o1`02o`X00ol500?o1@02o`@00_l500?o1@03o`<00_l500;o
1`02o`H00_l400;o1P02o`L01Ol500?o1P03o`<00ol500?o1@02o`@00olB00005P02o`X01?l700?o
1003o`L00_lH00Co0`04o`@02_l500Wo1@0:o`@02_l300So1`04o`801_l200co00<0ool01?l200Ko
0`04o`<01?l200_o0`05o`801Ol300Co1@04o`030?oo00[o4@05o`<01Ol200Co0`04o`<02?l800[o
0`05o`801Ol400[o0`0:o`D01?l400Co00<0ool02_l400Oo1@06o`801_l300[o0`05o`<01Ol@0000
5`000ol0000900?o2008o`P000?o00005`04o`<01?l600Go00<0ool01`05o`030?l000H01Ol00`3o
o`0400[o0`08o`L00ol300Ko0P0<o`030?oo00Co0P06o`<01?l300Co0P09o`D01Ol200Go0`04o`D0
1?l00`3oo`0:oa401Ol300Go0P04o`<01?l300So2P05o`030?oo00<01Ol200Go1P05o`030?oo00<0
2_l500Co1004o`030?oo00[o1007o`D01_l200Ko1@05o`030?oo00<01Ol300Go400002<00ol900Ko
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(49\\) HGSGJLNTVHPYMTXKHLCXC UFCVCJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l<00Ko1@05o`h00_lF00Co0`04o`H01_l600;o00<0ool0
0ol900Ko1`06o`H03Ol200Ko0`02o`D02?l900;o2@04o`<01?l200So2008o`D01Ol300Go0`08o`D0
1Ol200Go0P05o`H00_l200Co0`04o`<03Ol500Go1P05o`801Ol600Go6@04o`D01ol<00Go2P02o`/0
1Ol800Ko5@0001<00_l=00Ko1@07o`d00_lE00Co0`04o`@02_l400[o1@0:o`<02Ol500go0P06o`80
0ol500So2004o`P01?l300Co0P08o`P02?l500Go0`05o`<02?l500Go0P05o`801Ol500?o0P04o`<0
1?l300go0`09o`@01Ol200Go1009oaD02?l300Oo2P09o`L01?l800Wo1009oa@0000C00;o3`02o``0
0ol<00;o5P02o`D00_l400Co1@02o`@00ol500?o0`04o`D00_l300?o1003o`L00_l600;o0`02o`@0
1?l800;o2`04o`T00_l500;o1@02o`l00_l900;o1`02o`L00_l900?o1003o`D00_l500?o1002o`D0
0_l700;o1P02o`800ol500?o1003o`@00ol400?o1@03oa@00_l400;o1@02o``00ol500?o1P04o`L0
0ol500?o0`03o`@00olC00004`02o`l00_l=00?o2`02oaH00_l500;o1002o`L00_l400;o1`02o`<0
0_l700;o0`02o`H00_l700;o1P02o`<00_l400Co2002o`/01?l900;o1@02o`D00_l?00;o2@02o`L0
0_l700;o2P03o`800ol600;o1@02o`D00_l500;o1`02o`H00_l200;o1`02o`D00ol200?o1@02o`L0
0_lC00;o1P02o`@00_l<00;o1`02o`H01?l700;o1`02o`<00_l600;o4`0001<00_l900[o3002o`/0
0_lF00;o1@02o`<00ol700;o1002o`L00_l200?o1`02o`<00_l600;o1`02o`H00_l300;o0`05o`P0
0_l:00;o0P02o`P00_l500;o1@02o`l00_l900;o0`02o`800_l700;o2`02o`800_l700;o1002o`H0
0_l500;o1`02o`H00_l0103oool?00;o0P02o`D00olL00;o1P02o`@00_l200;o1`03o`h00_l200;o
1@03o``00_l600;o4`0001<00_l900[o2004o`030?oo00X00_lF00;o1@02o`<00_l400Oo2`03o`80
0_l400Oo0P02o`H00_l700;o1P02o`<00_l300;o00<0ool02002o`X00_l200;o2002o`D00_l500Oo
2P02o`T00_l200?o0P02o`L00_l<00Co2003o`800ol600;o1@02o`L00_l600;o00<0ool04@04o`H0
0_lM00;o1P02o`@00_l200;o1`02o`l00_l200;o1@02o`d00_l600;o4`0001<00_l900;o1002o`P0
2Ol:00;o5P02o`D00_l300;o1007o`H01ol300;o1007o`X00_l700;o2`02o`800ol00`3oo`0800;o
2@03o`800ol700;o1@02o`D02Ol800?o2002o`8000?o0?l00P02o`L00_l<00Co2007o`L00_l500;o
1`02o`T00_lA00Co1P02oad00_l600;o1006o`L00_l>00?o0P03o`@00_lE00;o4`0001<00_l:00;o
0`02o`P00_l400?o2P02oaH02Ol300;o3`07o`D00_lE00;o1`02o`/00_l200;o0P02o`P00_l900;o
1002o`L02Ol500;o1@03o`H01?l800;o00@0ool00_l00`3oo`0700;o3003o`T01Ol900Wo1`02o`T0
0_lA00?o1`02oad00_l600;o1006o`L00_l>00;o1002o`@00_lE00;o4`0001@00_l:0004o`0000;o
1`02o`H00_l900;o5`09o`<00_l>00?o2P02oaD00_l700;o2`02o`030?oo00<00_l300;o0`02o`<0
0_l400;o1002o`L02Ol500;o1P02o`D01_l700;o00<0ool00P001?l0ool200;o0`02o`<00_l700Co
2002o`040?ooo`P02Ol700;o2@02oa401?l600;o7@02o`H00_l400;o0P02o`L00_l>00;o1002o`@0
0_lE00;o4`0001@00_l:00;o0P02o`L00_l600;o2@02oaL00_l500;o0`02o`P00_l400;o1`001?l0
0002o`P00_l;00;o1`02o`/01Ol300;o0`02o`<00_l300;o0`02o`H00_l600;o1@02o`D00_l600;o
1@02o`800_l700;o00<0o`000P001?l0ool200;o0`02o`<00_l600Ko1`02o`800ol700;o1@02o`L0
0_l900?o1`02o`H01_l500?o1`02oa<00_l600;o1002o`800_l200;o0`03o`L00_l300;o1P02o`<0
0ol700;o2`02oa<0000D00?o2P000ol00002o`L00_l600;o2@02oaL00_l500;o1002o`H00ol400;o
1P02o`@00_l600?o2`02o`L00_l;00Co1002o`<00_l300;o0`02o`<00_l600;o1P02o`D00_l500;o
1P02o`@00ol300;o1P04o`<01?l200;o0`02o`<00_l500?o0P03o`H00_l300?o1P02o`D00_l700;o
2P02o`L00_l500?o0P03o`D00_l700;o4`02o`H00_l400;o1P02o`@00_l700;o0`02o`H00_l400;o
1`02o`/00_lC00005@02o`/000Co0?oo1`02o`H000?o00001`02oaP00_l500;o1003o`@01?l400?o
1003o`@00ol400Co2`02o`L00_l;00Co1002o`<00_l300;o0`02o`800ol600?o1@02o`D00_l500;o
1@03o`@00_l400;o1P04o`@00ol200;o0`02o`<00_l500;o1002o`H00_l400?o1@02o`D00_l700;o
2P03o`D00ol500;o1002o`D00ol500?o4`02o`H00_l400;o1P02o`@00ol500?o0P03o`H00ol300?o
1@03o`/00_lC00005P02o`X01?l800;o1002o`P00_lH00Co0`04o`@02_l500Wo1@0:o`H02_l00`3o
o`06o`L01?l200Ko0P0<o`030?oo00Co0P06o`<01?l300Co0P0;o`<01Ol200Go0`04o`D01?l00`3o
o`0:o`<01Ol200Go0P05o`<01Ol200Co0`04o`<02?l800[o0`05o`801Ol400[o4P04o`@01?l00`3o
o`0:o`D02_l00`3oo`04o`801_l300[o1P0:oa00000G0003o`0000T00ol800Oo2@000ol0000G00Co
0`04o`H01Ol00`3oo`0700Go00<0o`001P05o`030?oo00H02_l00`3oo`06o`L00ol300Ko0P0<o`03
0?oo00Co0P06o`<01?l300Co0P09o`D01Ol200Go0`04o`D01?l00`3oo`0:o`<01Ol200Go0P05o`<0
1Ol200Co0`04o`<02?l:00Go00<0ool00`05o`801Ol600Go00<0ool04P04o`@01?l00`3oo`0:o`L0
1Ol0103oo`06o`801_l500Go00<0ool01P0:oa00000S00?o2P04ool0aP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(50\\) HGSGJLNWZHSYNTVKHLC CVUGCVCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lF00Co0`04o`H01_l600;o00<0ool0
0ol900Ko1`06o`H03Ol200Ko0`02o`D00_l400;o1@0:o`D01?l300Co0`02o`030?oo00?o1`08o`H0
1_l300;o1008o`X00_l700Go1P02o`801?l300Co0`0=o`D01OlH00Go2P02o`d01?l900Ko2@05o`X0
0_l;00Go1P05o`H00_l@00004`02o`T02Ol800Ko3002oaD01?l300Co100:o`@02_l500[o0`09o`D0
3Ol200Ko0P03o`D00_l400;o1@0:o`D01?l300Co0`0:o`D02?l600Ko0P03o`@02?l900Co1P05o`D0
0ol200Co0`04o`<03Ol300Wo5009o`L01?l:00So1@0:o`D02Ol700Co2009o`@01Ol500?o400001<0
0_l900;o1@02o`L00ol200?o2`02oaH00_l500;o1004o`D00_l400?o1@03o`<01?l500;o0`03o`@0
0ol700;o1P02o`<00_l400Co1003o`@00ol500;o1@02o`H00_l500;o1003o`D00ol700;o2P02o`@0
1?l700;o3004o`P00_l500?o1002o`D00_l700;o1P02o`800ol500?o4P03o`D00ol600Co2P02o`@0
0_l400Co1@02o`@00ol500?o1P04o`L00ol500?o1@02o`D00olA00004`02oa400_l600;o1002o`/0
0_lF00;o1@02o`@00_l700;o1002o`L00_l300;o1`02o`<00_l600;o1`02o`H00_l300;o1004o`@0
1?l300?o1@03o`@00_l600;o1@02o`@00_l700;o1`02o`X00_l400Co1`02o``01?l800;o1@02o`D0
0_l500;o1`02o`H00_l200;o1`02oa800_l700;o1P04o`T00_l600;o0`02o`L00_l400;o1`02o`H0
1?l700;o1`02o`D00_l500;o4P0001<00_lA00;o1@02o`H00_l:00;o5P02o`D00_l300?o1`02o`@0
0_l700;o0P03o`L00_l300;o1P02o`L00_l600;o0`02o`<01Ol400Co0P04o`H00ol300;o1P02o`D0
0_l400;o1`02o`L00_l:00;o0`05o`L00_l;00;o0P02o`L00_l400;o1P02o`D00_l700;o1P02o`04
0?oooaX00ol>00;o0P02o`P00_l600;o0P03o`L00_l300?o3P02o`800_l500?o3P02o`@00_lC0000
4`02oa400_l500;o1P02o`X00_lF00;o1@02o`<00_l400Oo2`03o`800_l400Oo0P02o`H00_l700;o
1P02o`<00_l300;o00<0ool01002o`040?l000Co1`02o`<00_l600;o1@02o``00ol700;o2P02o`<0
0_l00`3oo`0700;o2`02o`800_l700?o0P03o`H00_l500;o1`02o`H00_l00`3oo`0K00;o3`02o`80
0_l800;o1P02o`800_l400Oo0P02o`l00_l200;o1@02o`l00ol200?o4`0001<00_lA00;o1@02o`H0
0_l:00;o5P02o`D00_l300;o1007o`H01ol300;o1007o`X00_l700;o2`02o`800ol00`3oo`0400;o
00H0o`00o`02o`L00ol:00;o1@02o`L01ol800?o2@02o`800ol00`3oo`0700;o2P03o`800ol600Oo
1`02o`D00_l700;o2@02oa/00_l>00?o0P03o`L00_l600;o0P02o`@01ol200;o3P03o`800ol400;o
3`07oa@0000C00;o2P02o`@00_l600;o1P02o`X00_lF00Wo0`02o`l01ol500;o5@02o`L00_l;00;o
0P02o`800_l400;o00<0ool00_l00`3oo`0800?o2@09o`D01ol900Co2@02o`800_l200;o1`02o`X0
0_l400;o1P05o`T02Ol700;o2@02oa/00_l>00;o1002o`L00_l600;o0P02o`d00_l>00;o1002o`@0
0_l?00Go5P0001@00_l900So1P02o`H00_l900;o5`09o`<00_l>00?o2P02oaD00_l700;o2`02o`03
0?oo00<00_l400;o00<0ool00_l00`3oo`0400;o0`02o`T02Ol400?o3@06o`P00_l00`3oo`0300;o
0P02o`<00_l300;o1@02o`@00_l600;o00@0oooo2009o`L00_l900;o6`02o`h00_l400;o1`02o`H0
0_l200;o3@02o`h00_l400;o1002o`l00_l0103ooolE00005002o`T01ol700;o1P02o`T00_lG00;o
1@02o`<00_l800;o1002o`L000Co00000_l800;o2`02o`L00_l;00Go0`02o`<00_l300;o0`02o`<0
0_l300?o2002o`D00_l400;o1`000ol0000400;o0P02o`P01Ol300;o0P02o`<00_l300;o1002o`H0
0_l500;o0P03o`L00_l500;o1`02o`T00ol700;o4@03o`L00_l300;o1P02o`H00_l600;o0P02o`P0
0_l300?o1`02o`<00_l600;o0`03o`L00_l500;o0P03oa@0000D00?o2002o``00_l600;o2@02oaL0
0_l500;o1002o`H00ol400;o1P02o`@00_l600?o2`02o`L00_l;00Co1002o`<00_l300;o0`02o`<0
0_l400?o1`02o`D00_l400;o1P02o`D00ol300;o1`04o`@00_l200;o0`02o`<00_l400;o1P02o`D0
0_l300?o1P02o`D00_l700;o2P02o`L00_lB00;o1`02o`<00_l600;o1P02o`H00_l300;o1P03o`@0
0_l700;o0`02o`H00_l400;o1`02o`D00_l300?o4`0001D00_l800;o3@02o`@00_l900;o6002o`D0
0_l400?o1004o`@00ol400?o1003o`@01?l;00;o1`02o`/01?l400;o0`02o`P00_l300;o1@02o`L0
0_l500;o1003o`@00ol500;o1002o`L01?l400;o0P02o`<00_l300;o0`03o`H00ol400;o1003o`D0
0_l500;o1`02o`X00ol500?o4P03o`D00ol200?o1P03o`D00_l600;o0`03o`@01?l400?o1@03o`80
0ol600?o0`03o`D00ol500;o1003oa80000F00;o1`02o`d00ol200?o2002oaP01?l300Co100:o`D0
2Ol500[o1P0:o`030?oo00Ko1`04o`801_l00`3oo`04o`801_l200[o1@04o`<01?l400Wo0`05o`80
1Ol400Co0P06o`030?oo00[o0P06o`801_l00`3oo`03o`<01Ol200Co0`04o`<02?l800[o4`0:o`03
0?oo00Co0P06o`<01?l400Co0`0:o`D02_l00`3oo`04o`801_l300[o0`05o`<01Ol@00005`000ol0
000500So2006o`T000?o00005`04o`<01?l600Go00<0ool01`05o`030?l000H01Ol00`3oo`0600[o
00<0ool01_l700?o0`06o`030?oo00Co0P06o`802_l500Co0`04o`H01Ol00`3o000200Go0P05o`@0
0ol300Ko00<0ool02_l200Ko0P06o`030?oo00?o0`05o`801?l300Co0`08o`X01Ol00`3oo`0E00Go
00@0ool01_l200Ko0`04o`@01?l500Go00<0ool01`05o`040?oo00Ko0P06o`D01Ol00`3oo`0300Go
0`05oa00000O00So2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(51\\) MGSFJLNXZMQZIQVKLLF CVUGCQCO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00onT00;o1003obh0
000E00;o:002ojT02_lQ00[oX`0:obd0000D00;o:P02ojT01Ol200;o8P05o`800_nT00Go0P02obd0
000D00;o:P02ojT000?o0000:0000ol0002Z0003o`0003<0000D00;o2P05o`T02Ol900;o5@05o`<0
1Ol500Ko1P02o`030?oo00?o1@07o`X01_l600go0P06o`<00_l300Go0P05o`<02_l400Go0`05o`D0
1Ol600[o1@0:o`L01Ol;00;o1`05o`H00_l00`3oo`0;o`803Ol00`3oo`05oaX01Ol:00;o3@04o`T0
1_l900Go2@05o`T01Ol:00Go500001<00_l900Wo1`09o`X00_lD00Go0`05o`<02_l400[o0`07o`P0
2Ol500go0P06o`800ol300Go0P05o`<02_l400Go0`05o`<02Ol400[o1@0:o`D02Ol800Co1P05o`D0
0ol00`3oo`0;o`803Ol00`3oo`05oaP02Ol700Co2P08o`D02_l500Wo1@09o`D02Ol600Wo4P0001<0
0_l900;o1@02o`/00_l=00;o5@02o`L00_l300Co1@02o`@00ol500?o1002o`/00ol400?o1`02o`H0
0_l300;o1004o`@00ol400?o1@02o`D00_l500;o1`02o`<00ol500?o1002o`D00_l900;o2003o`D0
0ol700Co2002o`D00ol500;o1P02o`D00_l600;o0`02oaX00ol500?o1P04o`X00_l400;o1004o`D0
0_l400?o1@03o`<00ol500?o0`03o`D00ol400?o1@03oa40000C00;o4@02o`X00_l=00;o5@02o`L0
0_l300;o1`02o`@00_l700;o1002o`/00_l600;o1`02o`H00_l300;o1004o`D00ol200?o1P03o`@0
0_l500;o1`02o`<00_l700;o1003o`@00_l900;o2002o`L00_l700Co2002o`D00_l600;o1P02o`D0
0_l600;o0`02oaX00_l700;o1P04o`T00_l600;o0`02o`L00_l400;o1`02o`<00_l700;o0`02o`L0
0_l400;o1`02oa40000C00;o4@02o`X00_l=00;o5@02o`<00_l200;o0P03o`L00_l400;o1`02o`@0
0_l200;o1`02o`H00_l700;o1P02o`<00_l300Go1P02o`800_l800?o0`02o`D00_l300;o0P02o`80
0_l900;o1003o`<00_l900;o1`02o`T00_l500;o0P02o`L00_l400;o1`02o`H00_l500;o1P02o`<0
0_l200;o5@03o`h00_l200;o2002o`H00_l200?o1`02o`<00ol;00;o2@02o`040?ooo``00_l900;o
400001<00_lA00;o2P02o`d00_lE00;o0P03o`800_l200;o1007o`/00ol400;o0P02o`L00_l600;o
1`02o`H00_l300;o0`02o`030?oo00L01?l:00;o0`02o`D00_l200?o0P02o`800_l900;o1@02o`<0
0_l900;o1`02o`T00_l500;o0P02o`L00ol200?o1`02o`H00_l500;o1P02o`<00_l200;o5@02o`l0
0_l200;o2002o`H00_l200;o1007o`800_l<00;o2@02o`030?oo00d00_l900;o400001<00_lA00;o
2P02o`d00_lE00;o0P000ol0o`0200;o0P02o`@01ol600Oo1@06o`l00_l700;o2`02o`800ol00`3o
o`0700Co2P03o`T00_l20003o`3o00800_l200;o2@02o`D00ol=00;o1`02o`T00_l400?o0P03o`H0
1ol800;o3@02o`/01_lE00;o3P03o`800ol700;o1P02o`800_l400Oo0P02o``00_l900;o00<0ool0
3@02o`T00_l@00004`02o`X00_l400;o2`02o`d00_lE00;o00@0ool00_l00`3oo`0200;o3`07o`L0
1_l?00;o1`02o`/00_l200;o0P02o`L00ol<00?o2002o`040?oo00;o00<0ool00P02o`T00_l600?o
3002o`L00_l900;o1002o`@00_l600Go2P02o`d00_l;00Ko5@02o`h00_l400;o1`02o`H00_l200;o
3@02o``00_l900;o00<0ool03@02o`T00_l@00005002o`T02?l;00;o3002oaH00_l00`3oo`020004
o`3oo`800_l>00?o3002o`800_l?00;o1`02o`/00_l00`3oo`0300;o1`04o`L00_l300;o2002o`03
0?oo008000Co0?oo0P02o`T00_l200;o0`02o``00_l700;o2@02o`@00_l400;o1P02o`040?ooo`T0
0_l=00;o2`02o`800_lE00;o3P02o`@00_l700;o1P02o`800_l=00;o3002o`T00_l00`3oo`0=00;o
2@02oa00000D00;o2@07o``00_l<00;o5P02o`030?l0008000Co0?oo0P02o`P00_l400;o1`000ol0
000300;o0P02o`800_l;00;o1`02o`/01Ol300;o1P06o`H00_l300?o1`02o`030?l0008000Co0?oo
0P03o`P00_l200;o0`03o`/00_l700?o2002o`<00_l600;o1@02o`800ol800;o3@02o`/00_l200;o
0P02oa400ol700;o0`02o`H00_l600;o1P02o`800_l800;o0`03o`L00_l200?o2002o`040?ooo`L0
0_l300;o2@02oa00000D00?o2002oa400_l<00;o5P04o`<01?l300;o1P03o`@00_l600;o1@02o`H0
0_l;00;o1`02o`/01?l400;o1@03o`800ol500;o1003o`H01?l300Co0`02o`L00_l300;o1003o`X0
0_l800;o1`02o`@00_l600;o1@02o`<00ol700;o3@02o`/00_l600;o4P02o`L00_l300;o1P02o`H0
0_l600;o0`02o`H00ol400;o1`02o`<00_l700;o0`02o`L00_l400;o1`02oa40000E00;o2002oa40
0_l;00;o5`04o`@00ol300?o1004o`@00ol400?o1@02o`H00_l;00;o1`02o`/01?l400;o1@02o`@0
0_l500;o1@02o`H01?l400?o1002o`D00_l400;o1@02o`X00_l900;o1@02o`@00ol600?o1002o`@0
0ol600;o3@02o`/00_l600;o4P03o`D00ol200?o1P03o`D00_l600;o0`03o`@01?l400?o1@03o`@0
0_l500;o1003o`D00ol400?o1@03oa40000F00;o1`02o`d00ol00`3oo`0:00;o5`04o`D01?l300[o
1@09o`<03?l600[o00<0ool01_l700Co0P06o`801Ol200Go0`0:o`@01?l500Co0`09o`@02_l500[o
1@09o`<01_l200Ko00<0ool00ol300Go00<0ool01_l700So1P0<oa<02_l00`3oo`04o`801_l300Co
1004o`<02_l500[o1009o`D02_l500Wo4P0001L000?o00001@08o`L01_l:0003o`0001H01?l500Co
1@05o`030?oo00L01Ol00`3o000200co1P0:o`030?oo00Ko1`03o`<01_l200Go0P05o`<02_l400Co
1@04o`D01Ol600[o1@0:o`L01Ol500Ko0P06o`030?oo00?o0`05o`030?oo00Ko1`08o`H03?lE00Go
00@0ool01_l200Ko0`04o`@01?l500Go00<0ool01`05o`030?oo00H01Ol900Go00<0ool01`05oa@0
000O00So2P03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(52\\) MGUFJLNXZMQ LQVKMLF AXUGCQDN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00onT00;o1003obh0
000E00;o:002ojT02_lQ00[oX`0:obd0000D00;o:P02ojT01Ol200;o8P05o`800_nT00Go0P02obd0
000D00;o:P02ojT000?o0000:0000ol0002Z0003o`0003<0000D00;o2P05o`P02_l900;o5@05o`<0
1Ol500Ko2P04o`D01ol:00Ko1P0=o`801_l300;o0`05o`801Ol300[o1005o`<01Ol500Go500=o`D0
1Ol;00;o1`05o`H00_l00`3oo`03o`<01Ol200go00<0ool01OlE00Ko0`0;o`801Ol800Co2@06o`T0
1Ol900Go1P08o`L01_l300;o4@0001<00_l900Wo1P0:o`X00_lD00Go0`05o`<02_l600So0`07o`P0
2Ol500go0P06o`800ol300Go0P05o`<02_l400Go0`05o`<02OlB00go0`09o`P01?l600Go1@03o`03
0?oo00?o0`05o`803Ol00`3oo`05oaD01_l300_o0P05o`H02?l500[o1@09o`D02Ol400[o1@06o`80
0olA00004`02o`T00_l500;o1`02o`D00_l:00;o5@02o`L00_l300Co1@02o`H00_l400;o1@02o`/0
0ol400?o1`02o`H00_l300;o1004o`@00ol400?o1@02o`D00_l500;o1`02o`<00ol500?o5002o`H0
0_l200?o1@03o`L01?l800;o1@03o`<00_l700;o1P02o`H00_l300;o6P02o`L00_l300?o1003o`L0
0_l400;o1004o`D00_l400?o1@03o`<00ol500?o1002o`@01?l500;o1004oa40000C00;o4@02o`L0
0ol?00;o5@02o`L00_l300;o1`02o`D00_l600;o1002o`/00_l600;o1`02o`H00_l300;o1004o`D0
0ol200?o1P03o`@00_l500;o1`02o`<00_l700;o5002o`H00_l200;o1`02o`L01?l800;o1@02o`@0
0_l700;o1P02o`H00_l300;o6P02o`L00_l400?o0P03o`L00_l600;o0`02o`L00_l400;o1`02o`<0
0_l700;o1002o`H00_l500;o1004oa40000C00;o4@02o`P00ol>00;o5@02o`<00_l200;o0P03o`L0
0_l500;o1P02o`@00_l200;o1`02o`H00_l700;o1P02o`<00_l300Go1P02o`800_l800?o0`02o`D0
0_l300;o0P02o`800_l900;o4`02o`H00_l00`3oo`0900;o1@02o`800_l700;o1002o`D00_l300;o
0P02o`H00_l600;o0`02o`800_lF00_o1@02o`800_l800;o1P02o`800ol700;o0`03o`/00_l900;o
0`02o`L00_l400;o0`05oa40000C00;o4@02o`T00ol=00;o5@02o`800ol200;o0P02o`@01ol400;o
1P02o`@00_l200;o1`02o`H00_l700;o1P02o`<00_l300;o00<0ool01`04o`X00_l300;o1@02o`80
0ol200;o0P02o`T00_lC00;o1P02o`030?oo00T00_l500;o0P02o`L00ol200?o1@02o`800ol200;o
1P02o`H00_l300;o0P02oaL02Ol700Co2@02o`H00_l200;o1007o`800_l<00;o2@02o`<00_l700;o
1002o`<00_l00`3oo`0A00004`02oa400_l:00?o3002oaD00_l20003o`3o00800_l200;o1007o`@0
0_l600;o1006o`l00_l700;o2`02o`800ol00`3oo`0700Co2P03o`T00_l20003o`3o00800_l200;o
2@02oa<00_l900;o2@02o`@00ol200?o1P07o`H00_l20003o`3o00800_l600;o2`06oaL00_l500;o
1`04o`T00_l600;o0P02o`@01ol200;o3002o`T00_l300;o1`02o`@00_l200?o00<0ool04@0001<0
0_l:00;o1002o``00ol;00;o5@02o`040?oo00;o00<0ool00P02o`l00_l600;o1006o`l00_l700;o
2`02o`800_l200;o1`03o``00ol800;o00@0ool00_l00`3oo`0200;o2@02oa<00_l900;o2@02o`@0
0_l400;o1P05o`P00_l0103oo`02o`030?oo00H00_l;00Ko6002o`<00_l800?o2P02o`H00_l200;o
3@02o``00_l900;o0`02o`L00_l400;o0P02o`800_lA00005002o`T02?l=00;o2P02oaH00_l00`3o
o`020004o`3oo`800_l?00;o1P02o`@00_l200;o3`02o`L00_l;00;o00<0ool00`02o`L01?l700;o
0`02o`P00_l00`3oo`020004o`3oo`800_l900;o4`02o`T00_l900;o1002o`@00_l600;o00@0oooo
1`02o`030?oo008000Co0?oo1P02o`/00_l200;o6002o`<00_l800Co2@02o`H00_l200;o3@02o``0
0_l900;o0`02o`L00_l400;o00<0ool00`02oa40000D00;o2@07o`l00_l900;o5P02o`030?l00080
00Co0?oo0P02o`P00_l500;o1P02o`@00_l200;o0P02o`/00_l700;o2`05o`<00_l600Ko1P02o`<0
0ol700;o00<0o`000P001?l0ool200?o2002oa<00_l900?o2002o`<00_l600;o1@02o`800ol600;o
00<0o`000P001?l0ool600;o2`02o`800_l200;o5@02o`040?ooo`L01_l800;o1P02o`800_l800;o
0`03o`L00_l200?o2002o`<00_l700;o1005o`<00_lA00005003o`P00_lD00;o2@02oaH01?l300Co
0`02o`H00ol500;o1P02o`@00_l600;o2`02o`L00_l;00Co1002o`D00ol200?o1@02o`@00ol600Co
0`04o`<00_l700;o5002o`X00_l700;o1002o`H00_l500;o0`03o`D01?l300Co1P02o`/00_l600;o
5@02o`030?oo00L00ol200?o1`02o`H00_l300;o1P03o`@00_l700;o0`02o`L00_l400;o1P02o`D0
1?l400;o4@0001D00_l800;o3@02o`D00_l800;o5`04o`@00ol300?o1004o`D00_l600;o1002o`H0
0_l;00;o1`02o`/01?l400;o1@02o`@00_l500;o1@02o`H01?l400?o1002o`D00_lE00;o2`02o`D0
0_l400?o1P03o`@00_l400?o1004o`@00ol600;o2`02o`H00_lE00Go1`02o`@00_l700;o1P02o`<0
0ol400Co1003o`D00ol400;o1@02o`D00_l400Co1@04o`@00_lA00005P02o`L00_l=00?o0`03o`L0
0_lG00Co1@04o`<02_l400Co1004o`030?oo00[o1P0:o`030?oo00Ko1`04o`801_l200Go0P05o`<0
2_l400Co1@04o`<02OlB00So2009o`<01_l200Ko00<0ool00ol300Go00<0ool00_l500Co0P08o`H0
3?lB00Oo1P05o`801Ol400Co1004o`<02_l500[o1009o`@02_l500Co0P06oa00000G0003o`0000D0
2?l800Oo20000ol0000F00Co1@04o`D01Ol00`3oo`0400Co1004o`030?oo00[o1P0:o`030?oo00Ko
1`03o`<01_l200Go0P05o`<02_l400Co1@04o`D01OlD00So2P05o`D01_l200Ko00<0ool00ol300Go
00<0ool00_l500Co0P08o`H03?lB00Oo1P05o`801Ol400Co1004o`D01Ol00`3oo`0700Go00<0ool0
1P05o`H02?l700?o0`06oa00000O00So2@05ool0a@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(53\\) NGUFJONSYMQ LQVMMLF A UEGQAN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?o8P02o`@00onT00;o1003obh0
000E00;o:002ojT02_lQ00[oX`0:obd0000D00;o:P02ojT01Ol200;o8P05o`800_nT00Go0P02obd0
000D00;o:P02ojT000?o0000:0000ol0002Z0003o`0003<0000D00;o2P05o`X01Ol<00;o5P06o`<0
0_l600Ko2P04o`D01ol:00Ko2P05o`H01_l300;o1002o`030?oo00?o1`08o`D01Ol300Go1@05oa@0
3Ol500Go2`02o`L01Ol300Go00<0ool00ol300Go0P0=o`030?oo00Go5@06o`<01_lD00Co1@0<o`L0
1_l800Go1006o`<01_l200Ko0`02oa40000C00;o2@09o`H02Ol;00;o5@06o`800ol400[o1P08o`<0
1ol800Wo1`09o`@01_l200?o100:o`D02?l500Go0`05o`<02OlB00go0`09o`P01?l600Go0`05o`03
0?oo00?o0`05o`803Ol00`3oo`05oaD01_l300Ko4P08o`<03?l500[o1009o`801_l300Ko0P06o`80
0olA00004`02o`T00_l500;o1P02o`D00_l;00;o5P02o`@01?l300Co1@02o`H00_l400;o1@02o`/0
0ol400?o1@03o`D00ol400;o1004o`@00ol500?o1`02o`T00_l700;o0`03o`D00olD00;o1P02o`80
0ol500?o1`04o`L00_l700;o0`02o`L00_l600;o1P02o`<00_lJ00;o1`02oa@00_l400;o1@02o`H0
0_l400Co1@02o`<00ol500?o0`02o`L00_l500;o1004oa40000C00;o4@02o`d00_l:00;o5P02o`@0
1?l300;o1`02o`D00_l600;o1002o`/00_l600;o1@02o`L00_l400;o1004o`@00_l700;o1`02o`T0
0_l700;o0`02o`L00_lD00;o1P02o`800_l700;o1`04o`L00_l700;o0`02o`L00_l600;o1P02o`<0
0_lJ00;o1`02oa<00_l600;o1002o`H00_l400;o1`02o`<00_l700;o0`02o`L00_l500;o1004oa40
000C00;o4@02o`d00_l:00;o5P02o`<01Ol200?o1`02o`D00_l600;o1002o`800_l700;o1P02o`@0
0_l900;o0`02o`<01Ol400;o1`02o`L00_l900;o0`02o`800_l200;o2@02oa<00_l600;o00<0ool0
2@02o`D00_l200;o1P02o`<00_l200;o0`02o`<00_l200;o1P02o`H00_l300;o0P02oaH02olC00;o
1P02o`@00_l200;o0P02o`<00ol700;o0P02o`T00_l200_o1@02o`<01OlA00004`02oa400_l=00;o
2P02oaH00_l300;o00<0ool00P02o`@01ol400;o1P02o`@00_l200;o1`02o`H00_l400;o2@02o`<0
0_l300;o00<0ool03003o`L00_l900;o0P03o`800_l200;o2@02oa<00_l600;o00<0ool02@02o`D0
0_l200;o1P02o`800ol200;o0`02o`800ol200;o1P02o`H00_l300;o0P02oaL02OlD00;o1P02o`@0
0_l200;o1`02o`@01ol00`3oo`0900;o0`09o`H00_l300;o00<0ool04@0001<00_lA00;o3002o`/0
0_lF00;o0P03o`030?oo00800_l400Oo1002o`H00_l400Ko3`02o`@00_l900;o0`02o`800ol00`3o
o`0700Oo2003o`P00_l20003o`3o00800_l200;o2@02oa<00_l900;o2@02o`@00ol200?o1@02o`80
00?o0?l00P02o`<00_l20003o`3o00800_l600;o2`06oaL00_l500;o5002o`H00_l400Ko1`02o`@0
1ol00`3oo`0900;o0`02o`D00_l600;o0P03o`030?oo0140000C00;o2P02o`@00_l:00Co3002oaH0
0_l200;o0P02o`800_l?00;o1P02o`@01_l?00;o1002o`T00_l300;o0P02o`800_l500Oo2@04o`P0
0_l0103oo`02o`030?oo00800_l900;o4`02o`T00_l900;o1002o`@00_l500;o00@0ool00_l00`3o
o`0300;o00@0ool00_l00`3oo`0600;o2`06oaP00_l300;o5@02o`H00_l400Ko1`02o``00_l900;o
1002o`<00_l700;o0P02o`800_lA00005002o`T02?l:00?o3002oaL00_l00`3oo`0300;o0P02o`l0
0_l600;o1002o`800_l?00;o1002o`T00_l300;o00<0ool00`02o`@00ol=00Ko1`02o`030?oo0080
00Co0?oo0P02o`T00_lC00;o2@02o`T00_l400;o1002o`D00_l00`3oo`020004o`3oo`<00_l00`3o
o`020004o`3oo`H00_l;00;o0P02oaP00_l300;o5@02o`H00_l400;o0P02o`L00_l<00;o2@02o`@0
0_l300;o1`02o`030?oo00<00_lA00005002o`T01ol=00;o2`02oaL01Ol300;o0P02o`P00_l500;o
1P02o`@00_l200;o0P02o`/00_l400;o2@02o`<01Ol300;o1002o`L000?o00001002o`800_l700;o
00<0o`000P001?l0ool200?o2002oa<00_l900?o2002o`<00_l600;o1002o`030?l0008000Co0?oo
0`02o`030?l0008000Co0?oo1P02o`/00_l200;o0P02oaD00_l0103ooolE00;o1P02o`@00_l200;o
0P02o`<00_l800;o0P03o`P00_l500;o00@0oooo1`05o`<00_lA00005003o`P00_lC00;o2P02oaL0
1?l400;o0`02o`H00ol500;o1P02o`@00_l600;o2`02o`D00_l700;o1004o`@00_l400;o1P02o`D0
0ol300;o1P04o`<01?l300;o1`02oa@00_l:00;o1`02o`@00_l600;o1004o`<01?l300Co0`04o`H0
0_l;00;o1P02oaD00_l00`3oo`0F00;o1P02o`@00_l600;o1002o`H00ol300;o1`02o`H00_l00`3o
o`0800Co1002oa40000E00;o2002oa<00_l900;o6004o`@00_l300?o1004o`D00_l600;o1002o`H0
0_l;00;o1@03o`D00ol400Co1002o`@00ol400?o1@02o`@00_l600Co1003o`@00_l500;o5@02o`/0
0_l500;o1003o`H00ol300Co1003o`<01?l400?o1P02o`/00_l600;o5@05oaH00_l600;o1002o`H0
0_l400?o1004o`@00_l500;o1`05o`P01?l400;o4@0001H00_l700;o3@02o`<00ol800;o6004o`80
1_l300[o1004o`@01?l00`3oo`0:o`H02_l300Wo1004o`801_l400Wo0`05o`801Ol300Co1@04o`<0
2OlB00So2009o`<01_l200Ko00<0ool00_l500Co00<0ool00_l500Co0P08o`H03?lB00Oo5P04o`@0
1?l00`3oo`0:o`D02_l400Wo1007o`P01?l200Ko400001L000?o00001@08o`L01ol90003o`0001L0
0ol300Ko1@05o`030?oo00@01?l400Co00<0ool02_l600[o1@05o`H00ol300Ko1P05o`030?l00080
1Ol200Go0`04o`D01?l500Go5008o`X01Ol500Ko0P06o`030?oo00;o1@04o`030?oo00;o1@04o`80
2?l600co4P07oaH01?l400Co00<0ool02_l700Go00<0ool01P05o`H01ol800?o0`06oa00000O00So
2@04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(54\\) NGUFJLNSYJO JV MMLE A WHFNAN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go3006o`T00_lF00Ko0`02o`H01_l:00Co1@07o`X0
1_l600go0P06o`<00_l400;o00<0ool00ol700So1`06o`X01OlF00Ko2`02oaH01Ol300Go00<0ool0
0ol300Go0P0=o`030?oo00[o4006o`<01_lA00;o1002o`D01?l300Co0`07o`P01_l300;o00<0ool0
1?l300Ko0P06o`<00_lA00004`02o`T02Ol:00Ko2P02oaD01_l200?o100:o`H02?l300Oo2009o`D0
3Ol200Ko0P03o`@02_l500So1@09o`L02OlB00Wo2@04oaD01Ol300Go00<0ool00ol300Go0P0=o`03
0?oo00[o4006o`<01_lA00;o1002o`D01?l300Co0`07o`P01_l200?o00<0ool01?l300Ko0P06o`80
0olA00004`02o`T00_l500;o3002o``00_lF00;o1004o`<01?l500;o1P02o`@00_l500;o2`03o`@0
0ol700;o1P02o`<00_l400Co1003o`D00ol700;o2003o`@00ol500?o1@03oa400ol400?o2004oaH0
0_l700;o0`02o`L00_l600;o1P02o`<00_l600;o4P02o`L00_lB00?o1003o`D00_l500;o1P02o``0
0_l400Co0`02o`L00_l500;o1004oa40000C00;o4@02o`/00_l<00;o5P02o`@01?l300;o1`02o`D0
0_l600;o1002o`/00_l600;o1`02o`H00_l300;o1004o`@00_l700;o1`02o`P00_l600;o1@02o`L0
0_lA00;o1P02o`P01?lF00;o1`02o`<00_l700;o1P02o`H00_l300;o1P02oa800_l700;o4P04o`<0
0ol500;o1@02o`H00_l<00;o1004o`<00_l700;o1@02o`@01?lA00004`02oa400_l500[o2P02oaH0
0_l300Go0P03o`L00_l500;o1P02o`@00_l200;o1`02o`H00_l700;o1P02o`<00_l300Go1002o`L0
0_l700;o2002o`H00_l400;o2@02oa000_l600;o1`02o`800_lE00;o0`02o`800_l300;o0`02o`80
0_l600;o1P02o`<00_l200;o0P02oa802olB00Co0P04o`D00_l500;o1P02o`800_l800;o0`05o`<0
2ol500;o0`05oa40000C00;o4@02o`D02_l:00;o5P02o`<00_l00`3oo`0200;o1007o`@00_l600;o
1002o`800_l700;o1P02o`L00_l600;o0`02o`<00_l00`3oo`0<00?o1`02o`P00_l600;o1002o`T0
0_l@00;o1P02o`L00_l200;o5@02o`800ol200;o0`02o`800ol200;o1P02o`H00_l300;o0P02oaL0
2OlC00;o00@0o`001?l500;o1@02o`H00_l200;o2002o`<00_l00`3oo`0400Wo1P02o`<00_l00`3o
o`0A00004`02oa400_l500;o1002o``00_lF00;o0P03o`030?oo00800_l400Oo1002o`H00_l400Ko
3`02o`L00_l;00;o0P03o`030?oo00L01ol800?o3`02o`@00_l900;o6002o`H00ol200?o5002o`80
00?o0?l00P02o`<00_l20003o`3o00800_l600;o2`06oaL00_l500;o4`02o`060?l00?l00_l500;o
1@02o`H01_l800;o0P03o`030?oo00@00_l500;o1P02o`800ol00`3oo`0A00004`02o`X00_l400;o
1`02o`<00_l<00;o5P02o`800_l200;o0P02o`l00_l600;o1006o`l00_l700;o2`02o`800_l200;o
1@07o`T01?l?00;o1002o`T00_lH00;o1P02o`@00_lD00;o00@0ool00_l00`3oo`0300;o00@0ool0
0_l00`3oo`0600;o2`06oaP00_l300;o5002o`030?oo00;o00<0ool01@09o`H01_l800;o0P02o`80
0_l500;o0`02o`L00_l200;o0P02oa40000D00;o2@08o`P000Co00000_l;00;o5`02o`030?oo00<0
0_l200;o3`02o`H00_l400;o0P02o`l00_l700;o2`02o`030?oo00<00_l400?o3@06o`h00_l400;o
2@02oaP00_l600;o1002oa@00_l00`3oo`020004o`3oo`<00_l00`3oo`020004o`3oo`H00_l;00;o
0P02oaP00_l300;o5002o`030?oo00;o00<0ool01@09o`H00_l200;o2002o`030?oo00<00_l500;o
0`02o`L00_l00`3oo`0300;o4@0001@00_l900Oo2@02o`800_l;00;o5`05o`<00_l200;o2002o`D0
0_l600;o1002o`800_l200;o2`02o`L00_l;00Go0`02o`@00_l70003o`0000@00_l200;o3P02o`@0
0_l900;o6002o`D00_l600;o4`02o`030?l0008000Co0?oo0`02o`030?l0008000Co0?oo1P02o`/0
0_l200;o0P02oaD00_l0103ooolC00;o0`02o`<00_l400;o1@02o`H00_l200;o0P02o`@01Ol300;o
1P02o`040?ooo`L01Ol300;o4@0001@00ol800;o3`000ol00002o`/00_lG00Co1002o`<00_l600?o
1@02o`H00_l400;o1P02o`/00_l700;o2`04o`@00_l400;o1P02o`D00ol300;o3@02o`D00_l700;o
6@02o`D00_l600;o4`04o`<01?l300Co0`04o`H00_l;00;o1P02oaD00_l00`3oo`0D00;o0`02o`<0
0_l400;o1@02o`H00_l600;o1004o`@00_l600;o00<0ool02004o`@00_lA00005@02o`P00_l@0004
o`3oo`X00_lH00Co1002o`<00ol400Co1@02o`H00_l400;o1P02o`/00_l700;o2`04o`@00_l400?o
1003o`D00_l400;o3@02o`D00ol500?o6@02o`@00ol600?o4P04o`@00ol300Co1003o`H00_l;00;o
1P02oaD01OlD00;o2002o`@00_l500;o1P02o`H00_l400Co1002o`H01Ol800Co1002oa40000F00;o
1`02oa001?l900;o6004o`801_l300[o1004o`@01?l00`3oo`0:o`H02_l00`3oo`06o`L01?l200Ko
1009o`<01Ol200Go1P0:o`<02OlE013o0P06oa001?l500Co00<0ool00_l500Co0P08o`H03?lB00Oo
5006o`801_l200Co0`04o`<03?l300Co0P06o`801ol800Co0P06oa00000G0003o`0000D02?l;00?o
2@000ol0000G00?o0`06o`D01Ol00`3oo`0400Co1004o`030?oo00[o1P0:o`030?oo00Ko1`03o`<0
1_l600Go00<0o`000P05o`801Ol600[o1@05oaL04?l200Ko4004o`D01?l00`3oo`02o`D01?l200So
1P0<oa801olD00Ko0P06o`801?l300Co0`0<o`<00ol300Ko0P07o`P00ol300Ko400001l02?l;00?o
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(55\\) JHUJJLLSYJOZJVZMMNE A WCBNAO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2P05o``00_lG00Ko1`04o`<01?l800Co1`06o`T0
1_l600go00<0ool02ol300;o00<0ool00ol700So1`06o`X01Ol600[o1P06o`/00_l900[o0`05o`<0
1Ol00`3oo`03o`<01Ol300Ko0`02o`803?l@00Ko0`06oa400_l400;o2005o`H02_l500Ko0`02o`03
0?oo00Co0`06o`D01OlD00004`02o`T02Ol600Wo2`02oa@02Ol600Co0`04o`H02?l300Wo1P09o`D0
3Ol00`3oo`0;o`<02_l500So1@09o`L02Ol400[o1009o`T01?l800[o0`05o`<01Ol00`3oo`03o`<0
1Ol300Ko0P03o`803?l@00Ko0`06oa400_l400;o1P09o`@02ol400Ko0P03o`030?oo00Co0`06o`<0
2OlB00004`02o`T00_l500;o1P02o`D00_l;00;o5003o`@00ol600;o1@02o`L00_l400;o0`03o`@0
0ol500?o1003o`L00_l600;o1002o`H00_l300?o1@03o`L00_l800?o1003o`D00ol500?o1002o`D0
0_l400?o1003o`P01?l900;o1@02o`@00_l700;o0`02o`L00_l500;o1004o`@00_l600;o4P02o`L0
0_lB00?o1003o`@00ol500?o1@02o`D00ol400;o1004o`<00_l700;o1003o`D00olA00004`02oa40
0_l=00;o2P02oa@00_l600;o1P02o`D00_l600;o1P02o`800_l600;o1@02o`H00_l700;o1P02o`@0
0_l600;o0`02o`L00_l700;o2002o`H00_l500;o1`02o`@00ol400;o1002o`H00_l800Co2@03o`@0
0_l400;o1`02o`<00_l700;o1@02o`@01?l400;o1P02oa800_l700;o4P04o`<00ol400;o1`02o`D0
0_l600;o1002o`@01?l300;o1`02o`@00_l700;o4@0001<00_lA00;o3@02o`X00_lD00;o1P02o`H0
0_l500;o1P02o`H00_l200;o1P02o`D00_l600;o1`02o`H00_l400;o1P02o`<00_l700;o1`02o`P0
0_l600;o1002o`T00_l400?o0`02o`@00_l600;o1`02o`800_l900?o0`02o`@00_l300;o0P02o`<0
0_l300;o0P02o`D00_l300Go1002o`800_l200;o4P0;oa801?l200Co0`03o`h00_l600;o1002o`<0
1Ol300_o0`02o`T00_l@00004`02oa400_l=00;o2P02oa@00_l600;o1P02o`D00_l600;o1P02o`80
0_l600;o1@02o`H00_l700;o1P02o`@00_l600;o2`03o`L00_l800;o1P02o`@00_l900;o1@02o`<0
0_l400;o1P02o`L00_l200;o2P02o`<00_l400;o0P03o`800_l300;o0P03o`800_l500;o0`02o`03
0?oo00@00_l200;o5`09oa<00_l0103o0004o`<00_l?00;o1P02o`@00_l300;o00<0ool01009o`@0
0_l900;o400001<00_lA00;o3@02o`X00_lL00;o1P02o`D00_l600;o1P02o`X00_l=00;o1`02o``0
0_l>00Oo2003o`l00_l400;o2@02o`D00ol@00;o1P03o`800ol900?o2002o`8000?o0?l00P02o`<0
0_l20003o`3o00800_l500;o0P03o`030?oo00@01_lG00;o1@02oa<00_l01P3o003o00;o0`02o`l0
0_l500?o1002o`800ol00`3oo`0400;o1@02o`@00_l900;o400001<00_l:00;o1002o`L00_l400;o
2`02oa`00_l600Wo1P02o`H00_l:00;o3@02o`L00_l<00;o3007o`T01?l?00;o1002o`T00_l600?o
3`02o`H00_l400;o2P03o`L00_l0103oo`02o`030?oo00<00_l0103oo`02o`030?oo00D00_l200;o
0P02o`@01_lH00;o0`02oa@00_l00`3oo`02o`030?oo00<00_l?00Wo1@02o`800_l200;o1@02o`<0
0_l500;o2@02oa00000D00;o2@08o`L02?l:00;o7@02o`H02Ol600;o1P02o`X00_l=00;o1`02o``0
0_l;00?o3@06o`h00_l400;o2@02o`800_l300;o3`02o`H00_l400;o1P02o`<00_l700;o00<0ool0
0P001?l0ool300;o00<0ool00P001?l0ool500;o00<0ool00`02o`@00_l200;o6002o`<00_lD00;o
00<0ool00_l00`3oo`0300;o3`08o`H00_l00`3oo`0300;o1@02o`<00_l500;o2@02oa00000D00;o
2@07o`P01ol;00;o7@02o`H00_l500;o1P02o`H00_l:00;o3@02o`L00_l<00;o2`02o`L000?o0000
1002o`800_l>00;o1002o`T00_l200;o0`03o`h00_l500;o1P02o`D00_l300?o1P02o`030?l00080
00Co0?oo0`02o`030?l0008000Co0?oo1@05o`<00_l400;o0P02o`800_lE00;o00@0oooo4`02o`<0
0_l300;o0P03o`L00_l500;o1003o`D01Ol300;o1P02o`040?ooo`D00_l900;o400001@00ol800;o
3@02oa000_lM00;o1P02o`D00_l600;o1P02o`X00_l=00;o1`02o``00_l;00;o1P02o`D00ol300;o
3@02o`D00_l700;o0`02o`@00ol=00;o1@02o`H00_l500;o1003o`D01?l300Co0`04o`<01?l500Co
1002o`@00_l600;o5@02o`030?oo01@00_l300;o0`02o`<00_l700;o1@02o`D00_l500Co1002o`H0
0_l00`3oo`0700;o1`02oa40000E00;o2002o`d00_l?00;o7P02o`H00_l500;o1P02o`H00_l:00;o
3@02o`L00_l<00;o2`03o`@00ol500;o1002o`d00_l500?o1@03o`<00_l500;o3@02o`@00ol600?o
1002o`D00_l500Co1003o`<01?l400?o1@04o`@00_l400;o1P02oaD01OlD00;o2002o`<00ol500?o
1@02o`@00ol500Co1002o`H01Ol700?o1@03oa40000F00;o1`02o`d00_l>00;o6P0:o`801?l300Co
1004o`@01?l400[o1@0:o`030?oo00Ko1P08o`T02Ol300Go0P05o`H02_l300Wo100:o`L04?l200Ko
0`0:o`<01?l500Co00<0ool00_l500Co0`04o`801_l00`3oo`0:oa801olD00Ko0P06o`<02_l300[o
1@04o`801_l200Oo2@09oa80000G0003o`0000D02?l700So20000ol0000I00[o0P04o`<01?l400Co
1004o`@02_l500[o00<0ool01_l600So2`05o`030?l000801Ol200Go1P0:o`D01Ol600[o1`0@o`80
1_l300[o0`04o`D01?l00`3oo`02o`D01?l300?o0`06o`030?oo00[o4P07oa@01_l200Ko1@05o`03
0?oo00<02Ol600?o0`06o`801ol;00Go500001l02?l700Soo`340000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(56\\) JJVJJLLVYKSZJVYMINB A VDBNFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l:00Go2`04o``00_lG00Ko2006o``00_l900Ko2@06o`H0
3Ol00`3oo`0;o`L00_l900So1@05o`H00_l200;o00<0ool00ol600[o1P06o`/00_l:00So1005o`<0
1Ol200[o1@06o`<00_l200[o4P06o`<01_lD00;o2008o`H02_l500Ko0`02o`801ol<00Go500001<0
0_l900Wo2007o`/00_lD00Wo1@09o`X01?l600Wo1P09o`D03Ol00`3oo`0;o`H01?l800So1@05o`D0
0ol200[o100:o`@02Ol900Co2@08o`@01Ol300Go0P0:o`D01_l200?o0P0;oa401_l300Ko4`04o`L0
2_l400_o1006o`800ol200Oo2P09oa80000C00;o2@02o`D00_l700;o1002o`/00_lD00?o1003o`@0
0ol400?o2@04o`H00ol400?o1@03o`@00ol700;o1P02o`@00_l600;o1P04o`/00_l:00;o1@03o`<0
0ol500?o1002o`D00_l400?o1003o`P01?l<00;o2002o`L00_l700;o2P02o`@01?l400;o1@03oa80
0_l700;o5@04o`P00_l400Co1@02o`D00ol400;o1004o`@00_l<00?o1@03oa40000C00;o4@02o`D0
0_l600;o2P02oa@00_l600;o1002o`H00_l900Co1P02o`H00_l500;o1P02o`L00_l600;o1002o`H0
0_l600Co2`02o`X00_l500;o1002o`L00_l400?o1002o`@00_l600;o2004o``00_l800;o1`02o`L0
0_l:00;o1004o`@00_l600;o4P02o`L00_lE00Co2002o`H00_l500;o1P02o`@00_l400Co1002o``0
0_l700;o4@0001<00_lA00;o1@02o`H00_l:00;o5002o`H00_l400;o1P02o`P00_l200;o1@02o`H0
0_l500;o1P02o`L00_l600;o1002o`H00_l500;o0P02o`X00_l:00;o1002o`D00_l700;o1@03o`<0
0_l400;o1P02o`L00_l200;o2`02o`P00_l300;o0P02o`L00_l:00;o0`05o`@00_l600;o4P0;oa@0
0_l200;o1`02o`L00_l400;o1P02o`@00_l300Go1002o`800_l700;o2@02oa00000C00;o4@02o`D0
0_l600;o2P02oa@00_l600;o1002o`H00_l800;o0P02o`D00_l600;o1@02o`H00_l700;o1P02o`@0
0_l600;o1@02o`800_l:00;o2P03o`800ol=00?o1P02o`<00_l400;o1P02o`L00_l200;o2`02o`P0
0_l200?o0P02o`L00_l:00;o0`02o`030?oo00@00_l600;o4`09oaD00_l200;o1`02o`L00_l400;o
1P02o`@00_l300;o00<0ool01002o`800_l700;o2@02oa00000C00;o4@02o`D00_l600;o2P02oa`0
0_l<00;o1`03o`800ol<00;o3@02o`L00_l<00;o3003o`800ol900?o2@07o`T01ol700?o4002o`H0
0ol200?o2P03o`L00_l20003o`3o00800_l700;o2P02o`800ol00`3oo`0400;o1@03oa<00_l500;o
5003o`800ol600;o1`02o`@00_l500?o1002o`800ol00`3oo`0400Ko1`02o`T00_l@00004`02o`X0
0_l400;o1P03o`@00_l;00;o7002o``00_l700;o1002o``00_l=00;o1`02o``00_l<00;o1002o`P0
1?l900Go2@07o`X00ol?00;o1P02o`@00_l900Co1`02o`040?oo00;o00<0ool01`02o`X00_l200;o
0P02o`@02OlE00;o0`02oaD00_l400;o1P02o`L00_l400Wo1@02o`800_l200;o1006o`L00_l900;o
400001@00_l900So1P09o`X00_lM00;o3002o`L00_l400;o3002o`d00_l700;o3002o``00_l400;o
1`06o`P00_l0103oool700?o2`02o`<00_l?00;o1P02o`@00_l800Ko1P02o`030?oo008000Co0?oo
1`02o`X00_l00`3oo`0300;o1008oaH00_l300;o5@02o`@00_l600;o1`02o`@02?l600;o00<0ool0
0`02o`@00_l200;o1`02o`T00_l@00005002o`T01ol700;o00<0ool00_l<00;o7@02o``00_l600;o
1P02o`/00_l=00;o1`02o``00_l;00;o1P02o`H00_l200;o2002o`800ol600;o1`000ol0000200;o
0`03o`h00_l500;o1P02o`L00_l200;o1P02o`030?l0008000Co0?oo1`02o`X01Ol300;o1002o`@0
0olF00;o00@0oooo5002o`H00_l500;o1`02o`@00_l400?o1@05o`<00_l400;o0P02o`800_l300;o
2@02oa00000D00?o2002o`d00_l@00;o7@02o``00_l600;o1P02o`/00_l=00;o1`02o``00_l;00;o
1P02o`D00ol300;o1`02o`<00ol500;o1P02o`@00_l400?o3@02o`D00_l600;o1P03o`<00_l500Co
0`04o`L00_l:00Co1002o`@00_l500;o5P02o`030?oo01D00_l600;o1@02o`H00_l500;o1@02o`D0
1?l400;o1002o`H00_l400;o1`02oa40000E00;o2002o`d00ol>00;o7P02o``00_l500?o1P03o`X0
0_l=00;o1`02o``00_l:00?o1P03o`@00_l400;o1`02o`@00ol400?o1003o`@00_l500;o3@02o`@0
0ol600?o1@02o`@00_l500Co1003o`L00_l:00Co1002o`@00_l400?o5P05oa@00ol600?o1002o`@0
1?l500;o1003o`D01?l400;o1002o`H00_l400?o1@03oa40000F00;o1`02o`h00ol<00;o6P0:o`@0
2_l00`3oo`04o`801_l400[o1@0:o`030?oo00Ko1P08o`H01_l200Ko00<0ool00ol200Go0`05o`<0
1Ol300Wo100:o`L04?l200Ko0P05o`801Ol200Co1@04o`802_l500Co0P06o`030?oo00So5007oa@0
1_l200Ko0P0:o`@02_l500Co0P06o`030?oo00[o1@09oa80000G0003o`0000D02?l900Oo1`000ol0
000I00[o100:o`030?oo00Co0P06o`@02_l500[o00<0ool01_l600So1P06o`801_l00`3oo`03o`80
1Ol300Go0`05o`D01Ol00`3o000300[o1`0@o`801_l200Go0P05o`801?l500Co0P0:o`D00ol300Ko
00<0ool01olE00Oo5006o`801_l200So1P09o`H00ol300Ko00<0ool02_l700Go500001l02?l;00Go
o`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(57\\) JHTJKLLT IVXFQYIINF A VDBNFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`X01Ol;00;o3P02oaL0
1_l700Co0`04o`D02?l600Ko1`05o`H00_l00`3oo`0;o`030?oo00_o1008oa@02_l800;o1`05o`80
1Ol300Oo2`05o`P02?l500[o100:o`D01_l300;o0P07oaD01_l300Ko5002o`P02?l600[o1@06o`<0
0_l200Oo3005oa@0000C00;o2@09o`T00_l?00;o5009o`H01?l300Co1@08o`@02Ol600Go1@03o`03
0?oo00_o00<0ool02ol400So500:o`L01?l600Go0P05o`<01ol900Wo1P08o`D02_l400[o1@06o`80
0ol200Oo5@06o`<01_lC00Co1`0:o`@02ol400Ko0P03o`801ol:00Wo4P0001<00_l900;o1@02o`X0
0_l>00;o5003o`@00ol600;o1@02o`T00_l700?o1003o`L00_l500?o1@02o`H00_l400;o1P02o`L0
0_lK00;o2`04o`L00ol400?o1P02o`/00ol500?o2002o``00_l<00;o2P02o`@01?l400;o6P02o`L0
0_lE00Co2002o`@01?l500;o1@03o`@00_l400Co1002o``00ol500?o4@0001<00_lA00;o2@02o`h0
0_lD00;o1P02o`H00_l500;o2@02o`L00_l600;o1`02o`D00_l600;o1P02o`@00_l600;o1`02oa/0
0_l;00Co2003o`800ol700;o2`02o`L00_l800;o3002o``00_l:00;o1004o`@00_lJ00;o1`02oaD0
1?l800;o1P02o`D00_l600;o1002o`@01?l400;o3002o`L00_lA00004`02oa400_l900;o3P02oa@0
0_l600;o1P02o`D00_l900;o1`02o`H00_l700;o1002o`L00_l600;o1002o`H00_l700;o6`02o`X0
0_l200;o2002o`800_l800;o0P02o`H00_l900;o1`02o``00_l<00;o2P02o`<01Ol400;o0P02oaH0
2olD00;o0P02o`L00_l700;o1002o`H00_l400;o0`05o`@00_l200;o1`02o`T00_l@00004`02oa40
0_l:0003o`0000`00_lD00;o1P02o`H00_l500;o2@02o`L00_l600;o1`03o`800ol700;o1P02o`@0
0_l600;o1`02oa/00_l:00;o0P02o`T01?l900;o0P02o`H00_l900;o1`02o``00_l<00;o2P02o`<0
0_l00`3oo`0400;o0P02oaL02OlE00;o0P02o`L00_l700;o1002o`H00_l400;o0`02o`030?oo00@0
0_l200;o1`02o`T00_l@00004`02oa400_l:00;o3@02oa`00_l600;o1@02o`T00_l?00;o1`07o`P0
0_l<00;o3`02oa/00_l900?o0P03o`P01?l900Ko1P02o`T00_l700?o2`02o``00_l:00;o0P03o`03
0?oo00@01_lG00;o1@02oa@00ol200?o1P02o`L00_l400;o1@03o`@00_l200?o00<0ool01006o`L0
0_l900;o400001<00_l:00;o1002o`/00_l=00;o7002o`H02Ol900;o3`02o`L01Ol:00;o3002o`l0
0_lK00;o2@02o`@00_l800?o2P06o`H00_l900;o1P04o`/00_l<00;o2P02o`800_l200;o1006oaP0
0_l300;o5@02o`@00_l600;o1`02o`@02Ol500;o0P02o`800_l400Ko1`02o`T00_l@00005002o`T0
2?l<0003o`0000X00_lM00;o1P09o`@00_l300;o0`02o`X00_l700;o00@0oooo2@02o``00_l:00;o
0`02o`<00_lF00;o2@02o`@00_l800Co2@02o`800_l600;o2@02o`D01_l:00;o3002o`X00_l00`3o
o`0300;o1002o`800_lH00;o0`02oaD00_l400;o1P02o`L00_l400So1P02o`030?oo00<00_l400;o
0P02o`L00_l900;o400001@00_l900Oo3@02o`/00_lM00;o1P02o`D00_l400;o0`02o`<00_l:00;o
1`02o`800ol800;o3002o`X00_l300;o0`02oaH00_l800;o1P02o`H01_l800;o0P02o`800_l200?o
2002o`D00_l200;o2P02o``00_l:00Go0`02o`@00_l200;o0P02oaD00_l0103ooolD00;o1P02o`D0
0_l700;o1002o`@00ol500Go0`02o`@00_l200;o0P02o`<00_l900;o400001@00ol800;o4P02o`/0
0_lM00;o1P02o`D00_l400;o0`02o`<00_l:00;o1`02o`<00ol700;o3002o`X00_l300;o0`02oaH0
0_l800;o1P02o`D00ol200?o1`02o`H00_l300;o1`02o`D00ol300;o2@02o``00_l:00Co1002o`@0
0_l600;o5@02o`030?oo01D00_l600;o1@02o`H00_l500;o1@02o`D01?l400;o1002o`H00_l400;o
1`02oa40000E00;o2002oa<000?o00002002oah00_l600;o1@02o`@00_l300;o0`02o`X00_l700;o
1003o`H00_l<00;o2P02o`<00_l300;o5P02o`L00ol600?o1002o`@00_l700;o1P02o`@00_l500;o
1P02o`@00_l900;o3002o`X01?l400;o1002o`H00_lE00Go5003o`H00ol400;o1004o`D00_l400?o
1@04o`@00_l400;o1P02o`@00ol500?o4@0001H00_l700;o3002o`D00_l800;o6P0:o`801?l300Co
0`0<o`D02_l200Go0`05o`030?oo00Ko1P08o`L03?lB00[o0P06o`801_l00`3oo`03o`801Ol300co
1009o`@01Ol200Go0`0:o`@02_l500Co0P06o`030?oo00[o4P07oa@01_l200Ko0P0:o`@02_l500Co
0P06o`030?oo00[o1@09oa80000G0003o`0000D02?l600Wo20000ol0000I00[o0P04o`<01?l300co
1@0:o`801Ol300Go00<0ool01_l600So1`0<oa802_l200Ko0P06o`030?oo00?o0P05o`<03?l600Go
1P05o`801Ol300[o100:o`D00ol300Ko00<0ool02_lB00Oo5006o`801_l200So1P09o`H00ol300Ko
00<0ool02_l700Go500001l02?l600Woo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(58\\) NDTJKLLT IVXKQYIJNF A VABPFL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`X01Ol;00Co3002oaH0
1_l300;o0`08o`P02?l600Ko1`05o`H00_l00`3oo`0;o`030?oo00_o1008oa@02_l800;o1`05o`80
1Ol300Go1P02o`D01Ol800So1@0:o`D01_l800Ko0`02o`801olE00Ko0`06oa@00_l600Ko0`06o`03
0?oo00So1008o`H01ol800go400001<00_l900Wo1`08o`/00_lE00Ko0P03o`<02_l600So1009o`H0
1Ol500?o00<0ool02ol00`3oo`0;o`@02?lD00[o1`04o`H01Ol200Go0`05o`D00ol300Wo1P08o`D0
2_l300Wo1`06o`800ol200Oo5@06o`<01_lC00Co1@06o`<01_l00`3oo`09o`<02?l600Oo200=oa00
000C00;o2@02o`D00_l600?o1003o`X00_lF00;o1004o`@00_l400Co2002o`L00ol400?o1`02o`D0
0ol500;o1P02o`@00_l600;o1`02oa/00_l;00Co1`03o`@00ol600;o1@03o`<00ol500?o2002o``0
0_l700?o1003o`L00_l400Co1002oaX00_l700;o5@04o`L00_l700;o1@02o`D00ol400;o3002o`h0
0_l600;o400001<00_lA00;o1@02o`H00_l:00;o5P02o`@01?l400;o1P02o`P00_l700;o1P02o`L0
0_l500;o1P02o`H00_l400;o1P02o`L00_lK00;o2`04o`P00ol200?o1`02o`D00_l400;o1`02o`P0
0_l<00;o1`02o`H00_l700;o1004o`@00_lJ00;o1`02oaD01?l700;o1`02o`D00_l600;o1002o``0
0_l>00;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaH00_l300Go1002o`L00_l700;o1`02o`H0
0_l700;o1002o`L00_l600;o1002o`H00_l700;o6`02o`X00_l200;o2002o`800_l800;o1002o`@0
0_l900;o1`02o``00_l700;o1P02o`L00_l300Go1002o`800_lF00_o5002o`800_l600_o1@02o`H0
0_l400;o3002o`800_l:00;o1P02oa00000C00;o4@02o`D00_l600;o2P02oaH00_l300;o00<0ool0
1002o`L00_l700;o1`02o`H00_l700?o0P03o`L00_l600;o1002o`H00_l700;o6`02o`X00_l200;o
2@04o`T00ol200?o1002o`T00_l700;o3002o`L00_l600;o1`02o`<00_l00`3oo`0400;o0P02oaL0
2OlE00;o0P02o`L02Ol600;o1P02o`@01ol700;o0P02o`X00_l600;o400001<00_lA00;o1P02o`@0
0_l;00;o5P02o`800ol00`3oo`0400;o1`02o`L00_l?00;o1`07o`P00_l<00;o3`02oa/00_l900?o
0P03o`P01?l900Oo1@02o`T00_l700?o2`02o`l00_l700;o0P03o`030?oo00@01_lG00;o1@02oa@0
0ol200?o1P02o`D00_l600;o1@03o`@02Ol500Ko2P02oaP0000C00;o2P02o`@00_l800Oo2`02oaH0
0_l200;o0P02o`@00_l700;o1`02o`l00_l700Go2P02o``00_l?00;o6`02o`T00_l400;o2003o`X0
1Ol700;o2@02o`H01?l;00;o3`02o`L00_l200;o0P02o`@01_lH00;o0`02oaD00_l400;o1`02o`<0
0_l700Wo1@02o`D00ol400Ko2P02oaP0000D00;o2@08o`P01_l;00;o5`02o`030?oo00<00_l400;o
1`02o`800_l300;o0`02o`X00_l700;o00@0oooo2@02o``00_l:00;o0`02o`<00_lF00;o2@02o`@0
0_l800Co2@02o`040?ooo`H00_l900;o1@06o`X00_l?00;o1`02o`030?oo00<00_l400;o0P02oaP0
0_l300;o5@02o`@00_l700;o0`02o`L02?l600;o1P02o`@00_l200;o2P02oaP0000D00;o2@07o`P0
0_l400;o2P02oaL01Ol300;o1002o`L00_l200;o0`02o`<00_l:00;o1`02o`800ol800;o3002o`X0
0_l300;o0`02oaH00_l800;o1P02o`H01_l800;o0P03o`D00ol800;o1@02o`800_l:00;o3`02o`L0
1Ol300;o1002o`800_l200;o5@02o`040?oooa@00_l600;o1`02o`040?ooo`L00_l400?o1@02o`H0
0_l400;o0P02o`800_l600;o600001@00ol800;o3002o`H00_l900;o5`04o`@00_l400;o1P02o`<0
0_l300;o0`02o`X00_l700;o0`03o`L00_l<00;o2P02o`<00_l300;o5P02o`P00_l600;o1@03o`80
0ol700;o0`03o`D00_l700;o1@03o`<00_l900;o3`02o`L01?l400;o1002o`H00_lE00;o00<0ool0
5@02o`H00_l700;o00<0ool02002o`D00_l500;o1P02o`@00_l600;o1P02oaP0000E00;o2002o``0
0_l600;o2002oaP01?l400;o1002o`@01?l300;o0`02o`<00_l:00;o1`02o`@00ol600;o3002o`X0
0_l300;o0`02oaH00_l700?o1P03o`@00_l400;o1`02o`@00ol500;o1@02o`H00_l400;o2@02o`l0
0_l700Co1002o`@00_l600;o5@05oa@00ol600?o1P05o`P00_l400?o1@02o`D00ol400;o1P02o`H0
0_lH00005P02o`L00_l<00?o1003o`L00_lH00Co0P06o`802_l400co1@0:o`801Ol300Go00<0ool0
1_l600So1`0<oa802_l200Ko0P06o`030?oo00?o0P05o`<01Ol300Go0`09o`@01Ol200Go0`0:o`H0
2_l300Co0P06o`030?oo00[o4P07oa@01_l200Ko0P07o`L02_l400_o0`0<o`<02?lE00005`000ol0
000500So1`08o`P000?o00005`03o`<01_l200So1P0<o`D02_l200Go0`05o`030?oo00Ko1P08o`L0
3?lB00[o0P06o`801_l00`3oo`03o`801Ol300Go0`05o`D01Ol600Go0P05o`<02_l600[o0`03o`<0
1_l00`3oo`0:oa801olD00Ko0P06o`801ol700Wo1@09o`D03?l300So5@0001l02?l800Koo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(59\\) NDTJKLLT IVXKQ JJNF A VABUFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`X01Ol800Go3P02oaH0
1_l300;o0`08o`P02?l600Ko1`05o`H00_l00`3oo`0;o`030?oo00_o1008oa@02_l800;o1`05o`80
1Ol300Go1P02o`D01OlF00Ko2006o`P01_l300;o0P07oaD01_l300Ko5002o`H01_l300Ko00<0ool0
2?l900Co1@07o`P01Ol600;o400001<00_l900Wo1P07o`d00_lE00Ko0P03o`<02_l600So1009o`H0
1Ol500?o00<0ool02ol00`3oo`0;o`@02?lD00[o1`04o`H01Ol200Go0`05o`D00ol300Wo4P09o`D0
2Ol700Ko0P03o`801olE00Ko0`06oa<01?l500Ko0`06o`030?oo00Wo1P08o`<01ol800Go1@03oa00
000C00;o2@02o`D00_l;00?o3002oaH00_l400Co1002o`@01?l800;o1`03o`@00ol700;o1@03o`D0
0_l600;o1002o`H00_l700;o6`02o`/01?l700?o1003o`H00_l500?o0`03o`D00olA00?o1003o`@0
0ol400?o1`02o`@01?l400;o6P02o`L00_lE00Co1`02o`L00_l500;o1@03o`D00_l400;o1@02o`d0
0_l500?o4@0001<00_lA00;o2`03o`/00_lF00;o1004o`@00_l600;o2002o`L00_l600;o1`02o`D0
0_l600;o1P02o`@00_l600;o1`02oa/00_l;00Co2003o`800ol700;o1@02o`@00_l700;o4@02o`H0
0_l400;o1P02o`L00_l400Co1002oaX00_l700;o5@04o`L00_l700;o1@02o`H00_l400;o1P02o`@0
0_l=00;o1@02oa80000C00;o4@02o``00_l;00;o5P02o`<01Ol400;o1`02o`L00_l700;o1P02o`L0
0_l400;o1`02o`H00_l400;o1P02o`L00_lK00;o2P02o`800_l800;o0P02o`P00_l400;o1002o`T0
0_l@00;o1P02o`@00_l600;o1`02o`<01Ol400;o0P02oaH02olD00;o0P02o`H02ol500;o1P02o`@0
0_l600;o1002o`800_l900;o1002oa<0000C00;o4@02o`P01?l00`3oo`0:00;o5P02o`<00_l00`3o
o`0400;o1`02o`L00_l700;o1P02o`L00ol200?o1`02o`H00_l400;o1P02o`L00_lK00;o2P02o`80
0_l900Co2@03o`800ol400;o2@02oa000_l600;o1002o`H00_l700;o0`02o`030?oo00@00_l200;o
5`09oaD00_l200;o1`09o`H00_l600;o1002o`H00_l400;o0P02o`T00ol200?o4`0001<00_lA00;o
1P09o`X00_lF00;o0P03o`030?oo00@00_l700;o1`02o`l00_l700Oo2002o``00_l?00;o6`02o`T0
0ol200?o2004o`T01ol500;o2@02oaP00_l<00;o1`02o`800ol00`3oo`0400Ko5`02o`D00_lD00?o
0P03o`H00_l500;o1P02o`D00ol400;o1P02o`@01_l900Oo500001<00_l:00;o1002o`L00_l400?o
2P02oaH00_l200;o0P02o`@00_l700;o1`02o`l00_l700Go2P02o``00_l?00;o6`02o`T00_l400;o
2003o`X01Ol700;o2@02oaP00_l<00;o1`02o`800_l200;o1006oaP00_l300;o5@02o`@00_l700;o
0`02o`L02Ol500;o1P02o`@01_l900Go5P0001@00_l900So1P02o`H00_l900;o5`02o`030?oo00<0
0_l400;o1`02o`800_l300;o0`02o`X00_l700;o00@0oooo2@02o``00_l:00;o0`02o`<00_lF00;o
2@02o`@00_l800Co2@02o`040?ooo`H00_l900;o6002o``00_l700;o00<0ool00`02o`@00_l200;o
6002o`<00_lE00;o1002o`L00_l300;o1`08o`H00_l600;o1002o`800_l900;o00@0oooo5@0001@0
0_l900Oo1`02o`H00_l900;o5`05o`<00_l400;o1`02o`800_l300;o0`02o`X00_l700;o0P03o`P0
0_l<00;o2P02o`<00_l300;o5P02o`P00_l600;o1P06o`P00_l200?o1@03o`P00_lH00;o3002o`L0
1Ol300;o1002o`800_l200;o5@02o`040?oooa@00_l600;o1`02o`040?ooo`L00_l400?o1@02o`H0
0_l400;o0P02o`800_l500;o0P03oa@0000D00?o2002o``00_l600;o2@02oaL01?l400;o1002o`H0
0_l300;o0`02o`<00_l:00;o1`02o`<00ol700;o3002o`X00_l300;o0`02oaH00_l800;o1P02o`D0
0ol200?o1`02o`<00ol500;o1`02oaT00_l<00;o1`04o`@00_l400;o1P02oaD00_l00`3oo`0E00;o
1P02o`L00_l00`3oo`0800;o1@02o`D00_l600;o1002o`H00_l500;o0`03oa<0000E00;o2002o``0
0_l60003o`0000L00_lH00Co1002o`@00_l400Co0`02o`<00_l300;o2P02o`L00_l400?o1P02o``0
0_l:00;o0`02o`<00_lF00;o1`03o`H00ol400;o1002o`L00_l400?o1@02o`D00_lJ00;o3002o`L0
1?l400;o1002o`H00_lE00Go5003o`H00ol600Go2002o`@00ol500;o1P02o`@00_l600;o1@02o`@0
0olB00005P02o`L00_l=00;o1002o`P00_lH00Co0P06o`802_l400co1@0:o`801Ol300Go00<0ool0
1_l600So1`0<oa802_l200Ko0P06o`030?oo00?o0P05o`<01Ol300Go0`09oaD02_l400[o0`04o`80
1_l00`3oo`0:oa801olD00Ko0P06o`801ol700[o1@04o`@01?l00`3oo`0:o`<01Ol300Go400001L0
00?o00001@08o`L01ol90003o`0001L00ol300Ko0P08o`H03?l500[o0P05o`<01Ol00`3oo`06o`H0
2?l700co4P0:o`801_l200Ko00<0ool00ol200Go0`05o`<01Ol500Go5`0:o`@02_l300?o0`06o`03
0?oo00[o4P07oa@01_l200Ko0P07o`L02Ol600Co1004o`030?oo00[o0`05o`<01Ol@00007`08o`T0
1?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(60\\) NDTJLPKTVIRXKQ JJLFYA VCBUFK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`/01?l;00Co3002oaH0
1_l300;o0`08o`P02?l600Ko1`0=o`030?oo00Ko1P05o`H00_l400So2@02o`T02_l300Go1P08o`80
1Ol300Go1P02o`D01OlF00Ko2006o`L03Ol00`3oo`05o`X02?l300Ko0`06oa@00_l;00Go1P0:o`T0
1?l500Oo2005o`H00_l@00004`02o`/01ol800Ko3002oaD01_l200?o0`0:o`H02?l400Wo1P0=o`03
0?oo00Ko1P05o`D00ol400So2004o`P02_l300Go1@09o`801Ol300Go1@03o`<02OlB00Wo1@09o`H0
3Ol00`3oo`05o`X02?l300Ko0`06oa<01?l800Wo100;o`H02?l300Oo2005o`D00ol@00004`02o`X0
0_l400;o1`03o`800ol;00;o5P02o`@01?l400;o1004o`P00_l700?o1003o`P00_l600;o0`02o``0
0_l500?o2002o`/01?l<00;o2@02o`D00ol300?o1003o`H00_l500?o0`03o`D00olA00?o1003o`@0
0ol400?o2002o`H00_l300;o4002o`P00_l700;o5@04o`L00ol500?o1@02o`D00ol500;o1002o`D0
0_l=00;o1@03oa40000C00;o2@02o`H00_l600;o1002o`/00_lF00;o1004o`@00_l600;o2002o`L0
0_l600;o2002o`H00_l300;o3002o`D00_l900;o2`04o``00_l900;o1@02o`D00ol200?o1`02o`D0
0_l400;o1`02oa400_l600;o1002o`H00_l800;o1P02o`<00_l@00;o2002o`L00_lE00Co1`02o`L0
0_l500;o1P02o`@00_l600;o1002o`d00_l500;o4P0001<00_l900;o1P02o`D00_l600;o2P02oaH0
0_l300Go1002o`L00_l700;o1`02o`H00_l800;o1P02o`<00_l<00;o1002o`X00_l:00;o0P02o`/0
0_l900;o1002o`L00_l200;o2002o`@00_l400;o2@02oa000_l600;o1002o`H00_l800;o1P02o`<0
0_l200;o3002o`P02olD00;o0P02o`D00ol>00;o1P02o`@00_l600;o1002o`800_l900;o1002oa<0
000C00;o2@02o`H00_l500;o1P02o`X00_lF00;o0`02o`030?oo00@00_l700;o1`02o`L00_l600;o
2002o`H00_l300Oo1`03o`800ol:00;o2P02o`800_l;00;o2@02o`<00ol800Co2@03o`800ol400;o
2@02oa000_l600;o1002o`H00_l800;o1P02o`<00_l200;o3002o`T02OlE00;o0P02o`D00_l?00;o
1P02o`@00_l600;o1002o`800_l900?o0P03oa<0000C00;o2@02o`H00_l500;o1P02o`X00_lF00;o
0P03o`030?oo00@00_l700;o1`02o`l00_l800;o2`09o`D01ol;00;o2@03o`800ol:00;o2@07o`T0
1?l900Oo1@02o`T00_lH00;o3002o`P00_l;00Ko3003o`P00_l500;o5003o`800ol400;o3`02o`D0
0ol400;o1P02o`@01_l900Oo500001<00_l900?o1002o`H00_l600;o2P02oaH00_l200;o0P02o`@0
0_l700;o1`02o`l00_l800;o2`02o`D00ol400Go3@02o`T00_l400;o2P02o`T02Ol700?o2P05o`L0
0_l900;o6002o``00_l800;o2`06o`/01?l900;o0`02oaD00_l400;o1002o`l02Ol500;o1P02o`@0
1_l900Go5P0001@00_l800Wo1P02o`H00_l900;o5`02o`030?oo00<00_l400;o1`02o`800_l300;o
0`02o`X00_l800;o2`02o`H00_l400;o00@0oooo1`02o`<00_l300;o1002o`@00_l:00;o2@02o`D0
0ol600Co2@02o`040?ooo`H00_l900;o6002o``00_l800;o2`02o`800_l:00Ko2002o`<00_lE00;o
1002o`@00_l?00So1P02o`H00_l400;o0P02o`T00_l0103ooolE00005002o`P00_l00`3oo`02o`P0
0_l600;o2@02oaL01Ol300;o1002o`L00_l200;o0`02o`<00_l:00;o2002o`/00_l600;o1002o`80
0ol600;o0`02o`<00_l300;o1P02o`T00_l900;o1P02o`D01_l800;o0P03o`D00ol800;o6002o``0
0_l800;o2`02o`800_l200;o1P02o`800_l900;o00@0oooo5002o`H00_l300?o1`02o`D00_l400?o
1@02o`H00_l400;o0P02o`800_l500;o0P03oa@0000D00?o2002o``00_l600;o2@02oaL01?l400;o
1002o`H00_l300;o0`02o`<00_l:00;o2002o`/00_l600;o1002o`<00ol500;o0`02o`<00_l300;o
1P02o`T00_l900;o1P02o`@00ol200?o1`02o`<00ol500;o1`02oaT00_l<00;o2002o`/00_l600;o
1@03o`<00_l800;o00<0ool05@02o`H00_l400;o1`02o`D00_l500;o1@02o`H00_l400;o1P02o`D0
0_l300?o4`0001D00_l800?o3002o`@00_l900;o6004o`@00_l400;o1004o`<00_l300;o0`02o`X0
0_l800;o2`02o`D00ol400;o1003o`@00_l300;o0`02o`800ol600?o2002o`T00_l500?o1002o`@0
0_l700;o1003o`D00_l500;o6P02o``00_l800;o2`02o`H00_l500;o1002o`P01OlD00?o1P03o`<0
0ol500?o1@02o`@00ol500;o1P02o`@00_l600;o1@02o`@00olB00005P02o`P00ol;00?o0P03o`P0
0_lH00Co0P06o`802_l400co1@0:o`802?l600_o0`05o`<01Ol200co00<0ool01?l200Ko0`0:o`<0
2ol300Go0P05o`<01Ol300Go0`09oaD02_l400[o0P08o`H03?l300Go0P05o`<01olD00Ko0P06o`<0
2_l300[o1@04o`@01?l00`3oo`0:o`<01Ol300Go400001L000?o00001`07o`L01_l90003o`0001L0
0ol300Ko0P08o`H03?l500[o0P08o`H02Ol500Go0`05o`803?l00`3oo`04o`801_l300[o0`09o`D0
1Ol200Go0`05o`<01Ol500Go5`0:o`@02_l200So1P0<o`<01Ol200Go0`07oa@01_l200Ko1@05o`03
0?oo00<02Ol600Co1004o`030?oo00[o0`05o`<01Ol@00008`05o`P01?oo0<H0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(61\\) KDRJLPKTWIQZIR JJMFYC VBAUCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`04o`T0
2Ol900;o5@05o`H00_l200So1P05o`H00ol200Ko1`0=o`030?oo00Ko1P05o`H00_l400So1P02o`@0
0_l600[o1`05o`H02_l500[o0`05o`H00olA00Ko2006o`L01Ol300Go00<0ool01Ol:00So2005oaT0
0_l700[o1006o`<01_l500Co2@05o`H01Ol600;o400001<00_l;00Oo1`09o`X00_lD00Go1@03o`80
2_l400Go1@0=o`H03Ol00`3oo`06o`H01Ol500?o1008o`H00_l400;o1P0:o`D02Ol400[o1@0:o`<0
1Ol500Co3`09o`D02Ol600Go0`05o`030?oo00Go2P08o`H02OlF00Co1P0;o`<01_l300Ko0`08o`D0
2Ol400Go1@03oa00000C00;o2P02o`@00_l;00;o3@02oaH00_l500?o1002o`@01?l500;o1@03o`80
0ol400?o2002o`H00_l300;o3002o`D00ol800;o2003o`@00ol900;o2003o`D00ol400;o1@02o`T0
0_l900;o1@03oa400ol400?o1003o`@00ol600;o1`02o`@00_l@00;o2003o`D00olE00Co2002o`D0
0ol400;o1`02o`D00_l400;o1003o`D00ol500;o1@03oa40000C00;o2@02o`H00_l:00;o3@02oaH0
0_l500;o1@02o`H00_l500;o1@02o`<00_l600;o2002o`H00_l300;o3002o`D00_l900;o2004o`<0
0ol900;o2002o`L00_l400?o1002o`T00_l900;o1@02oa800_l600;o1002o`H00_l600;o1`02o`@0
0_l@00;o2002o`L00_lE00Co2002o`H00_l400;o1`02o`@00_l600;o0`02o`L00_l500;o1@02oa80
000C00;o2@02o`H00_l:00;o3@02oaH00_l400;o1P02o`L00_l400;o1002o`@00_l600;o2002o`H0
0_l300;o3002o`@00_l:00;o2004o`801?l900;o1`02o`T00_l400?o0`02o`T00_l900;o1002oa<0
0_l600;o1002o`H00_l600;o0`02o`800_l400;o0P02o``00_l700?o7@02o`800_l700;o1P02o`@0
2ol400;o1P02o`800ol>00;o1002oa<0000C00;o2@02o`H00_l:00;o3@02oaH00ol200?o1P02o`L0
0_l400;o0`03o`@00_l600;o2002o`H00_l300Oo1`03o`800ol:00;o2002o`040?l000Co2@02o`L0
0_l900;o1@02o`<00_l900;o2@02o`<00olC00;o1P02o`@00_l600;o1P02o`800ol200;o1002o`80
0_l<00;o1`02oah00_l200;o1`02o`H00_l500Wo1@02o`H00_l200;o3`03o`800olC00004`02o`T0
0_l600;o2P02o`d00_lF00Oo1`02o`L00_l400Oo3@02o`P00_l;00Wo1@07o`/00_l800;o00H0o`00
o`02o`T00_l700;o2@02o`D00ol=00;o2@07oa`00_l<00;o1P02o`8000?o0?l00P02o`@01_l<00?o
1P02oad00ol200?o1P02o`D00ol500;o1@02o`D00_l600;o0P02o`l01olD00004`02o`T00ol400;o
2`02o`d00_lF00Go2@02o`L00_l400Wo2`02o`P00_l;00;o1@03o`@01Ol=00;o2002o`030?oo00;o
00<0ool02@02o`L00_l900;o1P03o``00_l900Wo6P02o``00_l600;o00@0ool00_l00`3oo`0400Ko
2`04o`H00_lM00;o1002o`H02Ol700;o0`02o`H00_l600;o0P02o`l01OlF00005002o`P02Ol;00;o
3002oaL00_l0103oool800;o1`02o`@00_l500?o2P02o`P00_l;00;o1P02o`@00_l0103oool700;o
0`02o`<00_l300;o00<0ool00_l00`3oo`0900;o1`02o`T00_l200;o0`02o``00_l900;o1@03oaT0
0_l<00;o1P02o`030?oo008000Co0?oo1002o`800_l:00Ko1@02oad00_l400;o1P08o`P00_l300;o
1P02o`H00_l200;o3`02o`040?oooaD0000D00;o2002o`030?oo00;o3@02o``00_lG00;o0P03o`L0
0_l700;o1002o`H00_l:00;o2002o`/00_l600;o1002o`800ol600;o0`02o`<00_l200;o0`02o`<0
0_l800;o1`03o`P00_l200;o0`03o`/00_l900;o1P02oaT00_l<00;o1P02o`030?l0008000Co0?oo
1002o`800_l200;o1P02o`800_l500?o1`02oa800_l600;o1@02o`@00ol800;o00@0oooo1P02o`H0
0_l200?o1`02o`D00_l200?o500001@00ol800;o4@02o``00_lG00;o0`03o`H00_l600;o1@02o`H0
0_l:00;o2002o`/00_l600;o1002o`<00ol500;o0`02o`<00_l200;o0`02o`<00_l800;o2002o`L0
0_l300;o1003o`X00_l900;o1P02oaT00_l<00;o1P04o`<01?l400;o1P02o`D00ol300;o1@02o`L0
0_lB00;o1P02o`D00_l500;o2002o`030?oo00L00_l600;o0`02o`L00_l500;o0`03oa<0000E00;o
2003oa000_l;00;o6002o`@00ol500;o1004o`D00_l500?o2P02o`P00_l;00;o1@03o`@00_l400?o
1002o`<00_l300;o0P02o`P00_l800;o2@02o`D00_l400;o1@02o`X00_l900;o1@03oaT00_l<00;o
1P04o`@00ol400;o1P02o`D00_l400;o1@03o`D00olA00?o1P03o`@00_l400?o2005o`L00_l600;o
0`03o`D00ol500;o1003oa80000F00;o2003o`/00ol00`3oo`0:00;o5`05o`<01Ol200[o100;o`H0
2_l200So1P0;o`<01Ol300Go0P0<o`030?oo00Co0P06o`<02_l500Wo100:o`D02_l300_o5@0:o`@0
2_l200Co1@04o`030?oo00[o0`05o`801Ol400[o4006o`801_l00`3oo`08o`H01ol700Co1004o`<0
2_l300Go0`05oa00000G0003o`0000L01ol600Ko2P000ol0000F00Go0`05o`802?l600Wo200:o`80
2?l600Wo1@05o`<01Ol200co00<0ool01?l200Ko0`0:o`L01Ol600[o1@0:o`<02OlG00[o100:o`80
1?l500Co00<0ool02_l300Go0P05o`H01Ol00`3oo`0@00Ko0P06o`030?oo00Oo1`07o`L01?l400Co
1@05o`030?oo00<01Ol300Go400002<01Ol900?oo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(62\\) KGRJLKKTWIQZIU JJMC C VCAUBK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`04o`P0
2_l900;o5@05o`H00_l500Ko1@05o`H00ol200Ko1`0=o`030?oo00?o1P02o`030?oo00?o1P02o`@0
2?l600;o1002o`H02_l700Go1P0:o`D02_l800Co5P06o`P01_l700Go0`05o`D01OlH00Go6@02o`/0
1Ol500Ko0`06o`D01?l500[o1@05o`H00_l@00004`02o`/01ol600[o2P02oa@01Ol500?o0`0:o`<0
1Ol500go1P0=o`030?oo00?o1@03o`030?oo00?o1@03o`@02?l600;o1002o`H02_l500Wo100:o`D0
2_l600So4P09o`D02Ol600Go0`05o`<02OlD00Wo5P04o`P02Ol300Ko0`06o`<02?l300_o1005o`D0
0ol@00004`02o`X00_l400;o1`02o`D00_l:00;o5P02o`D00ol300Co1@02o`D00_l500?o0P03o`@0
0ol800;o1P02o`<00_l500?o1002o`D00ol800;o2003o`@00ol900;o2003o`D00ol400;o1@02o`T0
0_l:00;o1002oa800ol400?o1003o`@00ol600;o1`02o`<00ol500?o4P03o`D00olE00Co1`03o`D0
0ol400;o1`02o`D00_l400;o1@02o`D00ol500;o1@03oa40000C00;o2@02o`H00_l700?o3`02oaH0
0_l500;o1002o`L00_l500;o1@02o`<00_l600;o2002o`H00_l300;o1@02o`D00_l500;o2@02o`P0
1?l300?o2@02o`P00_l700;o1003o`@00_l900;o2@02o`H00_lA00;o1P02o`@00_l600;o1P02o`L0
0_l300;o1`02oa800_l700;o5@04o`L00_l700;o1002o`L00_l400;o1P02o`@00_l600;o1@02o`D0
0_lB00004`02o`T00_l600;o2003o`h00_lF00;o1002o`@00ol700;o1@02o`@00_l400;o1P02o`P0
0_l600;o0`02o`@00_l600;o1002o`X00_l800Co0P04o`T00_l700;o2@02o`@00ol300;o2@02o`T0
0_l600;o4@02o`H00_l400;o1P02o`H00_l300;o0P02o`800olJ00?o7@02o`800_l500?o3@0;o`@0
0_l600;o1002o`H00_l500;o1002oa<0000C00;o2@02o`H00_l900?o3@02oaH00ol200?o1002o`@0
1ol400;o0`03o`@00_l600;o2002o`H00_l300?o0P03o`H00ol200?o2P02o`P00_l0103o0004o`T0
0_l700;o2@02o`D00_l300;o2@02o`T00_l600;o4@02o`H00_l400;o1P02o`H00_l200?o0P02o`80
0_lK00;o7P02o`800_l500;o3`09o`D00_l600;o1002o`H00_l500?o0P03oa<0000C00;o2@02o`H0
0_l:00?o3002oaH01ol500;o1007o`@01ol=00;o2002o`/01ol700Oo2`02o`P00_l01P3o003o00;o
2@02o`L00_l900;o1@03o`d00_l900;o1P02oaT00_l<00;o1P02o`8000?o0?l00P02o`800_lK00;o
7@03o`800ol400;o3`02o`D00_l500;o1P02o`@00_l500?o1@07oa@0000C00;o2@03o`@00_l<00?o
2`02oaH01Ol700;o3`09o`/00_l800;o2`05o`T01Ol=00;o2002o`030?oo00;o00<0ool02@02o`L0
0_l900;o1P03o``00_l900;o1P02oaT00_l<00;o1P02o`040?oo00;o00<0ool00P02oa/00_lM00;o
1002o`@00_l@00;o0`02o`H00_l600;o1009o`H01OlF00005002o`P02Ol=00;o2P02oaL00_l0103o
ool600;o3`02o`D00ol:00;o2002o`/00_l0103oool800;o00@0oooo1`02o`<00_l300;o0`02o`03
0?oo00;o00<0ool02@02o`L00_l900;o0P02o`<00_l<00;o2@02o`H00_lI00;o3002o`H00_l00`3o
o`020004o`3oo`800_lK00;o7@02o`@00_l400;o4002o`<00_l600;o1P02o`@02?l700;o00@0oooo
5@0001@00_l800;o00<0ool00_l@00;o2@02oaL00_l200?o1@02o`P00_l500;o1P02o`X00_l800;o
2`02o`800ol700;o0P03o`H00_l300;o0`02o`800_l300;o0`02o`P00_l700?o2002o`800_l300?o
2`02o`T00_l600;o6@02o``00_l600;o00<0o`000P001?l0ool200?o1`02oa400ol700;o4P02o`H0
0_l300?o1`02o`L00_l0103oool600;o1P02o`@00_l400?o1P02o`800olD00005003o`P00_lD00;o
2@02oaL00_l300?o1@02o`H00ol500;o1P02o`X00_l800;o2`02o`<00ol600;o0`03o`D00_l300;o
0`02o`800_l300;o0`02o`P00_l800;o1`02o`<00_l400?o2P02o`T00_l600;o6@02o``00_l600Co
0`04o`<00_l700;o4P02o`L00_lB00;o1P02o`@00_l700;o1`02o`030?oo00L00_l600;o1002o`D0
0_l600;o0`03oa<0000E00;o2003o``00_l500;o2002oaP00_l400?o1003o`@01?l500;o1@03o`X0
0_l800;o2`02o`@00ol500;o1003o`@00_l300;o0`02o`800_l800;o2002o`T00_l500;o1002o`D0
0_l:00;o2@02o`H00_lI00;o3002o`H01?l400?o0`03o`D00olB00?o1@03oa400ol600?o0`03o`D0
0ol700Go1`02o`H00_l400;o1003o`H00_l400?o4P0001H00_l800?o2`03o`<00ol700;o5`05o`<0
1Ol300[o0`0;o`H02_l200So1P05o`<01Ol00`3oo`03o`<01Ol200co00<0ool01?l200Ko0`0:o`D0
2Ol400[o1@0:o`@01?l400Co4`0:o`@02_l200Co1@04o`<02_lC00[o4006o`801_l300[o1007o`L0
1?l400Co00<0ool02?l500Go0`05oa00000G0003o`0000L01ol700Oo20000ol0000F00Go0`05o`D0
1Ol00`3oo`0300Wo200:o`802?l600Go0`05o`030?oo00?o0`05o`803?l00`3oo`04o`801_l300[o
1`05o`H02_l500[o1004o`@01?lC00[o100:o`801?l500Co1@05o`030?oo01D01Ol00`3oo`0@00Ko
0P06o`D01Ol00`3oo`0400Oo1`04o`@01?l00`3oo`07o`H01Ol300Go400002<01Ol800Goo`350000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(63\\) KGVJLJKTWIQ IU MJICYA SEAUAK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`04o`X0
1Ol<00;o5@05o`H00_l500Ko2P02o`T01_l700go0`06o`H01Ol600;o1008o`H00_l400;o1P0:o`L0
1OlE00[o2004oa@01Ol300Go0`06o`P02_l700Go2008o`<01_l300Ko4002o`030?oo00?o1@0<o`80
1_l300Ko1@04o`@01_l300Ko00<0ool00ol600;o400001<00_l;00Oo1P09o`/00_lD00Go1@03o`<0
2_l700Co1P09o`H03Ol00`3oo`07o`D01Ol500?o1008o`H00_l400;o1P0:o`D02OlC00[o1P08oa80
1Ol300Go00<0ool01ol700[o1@09o`H02?l300Ko0`06oa002_l300co0P06o`<01_l300So0P06o`<0
1_l00`3oo`03o`D00ol@00004`02o`X00_l400;o1P02o`D00_l;00;o5P02o`D00ol300Co1@02o`L0
1?l600?o1003o`P00_l600;o00@0oooo1003o`H00_l500?o2002o`P00ol400?o2@02o`P00ol500?o
5P02o`X00_l400;o4`02o`L00_l200?o1003o`X00_l800?o1@03o`P00_l800;o1`02oa800ol500?o
1002o`H00_l400;o1`02o`D00_l400;o1002o`L00_l500;o1@03oa40000C00;o2@02o`H00_l=00;o
2P02oaH00_l500;o1002o`L00_l700Co1P02o`H00_l800;o1P02o`030?oo00H00_l600;o1@02o`T0
0_l800Co0`03o`T00_l800;o1`02oaH00_l900;o1P02oa800_l700;o0P02o`H00_l:00;o2002o`L0
0_l800;o2002o`L00_lB00;o1`02o`@00_l600;o1002o`L00_l400;o1P02o`<00_l700;o1@02o`D0
0_lB00004`02o`T00_l600;o3@02o`X00_lF00;o1002o`@00ol700;o1P02o`800_l500;o1P02o`P0
0_l600;o00<0ool01P02o`H00_l400;o2P02o`P01?l200Co2@02o`L00_l900;o5@02o`T00_l600;o
4P02o`<00_l200;o0P02o`H00_l:00;o1`03oa400_l800_o4P02o`L00_l400;o0P02o`800_l400_o
1002o`H00_l300_o1@02o`@00_lC00004`02o`T00_l600;o3@02o`X00_lF00?o0P03o`@00_l400Oo
1@02o`800_l500;o1P02o`P00_l600;o00<0ool01P02o`H00ol200?o2P02o`P00_l0103o0004o`T0
0_l700;o2@02oaD00_l900;o1P02oa800_l200?o0P02o`800_l600;o2P02o`L00_lB00;o2@09oa/0
0ol400;o0P02o`T02Ol500;o1P02o`@02Ol600?o0P03oa<0000C00;o2@02o`H00_l<00;o2`02oaH0
1ol500;o1007o`@00ol200?o3002o`P00_lA00;o1P07o`/00_l800;o00H0o`00o`02o`T00_l700;o
2@02oaD00_l900;o1P02oa800_l20003o`3o00800_l:00;o2P02o`L00_lB00?o2002o`D00_lF00Oo
1@06o`T00_l500;o1@02o`H00_l400;o1@02o`H01olD00004`02o`T00ol400;o2P04o``00_lF00Go
1`02o`l00_l400;o3002o`P00_lA00;o1P05o`d00_l800;o00<0ool00_l00`3oo`0900;o1`02o`T0
0_lE00;o2@02o`H00_lB00;o00@0ool00_l00`3oo`0:00;o2P02o`L00_lA00Co2@02o`<00_lE00Oo
1`06o`X00_l300;o1P02o`H00_l500;o0`02o`L01OlF00005002o`P02Ol:00?o3002oaL00_l0103o
ool600;o3`02o`@00_l<00;o2002oa400_l600;o00@0oooo1`02o`<00_l300;o0`02o`030?oo00;o
00<0ool02@02o`L00_l900;o5@02o`T00_l600;o4P02o`030?oo008000Co0?oo2P02o`X00_l700;o
4006o`P00_l300;o5003o``00_l200;o2P02o`<00_l600;o1P02o`D00_l300;o1`02o`040?oooaD0
000D00;o2002o`030?oo00;o3P02o`/00_lG00;o0P03o`D00_l800;o1002o`H00_l;00;o2002oa40
0_l600;o0P03o`H00_l300;o0`02o`800_l300;o0`02o`P00_l700?o2002oaD00_l900;o1P02oa80
0_l00`3o00020004o`3oo`X00_l:00;o1`03o`L00_l600;o0P02o`T00_l0103ooolD00;o1`000ol0
000300;o0P02o`800_l700;o00@0oooo1P02o`H00_l600;o00@0oooo1`02o`800olD00005003o`P0
0_lC00;o2P02oaL00_l300?o1@02o`H00ol400;o1P02o`/00_l800;o4@02o`H00_l300?o1@02o`<0
0_l300;o0P02o`<00_l300;o2002o`P00_l700;o5P02o`T00_l600;o4P04o`<01?l:00;o2P02o`P0
0_l700;o1@03o`<00_l800;o00<0ool05@02o`H00_l500;o1P02o`L00_l00`3oo`0700;o1P02o`H0
0_l00`3oo`0800;o0`03oa<0000E00;o2003oa800_l900;o6002o`@00ol400?o1004o`<00ol600?o
2P02o`P00_lA00;o1P02o`@00ol400;o0`02o`<00_l200;o2002o`P00_l900;o1@02oaL00_l900;o
1P02oa801?l400?o2P02o`X00_l800?o1@03o`D00_l400;o2005oaD00ol400?o1@02o`H00_l700Go
1`02o`H00_l600Go2002o`@00olB00005P02o`P00ol;00;o0`03o`P00_lG00Go0`05o`<02_l200Ko
0P06o`@02_l200So2@0:o`030?oo00?o0`05o`803?l00`3oo`04o`801_l300[o1@09oa<02_l400Co
1004oa001?l500Co100:o`<02_l500[o0`05o`801Ol300Oo5`09o`<03?l400Oo1`04o`@01?l200Oo
1`05o`<01Ol@00005`000ol0000700Oo1P07o`T000?o00005P05o`<01Ol500Go00<0ool00P06o`80
1_l400[o0P08o`T02_l00`3oo`03o`<01Ol200co00<0ool01?l200Ko0`0:o`L01OlE00[o1004o`@0
1?l@00Co1@04o`@02_l300[o1`05o`030?oo00<01Ol200Go0`07oaT01Ol00`3o000200co1007o`L0
1?l400Co0P07o`L01Ol300Go400002<01Ol800Coo`360000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(64\\) JCVJJLKTWIQXLU MHJE A SEATBK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`04o``0
1_l900;o5`06o`X01Ol;00;o2@06o`T01_l600go00<0ool00ol600;o1008o`H00_l400;o1P0:o`L0
1Ol500Go0P05o`<03Ol600Co5005o`<01Ol200Co0`04o`D01_l600co4006o`<01_l@00;o00<0ool0
0ol500co0P06o`<01_l200So100:o`D01Ol600;o400001<00_l;00Oo2P06o`X00_lD00Wo1`09o`P0
1?l600Wo1P09o`D03Ol00`3oo`03o`D00ol400So1P02o`@00_l600[o1@09o`<01Ol200Go0`0=o`@0
2?lB00Go0`05o`801?l300Co0`09o`D03?l@00Ko0`06oa002_l300co0P06o`<01_l200So100;o`@0
1Ol500?o400001<00_l:00;o1002o``00_l<00;o5003o`@00ol500?o1@03o`L01?l600?o1003o`D0
0ol400?o1`02o`H00_l300;o1@03o`P00_l800?o1003o`T00_l800?o1@03o`<00ol400?o1`02o`H0
0_l400;o1002oa<00_l700;o1002o`D00_l400?o1003o`H00_l600;o4P02o`L00_lB00?o1@03o`@0
0_l600;o1002o`L00_l700;o2@02o`D00ol500;o1@03oa40000C00;o2@02o`H00_l;00;o3002oa@0
0_l600;o1@02o`L00_l700Co1P02o`H00_l500;o1P02o`L00_l600;o0`02o`D00_l900;o2004o`<0
0ol900;o2002o`L00_l400?o0P03o`P00_l600;o0`02o`H00_lB00;o1`02o`@00_l500;o1002o`H0
0_l600;o1P02oa800_l700;o4P02o`L00_l400;o1P02o`@00_l700;o1`02o`T00_l600;o1@02o`D0
0_lB00004`02o`T00_l600;o1@0:o`X00_lD00;o1P02o`@00ol?00;o0P02o`D00_l600;o1@02o`H0
0_l700;o1P02o`<00_l400;o2P02o`P01?l200Co2@02o`L00_l900;o1002o`800_l900;o1P02o`<0
0_l600;o4P02o`<00_l200;o1002o`D00_l400;o1P02o`H00_l200;o0P02oa802olB00;o1`02o`@0
0_l200;o0P02o`@02ol700;o2@02o`H00_l500;o1002oa<0000C00;o2@02o`H00_l500[o2P02oa@0
0_l600;o1002oa000_l200;o1@02o`H00_l500;o1P02o`L00_l600;o0`03o`800ol:00;o2002o`04
0?l000Co2@02o`L00_l900;o1@04o`X00_l600;o0`02o`H00_lB00;o0P03o`800_l400;o1@02o`@0
0_l600;o1P02o`800_lG00Wo6`03o`@00_l200;o2@09o`P00_l900;o1P02o`D00ol200?o4`0001<0
0_l900;o1P02o`D00_l400;o3002oa`00_l400;o3`03o`800ol<00;o3@02o`L00_l;00Oo2`02o`P0
0_l01P3o003o00;o2@02o`L00_l900;o1@04o`X00_l;00;o1P02oa800_l20003o`3o00800_l400;o
1@02o``00_l600Ko5`02o`D00_lF00Oo1@06o`T00_l500;o2002o`T00_l500?o1@07oa@0000C00;o
2@03o`@00_l700;o0`02o``00_lL00;o1002o`l00_l400;o3002o`d00_l700;o2`05o`d00_l800;o
00<0ool00_l00`3oo`0900;o1`02o`T00_l500?o2`02o`/00_l600;o4P02o`040?oo00;o00<0ool0
1009o``00_l600Ko6002o`<00_lE00Oo1`06o`X00_l300;o2@02o`T02Ol600Go5P0001@00_l800Wo
20001?l00002o`/00_lM00;o1002o`l00_l400;o3002o`d00_l700;o2`02o`040?ooo`L00_l300;o
0`02o`<00_l00`3oo`02o`030?oo00T00_l700;o2@02o`D01?l:00;o2`02o`H00_lB00;o00<0ool0
0P001?l0ool400Wo3002o`H00_l200;o6002o`<00_lD00?o3002o`800_l:00;o0`02o`@00_l300;o
0`02o`@02?l700;o00@0oooo5@0001@00_l800;o00<0ool00_l:00;o0P02o`/00_lM00;o1003o`L0
0_l400;o1P02o`/00_l=00;o1`02o`/00_l200?o1P02o`<00_l300;o0P02o`<00_l300;o2002o`L0
0ol800;o1006o`T00_l;00;o1P02oa800_l00`3o00020004o`3oo`@00_l500;o3002o`H00_l200;o
0P02oaD00_l0103ooolD00;o1`000ol0000300;o0P02o`800_l700;o00@0oooo1002o`<00_l300;o
1002o`@00ol600;o0P03oa@0000D00?o2002o`l000?o00000_l;00;o7@02o`D00_l700;o1002o`H0
0_l;00;o3@02o`L00_l;00;o0`03o`D00_l300;o0`02o`800_l300;o0`02o`P00_l800;o1`02o`@0
0ol200?o2002o`/00_l600;o4P04o`<01?l400;o1@02o``00_l600;o1P02oaD00_l00`3oo`0E00;o
1P02o`D00_l600;o1`02o`030?oo00D00_l300;o0`02o`@00_l500;o1P02o`<00olC00005@02o`P0
0ol?0004o`3oo`X00_lN00;o1@03o`D00ol300?o1P03o`X00_l=00;o1`02o`/00_l400?o1002o`<0
0_l300;o0P02o`P00_l800;o2@02o`D00_l500;o1002o`P00_l;00;o1P02oa801?l400?o1002o`D0
0_l<00;o1P02o`H00_lE00Go5@03o`@00ol500;o1P02o`L01Ol500;o0`02o`<00_l400;o1003o`H0
0_l400?o4P0001H00_l800?o3P04o`T00_lJ00[o0`0:o`801_l200Ko100:o`D02_l00`3oo`06o`H0
1Ol300Go0P0<o`030?oo00Co0P06o`<02_l500Wo0`05o`801Ol300So1`04o`@01?l@00Co1@04o`80
1?l300Co1P0:o`030?oo00[o4P07oaL02Ol300co1007o`H03?l200[o1@05o`<01Ol@00005`000ol0
000700Oo2P03o`T000?o00006@0:o`D01Ol00`3oo`0200Ko0P06o`@02_l500[o00<0ool01_l600Go
0`05o`803?l00`3oo`04o`801_l300[o1`05o`D01Ol200Go0`08o`L01?l400Co4004o`D01?l200Co
0`04o`H02_l00`3oo`0:oa801olI00Go00<0o`000P0<o`@01ol600co0P09o`H01Ol300Go400002<0
1Ol:00?oo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(65\\) JCVJJPKTWIR LU MHGJ A WEATBK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lG00Ko2P05o`/00_l900Ko2@06o`H0
2?l600Go1P02o`@02?l600;o1002o`H02_l300Go1P03o`l03Ol600Co5005o`<01Ol200Co0`04o`L0
1_l600Ko5006o`<01_lA00;o1002o`@03?l200Ko0`06o`802?l400[o1@05o`H00_l@00004`02o`/0
1ol600Wo2`02oa@02Ol700Wo2004o`H02Ol600Wo1@08o`H01Ol500?o1008o`H00_l400;o1P0:o`<0
1Ol500Co3`0=o`@02?lB00Go0`05o`801?l300Co1@0:o`802OlC00Ko0`06oa400_l400;o100<o`80
1_l300Ko0P08o`@02ol400Go1@03oa00000C00;o2P02o`@00_l600;o1@02o`/00_lD00?o1003o`D0
0ol500?o1`04o`H00ol400?o1@03o`@00ol600;o3002o`D00ol800;o2003o`@00ol900;o2@02o`D0
0olD00;o1P02o`@00_l400;o4`02o`L00_l400;o1@02o`D01?l500;o0P03o`@00olD00;o1`02oa80
0ol400?o1@02o`H00_l400;o1`02o`L00_l900;o1@03o`D00_l500?o4@0001<00_l900;o1P02o`d0
0_l:00;o5002o`H00_l500;o1`02o`L01?l600;o1P02o`D00_l600;o1P02o``00_l500;o2@02o`P0
1?l300?o2@02o`T00_l500;o5@02o`H00_l300;o1P02oa800_l700;o1002o`D00_l500;o1`02o`80
0_l600;o5002o`L00_lB00Co0`03o`D00_l600;o1002o`L00_l700;o2@02o`H00_l500;o1@02oa80
000C00;o2@02o`H00_l=00;o2P02oa@00_l600;o1003o`l00_l200;o1@02o`H00_l500;o1P02o`H0
0_l<00;o1002o`X00_l800Co0P04o`T00_l900;o1002oaH00_l600;o0`02o`H00_lB00;o0`02o`80
0_l400;o1@02o`@00ol700;o0P02o`H00_lD00_o4P04o`801?l500;o0P02o`800_l400_o1`02o`T0
0_l600;o1@02o`@00_lC00004`02o`T00_l600;o3@02o`X00_lD00;o1P02o`@00_l@00;o0P02o`D0
0_l600;o1@02o`H00_l600Oo1`03o`800ol:00;o2002o`040?l000Co2@02o`T00_l300?o5P02o`H0
0_l300;o1P02oa800_l200?o0P02o`@00_l500;o1002o`@01ol00`3oo`0600;o5@09oa<00_l0103o
0004o`D00_l200;o2@09o`P00_l900;o1P02o`D00ol200?o4`0001<00_l900;o1P02o`d00_l:00;o
7002o`@00_l?00?o0P03o``00_l=00;o1P09o`D01ol;00;o2002o`060?l00?l00_l900;o2@07oaL0
0_l;00;o1P02oa800_l20003o`3o00800_l400;o1@02o`@00_l400Oo2@02oaD00_l500;o4`02o`06
0?l00?l00_l500Ko2@02o`D00_l800;o2@02o`D00ol500Oo500001<00_l900?o1002o`L00_l400;o
2`02oa`00_l400;o3`02o`@00_l<00;o3@02o`H00_l500?o1005o`d00_l800;o00<0ool00_l00`3o
o`0900;o2@09oaD00_l;00;o1P02oa800_l0103oo`02o`030?oo00@02Ol400;o5002oaH00_l300;o
5002o`030?oo00;o00<0ool01@06o`X00_l300;o2@02o`T02Ol600Go5P0001@00_l800Wo1`08o`X0
0_lM00;o1002o`l00_l400;o3002o`d00_l600;o1P02o`@00_l0103oool700;o0`02o`<00_l300;o
00<0ool00_l00`3oo`0900;o2@02o`D00olD00;o2`02o`H00_lB00;o00<0ool00P001?l0ool400Wo
1002oa@00_lF00;o0`02oa@00_l00`3oo`02o`030?oo00D00_l200;o2P02o`<00_l400;o0`02o`<0
0_l400So1`02o`040?oooaD0000D00;o2002o`030?oo00;o2@07o`/00_lM00;o1003o`L00_l400;o
1P02o`/00_l=00;o1P02o`H00_l400;o0P03o`H00_l300;o0`02o`800_l300;o0`02o`P00_l900;o
1P02oa@00_l;00;o1P02oa800_l00`3o00020004o`3oo`@00_l500;o1002o`P00_l:00;o5`02o`04
0?oooa<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool400;o0`02o`<00_l400;o1003o`H0
0_l200?o500001@00ol800;o3@02oa000_lM00;o1@02o`L00_l400;o1P02o`/00_l=00;o1P02o`H0
0_l400;o0`03o`D00_l300;o0`02o`800_l300;o0`02o`P00_l900;o1P02oa@00_l;00;o1P02oa80
1?l300Co1002o`D00_l500;o1P03o`X00_lG00;o00<0ool05002o`<00_l300;o1002o`H00_l700;o
00<0ool01@02o`<00_l300;o1002o`D00_l600;o0`03oa<0000E00;o2003o``00_l?00;o7P02o`D0
0ol500?o0`03o`H00ol:00;o3@02o`H00_l500?o1002o`@00ol400;o0`02o`<00_l200;o2002o`P0
0_l900;o1@03oa@00_l;00;o1P02oa801?l400?o1002o`D00_l500?o1004o`X00_lG00Go5002o`P0
0_l400;o1P02o`L01Ol500;o0`02o`<00_l400;o1003o`H00_l400?o4P0001H00_l800?o2`02o`h0
0_lJ00[o0`0:o`801_l200Ko100:o`D02_l00`3oo`09o`<01Ol300Go0P0<o`030?oo00Co0P06o`<0
2_l300_o4P08o`L01?l400Co4004o`D01?l200Co0`04o`D02_l500[o4@07oa@01_l200Ko00<0ool0
2_l400Oo1P0<o`802_l500Go0`05oa00000G0003o`0000L01ol600So20000ol0000I00[o1@05o`03
0?oo00801_l200Ko100:o`D02_l00`3oo`07o`D01Ol300Go0P0<o`030?oo00Co0P06o`<02_l300Wo
5008o`L01?l400Co4004o`D01?l200Co0`04o`L01Ol00`3oo`0500[o4@07oa@01_l200Ko00<0ool0
2_l400Oo1P0<o`802Ol600Go0`05oa00000S00Go1P08ool0a0000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(66\\) JCUEJLKTZIR LU IDKE A  EAUDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lG00Ko2P05o`/01?l500co1@06o`H0
3Ol00`3oo`03o`H00_l400So1@0:o`D02_l300Go1P03o`l03Ol600Co5@0:o`@02?l600Go1P02o`03
0?oo00[o4006o`<01_lM00co0P06o`<01_l500Co1P08o`H01Ol600;o400001<00_l;00Oo2007o`/0
0_lD00Wo1`09o`L02?l300co0`09o`D03Ol00`3oo`03o`D00ol400So1@0:o`D02_l300Go1@04o`l0
3Ol400So4`0:o`@02_l400Go1@03o`030?oo00[o4006o`<01_lM00co0P06o`<01_l300So100:o`@0
1Ol500?o400001<00_l:00;o1002o`L00_l400;o2`02oa@00ol400?o1@03o`D00ol600;o1002o`D0
0_l600;o0`03o`@00ol700;o1P02o`<00_l500?o2002o`T00_l500;o2@02o`T00_l500?o5002o`H0
0_l400;o1002oaL00_l900;o1004o`D00_l500?o1002o`H00_lB00;o1`02ob400_l600;o1002o`L0
0_l500;o1002o`D00_l400Co1@02o`D00olA00004`02o`T00_l600;o1@02o`H00_l:00;o5002o`H0
0_l500;o1`02o`D00_l600;o1002o`H00_l300;o1P02o`L00_l600;o0`02o`D00_l900;o2@03o`@0
0_l900;o2@02o`D00_lE00;o1P02o`<00_l600;o5P02o`T00_l600;o1@02o`D00_l500;o1P02oa80
0_l700;o8@02o`H00_l400;o1`02o`@00_l600;o1002o`H00_l500;o1@02oa80000C00;o2@02o`H0
0_l500;o1P02o`X00_lD00;o1P02o`@00ol>00;o1P02o`@00_l200;o0P02o`<00_l600;o1`02o`H0
0_l300;o1002o`X00_l:00?o0`02o`T00_l900;o1002oaH00_l600;o0`02o`H00_lF00;o2@02o`L0
0_l400;o1002o`H00_l200;o0P02oa802olQ00;o0P02o`800_l400_o1002o`H00_l400;o1`02o`@0
0_l400;o4`0001<00_l900;o1P02o`D00_l600;o2P02oa@00_l600;o1002o`l00_l600;o1002o`80
0_l700;o1P02o`L00_l600;o0`03o`800ol:00;o2`02o`<00_l900;o2@02o`<00olF00;o1P02o`<0
0_l600;o5P02o`T00_l700;o1003o`800ol600;o0P02oaL02OlR00;o0P02o`T02Ol500;o1P02o`@0
0_l700;o1003o`800olC00004`02o`T00_l600;o1@02o`H00_l:00;o7002o`@00_l?00;o1P02o`@0
1_l?00;o1`02o`/01ol;00;o2`03o`d00_l900Oo5`02o`/00_l600;o5P02o`T00_l700;o1007o`L0
1_lG00;o1@02ob801_l900;o1@02o`D00_l600;o1002o`L00_l400Oo500001<00_l900?o1002o`H0
0ol400;o2`02oa`00_l400;o3`02o`H00_l400Ko3`02o`L00_l;00Go3@02o``00ol<00;o2@09oaD0
0_l;00;o1P02oaH00_l900;o1`02o`@01Ol900Ko6002o`<00_lS00Ko2P02o`<00_l600;o1P02o`@0
0_l700;o1005oaH0000D00;o2009o`H02Ol:00;o7@02o`@00_l?00;o1P02o`@00_l200;o3`02o`L0
0_l;00;o00@0oooo1`02o`<00_l300;o0`02o`<00_l<00;o2@02o`D00olD00;o2`02o`H00_lF00;o
2@02o`L00_l400;o00@0oooo2002o`800_lH00;o0`02ob<00_l200;o2P02o`<00_l600;o1P02o`@0
0_l700;o1002o`040?oooaD0000D00;o2002o`030?oo00;o2002o`030?oo00;o3002oad00_l400?o
1`02o`D00_l600;o1002o`800_l200;o2`02o`L00_l;00;o0P03o`H00_l300;o0`02o`<00_l300?o
2`02o`T00_l600;o5002o`/00_l600;o5P02o`T00_l700;o1002o`800ol700;o0P02o`800_lE00;o
00@0oooo8`02o`800_l200;o1`02o`040?ooo`H00_l600;o1002o`L00_l400;o0P03oa@0000D00?o
2002o`d00_l@00;o7@02o`D00_l700;o1@02o`H00_l400;o1P02o`/00_l700;o2`02o`<00ol500;o
0`02o`<00_l300;o1003o`X00_l900;o1P02oa@00_l;00;o1P02oaH00_l900;o1P02o`D00_l300?o
1P02o`H00_lE00;o00<0ool09002o`H00_l700;o00<0ool01`02o`H00_l400;o1P02o`D00_l300?o
4`0001D00_l800?o3003o`h00_lN00;o1@03o`D00ol500;o1P02o`@00_l600;o2`02o`L00_l;00;o
1003o`@00_l300;o0`02o`<00_l500;o2P02o`T00_l500?o5002o`/00_l600;o5P02o`T00_l400Co
1@02o`@00ol500;o1P02oaD01OlT00;o1P02o`L01Ol700;o1P02o`@00_l400Co1@02o`@00olB0000
5P02o`P00ol<00?o3002oaX02_l300[o1004o`@01?l00`3oo`0:o`H02_l00`3oo`06o`H01Ol300Go
0P0<o`<02_l500[o0`0;oa802?l700Co1004oa402_l400[o1005o`<01Ol00`3oo`0:oa801olS00co
1007o`L01?l400Co0P0:o`@01Ol300Go400001L000?o00001`07o`P01ol70003o`0001T02_l500Go
00<0ool01004o`@01?l00`3oo`0:o`H02_l00`3oo`06o`H01Ol300Go0P0<o`<02_l500[o0`09oa@0
2?l700Co1004oa402_l400So1P05o`<01Ol00`3oo`0:oa801olS00co1007o`L01?l400Co0P08o`H0
1Ol300Go400002<01Ol:00Goo`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(67\\) JDUIJLHTZIR JS IIOE A  IATDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`02o`h00_lG00Ko1`08o`/01?l600[o1P06o`H0
3Ol200Co0`04o`D02?l500[o1@0:o`<01Ol600?o4@06o`L00_l00`3oo`03oaD02_l400[o2005o`D0
3?l@00Ko0`06oah02_l300Ko0`06o`802?l500So1P05o`H00_l@00004`02o`/01ol900;o3`02oa@0
2Ol600[o1`08o`@02_l400Wo1@0=o`801?l300Co1@08o`D02_l500[o0`05o`D01?l?00Wo1P0:oa<0
2_l400[o1P09o`<03?l@00Ko0`06oah02_l300Ko0`06o`802?l500[o1005o`D00ol@00004`02o`X0
0_l400;o2P02o`h00_lD00?o1003o`H00_l400Co1P02o`@00_l800;o2003o`@00ol700;o1P02o`<0
0_l500;o2@02o`T00_l500;o2@02o`T00_l500?o4@03o`@00ol500?o1@03oaH00_l<00;o2@03o`D0
0ol400;o1P02oa800_l700;o9002o`T00_l700;o1`02o`T00_l400Co1@02o`D00olA00004`02o`T0
0_l600;o2@02o`h00_lD00;o1P02o`H00_l600;o1@02o`H00_l700;o2002o`H00_l700;o1P02o`<0
0_l500;o2@02o`T00ol400;o2@02o`T00_l500;o4P02o`H00_l500;o1`02oaH00_l<00;o2@02o`L0
0_l400;o1P02oa800_l700;o9002o`T00_l700;o1`02o`T00_l600;o1@02o`D00_lB00004`02o`T0
0_l600;o2@02o`h00_lD00;o1P02o`H00_l700;o1002o`H00_l700;o2002o`H00_l700;o1P02o`<0
0_l500;o2@02o`X00ol300;o2@02o`T00_l400;o4`02o`H00_l500;o1`02oaH00_l<00;o2002o`T0
0_l300;o0P02o`800_lB00_o9002o`T02ol700;o2@02o`L00_l400;o1002oa<0000C00;o2@02o`H0
0_l:0003o`0000`00_lD00;o1P02o`H00_l700;o1002o`H00_l700;o2002o`H00_l700;o1P02o`<0
0_l500;o2@02o`/00_l300;o2@02o`T00_l300?o4`02o`H00_l=00?o5P02o``00_l800;o2@02o`<0
0_l200;o5`09obD00_l:00Wo2002o`T00_l700;o1003o`800olC00004`02o`T00_l600;o2P02o`d0
0_lL00;o1P02o`L00_l400;o1P02o`L00_l@00;o1`02o`/00_l500;o2@02o`/00ol=00;o2@07oa`0
0_l800Oo5`02o``00_l800;o2@02o`<01_lG00;o1@02obD00_l:00;o1@02o`P00_l900;o1`02o`@0
1olD00004`02o`T00ol400;o2`02o`d00_lL00;o1P02o`L00_l400;o1P02o`L00_l@00;o1`02o`/0
2Ol900;o3003o``00_l900Wo6P02o`H01olI00;o3002o`P00_l900;o0`06oaP00_l300;o9P02o`/0
0_l300;o2@02o`T00_l700;o1005oaH0000D00;o2009o``000?o00002P02oad00_l600;o1`02o`@0
0_l600;o1`02oa000_l700;o2`09o`@00_l300;o0`02o`<00_l300;o3002o`T00_l500?o6@02o`D0
0olN00;o3002o`P00_l900;o0`02o`800_lH00;o0`02obH00_l;00;o0`02o`@00_l300;o0`02o`@0
0_l700;o1002o`040?oooaD0000D00;o2002o`030?oo00;o3P02o`/00_lM00;o1P02o`L00_l400;o
1P02o`L00_l@00;o1`02o`/00_l500;o1002o`<00_l300;o0`02o`<00ol;00;o2@02o`H00_lI00;o
1@02o`L000?o00005@02o``00_l800;o2@02o`<00_l200;o0P02oaD00_l0103ooolV00;o3002o`04
0?ooo`@00_l300;o0`02o`@00_l700;o1002o`800olD00005003o`P00_lB00;o2`02oad00_l600;o
1P02o`D00_l600;o1`02oa000_l700;o2`02o`D00_l400;o0`02o`<00_l300;o1003o`X00_l900;o
1P02oaT00_l500;o1P02oaL00_l<00;o2@02o`L00_l400;o1P02oaD00_l00`3oo`0W00;o3002o`03
0?oo00D00_l300;o0`02o`@00_l600;o1@02o`<00olC00005@02o`P00olB0003o`0000P00_lN00;o
1P02o`@01?l500;o1P02o`L00_l@00;o1`02o`/00_l500;o1002o`<00_l300;o0`02o`D00_l:00;o
2@02o`D00olI00;o1@03o`@00olG00;o3002o`T00ol500?o1002o`H00_lE00Go9`02o``01Ol500;o
0`02o`<00_l400;o1004o`D00_l400?o4P0001H00_l800?o2P02o`D00_l800;o6P0:o`802_l500Co
1004o`802_l700[o00<0ool01_l700Co0`04o`<03?l300[o1@0:o`<02olE00[o0`09oa<02_l400[o
1P09o`<03?lB00Oo900:o`D01ol600co0`0:o`@01Ol300Go400001L000?o00001`07o`D02Ol80003
o`0001T02_l200So1`04o`@01?l200[o1`0:o`030?oo00Ko1`04o`<01?l300co0`0:o`D02_l300Wo
5`0:o`D01Ol00`3o000B00[o100:o`P01Ol500co4P07ob@02_l500Oo1P0<o`<02?l600Go0`05oa00
000S00Go1@09ool0a0000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(68\\) ODUIGLMTYIT JU IIQE D VIATDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool04002o`@00onQ00005@02obP00_oo00l0
2_nP00005002obX00_oo00l01Ol200;oX00001@00_lZ00;oo`0?0003o`000:H0000D00;o2`04o`/0
1?l<00;o6@05o`H02?l;00Co1P0:o`P01_l400go00<0ool00ol300Go1008o`H02?l600[o1@08oaD0
1_l;00Co5@0:o`@02_l800Go1@0<oa802?lI00;o200:o`<01_l300Ko0P08o`D02?l600Go1P02oa00
000C00;o2`07o`L02?l;00;o5P09o`@02_l700So100:o`H02_l200go00<0ool00ol300Go1008o`H0
2?l600[o1@08oa<02Ol800So4`0:o`@02_l600Wo0`0<oa802_lF00Co1`0:o`<01_l300Ko0P08o`D0
2_l400Go1@03oa00000C00;o2P02o`@00_l600?o1003o`X00_lE00?o1@03o`@00_l400Co1P02o`@0
0_l800;o2@04o`D00_l500;o1P02o`800_l700;o2002o``00_l=00;o3002oaH00ol400?o1`02o`@0
0_lG00;o3002o`T00ol500?o1002o`H00_lC00;o1004oaD01?l;00;o2@02o`L00_l700;o2@02o`@0
1?l500;o1@03oa40000C00;o2@02o`H00_l500;o1P02o`X00_lE00;o1`02o`@00_l600;o1@02o`H0
0_l700;o2@02o`L00_l500;o1P02o`800_l700;o2002o``00_l=00;o3002oaH00_l600;o1P02o`H0
0_lF00;o3002o`T00_l700;o1002o`H00_lC00;o1P02oaD01?l;00;o2@02o`L00_l700;o2@02o`H0
0_l500;o1@02oa80000C00;o2@02o`H00_l500;o1P02o`X00_lD00;o2@02o`<00_l700;o1002o`H0
0_l700;o2003o`L00_l500;o1P02o`800_l300;o0P02o`P00_l<00;o3@02o``00_lF00;o1P02o`H0
0_l600;o5P02o``00_l800;o2@02o`<00_l200;o0P02oa<00_l700;o4`02o`800_l:00;o2@0;o`L0
0_l900;o1`02o`@00_l400;o4`0001<00_l900;o1P02o`D00_l600;o2P02oa@00_l900;o0`02o`L0
0_l400;o1P02o`L00_l800;o1007o`@00_l600;o0P02o`800ol200;o2002o``00_l=00;o3002oaH0
0_l600;o1P02o`H00_lF00;o3002o`P00_l900;o0`02o`800_lG00;o1`02oa<00_l200;o2P02o`X0
2Ol800;o2@02o`L00_l400?o0P03oa<0000C00;o2@02o`H00_l600;o1002o`/00_lD00;o2@02o`<0
0_l700;o1002o`H00_l700;o2002o`@01ol400;o2P02o`8000?o0?l00P02o`P00_l<00?o3002o``0
0_lN00;o1P02o`H00_lF00;o3002o`P00_l900;o0`06oaL00_l700;o4P03o`800ol900;o2P02o`D0
0_l800;o2@02o`L00_l400Oo500001<00_l900?o1002o`P01ol;00;o5002o`T00_l300;o1`02o`@0
0_l600;o1`02o`P00_l?00;o2P02o`040?oo00;o00<0ool02002o`/01?l<00;o3002oah00_l600;o
1P02oaH00_l<00;o2002o`T00_l300Ko5`02o`L00_lB00;o1002o`T00_l;00;o0`02o`T00_l900;o
1`02o`@01OlF00005002o`P02Ol800Ko2`02oaD00_l900;o0`02o`L00_l400;o1P02o`L00_l800;o
3`02o`X00_l00`3oo`020004o`3oo`<00_l300;o0`02o`D01_l;00;o1`02o`<00_l300;o6@02o`H0
0_l600;o5P02o``00_l800;o2@02o`<00_l200;o5`02o`L00_lB00;o1002o`T00_l;00;o0`02o`@0
0_l300;o0`02o`@00_l700;o1002o`040?oooaD0000D00;o2002o`030?oo00;o2@02o`@00_l:00;o
5@02o`T00_l300;o1`02o`@00_l600;o1`02o`P00_l800;o1@02o`X00_l00`3o00020004o`3oo`<0
0_l300;o0`02o`D00_l200;o2`02o`L00_l300;o0`02oaT00_l600;o1P02oaH00_l<00;o2003o`P0
0_l300;o0P02o`800_lC00;o1`02oa400_l600;o2002o``00_l0103oool400;o0`02o`<00_l400;o
1`02o`@00_l200?o500001@00ol800;o3002o`H00_l900;o5P02o`L00_l400;o1P02o`D00_l600;o
1`02o`T00_l600?o1@02o`X01?l300Co0`02o`<00_l300;o1003o`<00_l:00;o1`02o`<00_l300;o
6@02o`H00_l600;o5P02o``00_l900;o1`02o`@00_l600;o4`02o`H00_lB00;o1P02o`P00_l<00;o
00<0ool01@02o`<00_l300;o1002o`H00_l500;o0`03oa<0000E00;o2003o`/00_l600;o2002oaL0
0ol500?o1002o`@01?l500;o1P02o`L00_l900?o1004o`D00_l:00Co1003o`<00_l300;o0`02o`@0
0_l400;o2P02o`L00_l300;o0`02oaT00_l600;o1P02oaH00_l<00;o2P02o`D00_l500;o1P02oa<0
0_l400Co4@03o`H00ol700;o3005o`D00_l300;o0`02o`@00_l400Co1@02o`@00olB00005P02o`P0
0ol:00?o1003o`L00_lI00Wo100:o`D01?l400Co0P0:o`H02_l200So1P04o`D01?l200co0P05o`80
1Ol400[o0`0<oa@02_l200Co1004oa402_l400[o1P09o`<03?lB00[o4@06o`801_l200[o1@07o`H0
3?l300[o1005o`<01Ol@00005`000ol0000700Oo1P08o`P000?o00006P05o`H02?l700Co1004o`80
2_l800Go00<0ool00P08o`H01?l500Co0P0<o`801Ol200Go100:o`<03?lD00[o0P04o`@01?lA00[o
100:o`P01Ol500co4P08oa<01_l200Ko0P0:o`D01ol600co0`08o`H01Ol300Go400002<01Ol700Ko
o`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(69\\) KDPIGLMOYIQ JU ILLA D XGATDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`04o`P0
1Ol>00;o5@05o`H00_l200So1P08o`L02_l800Ko100=o`030?oo00?o0`05o`H01Ol700So1P0:o`L0
1OlF00Ko2`04oaD02_l300go0P0Co`<01_l@00So5005o`801Ol600Ko1006o`<01_l200So1@08o`H0
1Ol600;o400001<00_l;00Oo1P07o`d00_lD00Go1@03o`802_l400So1`0:o`H02_l200go00<0ool0
0ol300Go1009o`D02?l600[o1@09oa802Ol800So4`0:o`<03Ol201?o0`06oa002_lB00Go0P05o`@0
2_l200Ko0`06o`802?l500[o1005o`D00ol@00004`02o`X00_l400;o2`03o``00_lF00;o1@03o`@0
0_l400Co1@02o`l00_l900Co1@02o`D00_l600;o0P02o`L00_l400?o1@03o`L00_l=00;o2003o`D0
0olA00?o1003o`L00_l400;o5`02o`X00_l600;o1@02o`H00_l200;o1`02oa<00_l400Co4P03o`@0
0ol400Co1@02o`@00_l700;o1`02o`T00_l400Co1@02o`D00olA00004`02o`T00_l600;o2`03o`/0
0_lF00;o1@02o`D00_l600;o1@02o`l00_l900;o1`02o`D00_l600;o0P02o`L00_l400;o1`02o`L0
0_l=00;o2002o`L00_lA00;o1P02o`H00_l600;o5P02o`X00_l600;o1@02o`H00_l200;o1`02oa<0
0_l600;o4`03o`800ol500;o1`02o`@00_l700;o1`02o`T00_l600;o1@02o`D00_lB00004`02o`T0
0_l600;o3002o`/00_lF00;o1002o`H00_l700;o1002o`l00_l800?o1`02o`D00_l600;o0P02o`<0
0_l200;o0`02o`T00_l600;o3@02o`L00_l900;o4002o`H00_l600;o1P02oaH00_l:00;o1P02o`D0
0_l600;o0P0;oa<00_l700;o4`02o`800_l500?o1`02o`@02ol700;o2@02o`L00_l400;o1002oa<0
000C00;o2@02o`H00_l800Co00<0ool02P02oaH00ol200?o1P02o`L00_l400Oo2P02o`P00_l400Oo
1002o`H00_l200;o0P03o`800_l300;o2@02o`H00_l=00;o1`02o`T00_l@00;o1P02o`H00_l600;o
5P02o`X00_l600;o1@02o`H00_l300Wo5002o`L00_lD00Co1P02o`@01ol400Wo2002o`T00_l700;o
1003o`800olC00004`02o`T00_l600;o1P09o`X00_lF00Oo1`02o`L00_l400Wo2002o`P00_l400Oo
1002o`X00_l20003o`3o00800_l300;o2@02o`H00ol<00;o1`02o`T00_lH00;o1P02o`H00_lF00;o
2P02o`d00_l;00;o1@02oa@00_l700;o5004o`H00_l400Oo1002o`D00_l800;o2@02o`L00_l400Oo
500001<00_l900?o1002o`L00_l400?o2P02oaH01Ol900;o1`02o`@00_l500?o1`02o`P00_l?00;o
2P02o`040?oo00;o00<0ool00`02o`T00_l500Co3002o`L00_l900;o6002o`H00_l600;o5P02o`X0
0_l=00;o3002o`<00_lE00;o1`02oa@00ol700;o4002o`<00_l900;o2@02o`L00_l400Go5P0001@0
0_l800Wo1P02o`H00_l900;o5`02o`040?ooo`P00_l700;o1002o`H00_l700;o2002o`l00_l:00;o
00<0ool00P001?l0ool300;o2@02o`@01_l;00;o1`02o`T00_lH00;o1P02o`H00_lF00;o2P02o`d0
0_l<00;o0`02oaD00_l700;o5004o`H00_l@00;o0`02o`@00_l300;o0`02o`@00_l700;o1002o`04
0?oooaD0000D00;o2002o`030?oo00;o2002o`H00_l900;o5`02o`800ol700;o1`02o`@00_l600;o
1`02o`P00_l800;o1@02o`X00_l00`3o00020004o`3oo`<00_l900;o1002o`800_l;00;o1`03o`P0
0_lH00;o1P02o`H00_lF00;o2P02o`d00_l=00;o00@0oooo5@02o`L00_lC00Ko1@02o`P00_l700;o
00@0oooo1002o`<00_l300;o1002o`L00_l400;o0P03oa@0000D00?o2002o``00_l600;o2@02oaL0
0_l300?o1P02o`H00_l500;o1P02o`L00_l900;o1P03o`D00_l:00Co0`04o`@00_l700;o1003o`<0
0_l:00;o2002o`L00_lI00;o1P02o`H00_lF00;o2P02o`d00_l=00;o00<0ool05P02o`H00_lC00?o
0P03o`D00_l600?o1`02o`030?oo00D00_l300;o0`02o`@00_l600;o1@02o`<00olC00005@02o`P0
0ol;00;o1P000ol0000700;o6002o`@00ol500;o1004o`D00_l500?o1`02o`T00ol400Co1@02o`X0
1?l400?o1003o`D00ol400;o1002o`X00_l900;o1@02oaX00_l600;o1P02oaH00_l:00;o3@02o`d0
1OlF00;o1004oa<00_l400;o1@03o`@01?l700Go1@02o`<00_l300;o1002o`@01?l500;o1003oa80
000F00;o2003o`/00_l400;o2002oaL01Ol300Go0P0:o`@02ol400[o1P0:o`802?l600Co1@04o`@0
2Ol300Go0P05o`@02_l500Wo5@0:o`801?l400Co4@0:o`<02?l700So1`07oaH02_lB00Go0P05o`@0
2_l400Oo1P0<o`<02_l400Go0`05oa00000G0003o`0000L01ol600Oo2@000ol0000F00Go0`05o`80
2?l600Wo1P0:o`P01Ol00`3oo`0200So1P04o`D01?l600Go1@05o`801Ol400[o1`05oaL02_l200Co
1004oa402_l300So1`08o`L01olF00So5005o`801Ol600Go00<0ool01007o`H03?l300So1P05o`<0
1Ol@00008`05o`P01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(70\\) KAPIGLLO IQ JUXMLLA C XGATDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ojX00_l400?oo`0700005@02obP00_nY00[o
o`0600005002obX00_nY00Go0P02ool01P0001@00_lZ00;oZ@000ol0003o00`0000D00;o2`02o`d0
1?l<00;o5@05o`H02?l300Ko00<0ool01_l700[o2006o`@03Ol00`3oo`0;o`H01OlE00[o1`05oaH0
1_l;00Co1P05o`801Ol200Go0`05o`030?oo00_o0P0Co`<01_lC00Go5005o`801Ol600Ko1006o`<0
1_l200So1@08o`H01Ol600;o400001<00_l<00;o3006o``00_lD00Go1@09o`<01_l00`3oo`06o`L0
2_l600[o0P0=o`030?oo00_o1009oa<02_l500Wo4P09o`P02?l400Go0P05o`801Ol300Go00<0ool0
2ol201?o0`06oa402OlB00Go0P05o`@02_l200Ko0`06o`802?l500[o1005o`D00ol@00004`02o`d0
0_l:00?o0P03o`/00_lF00;o1@03o`<00_l700;o1@02o`l00_l900Co1@02o`D00_l600;o1002o`H0
0_l300?o1@03oaH00_l800?o1@03oa400ol400?o1`02o`@00_l500?o1003o`@00_l700;o1@02o`H0
0_l500;o1P02o`800_l700;o4P03o`D00olB00?o1003o`@01?l500;o1002o`L00_l700;o2@02o`@0
1?l500;o1@03oa40000C00;o3@02o`X00_l400;o2`02oaH00_l500;o1002o`L00_l500;o3`02o`T0
0_l700;o1@02o`H00_l400;o1P02o`<00_l700;o5P02o`P00_l700;o4@02o`H00_l600;o1P02o`D0
0ol200?o1@02o`L00_l500;o1P02o`D00_l600;o0P02o`L00_lB00;o1`02oa<00ol200?o1@02o`L0
0_l400;o1`02o`L00_l900;o1P02o`D00_l500;o4P0001<00_l=00;o2@02o`H00_l:00;o5P02o`@0
0_l500_o1@02o`l00_l800?o1`02o`D00_l600;o1002o`H00_l200;o2@02oaD00_l700;o2@02oa00
0_l600;o1P02o`H00_l600;o0P02o`H00_l300;o0P02o`D00_l600;o1@02o`H00_l200_o4@03oad0
0_l200;o1@03o`L00_l400_o1`02o`T00_l700;o1002o`@00_lC00004`02o`h000?o00001`02o`H0
0_l:00;o5P03o`800ol600Wo1P07o`X00_l800;o1007o`@00_l600;o1002o`H00_l200;o2@02oaD0
0_l700;o2@02oa000_l600;o1P02o`H00_l700Co1`02o`800ol200;o1@02o`H00_l500;o1P02o`<0
2OlB00;o7`04o`H00_l400Oo1009o`P00_l900;o1`02o`@00ol200?o4`0001<00_l>00;o2002o`H0
0_l:00;o5P07o`L00_l500;o1P09o`P00_l800;o1007o`@00_l<00;o2P02o`T00_lE00;o1`02o`T0
0_lH00;o1P02o`H00_l700Co1`02o`8000?o0?l00P02o`D00_l=00;o2`02o`D00_lB00;o7`04o`H0
0_l400Oo1002o`D00_l800;o2@02o`L00_l400Oo500001<00_l>00;o2002o`H00_l:00;o5P05o`X0
0_l300;o1`02o`D00ol700;o2002o`l00_l<00;o2P02o`T00_lE00;o1`02o`T00_lH00;o1P02o`H0
0_l700?o2002o`040?oo00;o00<0ool01@02o`d00_l<00;o0`02oa<00_lO00?o1`02oa000_l300;o
2@02o`T00_l700;o1005oaH0000D00;o3P000ol0000600;o1P02o`T00_lG00;o00@0oooo2@02o`<0
0_l700;o1P02o`L00_l800;o3`02o``00_l:00;o2@02oaD00_l700;o2@02oaP00_l600;o1P02o`L0
1?l700;o00<0ool00P001?l0ool500;o3@02o``00_l300;o4`02oal01?l600;o4002o`<00_l400;o
0`02o`<00_l400;o1`02o`@00_l0103ooolE00005002o`h00_l700;o1P02o`T00_lG00;o0P03o`T0
0_l0103oool700;o1P02o`L00_l800;o2002o`D00_l<00;o2P02o`T00_lE00;o1`03o`P00_lH00;o
1P02o`H00_l600Ko1P02o`030?l0008000Co0?oo1@02o`d00_l=00;o00@0oooo4`03o`L00_lD00Ko
1@02o`P00_l700;o00@0oooo1002o`<00_l300;o1002o`L00_l400;o0P03oa@0000D00?o3@02o`L0
0_l600;o2@02oaL00_l300?o2002o`030?oo00P00_l600;o1`02o`T00_l600?o1@02o``00_l;00;o
1`02oaH00_l800;o1`02oaT00_l600;o1P02o`D00ol200?o1@04o`<01?l500;o3@02o`d00_l00`3o
o`0E00;o1`02oa<00ol200?o1@02o`H00ol700;o00<0ool01@02o`<00_l300;o1002o`H00_l500;o
0`03oa<0000E00;o3P000ol0000600;o1002o`T00_lH00;o1003o`L01Ol800;o1@03o`L00_l900?o
1004o`D00_l<00;o2`03o`D00olF00;o2@02o`D00_lJ00;o1P02o`H00_l500;o1002o`D01?l400?o
1@02o`d00_l=00Go5@03o`D00olC00;o1002o`D00ol400Co1`05o`D00_l300;o0`02o`@00_l400Co
1@02o`@00olB00005P02o`H00_l500;o1`03o`800ol800;o5`05o`<01Ol200Oo1`0;o`@02_l600[o
0P08o`H02?l900Wo4`0:o`D02OlE00[o0P04o`@01?l200Go0P05o`801?l500Co00<0ool01_l700So
1`07oaL02_lA00Go0P05o`@02_l400Oo1P0<o`<02_l400Go0`05oa00000G0003o`0000@02Ol800Ko
2@000ol0000F00Go0`05o`801ol700Wo1P0:o`P01Ol00`3oo`0200So1P08o`/01OlE00[o1`05oaL0
2_l200Co1004o`801Ol200Go0P04o`D01?l00`3oo`06o`L02?l700Oo6@05o`030?oo01401Ol200Go
1P05o`030?oo00@01ol600co0`08o`H01Ol300Go400001h02Ol900Coo`360000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(71\\) OAPIGMLRZLV JUWMLLE C XFATDO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o2`09o`T00_lI00Go1006o`<01_l00`3oo`06o`L0
2_l800Ko1005o`<01Ol00`3oo`0;o`801Ol600?o00<0ool02?l400go1P02oaP01_l;00Co2002o`@0
0_l400Go0`05o`030?oo00_o0P0=o`030?oo00[o5@05oa@01Ol200Go0P07o`L01_l300Ko0P08o`D0
2?l:00Go500001<00_l<00;o2`09o`X00_lF00Wo0P06o`<01_l00`3oo`06o`L02_l600[o0P05o`<0
1Ol00`3oo`0;o`801Ol500Co00<0ool02?l400go1@04oaD02Ol800So1P02o`@00_l400Go0`05o`03
0?oo00_o0P0=o`030?oo00[o4`09oa801Ol200Go0P07o`L01_l300Ko0P08o`D02_l600Wo4P0001<0
0_l=00;o3P02o`d00_lE00?o1@03o`<00_l700;o1@02o`l00_l900Co1@02o`<00_l700;o1@02o`H0
0_l400;o1@03o`@00_l500;o1`02o`H00_l500Co5@03o`@00ol700;o1002o`D00ol400?o1002o`L0
0_l500;o1P02o`D00_l600;o0`02o`H00_lB00?o1@03oa800ol400?o1@02o``00_l700;o1`02o`T0
0_l400Co1003o`D00olA00004`02o`d00_l>00;o3@02oaD00_l700;o0`02o`L00_l500;o3`02o`T0
0_l700;o0`02o`L00_l500;o1P02o`@00_l500;o1@03o`@00_l700;o1P02o`D01?lE00;o1P02o`H0
0_l600;o1004o`<00ol400;o1`02o`D00_l600;o1@02o`H00_l300;o1P02oa800_l700;o4`03o`80
0ol600;o3002o`L00_l700;o2@02o`H00_l400;o1`02oa40000C00;o3@02o`h00_l=00;o5002o`T0
0_l200_o1@02o`l00_l800?o1`02o`<00_l300;o0P02o`D00_l600;o1002o`@00_l700?o0`02o`L0
0_l600;o1002o`800_lD00;o1P02o`H00_l600;o1004o`801?l400;o0`02o`800_l500;o1P02o`D0
0_l600;o0`02o`800_l200;o4@03oad00_l200;o1`02o`800_l800_o1`02o`T00_l700;o0P02o`T0
0_l@00004`02o`h000?o00003002o`d00_lD00;o2@02o`<02Ol600Oo2P02o`P00_l400Oo0P02o`80
0ol200;o1@02o`H00_l400;o0`03o`P00_l300;o1`02o`H00_l400;o0P02oa@00_l600;o1P02o`H0
0_l400;o00@0o`001?l400;o0P03o`800_l500;o1P02o`D00_l600;o0`02o`800_lE00;o7`04o`P0
0_l200;o2@09o`P00_l900;o1`02o`800_l900;o400001<00_l>00;o3@02o`d00_lD00;o2@02o`<0
0_l500;o1P09o`P00_l800;o1007o`800_l20003o`3o00800_l500;o3007o`T00ol;00;o2`03o`80
0olK00;o1P02o`H00_l400;o00H0o`00o`02o`@00_l20003o`3o00800_l500;o3@02o`/01_lE00;o
7`04o`P01_l900;o1@02o`P00_l900;o1`02o`800_l900;o400001<00_l>00;o3@02o`d00_lD00;o
2@02o`@00_l300;o1`02o`D00ol700;o2002o`d00_l0103oo`02o`030?oo00D00_l<00Wo2003o`X0
0_l;00;o1002oa/00_l600;o1P02o`@00_l00`3oo`02o`030?oo00@00_l0103oo`02o`030?oo00D0
0_l=00;o2`06oaD00_lO00?o2@06o`X00_l300;o2@02o`T00_l700;o0P02o`T00_l@00005002o`h0
00?o00002`02o``00_lE00;o2@02o`@00_l300;o1`02o`H00_l700;o2002o`d00_l00`3oo`020004
o`3oo`D00_l<00;o1@03o`<00_l300;o2P02o`/00_l400;o6`02o`H00_l600;o1002o`030?oo00;o
00<0ool01002o`030?oo008000Co0?oo1@02o`d00_l;00;o0P02oaD00_lO00Co2002o`800_l:00;o
0`02o`@00_l300;o0`02o`@00_l700;o0P02o`T00_l@00005002o`h00_l<00;o3002oaD00_l900;o
1@02o`040?ooo`L00_l600;o1`02o`P00_l800;o0`02o`030?l0008000Co0?oo1@02o``00_l600;o
0`02o`<00ol900;o2P02o`H00_lJ00;o1P02o`H00_l300;o0`02o`<00_l300;o00<0o`000P001?l0
ool500;o3@02o`/00_l200;o0P02oa400ol700;o5006o`L00_l200;o0P02o`L00_l0103oool400;o
0`02o`<00_l400;o1`02o`800_l900;o400001@00ol=00;o3002o``00_lF00;o1`02o`H00_l00`3o
o`0800;o1P02o`L00_l900;o1P03o`<01?l300Co1@02o``00_l600;o0`02o`@00ol800;o2P02o`H0
0_lJ00;o1P02o`H00_l300;o0`02o`<00_l300Co0`04o`D00_l=00;o2`02o`H00_lB00;o1`02oa<0
0ol200?o1P02o`H00_l700;o00<0ool01@02o`<00_l300;o1002o`H00_l400;o1`02oa40000E00;o
3P000ol0000:00;o2`02oaL00ol500?o1P05o`P00_l500?o1`02o`T00ol400Co0`04o`@00ol500;o
3002o`D00ol300;o1@02o`P00_l900?o1P03oaT00_l600;o1P02o`<00_l800;o0`04o`@00ol500;o
3@02o`/00_l600;o4P03o`D00olC00;o1002o`H00_l600;o1`05o`D00_l300;o0`02o`@00_l400Co
1003o`D00olA00005P02o`H00_l500;o1`03o`030?oo00X00_lI00Wo1007o`L02ol400[o1P0:o`80
1?l500Co00<0ool01_l700_o100:o`@02?l500Ko0P06oa<02_l200Co1004o`030?oo00Co0P06o`03
0?oo00;o1@04o`030?oo00Ko1`08o`H03?lC00[o4@05o`801Ol200co1007o`H03?l300[o1P09oa80
000G0003o`0000@02Ol700Ko2P000ol0000J00Go1P07o`L02Ol600[o2005o`030?oo00801?l500Co
00<0ool01_l700Wo1P0:o`@02?l500Ko0P06oa<02_l200Co1004o`030?oo00Co0P06o`030?oo00;o
1@04o`030?oo00Ko1`08o`H03?lE00Go00<0ool04@05o`801Ol200co1007o`H03?l300So2P05oa@0
000N00Wo2P03ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(72\\) ODPEIMLV JV LUWNLLE C YBAQEJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o2`02o`X0
2_l900;o6@05o`H02?l600So1P0<o`@02_l300Go0`05o`030?oo00_o1`02oaP01_l;00;o5P0=o`H0
1?l800;o1002o`D01_l300;o0P0=o`803Ol00`3oo`0:oaD01OlF00So100:o`@01_l300Ko1005o`D0
3?l500Ko5@0001<00_l<00;o2P0:o`X00_lF00Wo100:o`@02?l600co100:o`<01Ol300Go00<0ool0
2ol600Co5@09o`T01?lE00go1008o`H00_l400;o1@06o`800ol200go0P0=o`030?oo00[o4`09oa@0
2?l400_o0`06o`<01_l200Wo0`0<o`<02OlD00004`02o`d00_l:00;o1@02o`X00_lE00?o1@03o`@0
0_l400Co1@02o``00_l600;o2002o`P00_l700;o1@02o`H00_l600Co5@03o`@00ol800Co6002o`H0
0_l400;o1002o`D00ol400?o1@02o`@01?l500;o1P02o`D00_l600;o0`02o`H00_lB00?o1@03oaH0
0_l900;o1@03o`@00_l700;o0`03o`D00ol400;o1P02o`<00ol400?o4`0001<00_l=00;o2`03o`l0
0_lE00;o1`02o`@00_l600;o1@02o``00_l600;o2002o`P00_l700;o1@02o`H00_l600Co5@02o`H0
0_l800Co6002o`H00_l300;o1P02o`@01?l300?o1@02o`@01?l500;o1P02o`D00_l600;o0`02o`H0
0_lB00;o1`02oaH00_l900;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`<00_l600;o4`0001<0
0_l=00;o3003o`h00_lD00;o2@02o`<00_l700;o1002o``00_l200;o0P02o`P00_l800;o0`02o`80
0_l500;o1P02o`D00_l200;o5002o`H00_l700;o0P02oaL00_l600;o0`02o`H00_l400Co0P04o`D0
0_l300Go1@02o`H00_l500;o1P02o`<00_l200;o0P02oa400olO00;o2@02o`H00_l400_o0P02o`T0
0_l300;o0P02o`800_l300;o1P02oa<0000C00;o3P000ol0000;00?o3@02oa@00_l900;o0`02o`L0
0_l400Oo1`02o`800_l<00;o2002o`800ol200;o1@02o`H00_l500;o0P02oa@00_l600;o1`02o`80
0_lG00;o1P02o`<00_l600;o1002o`040?l000Co1@02o`<00_l00`3oo`0500;o1P02o`D00_l600;o
0`02o`800_lE00;o8002o`T00_l600;o1@09o`<00_l900;o0`02o`800_l700;o1P02oa<0000C00;o
3P02o`d00ol<00;o5002o`T00_l300;o1`02o`@02Ol500Ko3002o`P00_l20003o`3o00800_l500;o
3003o`800olK00;o1P03o`800olF00;o2`02o`H00_l400;o00H0o`00o`02o`D00_l200?o00<0ool0
1@02o`d00_l;00Ko5@02ob000ol800;o1@03o`D00_l500;o0`02o`T00_l300Ko3`02oa<0000C00;o
3P02o`h00ol;00;o5002o`T00_l300;o1`02o`@00_l500?o1006o``00_l800;o00@0ool00_l00`3o
o`0500;o3002o`@00_lK00;o1P02o`@00_lF00;o2`02o`H00_l400;o00<0ool00_l00`3oo`0500;o
0P02o`800_l500;o3@02o`/01_lE00;o7`04o`P02Ol700;o0`02o`@00_l900;o0`06o`l00_lC0000
5002o`h000?o00003@02o`X00_lE00;o2@02o`<00_l700;o1002o`H00_l400;o0P02o``00_l800;o
00<0ool00P001?l0ool500;o3002o`@00_lK00;o1P02o`@00_lF00;o2`02o`H00_l400;o00<0ool0
0_l00`3oo`0500;o00<0ool00`02o`D00_l=00;o2`02o`800_lE00;o7P06o`L02?l800;o0`02o`@0
0_l900;o0`02o`800_l?00;o4`0001@00_l>00;o3`02o`T00_lE00;o2@02o`<00_l700;o1002o`H0
0_l400;o0P02o`800_l800;o2002o`030?l0008000Co0?oo1@02o`/00_l600;o6P02o`D00_l600;o
5@02o`/00_l600;o0`02o`<00_l300;o1005o`<00_l500;o3@02o`/00_l200;o0P02oa400ol700;o
5002o`800_l700;o1003o`P00_l0103oool400?o2002o`<00_l200;o0P02o`/00_lC00005003o`d0
0_l?00;o2@02oaH00_l700;o1002o`H00_l500;o1P02o`@00_l600;o2002o`P01?l300Co1@02o`/0
0_l600;o6P02o`D00_l600;o5@02o`/00_l600;o0`02o`<00_l300;o1004o`@00_l500;o3@02o`/0
0_l600;o4P02o`L00_lC00?o0`02o`H00_l500;o2002o`030?oo00H00_l700;o1002o`H00_l;00;o
4`0001D00_l>0003o`0000H00_l500;o2002oaL00ol500?o1002o`@01?l500;o1@03o`@00_l600;o
2002o`P01?l400?o1@02o`X00ol600?o6@02o`@00ol600?o5002o`/00_l600;o0`02o`P00_l400Co
1002o`D00_l=00;o2`02o`H00_lB00?o1@03oa<00_l400;o1P02o`@00ol800Go1`02o`D00_l500;o
1P02o`/00_lC00005P02o`H00_l500;o1`03o`<00ol700;o6@09o`@02_l400_o0`0<o`@02_l300Co
1@04o`030?oo00Ko1P06o`801_lC013o0P06oa002?l700Co1004o`030?oo00Co0P06o`801?l200Ko
00<0ool01_l700So1P0<oa<02_lA00Go0P05o`802_l600Oo2009o`<03?l600[o400001L000?o0000
1009o`P01ol80003o`0001X01Ol600So1P09o`D03?l400[o0`04o`D01?l00`3oo`06o`H01_l200Ko
4`0@o`801_l@00So1`04o`@01?l00`3oo`04o`801_l200?o0`06o`030?oo00Ko1`08o`H03?lE00Go
00<0ool04@05o`801Ol200Wo1`07o`X01Ol500co1P0:oa00000N00Wo2@05ool0a@000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(73\\) ODNEIMLV JV LUWNILE C YBASEK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3005o``00_lI00Go1P08o`L01_l300;o0P0<o`@0
2_l300Go0`05o`030?oo00_o1`02oaP01_l;00;o5P0=o`H01?l800;o1002o`D01_l300;o0`0:o`@0
3Ol00`3oo`0:oaD01OlF00So100:o`@01_l300Ko00@0ool01Ol500co0`05o`H00_l@00004`02o``0
0_l:00Wo2`02oaH02Ol400[o1@06o`800ol200co100:o`<01Ol300Go00<0ool02ol600Co5@09o`T0
1?lE00go1008o`H00_l400;o1@06o`800ol300[o100=o`030?oo00[o4`09oa@02?l400_o0`06o`<0
1_l00`3oo`08o`<03?l300Go1@03oa00000C00;o3@02o`T00_l500;o2`02oaD00ol500?o1002o`@0
1?l500;o1004o`@00_l600;o2002o`P00_l700;o1@02o`H00_l600Co5@03o`@00ol800Co6002o`H0
0_l400;o1002o`D00ol400?o1@02o`@01?l700;o2`02o`H00_l300;o1P02oa800ol500?o5P02o`T0
0_l500?o1002o`L00_l300?o1@03o`@00_l600;o1@02o`D00olA00004`02o`d00_lA00;o2P02oaD0
0_l700;o1002o`H00_l500;o1004o`@00_l600;o2002o`P00_l700;o1@02o`H00_l600Co5@02o`H0
0_l800Co6002o`H00_l300;o1P02o`@01?l300?o1@02o`@01?l700;o2`02o`H00_l300;o1P02oa80
0_l700;o5P02o`T00_l600;o1002o`L00_l300;o1`02o`@00_l600;o1@02o`D00_lB00004`02o`d0
0_lA00;o2P02oa@00_l900;o0`02o`L00_l400;o0`05o`@00_l200;o0P02o`P00_l800;o0`02o`80
0_l500;o1P02o`D00_l200;o5002o`H00_l700;o0P02oaL00_l600;o0`02o`H00_l400Co0P04o`D0
0_l300Go1`02o`/00_l600;o0`02o`800_l200;o4@03oal00_l900;o1P02o`@02ol300;o1`02o`@0
0_l200;o0P02o`D00_l400;o4`0001<00_l>0003o`0000l00_l:00;o5002o`T00_l300;o1`02o`@0
0_l300;o00<0ool01002o`800_l<00;o2002o`800ol200;o1@02o`H00_l500;o0P02oa@00_l600;o
1`02o`800_lG00;o1P02o`<00_l600;o1002o`040?l000Co1@02o`<00_l00`3oo`0700;o2`02o`H0
0_l300;o0P02oaD00_lP00;o2@02o`H00_l500Wo3003o`@00_l200;o2@03o`800olC00004`02o`h0
0_l?00;o2`02oa@00_l900;o0`02o`L00_l400;o0P03o`030?oo00@01_l<00;o2002o`8000?o0?l0
0P02o`D00_l<00?o0P03oa/00_l600?o0P03oaH00_l;00;o1P02o`@00_l01P3o003o00;o1@02o`80
0ol00`3oo`0700;o2`02o`/01_lE00;o8003o`P00_l500?o1@02o`D00_l700Oo1@06o`T01olD0000
4`02o`h00_l<00Co3002oa@00_l900;o0`02o`L00_l400;o0P02o`800_l400Ko3002o`P00_l0103o
o`02o`030?oo00D00_l<00;o1002oa/00_l600;o1002oaH00_l;00;o1P02o`@00_l00`3oo`02o`03
0?oo00D00_l200;o0P02o`L00_l;00;o2`06oaD00_lO00Co2009o`L00_l300;o1P07o`L01_l900Go
5P0001@00_l>0003o`0000X00ol<00;o5@02o`T00_l300;o1`02o`@00_l00`3oo`0300;o1002o`80
0_l<00;o2002o`030?oo008000Co0?oo1@02o``00_l400;o6`02o`H00_l400;o5P02o`/00_l600;o
1002o`030?oo00;o00<0ool01@02o`030?oo00<00_l700;o2`02o`/00_l200;o5@02oah01_l700So
2002o`<00_l500?o3002o`800_l900;o00@0oooo5@0001@00_l>00;o3@02o`/00_lE00;o2@02o`<0
0_l700;o1005o`<00_l400;o0P02o`800_l800;o2002o`030?l0008000Co0?oo1@02o`/00_l600;o
6P02o`D00_l600;o5@02o`/00_l600;o0`02o`<00_l300;o1005o`<00_l700;o2`02o`/00_l200;o
0P02oa400ol700;o5002o`800_l700;o1003o`P00_l0103oool500;o1`000ol0000300;o0P02o`80
0_l500;o0P03oa@0000D00?o3@02o`h00_l:00;o5P02o`L00_l400;o1P02o`D01?l400;o1002o`H0
0_l800;o2004o`<01?l500;o2`02o`H00_lJ00;o1@02o`H00_lE00;o2`02o`H00_l300;o0`02o`<0
0_l400Co1002o`L00_l;00;o2`02o`H00_lB00;o1`02oa<00ol300;o1P02o`D00_l800;o00<0ool0
1P02o`H00_l500;o1P02o`D00_l300?o4`0001D00_l>0003o`0000`00_l900;o5`03o`D00ol400;o
1004o`D01?l400;o1002o`H00_l800;o2004o`@00ol500;o2P03o`H00olI00;o1003o`H00olD00;o
2`02o`H00_l300;o2002o`@01?l400;o1`02o`/00_l;00;o1P02oa800ol500?o4`02o`@00_l600;o
1003o`P01Ol600?o1003o`D00_l600;o1@02o`@00olB00005P02o`H00_l500;o1`02o`<00ol800;o
6@09o`@02_l500Co0P06o`030?oo00[o100:o`<01?l500Co00<0ool01_l600Ko0P06oa<04?l200Ko
4008o`L01?l400Co00<0ool01?l200Ko0P04o`801_l200[o1008o`H03?lC00[o4@05o`801Ol200[o
1P07o`P02Ol300co0`05o`<01Ol@00005`000ol0000400Wo1`07o`T000?o00006P05o`H02?l700?o
0`06o`030?oo00[o100:o`<01?l500Co00<0ool01_l600Ko0P06oa<04?l200Ko4008o`L01?l400Co
00<0ool01?l200Ko0P03o`<01_l200[o1008o`H03?lE00Go00<0ool04@05o`801Ol200Wo1`07o`X0
1Ol00`3o000200co0`05o`<01Ol@00007P09o`T01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(74\\) OIREGMLV JVYNUZNILE C YAASCK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3P06o`T00_lI00Go1P0:o`@01Ol600oo1`06o`@0
1Ol300Go00<0ool02ol700;o6006o`/00_l900So1P06o`<00_l700Co1`0:o`@01_l300;o0`0:o`@0
3Ol00`3oo`0:oaD01OlF00So0`06o`<03?l300Ko00@0ool01Ol900Go1P05o`H00_l@00004`02o``0
0_l>00Ko2P02oaH02Ol400[o1005o`D04?l500[o0P05o`<01Ol00`3oo`0;o`H01?lE00Wo2@04o`P0
2?l600Ko0P03o`D02?l500[o1006o`800ol300[o100=o`030?oo00[o4`09oa@02?l300Ko0`0<o`<0
1_l00`3oo`08o`D02Ol400Go1@03oa00000C00;o3@02o`l00_l<00;o5@03o`D00ol700;o2P02o`D0
0ol400;o1P02o`@01?l500;o0`02o`L00_l500;o1P02o`H01?lE00?o1003o`P01?l;00;o2P02o`@0
1?l500;o1002o`H00_l500;o1@02o`@01?l700;o2`02o`H00_l300;o1P02oa800ol500?o5P02o`P0
0_l700;o1002o`L00_l300?o1@03o`<00ol500?o1@02o`D00olA00004`02o`d00_l?00;o3002oaD0
0_l700;o1`02o`X00_l500;o1@02o`H00_l400;o1`02o`<00_l700;o1@02o`H00_l600Co5@02o`H0
0_l800Co2`02o`X00_l400Co1002o`H00_l500?o1002o`D00_l400Co1`02o`/00_l600;o0`02o`H0
0_lB00;o1`02oaH00_l800;o1`02o`@00_l700;o0`02o`L00_l300;o1`02o`D00_l500;o4P0001<0
0_l=00;o2@0:o`X00_lD00;o2@02o`H00_l:00;o1002o`H00_l200;o0P02o`<00ol700;o0`02o`<0
0_l200;o1@02o`H00_l500;o0P02oa@00_l600;o1`02o`800_l:00;o2P02o`<01Ol400;o1P02o`H0
0ol300;o1@02o`<01Ol700;o2`02o`H00_l300;o0P02o`800_lA00?o7`02o`P02ol400_o0`02o`L0
0_l200?o3P02o`@00_lC00004`02o`h000?o00001`0:o`X00_lD00;o2@02o`H00_l:00;o0`03o`H0
0_l200;o1`02o`@01ol200;o0P03o`800_l500;o1P02o`D00_l200;o5002o`H00_l700;o0P02o`X0
0_l:00;o0`02o`030?oo00@00_l600;o1`02o`<00_l500;o0`02o`030?oo00L00_l;00;o1P02o`<0
0_l200;o5@02ob000_l900Wo1P09o``00ol200;o3`03o`800olC00004`02o`h00_l800;o1002o``0
0_lD00;o2@02o`H00_l:00Oo1`06o`L00_l400Oo0P02o`8000?o0?l00P02o`D00_l<00?o0P03oa/0
0_l600?o0P03o`T00ol900;o0P03o`030?oo00@00_l600;o1`03o`T00_l200?o00<0ool01`02o`/0
0_l;00Ko5@02ob000ol800;o1@02o`H00_l500;o1`07o`<00_l?00Oo500001<00_l>00;o2@02o`<0
0_l<00;o5002o`T00_l600;o2P09o`D01_l700;o3@02o`040?oo00;o00<0ool01@02o``00_l400;o
6`02o`H00_l400;o2004o`T00_l200;o0P02o`@00_l600;o2003o`P00_l200;o0P02o`L00_l;00;o
2`06oaD00_lO00Co2@02o`<00_l800;o0`02o`H01ol500;o3`05oaH0000D00;o3P000ol000080004
o`0000;o2`02oaD00_l900;o1P02o`X00_l500?o1002o`800_l700;o3@02o`030?oo008000Co0?oo
1@02o``00_l400;o6`02o`H00_l400;o1`06o`P00_l00`3oo`0300;o1002o`H00_l400;o0`02o`P0
0_l00`3oo`0300;o1`02o`/00_l;00;o0P02oaD00_lN00Ko2002o`<00_l800;o0`02o`D00ol:00;o
3`02o`040?oooaD0000D00;o3P02o`T00_l200;o2`02oaD00_l900;o1P02o`X00_l600;o1002o`80
0_l200;o0`02o`P00_l300;o00<0o`000P001?l0ool500;o2`02o`H00_lJ00;o1@02o`H00_l600;o
0P02o`P01Ol300;o1002o`H00_l400;o0`03o`L01Ol300;o1`02o`/00_l;00;o0P02o`800_lA00?o
1`02oa@00_l200;o2@02o`040?ooo`T00_l0103oool500;o1`001?l00003o`L00_l500;o0P03oa@0
000D00?o3@02o`X000?o00000_l;00;o5P02o`L00_l700;o2P02o`H00_l400;o1P02o`@00_l600?o
0`04o`<01?l500;o2`02o`H00_lJ00;o1@02o`H00_l500?o0`02o`L01?l400;o1002o`H00_l400;o
1003o`H01?l400;o1`02o`/00_l;00;o1P02oa800_l700;o4`03o`<00_l800;o00<0ool02P02o`03
0?oo00H00_l600;o1002o`L00_l500;o0`03oa<0000E00;o3P000ol000090004o`3oo`X00_lG00?o
1@03o`L00_l:00;o1@03o`@00_l600;o1003o`@01?l300Co1003o`D00_l:00?o1P03oaT00_l400?o
1P03o`@00_l400;o1`04o`@00_l400;o1P02o`@00_l500;o1P04o`@00_l700;o2`02o`/00_l600;o
4P03o`D00olC00;o1002o`P01Ol:00Go1P03o`@00ol400?o1@03o`D00_l400?o4P0001H00_l600;o
1@02o`X01?l900;o6@09o`@02_l400_o0`0<o`D02_l200Co1@04o`030?oo00Ko1P06o`801_lC013o
0P06o`030?oo00?o0P05o`@01?l200Ko0P04o`@01?l300[o1004o`801_l200[o1008o`H03?lC00[o
4@05o`801Ol300Oo2007o`P02Ol500[o0`05o`<01Ol@00005`000ol0000400Wo2`03o`T000?o0000
6P05o`H02_l400Wo1@0<o`L01Ol00`3oo`0200Co1@04o`030?oo00Ko1P06o`801_lC013o0P06o`03
0?oo00?o0P05o`@00ol300Ko0P04o`@01?l300[o1003o`<01_l200[o1008o`H03?lE00Go00<0ool0
4@05o`801Ol300Oo2007o`X01Ol00`3o000600Go00<0ool00`05o`<01Ol@00007P09o`/00ooo0<D0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(75\\) OIRJGMLV JVZNQ NILEWC YEAUAK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02omD00_l400?of`0001D00_lX00;oe00:omX0
000D00;o:P02om@01Ol200;ofP0001@00_lZ00;oe0000ol0003P00005002o`/00_l<00Go3002oaT0
1Ol600[o1005o`H00ol200Ko2`06o`@01Ol300Go00<0ool02ol700;o6006o`/00_l800[o1@06o`<0
0_l600Go5@06o`<00_l300[o100=o`030?oo00[o1@02o`@00_l800Go5P08o`@03?l200Ko0`06o`D0
1?l400Ko0`06o`030?oo00?o1P02oa00000C00;o3002o`X02Ol;00;o5P09o`@02_l400Go1@0=o`P0
2_l200Go0`05o`030?oo00_o1P04oaD02Ol900Co1`0:o`D01_l200?o1009oa<01_l200?o0`0:o`@0
3Ol00`3oo`0:o`D00_l400;o1P09oa@02?l400co0P06o`<01_l300So0P06o`<01_l00`3oo`03o`D0
0ol@00004`02o`d00_l900;o1@02o`/00_lE00?o1@03o`L00_l:00;o1@03o`800ol400?o1P04o`D0
0_l300;o1`02o`D00_l600;o1P04oaD00ol400?o2004o`P00_l500;o1P02o`@01?l300?o1@03oa<0
0_l400Co1`02o`/00_l600;o0`02o`H00_l400?o1003o`@00ol500?o5P02o`T00_l600;o1002o`L0
0_l500;o1002o`@00_l700;o1@02o`D00olA00004`02o`d00_lA00;o2P02oaD00_l700;o1`02o`X0
0_l500;o0`02o`H00_l600;o1`02o`<00_l700;o1@02o`H00_l600Co5@02o`H00_l800Co2003o`@0
0_l600;o1004o`<00_l700;o4`02o`@01?l700;o2`02o`H00_l300;o1P02o`@01?l300?o1002o`L0
0_lF00;o2@02o`H00_l400;o1`02o`@00_l600;o0`02o`L00_l500;o1@02oa80000C00;o3@02oa40
0_l:00;o5002o`T00_l600;o2P02o`@00_l400;o1P02o`D00ol700;o0`02o`<00_l200;o1@02o`H0
0_l500;o0P02oa@00_l600;o1`02o`800_l800?o0`02o`H00_l300Go0P02o`T00_lB00;o0`05o`L0
0_l;00;o1P02o`<00_l200;o0P02o`@01?l200Co0`03oal00_l900;o0P02o`800_l400_o1002o`H0
0_l300_o1@02o`@00_lC00004`02o`h000?o00003`02o`X00_lD00;o2@02o`H00_l:00;o0`03o`@0
0_l600;o1@02o`@01ol200;o0P03o`800_l500;o1P02o`D00_l200;o5002o`H00_l700;o0P02o`T0
0_l300;o1P02o`<00_l00`3oo`0200;o2@02oa800_l300;o00<0ool01`02o`/00_l600;o0`02o`80
0_l800;o00@0o`001?l300;o8002o`T00_l200;o2@09o`D00_l600;o1009o`H00ol200?o4`0001<0
0_l>00;o4002o`X00_lD00;o2@02o`H00_l:00Oo3@02o`D00_l400Oo0P02o`8000?o0?l00P02o`D0
0_l<00?o0P03oa/00_l600?o0P03o`P00ol:00;o0P03o`030?oo00800_l900;o4P02o`800ol00`3o
o`0700;o2`02o`/01_l800;o00H0o`00o`02o`<00_lP00?o2006o`T00_l500;o1@02o`H00_l400;o
1@02o`H01olD00004`02o`h00_l900;o1002o`/00_lD00;o2@02o`H00_l:00Wo2`02o`D00_l=00;o
00@0ool00_l00`3oo`0500;o3002o`@00_lK00;o1P02o`@00_l900?o2@02o`800_l200;o0P02o`T0
0_lB00;o0P02o`800_l700;o2`02o`/01_l800;o00<0ool00_l00`3oo`0300;o7`04o`P01_l:00;o
0`02o`H00_l600;o1@02o`<00_l700Go5P0001@00_l>0003o`0000L02?l:00;o5@02o`T00_l600;o
2P02o`D00ol:00;o1@02o`d00_l00`3oo`020004o`3oo`D00_l<00;o1002oa/00_l600;o1002o`D0
0_l300;o2@02o`030?oo00<00_l200;o2@02oa800_l00`3oo`0300;o1`02o`/00_l;00;o0P02o`P0
0_l00`3oo`02o`030?oo00<00_lN00Ko1`02o`800_l:00;o0`02o`H00_l600;o1@02o`<00_l700;o
00@0oooo5@0001@00_l>00;o2007o`/00_lE00;o2@02o`H00_l:00;o1P02o`X00_l500;o2002o`<0
0_l00`3o00020004o`3oo`D00_l;00;o1P02oaX00_l500;o1P02o`@00_l300?o2005o`<00_l200?o
2002oa801Ol300;o1`02o`/00_l;00;o0P02o`800_l300;o0`02o`<00_l200?o1`02oa@00_l200;o
1`02o`800_l200;o1`02o`040?ooo`H00_l600;o1P02o`040?ooo`L00_l200?o500001@00ol=00;o
2002oa000_lF00;o1`02o`L00_l:00;o1P02o`X00_l600;o1P03o`<01?l300Co1@02o`/00_l600;o
6P02o`D00_l600;o1002o`@00ol700Co1002o`<00_l700;o4`04o`@00_l700;o2`02o`/00_l600;o
0`02o`<00_l300;o0`02o`L00_lC00?o0`02o`H00_l600;o1`02o`030?oo00L00_l600;o1P02o`03
0?oo00P00_l300?o4`0001D00_l>0003o`0000H00_l?00;o5`03o`D00ol700;o2P02o`D00ol:00;o
1P03o`@01?l300Co1003o`D00_l:00?o1P03oaT00_l400?o1P03o`<00_l500;o1`04o`@00_l400;o
1@02oa@01?l400;o1`02o`/00_l;00;o1P02o`<00_l800;o0`03o`D00olC00;o1002o`H00_l600;o
1`05o`L00_l600;o1P05o`P00_l400?o4P0001H00_l600;o1@02o`L00_l>00;o6@09o`@02_l400_o
1P0:o`@02_l200Co1@04o`030?oo00Ko1P06o`801_lC013o0P06o`802_l500Co0P06o`<02OlC00Co
0P06o`802_l400So1P0<o`801_l200Ko0`0:oa401Ol200Go0P0<o`@01ol700Co1004o`801ol700Go
0`05oa00000G0003o`0000@02Ol700So20000ol0000J00Go1P0:o`@02Ol800[o1P05o`030?oo0080
1?l500Co00<0ool01_l600Ko0P06oa<04?l200Ko0P0:o`D00ol300Ko1@05oaD00ol300Ko0P0:o`@0
2?l600co0P06o`801_l500Go00<0ool04@05o`801Ol200co1007o`L01?l400Co0P07o`L01Ol300Go
400001h02Ol700Soo`340000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(76\\) OIRHGMLV IV NVYNILFWC YGAUAJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@04o``00_lI00Go1P0:o`@01Ol600?o00<0ool0
0_l300Co1`06o`@01Ol300Go00<0ool02ol700;o5`0:o`P00_lG00Ko0`02o`L00_l:00So1@06o`<0
0_l300[o100=o`030?oo00Go2P02o`@00_l800Go5P08o`P01_l400Ko0`06o`D01?l400Ko0`06o`<0
1_lE00004`02o``00_l<00Oo2`02oaH02Ol400[o1005o`D01?l00`3oo`02o`<01?l500[o0P05o`<0
1Ol00`3oo`0;o`H01?lF00[o1`04oaH01_l200?o1P04o`T02?l500Ko0P03o`<02_l400go00<0ool0
1Ol:00;o1002o`H02OlD00So1P0:o`801_l300Ko0`08o`801_l300Ko00<0ool01olD00004`02o`d0
0_l:00;o1002o`/00_lE00?o1@03o`L00_l:00;o1@03o`@00_l500;o1@04o`D00_l300;o1`02o`D0
0_l600;o1P04oaX00_l;00Co5`02o`@01?l600Co3002o`T00_l400Co1`02o`/00_l600;o0`02o``0
0ol400?o1003o`D00olF00;o2004o`D00_l400;o1`02o`D00_l400;o1002o`L00_l300?o1003oa<0
000C00;o3@02o`T00_l600;o2P02oaD00_l700;o1`02o`X00_l500;o1@02o`D00_l500;o1`02o`<0
0_l700;o1@02o`H00_l600Co6P02o`/01?lG00;o1004o`H01?l<00;o2@02o`@01?l700;o2`02o`H0
0_l300;o3004o`<00ol400;o1`02oaH00_l800;o1`02o`@00_l700;o1002o`H00_l300;o1`02o`<0
0_l600;o4`0001<00_l=00;o2@02o`H00_l:00;o5002o`T00_l600;o2P02o`@00_l600;o1@02o`@0
0ol700;o0`02o`<00_l200;o1@02o`H00_l500;o0P02oaT00_l:00;o0P02oaH00_l300Go1@02o`80
0_l;00;o2@02o`<01Ol700;o2`02o`H00_l300;o0P02o`P01?l200Co0`03oal00_l700?o1`02o`@0
2ol400;o1P02o`<02ol300;o1P02oa<0000C00;o3P000ol0000700;o1P02o`X00_lD00;o2@02o`H0
0_l:00;o0`03o`H00_l500;o1002o`@01ol200;o0P03o`800_l500;o1P02o`D00_l200;o6@02o`X0
0_l200;o5P02o`<00_l00`3oo`0500;o0P02o`/00_l900;o0`02o`030?oo00L00_l;00;o1P02o`<0
0_l200;o2002o`040?l000Co0`02ob000_l700;o1007o`@02Ol500;o1P02o`@02Ol400;o1P02oa<0
000C00;o3P02o`P00_l600;o2P02oa@00_l900;o1P02o`X01ol700;o1@02o`@00_l400Oo0P02o`80
00?o0?l00P02o`D00_l<00?o0P03oaP00_l900?o0P03oaD00_l200?o00<0ool01003o`800ol:00?o
2002o`800ol00`3oo`0700;o2`02o`/01_l800;o00H0o`00o`02o`<00_lP00?o1P02o`@01ol400;o
1@02o`D00_l600;o1002o`D00_l<00;o4`0001<00_l>00;o2003o`@00_l;00;o5002o`T00_l600;o
2P09o`D02Ol400;o3@02o`040?oo00;o00<0ool01@02o``00_l400;o6002o`T00_l400;o5@02o`80
0_l200;o1002o`@00_l900Co2002o`800_l200;o1`02o`/00_l;00Ko2002o`030?oo00;o00<0ool0
0`02oal01?l600;o4002o`<00_l600;o1P02o`D00_l300;o3@02oa<0000D00;o3P000ol0000600Wo
2P02oaD00_l900;o1P02o`X00_l500?o1009o`@00_l=00;o00<0ool00P001?l0ool500;o3002o`@0
0_lH00;o2@02o`@00_lE00;o00<0ool00`02o`@00_l400;o2006o`L00_l00`3oo`0300;o1`02o`/0
0_l;00;o0P02o`P00_l00`3oo`02o`030?oo00<00_lN00Ko1@02oa000_l300;o1P02o`H00_l500;o
0`02o`d00_lC00005002o`h00_l700;o00<0ool00_l<00;o5@02o`T00_l600;o2P02o`H00_l400;o
1@02o`@00_l800;o0`02o`030?l0008000Co0?oo1@02o`/00_l600;o5`02o`P00_l600;o5005o`<0
0_l300;o1P02o`L00_l200;o1`05o`<00_l700;o2`02o`/00_l200;o0P02o`<00_l300;o0`02o`80
0ol700;o5002o`800_l500;o2002o`L00_l0103oool600;o1P02o`H00_l0103oool=00;o4`0001@0
0ol=00;o2002oa000_lF00;o1`02o`L00_l:00;o1P02o`@00_l500;o1@02o`H00ol300Co0`04o`D0
0_l;00;o1P02oaL00_l800;o1P02oa@01?l400;o0`02o`H00_l600?o0`02o`H01?l400;o1`02o`/0
0_l;00;o1P02o`<00_l300;o0`02o`<00_l700;o4`03o`<00_l500;o1P03o`L00_l00`3oo`0700;o
1P02o`H00_l00`3oo`0>00;o4`0001D00_l>0003o`0000H00ol>00;o5`03o`D00ol700;o2P02o`D0
0ol400;o1@02o`D00ol400Co0`04o`@00ol500;o2P03o`H00olF00;o1`03o`H00olC00Co1002o`80
0ol600?o1@02o`@00_l600Co1002o`L00_l;00;o2`02o`H00_l300;o2002o`<00ol500?o4`02o`@0
0_l500?o1004o`L01Ol700;o1P02o`H01Ol>00;o4`0001H00_l600;o1@02o`P00ol<00;o6@09o`@0
2_l400_o1004o`<01?l500[o0P04o`D01?l00`3oo`06o`H01_l200Ko4@0:o`801_l200Ko4@04o`80
3?l200Ko0P05o`801Ol300Co0P06o`802_l400So1P0<o`801_l200Ko0`0:oa401Ol200Go100:o`@0
1ol700Co1004o`801ol:00[o400001L000?o00001009o`T01ol70003o`0001X01Ol600[o1009o`H0
1?l300Co1`05o`030?oo00801?l500Co00<0ool01_l600Ko0P06oa402_l200Ko0P06oa400ol300co
0P06o`801Ol200Go0`03o`<01_l200[o1008o`H03?l200Ko0P06o`D01Ol00`3oo`0A00Go0P05o`H0
1Ol00`3oo`0400Oo1`04o`@01?l200Oo2P0:oa00000N00Wo2`05ool0``000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(77\\) ODRHFMLV IT NWYNHLF C  GAUAO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00;o3@02o`h00_lI00Go1P08o`H01Ol600?o00<0ool0
0_l300Co0`07o`L01Ol300Go00<0ool02ol700;o5`0:o`D02?lD00Ko0`02o`@00_l400;o1`08o`D0
1_l300;o0`04o`<01?l300go00<0ool01OlJ00Go9P06o`@01_l300Ko1@04o`@01_l300Ko1@05oa@0
000C00;o3002o`d00_l?00;o5P09o`@02_l400Go1@04o`030?oo00;o0`04o`<01ol700Go0`05o`03
0?oo00_o1P04oaH02_l500So5006o`800ol400;o1002o`L02?l500Ko0P03o`<01?l300Co0`0=o`03
0?oo00Go6009ob802_l200Ko0`06o`<02?l200Ko0`06o`<02OlB00004`02o`d00_l=00;o3P02oaD0
0ol500?o1002o`@01?l500;o1@03o`@00_l500;o1P02o`/00_l700;o1@02o`H00_l600Co6P02o``0
0_lH00;o1004o`<00ol400?o2@02o`T00_l400Co1002o`D00_l700;o1P02o`<00_lJ00?o1@03ob00
1?l500;o1002o`L00_l500;o1002o`@00_l700;o1003o`D00olA00004`02o`d00_l=00;o3P02oaD0
0_l700;o1002o`H00_l500;o1@02o`D00_l500;o1P02o`/00_l700;o1@02o`H00_l600Co6P02o``0
0_lH00;o1004o`<01?l300?o2@02o`T00_l400Co1002o`D00_l700;o1P02o`<00_lJ00;o1`02ob00
0_l700;o1002o`L00_l400;o1P02o`<00_l700;o1002o`L00_lA00004`02o`d00_l=00;o3P02oa@0
0_l900;o0`02o`L00_l400;o1002o`H00_l500;o1P02o`800_l700;o0`02o`800_l500;o1P02o`D0
0_l200;o6@02o``00_lH00;o0`05o`<01?l200Co2@02o`T00_l300Go1002o`D00_l700;o1P02o`<0
0_l200;o5@03obP00ol700;o100;o`@00_l600;o0`0;o`<00_l900;o400001<00_l>0003o`0000`0
00?o00003002oa@00_l900;o0`02o`L00_l400;o0`03o`H00_l500;o1P02o`800_l700;o0P03o`80
0_l500;o1P02o`D00_l200;o6@02o``00_lH00;o0`02o`030?oo00<00_l0103o0004o`T00_l900;o
0`02o`030?oo00@00_l500;o1`02o`H00_l300;o0P02oaD00_lY00;o1007o`@02Ol500;o1P02o`@0
2Ol400;o2@02oa00000C00;o3P02o`d00_l=00;o5002o`T00_l300;o1`02o`@01ol700;o1@02o`H0
1_l700;o0P000ol0o`0200;o1@02o``00ol200?o6002o``00_lH00;o0P03o`030?oo00<00_l01P3o
003o00;o2@03o`P00_l200?o00<0ool01002o`D00_l700;o2`06oaD00_lY00;o1007o`@00_l500;o
1@02o`H00_l400;o1@02o`@00_l900;o400001<00_l>00;o3@02o`d00_lD00;o2@02o`<00_l700;o
1009o`D02Ol600Ko1`02o`040?oo00;o00<0ool01@02o``00_l400;o6002o``00_lH00;o0P02o`80
0_l300;o00<0ool00_l00`3oo`0800Co2002o`800_l200;o1009o`L00_l;00Ko5@02obT00_l@00;o
0`02o`H00_l600;o1@02o`<00_l500;o2@02oa00000D00;o3P000ol0000<0003o`0000X00_lE00;o
2@02o`<00_l700;o1002o`D00ol400Wo1P02o`800_l700;o00<0ool00P001?l0ool500;o3002o`@0
0_lH00;o1`02o`<00_l300;o4`02o`030?oo00<00_l300;o00<0ool00_l00`3oo`0700Ko1`02o`03
0?oo00<00_l400Wo1`02o`/00_l200;o5@02obT00_l@00;o0`02o`H00_l600;o1@02o`<00_l500;o
2@02oa00000D00;o3P02o`d00_l;00;o5@02o`T00_l300;o1`02o`@00_l600;o1002o`D00_l600;o
0P02o`800_l300;o00<0o`000P001?l0ool500;o2`02o`H00_lG00;o1`02o`<00_l300;o4`05o`<0
0_l200;o0`02o`<00_l600;o0P02o`L01Ol300;o1002o`D00_l700;o2`02o`800_l200;o4@03o`L0
0_lO00;o2002o`L00_l0103oool600;o1P02o`H00_l0103oool500;o2@02oa00000D00?o3@02o`d0
0_l;00;o5P02o`L00_l400;o1P02o`D00_l600;o1002o`D00_l600;o1P02o`<01?l300Co1@02o`/0
0_l600;o5`02o`L00_l300;o0`02oa<01?l400;o0P02o`<00_l300;o1@03o`<00_l600Co1002o`@0
0_l500;o1`02o`/00_l600;o4P02o`L00_lP00;o1P03o`L00_l00`3oo`0700;o1P02o`H00_l00`3o
o`0700;o1`02oa40000E00;o3P000ol0000<0003o`0000P00_lG00?o1@03o`@00_l400Co1@02o`D0
0ol400;o1@02o`H00_l600;o0`04o`@00ol500;o2P03o`H00olF00;o1`02o`<00_l300;o4`04o`@0
0_l200;o2002o`D00_l400;o1P04o`@00_l400;o1@02o`L00_l;00;o1P02oa800ol500?o8003o`@0
1?l700Go1`02o`H00_l600Go1`03o`D00olA00005P02o`H00_l500;o1P02o`D00_l800;o6@09o`@0
2_l400_o1004o`<01?l300co0P04o`D01?l00`3oo`06o`H01_l200Ko4@0:o`<03?lB00Co0P0<o`80
1_l200Go0P05o`<01?l200Ko0P04o`<01?l300So1P0<oa<02_lQ00[o1007o`L01?l400Co0P07o`T0
2OlB00005`000ol0000400Wo1P09o`P000?o00006P05o`H02?l600Wo1P04o`<01?l300co0P04o`D0
1?l00`3oo`06o`H01_l200Ko4@0:o`<03?lB00?o0`0<o`801_l200Go0P05o`<00ol300Ko0P04o`<0
1?l300So1P0<oaD01Ol00`3oo`0S00Go00<0ool01007o`L01?l400Co0P07o`/01OlD00007P09o`H0
2Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(78\\) TDRHFRLQ IR NT NHJF CZ GASDJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ogl00_l400?oo`0b00005@02obP00_mn00[o
o`0a00005002obX00_mn00Go0P02ool0<@0001@00_lZ00;oOP000ol0003o03L0000D00;o2`02o`d0
1?l<00;o5`08o`D02?l600Go1P03o`030?oo00;o0`04o`<01ol700Go1P0@o`H01OlE00[o0`05o`H0
0ol@00Ko0`02o`@02?lD00Ko0`02o`<01?l300Co1@06o`H01olJ00Go1P0:oaH01_l400Ko0`06o`04
0?oo00Go1P08o`P01_lE00004`02o``00_l;00So2`02oaH02?l500[o1005o`D01?l00`3oo`02o`<0
1?l300Oo1`05o`D04Ol400Wo4`0:o`<01Ol500Co4006o`800ol400So5006o`800ol300Co0`04o`<0
2Ol500Oo6009o`@02_lD00[o0P06o`<01_l00`3oo`08o`@02_l400Wo500001<00_l=00;o2@03o`@0
0ol:00;o6@02o`T00_l400Co1@02o`D00ol400;o1@02o`H00_l<00;o1@03o`D00_l600;o0`03o`D0
0olF00;o2@02o`D00olC00;o1004o`L00_lH00;o1004o`@00_l500;o1003o`@00ol600;o6P03o`D0
0ol400;o1@02oa<01?l500;o1002o`L00_l300?o1@03o`@00_l400Co0`03o`@00olC00004`02o`d0
0_l900;o1P02o`X00_lI00;o2@02o`H00_l500;o1@02o`D00_l500;o1P02o``00_l500;o1P02o`H0
0_l300;o1`02oaH00_l900;o1@02oa@00_l400Co1`02oaP00_l400Co1002o`D00_l400;o1P02o`H0
0_lJ00;o1`02o`@00ol400;o4`02o`L00_l400;o1`02o`<00_l700;o1002o`H00_l300;o1P02oa<0
000C00;o3@02o`T00_l600;o2P02oaT00_l900;o1`02o`@00_l400;o1P02o`D00_l600;o0P02o`P0
0_l400;o1`02o`H00_l200;o2@02oaD00_l900;o1002oaD00_l300Go1`02oaP00_l300Go1002o`D0
0_l400;o1P02o`H00_l200;o5@03o`h00ol300;o4P03o`L00_l400_o0`02o`L00_l400;o1`02o`80
0_l600;o4`0001<00_l>0003o`0000L00_l600;o2P02oaT00_l900;o1`02o`@00_l300?o1P02o`D0
0_l600;o0P02o`P00_l300?o1`02o`H00_l200;o2@02oaD00_l900;o0`03oaD00_l300;o00<0ool0
1`02oaP00_l300;o00<0ool01002o`D00_l400;o1P02o`H00_l200;o5@02oa000_l300;o4P02o`@0
1ol400Wo3003o`@00_l700;o0P02o`H00_lC00004`02o`h00_l900;o1002o`/00_lI00;o2@02o`L0
0_l400Oo1`02o`D00_l600Ko2007o`P00_l:00;o2@02oaD00_l900Oo5P02o`800ol00`3oo`0700;o
6002o`800ol00`3oo`0400;o1@02o``00_l600Ko5@02oa000olF00;o1007o`@00_l500;o1`07o`D0
0_l700;o2P02oa<0000C00;o3P02o`X01ol;00;o6@02o`T00_l700;o1009o`D02Ol600Ko2009o`H0
0_l:00;o2@02oaD00_l900Wo5002o`800_l200;o1`02oaP00_l200;o0P02o`@02Ol<00;o1P06oaD0
0_lA00?o5@02oa000_l300;o1P07o`L00_l700;o2P02oa<0000D00;o3P000ol0000800Ko2`02oaD0
0_l300;o0`02o`@00_l700;o1002o`D00ol400Wo1P02o`800_l800;o1@03o`D00_l:00;o2@02oaD0
0_l900;o1@03oa<00_l00`3oo`0300;o0P02o`<00_l300;o4`02o`030?oo00<00_l400Wo3002o`H0
0_l200;o5@02o`d00_l300;o5@02oa000_l300;o1@03o``00_l700;o2P02oa<0000D00;o3P02o`P0
0_l400;o2P02oaD00_l300;o0`02o`@00_l700;o1002o`H00_l400;o1@02o`H00_l200;o0P02o`@0
0_l600;o1@02o`X00ol800;o5@02o`T00_l600;o4`05o`<00_l200;o0`02o`<00_lC00Go0`02o`@0
0_l500;o3002o`H00_l200;o0P02oa400ol700;o0`02o`<00olD00;o2002o`L00_l0103oool500;o
1`000ol0000300;o1`02o`X00_lC00005003o`d00_l700;o1P02o`T00_lE00;o0`02o`<00_l400;o
1P02o`D00_l600;o1002o`D00_l600;o1P02o`@00_l600;o1@02o`/00_l700;o5P02o`T00_l600;o
4`04o`@00_l200;o0`02o`<00_lC00Co1002o`@00_l500;o3002o`H00_l600;o4P02o`L00_l300;o
1003oa@00_l600?o1`02o`030?oo00H00_l600;o1@02o`H00_l;00;o4`0001D00_l>0003o`0000D0
0_l600;o2002oaH00_l300;o0`02o`@00_l400Co1@02o`D00ol400;o1@02o`H00_l600;o1002o`D0
0ol500;o3002o`D00_lG00;o2@02o`D00olC00Co1002o`800_l300;o0`02oa<01?l400;o1002o`D0
0_l<00;o1P02o`H00_lB00?o1@03o`<00_l500;o5003o`@01?l700Go1P03o`@00ol500;o1004o`/0
0_lC00005P02o`H00_l500;o1P03o`@00ol700;o5`0<o`<02_l400_o1004o`<01?l300co0P0;o`<0
2?l900Wo4`0:o`<02olC00Co0P06o`030?oo00[o4P04o`801_l200Co0`04o`H02_l00`3oo`0:oa<0
2_l300[o500:o`@01ol800Wo100:o`L02_l@00005`000ol0000400Wo1`08o`P000?o00005P0<o`<0
2?l600Wo1P04o`<01?l300co0P09o`D02?l;00Go5@0:o`<02OlE00?o0`06o`030?oo00[o4P03o`<0
1_l200Co0`04o`H02_l00`3oo`0:oaD01Ol00`3oo`0300[o5P05o`030?oo00@01ol:00Go00<0o`00
0`08o`T02_l@00007P09o`P01_oo0<D0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(79\\) PDRHFRLTYIR NT NIJF C YEAQDJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o2`02o`X0
1Ol>00;o5@08o`L02?l600Go1P03o`030?oo00;o0`04o`<01ol700Go1P0@o`@02?l600So1P0:o`<0
1Ol600?o4006o`<00_l400So5006o`<00_l300[o1P06o`H01olJ00Go5P08o`@03?l200Ko0`06o`@0
1Ol600So2006oaD0000C00;o3002o`X01ol=00;o5008o`L02_l400Go1@04o`030?oo00;o0`04o`<0
1ol700Go1@0Ao`@02?l600So1P0:o`<01Ol500Co4006o`800ol400So5006o`800ol300[o1009o`D0
1olH00Wo5008o`@03?l200Ko0`06o`802Ol400[o1009oa@0000C00;o3@02o`h00ol<00;o5P02o``0
0_l400Co1@02o`D00ol400;o1@02o`H00_l<00;o1@03o`D00_l600;o1`02o``00_l=00;o2@02o`D0
0olC00;o1004o`L00_lH00;o1004o`L00_l800?o1003o`H00_lJ00?o1@03oaH00_l900;o1P02o`@0
0_l700;o0`03o`D00ol400;o1004o`<00ol400?o4`0001<00_l=00;o3`03o`/00_lF00;o3002o`H0
0_l500;o1@02o`D00_l500;o1P02o``00_l500;o1P02o`H00_l700;o3002o`d00_l900;o1@02oa@0
0_l400Co1`02oaP00_l400Co1`02o`P00_l600;o1P02oaX00_l700;o5P02o`T00_l600;o1002o`L0
0_l300;o1`02o`@00_l600;o0`02o`H00_lC00004`02o`d00_l@00;o2`02oaH00_l<00;o1`02o`@0
0_l400;o1P02o`D00_l600;o0P02o`P00_l400;o1`02o`H00_l700;o3002o`d00_l900;o1002oaD0
0_l300Go1`02oaP00_l300Go1`02o`P00_l600;o1P02o`800_lE00?o7`02o`T00_l200;o0P02o`@0
2ol200;o2@02o`<00_l700;o0P02o`H00_lC00004`02o`h000?o00002P04o`030?oo00X00_lF00Oo
1`02o`L00_l400;o0`03o`H00_l500;o1P02o`800_l800;o0`03o`L00_l600;o1`02o``00_l=00;o
2@02o`<00olE00;o0`02o`030?oo00L00_lH00;o0`02o`030?oo00L00_l800;o1P02o`H00_l200;o
5@02ob000_l900;o0P02o`T02Ol300;o2@02o`<00_l700;o0P02o`H00_lC00004`02o`h00_l900Wo
2P02oaH02Ol500;o1`02o`@01ol700;o1@02o`H01_l800Oo2002o`l00_l<00?o3002o`T01olF00;o
0P03o`030?oo00L00_lH00;o0P03o`030?oo00L00_l@00;o1P06oaD00_lP00?o2006o`T00_l500;o
0`02o`T00_l300;o1`02o`X00_lC00004`02o`h00_l900;o1003o`X00_lF00;o1@03o`@00_l700;o
1009o`D02Ol600Ko2009o`H00_l?00;o2`04o``00_l900Wo5002o`800_l200;o1`02oaP00_l200;o
0P02o`L00_l@00;o1P06oaD00_lO00Co2006o`X00_l300;o1002o`T00_l300;o1`02o`X00_lC0000
5002o`h000?o00001P02o`H00_l900;o5`02o`H00_l400;o1`02o`@00_l500?o1009o`H00_l200;o
2002o`D00ol500;o2P02o`<00_l300;o1@06o`/00_l900;o1@03oa<00_l00`3oo`0300;o0P02o`<0
0_l300;o4`02o`030?oo00<00_l700;o4002o`H00_l200;o5@02oah01_l700;o0P02o`X00_l300;o
1002o`T00_l300;o1`02o`X00_lC00005002o`h00_l700;o1P02o`T00_lG00;o1P02o`@00_l700;o
1002o`H00_l400;o1@02o`H00_l200;o0P02o`@00_l600;o1@02o`X00_l300;o0`02o`D00_l200;o
2`02o`T00_l600;o4`05o`<00_l200;o0`02o`<00_lC00Go0`02o`L00_l@00;o1P02o`800_l200;o
4@03o`L00_lD00;o0P02o`L00_l200;o0P02o`L00_l0103oool400?o2002o`<00_l700;o2P02oa<0
000D00?o3@02o`L00_l600;o2@02oaL00_l600;o1002o`H00_l500;o1P02o`@00_l500;o1P02o`H0
0_l400;o1P02o`D00_l:00;o0`02o`<00_l400?o0`02o`X00_l900;o1P02oa<01?l400;o0P02o`<0
0_l300;o4`04o`@00_l700;o4002o`H00_l600;o4P02o`L00_lC00?o0`02o`H00_l600;o1`02o`03
0?oo00H00_l700;o1002o`H00_l;00;o4`0001D00_l>0003o`0000D00_l60003o`0000L00_lH00;o
1@03o`@00_l400Co1@02o`D00ol400;o1@02o`H00_l600;o1002o`D00ol500;o2P02o`<00_l300;o
1002o`@00_l:00;o2@02o`D00olC00Co1002o`800_l300;o0`02oa<01?l400;o1`02oa000_l600;o
1P02oa800ol500?o4`02o`@00_l600;o1P02o`L01Ol700;o1@02o`D00_l400Co2`02oa<0000F00;o
1P02o`D00_l700;o1002o`P00_lG00_o100:o`@02ol400Co0`04o`<03?l200_o0`08o`L03?l200Go
0P05o`@02_l300_o4`04o`801_l00`3oo`0:oa801?l200Ko0P0:o`L02_l00`3oo`0:oa<02_lA00Go
0P05o`803?l400Oo2009o`@02_l700[o400001L000?o00001009o`L01ol90003o`0001H02Ol600So
1P09o`H01?l300Co0`0<o`802Ol500So1`0<o`801Ol200Go100:o`<02OlE00?o0`06o`030?oo00[o
4P03o`<01_l200[o1`0:o`030?oo00[o5@05o`030?oo01401Ol200Go0P0<o`@01ol:00Go1P08o`T0
2_l@00007P09o`T01?oo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(80\\) PDRHFRLTYIR IT NHJG C YECQDJ)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0P`02o`@00ol^00005@02obP00_oo0880
2_l]00005002obX00_oo08801Ol200;o;@0001@00_lZ00;oo`220003o`0003<0000D00;o2`04o`/0
1?l<00;o5@08o`L02?l600Go1P03o`030?oo00;o0`04o`<01ol700Go1P0@o`@02?l600So1P0:o`<0
1Ol600?o400:o`D02?lD00Ko0`02o`<01?l300Co1@06o`X01_lG00Go5P08o`@03?l700Go2@05o`H0
2?l800Ko5@0001<00_l:00So2006o``00_lD00So1`0:o`@01Ol500Co00<0ool00_l300Co0`07o`L0
1Ol5017o1008o`H02?l600[o0`05o`D01?l@00[o1@08oa@01_l200?o0`04o`<01?l300Wo1`0:oa<0
2OlD00So100<o`D02Ol500Wo100:o`@02OlD00004`02o`T00ol400?o1P03o`800ol;00;o5P02o``0
0_l400Co1@02o`D00ol400;o1@02o`H00_l<00;o1@03o`D00_l600;o1`02o``00_l=00;o2@02o`D0
0olF00;o3002oaP00_l400Co1002o`D00_l400?o1003o`D01?l500;o4P03o`D00olF00;o2@02o`H0
0_l400?o1@03o`<00ol500?o1002o`@01?l300?o1003oa<0000C00;o2@02o`H00_l600;o1002o`/0
0_lF00;o3002o`H00_l500;o1@02o`D00_l500;o1P02o``00_l500;o1P02o`H00_l700;o3002o`d0
0_l900;o1@02oaL00_l<00;o6002o`@01?l400;o1@02o`@00_l600;o1@02o`L00_lB00;o1`02oaH0
0_l900;o1P02o`@00_l700;o0`02o`L00_l400;o1P02o`<00_l600;o4`0001<00_l900;o1P02o`D0
0_l600;o2P02oaH00_l<00;o1`02o`@00_l400;o1P02o`D00_l600;o0P02o`P00_l400;o1`02o`H0
0_l700;o3002o`d00_l900;o1002oaP00_l<00;o6002o`<01Ol400;o1@02o`@00_l600;o1003o`L0
0_lA00?o7`02o`T00_l200;o0P02o`<00ol;00;o2@02o`<00_l700;o0P02o`H00_lC00004`02o`T0
0_l600;o1@02o`H00_l:00;o5P07o`L00_l700;o1002o`<00ol600;o1@02o`H00_l200;o2002o`<0
0ol700;o1P02o`L00_l<00;o3@02o`T00_l300?o6002o``00_lH00;o0`02o`030?oo00@00_l500;o
1002o`H00_l400;o1007oa000_lP00;o2@02o`800_l700;o3002o`T00_l300;o1`02o`800_l600;o
4`0001<00_l:00;o1002o`H00_l600;o2P02oaH02Ol500;o1`02o`@01ol700;o1@02o`H01_l800Oo
2002o`l00_l<00?o3002o`T01olI00;o3002oaP00_l200?o00<0ool01002o`D00_l<00;o1002o`@0
1ol@00;o8003o`P01_l700;o3002o`T00_l300;o1`02o`X00_lC00004`02o`/01ol600;o1P02o`X0
0_lF00;o1@03o`@00_l700;o1009o`D02Ol600Ko2009o`H00_l?00;o2`04o``00_l900Wo5`02o``0
0_lH00;o0P02o`800_l400Wo3002o`@00_lK00;o7`04o`P01_l700;o3002o`T00_l300;o1`02o`X0
0_lC00005002o`X01_l700;o1P02o`T00_lG00;o1P02o`@00_l700;o1002o`D00ol400Wo1P02o`80
0_l800;o1@03o`D00_l:00;o0`02o`<00_l500Ko2`02o`T00_l500?o5P02o`L00_l300;o0`02oa<0
0_l00`3oo`0300;o1009o``00_l400;o6`02oah01_l700;o0P02o`L00_l<00;o2@02o`<00_l700;o
2P02oa<0000D00;o2@02o`@00_l600;o1P02o`T00_lG00;o1P02o`@00_l700;o1002o`H00_l400;o
1@02o`H00_l200;o0P02o`@00_l600;o1@02o`X00_l300;o0`02o`D00_l200;o2`02o`T00_l600;o
5P02o`L00_l300;o0`02oa<01Ol300;o1002o`D00_l<00;o1002o`P00_lA00?o1`02oa@00_l200;o
1`02o`800_l200;o0`03o`L00_l200?o2002o`<00_l700;o2P02oa<0000D00?o1`02o`H00_l500;o
1P02o`T00_lG00;o1P02o`@00_l600;o1@02o`H00_l400;o1@02o`H00_l600;o1002o`H00_l500;o
2P02o`<00_l300;o1003o`<00_l:00;o2@02o`H00_lF00;o1`02o`<00_l300;o4`04o`@00_l400;o
1@02o``00_l500;o1P03oa800_l700;o4`03o`<00_l600;o1P02o`@00_l700;o0`02o`L00_l400;o
1P02o`/00_lC00005@02o`L00_l600;o1P02o`@00_l900;o6002o`D00ol400;o1004o`D00_l500?o
1002o`D00_l600;o1P02o`@00_l500?o1@02o`X00_l300;o0`02o`@00_l400;o2P02o`T00_l500?o
5P02o`L00_l300;o0`02oa<01?l400;o1002o`D00_l<00;o1@03o`@01?lB00?o1@03oa<00_l400;o
1P02o`H00_l400?o1@03o`@00_l500;o1@02o`@01?l;00;o4`0001H00_l600?o1003o`H00ol200?o
2002oaL02ol400[o100;o`@01?l300Co0`0<o`802ol300So1`0<o`801Ol200Go100:o`<02olC00[o
0`0<oa801?l200Ko0P04o`<01?l600[o0`0:oa<02_lA00Go0P05o`803?l500[o1009o`@02_l700[o
400001L000?o00001@08o`P01_l90003o`0001H02Ol600So1P09o`H01?l300Co0`0<o`802Ol500So
1`0<o`801Ol200Go100:o`<02OlE00[o0`0<oa800ol300Ko0P04o`<01?l600[o1@05o`030?oo01D0
1Ol00`3oo`0A00Go0P05o`803?l700Go00<0ool01P05o`H02?l900[o400002001_l:00Coo`360000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(81\\) LDRHIRLPYHR ITYKGNG C YGCTDK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2@09o`T00_lE00go0P08o`H01Ol600?o00<0ool0
0_l300Co100:o`<01Ol6013o0P08o`P02?l600Co0`04o`801Ol600?o400:o`D02?l700So1005o`H0
0_l500Ko1P06o`<00_l600Ko5`05oaH02?l800Ko2@05o`L02?l500So1P05o`H00_l@00004`02o`X0
2?l700Wo2P02oa@03Ol200[o1005o`D01?l00`3oo`02o`<01?l400[o0`05o`D04Ol200So2008o`H0
1?l300Co0P05o`D01?l@00[o1@08o`L02?l400Go1@03o`<02_l400Ko0P03o`@02_lC00Wo5008o`H0
2_l500Wo1@08o`D02_l400Go1@03oa00000C00;o2@03o`@00ol:00;o3@02oaL00_l600;o0`02o`@0
1?l500;o1@03o`@00_l500;o2@02o`T00_l500?o1@02o`H00_l400;o3`02o`X00_l500;o1@02o`D0
0olF00;o3002o`d00_l900;o1@03o`<01?l500;o1@02o`@01?l300Co1@02oa800ol500?o5P02o`P0
1?l500;o1003o`D00ol700;o2@02o`@01?l500;o1@03oa40000C00;o2@02o`H00_l:00;o3@02oaL0
0_l600;o0`02o`H00_l500;o1@02o`D00_l500;o2@02o`T00_l500;o1P02o`H00_l400;o3`02o`X0
0_l500;o1@02o`D00_lG00;o3002o`d00_l900;o1@02o`@00_l700;o1@02o`@01?l300;o1`02oa80
0_l700;o5P02o`P00_l700;o1002o`L00_l700;o2@02o`H00_l500;o1@02oa80000C00;o2@02o`H0
0_l:00;o3@02oaL00_l600;o0`02o`L00_l400;o1002o`H00_l500;o2@02o`T00_l400;o1`02o`H0
0_l400;o3`02o`X00_l500;o1@02o`@00_lH00;o3002o`d00_l900;o1002o`@00ol700;o1@02o`<0
1Ol200?o1`02oa400olO00;o1`03o`L00_l300?o4002o`T00_l700;o1002o`@00_lC00004`02o`T0
0_l600;o2P02o`d00_lG00;o1P02o`<00_l700;o1002o`<00ol600;o1@02o`T00_l900;o0`03o`L0
0_l600;o1007o`X00_l:00;o1@02o`D00_l300?o6002o``00_l=00;o2@03o`800ol400;o1007o`@0
0_l300;o00<0ool00P02o`@01ol@00;o8002o`L00_l400Oo0P02oa400_l900;o1`02o`@00ol200?o
4`0001<00_l:00;o1002o`/00_l=00;o5`02o`/00_l700;o1007o`L00_l500;o2@02o`T01ol800;o
3009o`P00ol900;o1@02o`D01olI00;o3002o`d00ol800Oo1@02o`@01ol400;o0P03o`030?oo0080
0_l400Oo4002ob000ol600;o1007o`800_lA00;o2@02o`L00_l400Oo500001<00_l;00Oo2`02o`d0
0_lG00;o2`02o`L00_l400Wo1@09o`T00_l900Wo1P02o``00_l500?o1P04o`T02Ol500Wo5`02o``0
0_l<00Co2005o`L00_l?00;o0P02o`800_l200;o6`02oal01?l600;o3@02oa400_l900;o1`02o`@0
1OlF00005002o`X01_l<00;o3002oaP00_l;00;o1`02o`@00_l500?o1009o`T00_l900;o1@03o`D0
0_l<00;o1P02o`D01_l800Wo1@02o`D00olF00;o1`02o`<00_l300;o1P06o`L00_l0103oool600;o
3`02o`030?oo00<00_l200;o6`02oah01_l500;o3@02o``00_l300;o0`02o`@00_l700;o1002o`04
0?oooaD0000D00;o2@02o`@00_l;00;o3002oaP00_l;00;o1`02o`@00_l600;o1002o`D00_l900;o
2@02o`H00_l500;o3002o`H00_l500;o0P02o`P00_l500;o1@02o`H00_lF00;o1`02o`<00_l300;o
1P02o`800_l700;o0P03o`D00_l800;o1@05o`<00_l200;o2002oa400ol700;o5002o`800_l500;o
2002o`<00ol700;o0P02o`<00_l300;o1002o`L00_l400;o0P03oa@0000D00?o1`02o`H00_l:00;o
3002oaP00_l;00;o1P02o`D00_l600;o1002o`D00_l900;o2@02o`H00_l500;o3002o`H00_l400?o
0`02o`L00_l500;o1@02o`H00_lF00;o1`02o`<00_l300;o1@03o`<00_l600;o0`03o`D00_l600?o
1@04o`@00_l300;o1P03oa800_l700;o4`03o`<00_l500;o1P03o`@00_l700;o0P02o`<00_l300;o
1002o`H00_l500;o0`03oa<0000E00;o1`02o`H00_l:00;o2`02oaT00_l;00;o1004o`D00_l500?o
1002o`D00_l900;o2@02o`D00ol500;o3002o`D00ol400;o1002o`L00_l500;o1@02o`D00olF00;o
1`02o`<00_l300;o1@02o`@00_l600;o1003o`@00ol400Co1@04o`@00_l300?o1004oa800ol500?o
4`02o`@00_l500?o1004o`@00ol500?o0P02o`<00_l300;o1002o`@01?l500;o1003oa80000F00;o
1P03o`@00ol600?o00<0ool02P02oaL02?l700[o100;o`@01?l300Co100:o`<02ol300So1`0;o`<0
1Ol200Go1004o`<01?l200_o4`0:o`<03?l300Go0P05o`801Ol300Go0`0:o`@01?l200Ko0`0:oa<0
2_lA00Go0P05o`@02_l500[o0P0<o`<02_l400Go0`05oa00000G0003o`0000D02?l700Ko2P000ol0
000F00So1`08o`H02Ol600Co0`04o`@02_l300Wo1@08o`L02Ol500Go0P05o`@01?l300Co0P09oaD0
2_l300co0`05o`801Ol200Go0`05o`D01Ol00`3oo`0400?o0`06o`D01Ol00`3oo`0E00Go00<0ool0
4@05o`801Ol600Go00<0ool01`05o`030?oo00803?l300So1P05o`<01Ol@00008006o`/00ooo0<H0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(82\\) LDREIMKPXHU ITYKGKG AWTDFTDI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co200:o`T00_lE00go0P08o`H01Ol600oo100:o`<0
1Ol300Go00<0ool00ol600;o0P08o`H01Ol200Go1004o`<01?l700Co5@0:o`D02?l700So1005o`H0
0_l500Ko1@05o`H00_l500Ko4P06o`<01_l200;o1002o`L02?l500So1P07o`T02?l500So1`0:oa80
000C00;o2P08o`H02_l:00;o500=o`802_l400Go1@0@o`@02_l300Go0`05o`030?oo00?o1@03o`80
2?l600Go0P05o`@01?l300Co1@08oa<02_l500So1`08o`@01Ol500?o0`0:o`<01Ol500?o0`0:oa00
1_l300Ko0P02o`@00_l700So1@0:o`@01ol900So1@0:o`D02_lB00004`02o`T00ol400?o1P02o`D0
0_l:00;o5`02o`H00_l300;o1004o`D00_l500?o1002o`H00_l800;o2002o`L00_l400;o1@03o`D0
0_l;00?o1003o`H00_l500;o1P02o`@00_lG00;o3002o`d00_l900;o1@03o`<01?l500;o1@02o`D0
0ol300Co1@02oa800_l700;o0`03o`@00ol900;o2@02o`@01?l500;o3`02o`T00_l400Co2002oaH0
000C00;o2@02o`H00_l700?o3`02oaL00_l600;o0`02o`H00_l500;o1@02o`D00_l600;o2002o`P0
0_l700;o1002o`D00_l600;o3003o`800ol700;o1@02o`D00_l600;o5P02o``00_l=00;o2@02o`D0
0_l400;o1`02o`D00_l500;o1002o`L00_lB00;o1`02o`<01?l300?o2@02o`T00_l600;o1@02o`l0
0_l900;o1P02o`P00_lF00004`02o`T00_l600;o2003o`h00_lG00;o1P02o`<00_l700;o1002o`@0
0_l600;o0P02o`800_l800;o2002o`<00_l200;o1002o`@00_l700;o3@02o`800_l800;o1@02o`D0
0_l600;o5P02o``00_l=00;o2@02o`@00_l400?o1`02o`D00_l400;o1003o`L00_lB00_o0`04o`80
1?l900;o2@02o`L00_l400;o0P02o`/00_l900;o1`02o`L00_lF00004`02o`T00_l600;o2@03o`d0
0_lG00;o1P02o`<00_l700;o1002o`<00ol600;o0P02o``00_l800;o0P03o`800_l400?o0P03o`L0
1ol900Co2@02o`D00_l500;o1P02oaH00_l<00;o3@02o`T00ol200?o1002o`@01ol400?o0P03o`@0
0_l400Oo4P09o`@00_l0103o0004o`T00_l900;o1`02o`@00_l200;o2`02o`T00_l700;o1`02oaH0
000C00;o2P02o`@00_l;00?o3002oaL00_l;00;o1`02o`@01ol700Ko3002o`P00_l20003o`3o0080
0_l400Oo2009o`L01?l900;o1@02o`D00_l600;o5P02o``00_l=00?o2007o`D00_l400Oo1007o`D0
0_l400Oo4P02o`D00_l400;o00H0o`00o`02o`T00_l900;o1`02o`@01_l;00;o2@02o`L00_l700;o
5P0001<00_l;00Oo3003o`/00_lG00;o2`02o`L00_l400Wo1@06o``00_l800;o00@0ool00_l00`3o
o`0400Go2P02o`D00ol600?o2P09o`D00_l600;o5P02o``00_l<00Co2005o`L00_l?00Go1`02oah0
0_l300;o1@02o`030?oo00;o00<0ool02@02o`T00_l700;o1006o`/00_l900;o1`02o`L00_lF0000
5002o`X01_l>00;o2P02oaP00_l;00;o1`02o`@00_l500?o1002o`800_l<00;o2002o`030?oo0080
00Co0?oo1002o`040?ooo`T00_l600;o1P04o`T02Ol500;o1P02oaH00_l700;o0`02o`<00_l600Ko
1`02o`040?ooo`H00_l?00;o00@0oooo1P02oah00_l300;o1@02o`030?oo00;o00<0ool01002o`<0
0_l300;o1002o`L00_l400;o0P02o`H00_l300;o0`02o`@00_l700;o1`02oaH0000D00;o2@02o`@0
0_l>00;o2@02oaP00_l;00;o1`02o`@00_l600;o1002o`800_l200;o2002o`P00_l00`3o00020004
o`3oo`@00_l200?o2002o`H00_l500Ko2002o`D00_l500;o1P02oaH00_l700;o0`02o`<00_l600;o
0P02o`L00_l200?o1@02o`P00_l500;o0P03o`D00_l800;o5@02o`040?ooo`@00_l300;o0`02o`<0
0_l300;o0`02o`@00_l700;o1002o`800_l200;o0P02o`<00_l300;o1002o`L00_l700;o5P0001@0
0ol700;o1P02o`d00_l900;o6002o`/00_l600;o1@02o`H00_l400;o1P02o`P00_l800Co0`04o`@0
0_l300?o1`02o`H00_l400?o0P03o`L00_l500;o1@02o`H00_lF00;o1`02o`<00_l300;o1@03o`<0
0_l600;o0`03o`D00_l600?o1@02o`<00ol500;o1P03oaD00_l00`3oo`0500;o0`02o`<00_l300;o
0`02o`<00_l400;o1P02o`D00_l600;o0P02o`<00_l300;o1002o`H00_l800;o5P0001D00_l700;o
1P02o`H00_l500;o2002oaT00_l;00;o1004o`D00_l500?o1002o`H00_l800;o2004o`@00ol400;o
1003o`H00_l500?o1002o`@00_l700;o1@02o`D00_l600;o5P02o`L00_l300;o0`02o`D00_l400;o
1P02o`@00ol400?o1004o`D00_l400?o1003o`@01?lE00Go1@02o`P00_l300;o0`02o`<00_l400;o
1004o`D00_l600;o0P02o`<00_l300;o1002o`@01?l800;o5P0001H00_l600?o1003o`H00ol300?o
1`02oaL02?l700[o100;o`<03?l400[o0`04o`D01?l00`3oo`03o`<01Ol200_o0`05o`801Ol400Co
0`04o`<01?l400Co4@0:o`<03?l300Go0P05o`801Ol300Go0`0:o`<01Ol300Go0`0:oa801ol500Ko
0P06o`803?l300[o100<o`803?l300[o1@0:oa80000G0003o`0000D02?l800Oo20000ol0000F00So
1`08o`H02Ol500co100:o`<01?l500Co00<0ool00ol300Go0P09o`D01Ol200Go1004o`<01?l300Co
1004oa402_l300co0`05o`801Ol200Go0`05o`D01Ol00`3oo`0300Go0`05o`D01Ol00`3oo`0B00Oo
1@06o`801_l200co0`08o`H03?l200co0`08o`L02_lB00008006o`X01Ooo0<D0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(83\\) LGREINKRXHV IRYKHJG AWTFAYBI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lE00go1@06o`D01Ol600oo100:o`@0
1_l300;o0P05o`H00_l200Go1P08o`801Ol400Co0`04o`L00_lG00[o0`05o`H00ol300So1005o`H0
0_l200Co0`04o`D01_l:00Ko4P06o`<01_l200;o1002o`L02?l400Oo1`06o`<01_l200So100:o`H0
2_lB00004`02o`X02?l600Wo2`02oa@03Ol300[o0`05o`D04?l400[o1006o`800ol200Go1@03o`80
1Ol500Wo0P05o`@01?l300Co1P04oaH02_l300Go1@04o`<02?l400Go1@03o`801?l300Co0`09o`L0
2_l@00Ko0`06o`800_l400;o1`08o`@01ol700Ko0`06o`802?l400_o1@0:oa80000C00;o2@03o`@0
0ol500;o1@02o`/00_lG00;o1P02o`801?l500;o1@02o`D00ol400;o1P02o`P00_l900;o1004o`@0
0_l500?o1@02o`D00ol300?o1003o`H00_l500;o1`04oaX00_l900;o1@03o`P00_l900;o1@03o`@0
0_l500;o1003o`@00ol500Co1@02oa800_l700;o0`03o`@00ol900;o2@02o``00_l700;o1`02o`T0
0_l500?o2002oaH0000C00;o2@02o`H00_l=00;o2P02oaL00_l600;o0P02o`L00_l500;o1@02o`D0
0_l600;o2002o`T00_l400Co1002o`D00_l600;o1@02o`D00ol200?o1`02o`D00_l700Co6P02o`T0
0_l500;o2@02o`T00_l500;o1@02o`D00_l400;o1P02o`D00_l700;o4P02o`L00_l300Co0`03o`T0
0_l900;o3002o`L00_l700;o2@02o`H00_l800;o5P0001<00_l900;o1P02o`d00_l:00;o5`02o`H0
0_l0103oool700;o1@02o`@00_l600;o0P02o`800_l800;o2@02o`<01Ol400;o1002o`L00_l400;o
1`02o`800_l800;o1@02o`H00_l200;o6@02o`T00_l400;o2P02o`T00_l400;o1P02o`D00_l400;o
1P02o`@00ol700;o4P0;o`<01?l200Co2@02o`T00_l200;o200;o`L00_l900;o1P02o`P00_lF0000
4`02o`T00_l600;o3@02o`X00_lG00;o1P02o`030?oo00@01ol400;o0`03o`H00_l200;o3002o`T0
0_l300;o00<0ool01003o`800ol700;o0`03o`P01?l900;o1@02o`H00_l200;o6@02o`T00_l300?o
2P02o`T00ol200?o1P02o`D00_l400;o1P02o`@00_l400Oo4P09o`@00_l0103o0004o`T00_l900;o
0P02o`T02Ol800;o2@02o`H00_l800;o5P0001<00_l:00;o1002o`d00_l;00;o5`02o`T00_l400Oo
1007o`L01_l<00;o2@02o`800ol00`3oo`0400Oo2007o`T01?l900;o1@02o`D00ol200?o6002o`T0
1ol;00?o2007o`L00_l500;o3002o`@00_l400Oo4P02o`D00_l400;o00H0o`00o`02o`T00_l900Ko
2@02o`D00_l800?o2002o`D00ol800;o5P0001<00_l;00Oo2P04o``00_lG00;o2@02o`l02Ol500Ko
3002o`T00_l200;o0P02o`@01Ol:00Wo1`03o`X02Ol500;o1002oaP00_l900Wo2004o`P01Ol900Wo
3002o`@00_lN00;o0`02o`D00_l00`3oo`02o`030?oo00T00_l900Ko2P02o`<00_l800Co2009o`T0
0_lF00005002o`X01_l;00?o3002oaP00_l900;o3`02o`D00ol400;o0P02o``00_l900;o00<0ool0
0`02o`@00_l0103oool900;o1@03o`H01?l900Wo1@02o`@00_lH00;o2@02o`D00ol600Ko1`02o`04
0?ooo`P02Ol<00;o1002oah00_l300;o1@02o`030?oo00;o00<0ool01002o`<00_l300;o1002o`80
0_l:00;o0`02o`L01_l700So2P02oaH0000D00;o2@02o`@00_l<00;o2`02oaP00_l900;o2002o`D0
0_l600;o1002o`800_l200;o2002o`T01Ol300;o1002o`800ol800;o1P02o`D01_l800;o1@02o`@0
0_l600;o5`02o`T00_l600;o1P02o`800_l700;o0P03o`L00_l500;o3002o`@00_l800;o5@02o`04
0?ooo`@00_l300;o0`02o`<00_l300;o0`02o`@00_l200;o0P02o`L00_l0103oool700;o0P02o`L0
0_l400?o2@02oaH0000D00?o1`02o`H00_l<00;o2P02oaP00_l:00;o1P03o`D00_l600;o1002o`H0
0_l800;o2@04o`@00_l400;o0`03o`L00_l600;o1003o`800ol700;o1@02o`@00_l600;o5`02o`T0
0_l600;o1@03o`<00_l600;o0`03o`H00_l500;o3002o`D00_l600?o5@02o`030?oo00D00_l300;o
0`02o`<00_l300;o0`02o`@00_l600;o1`02o`030?oo00L00ol300;o1P02o`D00_l900;o5P0001D0
0_l700;o1P02o``00_l900;o6@02o`X00ol400Co1@02o`D00ol400;o1P02o`P00_l900Co1002o`@0
0_l400?o1P02o`D00ol400;o1002o`L00_l500;o0`03o`H00olF00;o2@02o`D00ol500;o1002o`H0
0_l400?o1@02o`D00_l<00;o1@03o`@01?lE00Go1@02o`P00_l300;o0`02o`<00_l400;o1P02o`L0
1Ol700;o1002o`H00_l400?o2@02oaH0000F00;o1P03o`@00ol600;o0`03o`P00_lG00So200:o`<0
2ol300co100:o`@01?l200Ko00<0ool00ol300Go0P0;o`<01Ol200Go1004o`<01?l00`3oo`04o`80
1_lA00[o0`0;o`@01Ol200Go0P05o`<01Ol200Co0`04o`H02_l300[o4P07o`D01_l200Ko0P0<o`80
3?l400Oo1P05o`801Ol200[o1P0:oa80000G0003o`0000D02?l700Oo2@000ol0000F00So2P05o`03
0?oo00<02Ol500co100:o`@00ol300Ko00<0ool00ol300Go0P09o`D01Ol200Go1004o`<01?l00`3o
o`04o`801_lA00[o0`09o`H01Ol200Go0P05o`<01Ol200Co0`04o`H02_l500Go00<0ool04P07o`D0
1_l200Ko0P0<o`803?l400Oo1P05o`801Ol200Wo1`0:oa80000P00Ko2P04ool0aP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(84\\) LHRHJNKRXHT JOYKIMF AWTJAWBI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co3006o`T00_lE00go0P04o`<01?l300Go1P03o`03
0?oo00;o0`04o`D01_l700Ko0`02o`801Ol600;o0P05o`H02?l200Go1004o`<01?l400So5@06o`X0
1Ol800So1005o`H00_l200[o1005o`<01Ol00`3oo`05oaD01_l300Ko0P02o`@00_l700So1P06o`H0
1_l300Ko0P02o`@00_l400[o1P0:oa80000C00;o2P08o`X01_l:00;o500=o`801?l300Co0`05o`D0
1?l00`3oo`02o`<01?l300Wo1P06o`800ol200Go1@03o`801Ol500Wo0P05o`@01?l300Co1008oa<0
2Ol700Wo1P08o`@01Ol500?o0P0:o`@01Ol300Go00<0ool01OlE00Ko0`06o`800_l400;o1`08o`@0
2Ol500Ko0`06o`800_l400;o100;o`D02_lB00004`02o`T00ol400?o2`02o``00_lG00;o1P02o`<0
0_l500;o1P02o`D00ol400;o1@02o`@00ol400?o1P02o`@01?l400;o1@03o`D00_l500?o0`03o`@0
0ol600;o1@02o`P00_lF00?o1003o`D00ol500?o2002o`T00_l500?o1`02o`T00_l700;o1002oaX0
0_l700;o0`03o`@00ol900;o1`03o`@00ol600;o1`02o`<00ol400?o1@02o`D00ol800;o5P0001<0
0_l900;o1P02o`/00_l<00;o5`02o`H00_l300;o1@02o`H00_l500;o1@02o`D00_l400;o1P02o`H0
0_l400Co1002o`D00_l600;o1@02o`D00ol200?o1`02o`D00_l800;o5P02o`H00_l500;o1`02o`P0
0_l900;o1@02o`P00_l900;o1`02o`@00_lJ00;o1`02o`<01?l300?o2@02o`L00_l600;o1P02o`L0
0_l300Co0`03o`D00_l600;o2002oaH0000C00;o2@02o`H00_l500[o2P02oaL00_l600;o0`02o`D0
0_l600;o1002o`H00_l500;o1002o`H00_l600;o0`05o`@00_l400;o1`02o`@00_l700;o0P02o`P0
0_l500;o2002oaH00_l600;o1002o`T00_l700;o2@02o`@00_l900;o2@02o`<00_l200;o1002o`80
0_lF00_o0`04o`801?l900;o1`02o`H00_l600_o0`04o`801?l500;o1P02o`P00_lF00004`02o`T0
0_l600;o1@0:o`X00_lG00;o1P02o`<00_l500;o1P02o`<00ol600;o1@02o`@00_l600;o1P02o`<0
0_l00`3oo`0400?o0P03o`L00_l300?o2004o`T00_l500;o2002oaH00_l600;o1002o`T00_l700;o
2@03o`800ol900;o2@02o`800ol200;o1002o`800_lG00Wo1002o`040?l000Co2@02o`L00_l600;o
1`09o`@00_l0103o0004o`D00_l600;o2002oaH0000C00;o2P02o`@00_l600;o1002o``00_lG00;o
2`02o`D00_l600Oo1`02o`D00_l<00;o1P02o`800ol00`3oo`0400Oo2007o`T01?l900;o1@02o`P0
0_lN00;o1002o`T00_l700?o2007o`X00_l900;o0P000ol0o`0200;o1006oaL00_l500;o1002o`06
0?l00?l00_l900;o3`02o`L00_l500;o1002o`060?l00?l00_l500;o1@03o`P00_lF00004`02o`/0
1ol700;o0`02o``00_lG00;o2`09o`H02Ol500Wo3002o`H00_l200;o0P02o`@01Ol:00Wo1`03o`X0
2Ol800;o7P02o`@00_l900;o1P04o`P01Ol<00;o2@02o`040?oo00;o00<0ool01006oaP00_l300;o
1@02o`030?oo00;o00<0ool02@02o`l00_l800;o0`02o`D00_l00`3oo`02o`030?oo00D02Ol900;o
5P0001@00_l:00Ko2@001?l00002o`/00_lH00;o2`09o`H00_l500?o1009o``00_l600;o00<0ool0
0`02o`@00_l0103oool900;o1@03o`H01?l900Wo0`02o`<00_l300;o6@02o`@00_l900;o1@06o`L0
0_l0103oool;00;o2@02o`030?oo008000Co0?oo1002o`800_lH00;o0`02o`D00_l00`3oo`02o`03
0?oo00@00_l300;o0`02o`X00_l800;o0`02o`D00_l00`3oo`02o`030?oo00D02?l:00;o5P0001@0
0_l900;o1002o`P00_l200;o2`02oaP00_l;00;o1@02o`H00_l600;o1002o`D00_l<00;o1P05o`<0
0_l400;o0P03o`P00_l600;o1@06o`P00_l500;o0`02o`<00_l300;o6@02o`@00_l900;o1@02o`80
0_l700;o0P03o`X00_l900;o00<0o`000P001?l0ool400;o0P02o`800_lE00;o00@0oooo1002o`<0
0_l300;o0`02o`<00_l300;o2P02o`T00_l0103oool400;o0`02o`<00_l400;o1003o`T00_lF0000
5003o`L00_l600;o20000ol00002o`/00_lH00;o2`02o`D00_l600;o1P02o`@00_l500;o3002o`H0
1?l400;o1002o`<00ol700;o1P02o`@00ol200?o1`02o`D00_l300;o0`02o`<00_lI00;o1@02o`L0
0_l500?o0`02o`H00_l300?o2@02o`T01?l300Co1002o`H00_lE00;o00<0ool01@02o`<00_l300;o
0`02o`<00_l300;o2P02o`T00_l00`3oo`0500;o0`02o`<00_l400;o1@02o`T00_lF00005@02o`L0
0_l600;o2@001?l0ool:00;o6@02o`/00_l500;o1P02o`D00ol400;o1@02o``00_l600Co1002o`@0
0_l400?o1P02o`D00ol400;o1002o`L00_l500;o0`02o`<00_l300;o6@02o`D00ol500?o1@02o`@0
0_l600;o1003o`P00_l900Co1003o`@00_l600;o5@05o`D00_l800;o0`02o`<00_l300;o2P02o`T0
1Ol500;o2002o`@00_l400?o2@02oaH0000F00;o1P03o`@00ol900Co2@02oaL02?l700Co0`04o`<0
2ol400Co0`04o`H02_l200Co0P06o`030?oo00?o0`05o`802ol300Go0P05o`@01?l300Co0P0<oa@0
2_l300Wo1005o`801Ol200Go0`05o`802_l400Co1@04o`030?oo00[o4P07o`D01_l200Ko0P0<o`D0
2_l300Oo1@06o`801_l00`3oo`08o`H02_lB00005`000ol0000500So2`03o`T000?o00005P08o`L0
1?l300Co0`09o`H01?l300Co1P0:o`800ol300Ko00<0ool00ol300Go0P09o`D01Ol200Go1004o`<0
1?l200co500:o`D01Ol600Go0P05o`801Ol300Go0P0:o`@01?l500Co00<0ool02_lB00Oo1@06o`80
1_l200co1@0:o`<01ol500Ko0P06o`030?oo00Oo1`0:oa80000P00Ko3003ool0a@000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(85\\) NHWCJNKRXHW JR KIMF AWTJAVCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2P05o``00_lF00Ko0`02o`<01?l300Co1@02o`@0
0_l800Go2006o`L01_l300;o0P05o`H00_l200Go1P08o`801Ol400Co0`04o`@00_l400;o5@06o`H0
1Ol600?o3`05o`H00_l200[o1005o`<01Ol00`3oo`05oaD01_l300Ko0P02o`@00_l700So1P06o`H0
1_l300Ko1@02o`/01Ol700[o4P0001<00_l:00So1P09o`/00_lE00Ko0P03o`<01?l300Co1@02o`@0
0_l600Wo1009o`H01_l200?o0P05o`D00ol200Go1@09o`801Ol400Co0`04o`@00_l400;o4`09o`D0
1Ol500Co3`05o`D00ol200[o1005o`<01Ol00`3oo`05oaD01_l300Ko0P02o`@00_l700So1009o`D0
1_l300Ko1004o`P02Ol500[o4P0001<00_l900?o1003o`D00_l500;o2`02oaH00_l400Co1002o`D0
0_l500?o1003o`@00ol500?o0`03o`@00ol600;o1004o`@00_l500?o1@02o`D00ol300?o1003o`H0
0_l500;o1003o`@00olB00?o1003o`H00_l500?o4`02o`D00ol700;o2@02o`L00_l400;o6P02o`L0
0_l300?o1003o`T00_l700?o1003o`H00_l700;o1P04o`L00ol500?o2002oaH0000C00;o2@02o`H0
0_l=00;o2P02oaH00_l400Co1002o`D00_l500Co0`03o`@00_l700;o0`02o`H00_l600;o1004o`@0
0_l500;o1P02o`D00_l500?o0P03o`L00_l500;o1004o`<00olB00;o1P02o`H00_l500;o5002o`D0
0_l800;o2@02o`L00_l400;o6P02o`L00_l300Co0`03o`T00_l700;o1P02o`H00_l700;o1P04o`L0
0_l700;o2002oaH0000C00;o2@02o`H00_l=00;o2P02oaH00_l300Go1002o`D00_l500Co0P04o`<0
0ol<00;o1P02o`H00_l300Go1002o`@00_l700;o1002o`L00_l200;o2002o`D00_l400Co0P04oa80
0_l600;o1P02o`@00_lE00;o1002o`T00_l900;o0`02o`800_l400;o0P02oaH02ol300Co0P04o`T0
0_l700;o1P02o`H02ol500;o0P02o`D00olA00;o5P0001<00_l900;o1P02o`d00_l:00;o5P02o`<0
0_l00`3oo`0400;o1@02o`D00_l0103o0004o`<00_l=00;o1P02o`H00_l300;o00<0ool01003o`80
0ol700;o0`03o`P01?l900;o1@02o`@00_l0103o0004oa800_l600;o1P02o`<00olE00?o0P03o`T0
0_l900;o0P03o`800_l400;o0P02oaL02Ol400;o00@0o`001?l900;o1`02o`H00_l700Wo1P02o`80
0_l500;o4P02oaH0000C00;o2P02o`@00_l>00;o2P02oaH00_l200?o00<0ool01002o`D00_l500;o
00H0o`00o`02o`<00_lE00;o1P02o`800ol00`3oo`0400Oo2007o`T01?l900;o1@02o`@00_l01P3o
003o00;o6P02o`H01olF00Oo2P02o`T00_l20003o`3o00800_l400Ko5`02o`D00_l400;o00H0o`00
o`02o`T00_l?00;o1`02o`D00_l500?o0P03o`@00_lB00;o5P0001<00_l;00Oo1`02o`@00_l;00;o
5P02o`800_l200;o1009o`D00_l00`3oo`02o`030?oo00<00_lE00;o1P02o`800_l200;o1005o`X0
2Ol700?o2P09o`@00_l00`3oo`02o`030?oo01X00_l600Wo5005o``00_l900;o00@0ool00_l00`3o
o`0400Ko6002o`<00_l500;o00<0ool00_l00`3oo`0900;o3`02o`P00_l300;o1P02o`@00_l400;o
4P02oaH0000D00;o2P06o`P02?l:00;o5`02o`030?oo00<00_l400Wo1@02o`030?oo00;o00<0ool0
0`02oaD00_l600;o00<0ool00`02o`@00_l0103oool900;o1@03o`H01?l900Wo1002o`030?oo00;o
00<0ool06P02o`H00_l500?o4`02o`040?ooo`/00_l900;o00<0ool00P001?l0ool400;o0P02oaP0
0_l300;o1@02o`030?oo00;o00<0ool01002o`<00_l300;o2P02o`P00_l300;o1P02o`@00_l400;o
4P02oaH0000D00;o2@02o`@00_l700Oo2`02oaL01Ol300;o1002o`D00_l400;o0`02o`<00_l200?o
1`02o`/00_l600Go0`02o`@00_l200?o2002o`H00_l500Ko2002o`D00_l300;o0`02o`<00_lI00;o
1P02o`H00_lC00;o0P03o`X00_l900;o00<0o`000P001?l0ool400;o0P02o`800_lE00;o00@0oooo
1002o`<00_l300;o0`02o`<00_l300;o2P02o`T00_l0103oool500;o1P02o`<00ol700;o2002oaH0
000D00?o1`02o`H00_l600;o4002oaL01?l400;o1002o`D00_l400;o0`02o`<00_l300;o1`02o`/0
0_l600Co1002o`@00_l300?o1`02o`H00_l400?o0P03o`L00_l500;o0`02o`<00_l300;o6@02o`H0
0_l600;o4`02o`<00ol900;o2@04o`<01?l400;o1P02oaD00_l00`3oo`0500;o0`02o`<00_l300;o
0`02o`<00_l:00;o2@02o`030?oo00H00_l600;o1002o`L00_l800;o5P0001D00_l700;o1P02o`H0
0_l?00;o6004o`@00_l400;o1@02o`@00_l800;o0`03o`D00ol;00;o1P04o`@00_l400;o1003o`H0
0_l500?o1002o`@00_l700;o1@02o`<00_l800;o6@02o`H00_l500?o4`02o`@00ol800;o2@04o`@0
0ol400;o1P02oaD01Ol500;o2002o`<00_l300;o0`02o`X00_l900Go1@03o`H00ol300?o1@03o`P0
0_lF00005P02o`H00ol400?o1P02o`h00_lH00Co0P06o`801?l300Co0P06o`801_l300[o1P0:o`80
1?l200Ko00<0ool00ol300Go0P0;o`<01Ol200Go1004o`<01?l00`3oo`04o`801_lC00[o00<0ool0
2OlB00Go0`05o`802_l400Co1@04o`030?oo00[o4P07o`D01_l200Ko0P0<o`D02_l300Oo1@06o`80
1_l300[o100:oa80000G0003o`0000D02?l700So20000ol0000G00?o0`06o`801?l300Co0P06o`80
1_l500Go00<0ool01P0:o`800ol300Ko00<0ool00ol300Go0P09o`D01Ol200Go1004o`<01?l00`3o
o`04o`801_lC00[o00<0ool01olD00Go0`05o`802_l400Co1@04o`030?oo00[o4P07o`D01_l200Ko
0P0<o`D02_l300Oo1@06o`801_l500Go00<0ool0100:oa80000P00Ko2008ool0a0000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(86\\) QIWCINLRXEW KS KIHF AYTEARCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`2G00005@02obP00_lI00[o
o`2F00005002obX00_lI00Go0P02ool0UP0001@00_lZ00;o6@000ol0003o09`0000D00;o2`04o`/0
1?l<00;o6@05o`H02_l600;o1002o`P01Ol700[o1006o`<00_l200go0P05o`H02?l200Go0`0<o`@0
0_l400;o4`05o`H00_l200;o00<0ool00olD00Go1P02o`802_l500Co0`04o`801olE00Ko0`06o`80
2?l700So100<o`801_l300_o1P03o`@01Ol700[o4P0001<00_l:00So2007o`/00_lF00Wo100:o`H0
0_l400;o1P09o`D02_l400Ko0P03o`803Ol200Go1@09o`801Ol300co1002o`@00_lC00Go1@03o`80
2_lB00Go1@03o`802_l500Co0`04o`801olE00Ko0`06o`802?l700So100<o`801_l300_o1@04o`80
2Ol500[o4P0001<00_l900?o1003o`H00_l400;o2`02oaD00ol500?o1`02o`T00ol400?o1003o`D0
0ol800;o2@02o`@01?l500;o1P02o`@00_l500?o0`03o`@00ol600;o1P02o`<00ol400?o5002o`D0
0ol300?o1@03oa<00_l500?o1`02o`X00_l500;o1@02oaX00_l700;o1`02o`d00_l900;o1P02o`@0
0_l700;o1002o`D00ol300?o1@03o`P00_lF00004`02o`T00_l600;o1@02o`H00_l:00;o5@02o`L0
0_l700;o2@04o`<00ol400;o1`02o`P00_l900;o1004o`D00_l600;o1002o`D00_l500?o0P03o`L0
0_l600;o0`04o`<00olD00;o1@02o`@00_l700;o4`02o`D00_l800;o2P02o`D00_l500;o6P02o`L0
0_l700;o3@02o`T00_l600;o1002o`L00_l400;o1@02o`@00_l700;o2002oaH0000C00;o2@02o`H0
0_l500;o1P02o`X00_lD00;o2@02o`H00_l900Co0P04o`<00olA00;o2@02o`<01Ol500;o1P02o`@0
0_l400;o1`02o`800_l800;o0P02o`800_l300Co0P04oa@00_l400;o1@02o`L00_lC00;o1002o`T0
0_l:00;o1@02o`D00_l200;o5P0;o`L00_l=00;o2@02o`800_l200;o100;o`@00_l400;o1003oa40
0_lF00004`02o`T00_l600;o1@02o`H00_l:00;o5002o`T00_l600;o2@02o`040?l000Co0`02oa80
0_l900;o0`02o`030?oo00D00_l600;o1002o`<00ol800Co2@02o`800_l700;o00@0o`001?lD00?o
0P03o`d00olC00?o0P03o`T00_l:00;o1@02o`D00_l200;o5`09o`P00_l=00;o2@02o`800_l900Wo
1@02o`<00ol400;o4P02oaH0000C00;o2P02o`@00_l600;o1P02o`X00_lD00;o2@02o`H00_l900;o
00H0o`00o`02o`<00_lB00;o2@02o`800ol00`3oo`0500;o3007o`T01?l900Ko1`02o`060?l00?l0
0_lD00Oo2@07oa@01ol:00;o2P02o`D00_l500Ko5`02o`D00_l800?o3002o`T01_l900;o1@02o`D0
1ol500;o4P02oaH0000C00;o2`07o`H00ol400;o2`02oa@00_l900;o1P02o`T00_l00`3oo`02o`03
0?oo00<00_lB00;o2@02o`800_l200;o1@02o``02Ol700?o2P06o`L00_l00`3oo`02o`030?oo01@0
1Ol900Oo5P05o``00_l:00Wo1@06oaP00_l300;o2004o``00_l900Ko2P02o`<00_l600Wo0`02oa80
0_lF00005002o`X01_l700Wo2P02oaD00_l900;o1P02o`T00_l00`3oo`02o`030?oo00<00_lB00;o
2@02o`030?oo00<00_l500;o3002o`D00ol600Co2@02o`800_l700;o00<0ool00_l00`3oo`0D00;o
00@0oooo1`03oa/00_l0103oool;00;o2P09o`D00_l200;o6002o`<00_l700Ko1P02o`<00_l300;o
1002o`800_l:00;o0`02o`H00_l500?o0P02oa800_lF00005002o`T00_l400;o1P02o`030?oo00;o
3002oaD00ol800;o1P02o`P00_l300;o0`02o`800ol700;o2002o`T01Ol300;o1@02o``00_l600;o
1@06o`P00_l200;o0P02o`800_l300;o0`02oa<00_l200?o1P02o`L000?o00004P02o`800ol:00;o
2P02o`D00_l500;o0P02o`800_lE00;o00@0oooo1`02o`800_l600;o0`02o`<00_l400;o0P02o`80
0_l700;o00@0oooo1P02o`H00_l200?o1`02o`P00_lF00005003o`L00_l600;o1P02oa000_lF00;o
1`02o`L00_l800;o0`02o`<00_l300;o1`02o`P00_l900Co1002o`D00_l<00;o1P02o`@00ol200?o
1`02o`H00_l200;o0`02o`<00_lC00;o0`03o`D00_l600;o5002o`<00ol900;o2P02o`D00_l500;o
1P02oaD00_l00`3oo`0700?o0`02o`D00_l300;o0`02o`@00_l600;o1`02o`030?oo00L00_l600;o
0`02o`L00_l800;o5P0001D00_l700;o1P02o`H00ol>00;o6002o`D00_l800;o2002o`P00_l300?o
1@03o`P00_l900Co1002o`D00_l<00;o1@03o`@00_l400;o1`02o`H00_l200;o2002oa<00_l400?o
1003o`@00olD00;o1003o`P00_l:00;o1@02o`D00_l600;o5@05o`L00_l400;o1@02o`<00_l300;o
1002o`H00_l700Go1`02o`D00ol300?o1@03o`P00_lF00005P02o`H00ol400?o1`03o``00_lI00Wo
100:o`<01_l200Ko0`0:o`@02_l400Co0P06o`030?oo00Ko1`0;o`<01Ol200Go0`0<o`030?oo00Co
0P06oa001Ol300Go0`09oa801Ol300Go0P0:o`D01?l300Co0P0<oa801ol600Go0P05o`<03?l200co
1007o`H02ol500[o100:oa80000G0003o`0000D02?l900Oo1`000ol0000J00Go1P0:o`<01_l200Ko
1@05o`030?oo00@02_l400?o0`06o`030?oo00Ko1`09o`D01Ol200Go0`0<o`030?oo00Co0P06oa00
1Ol300Go1@05o`030?l001401Ol300Go0P0:o`D01?l300Co0P0<oa801ol600Go0P05o`<03?l200co
1007o`H02Ol900Go00<0ool0100:oa80000P00Ko3005ool0``000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(87\\) QISGINLVXEWWKS KKHF AYTEARCM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02oaX00_l400?oo`2G00005@02obP00_lI00[o
o`2F00005002obX00_lI00Go0P02ool0UP0001@00_lZ00;o6@000ol0003o09`0000D00;o2`04o`/0
0_l>00;o6@05o`H02_l500;o00<0ool00ol900Ko1P0:o`@01_l300;o0P0=o`L00_l700Go0P05o`<0
3?l400;o1002o`H00_l400;o1@05o`H00_l200;o00<0ool00olD00Go1P02o`030?oo00?o1P02o`<0
1?l300Co0P07oaD01_l300Ko0P08o`L02?l400co0P06o`<02ol600?o1005o`H01Ol300Go400001<0
0_l:00So2@02o`l00_lF00Wo100:o`D02_l500[o100:o`@01_l200?o0P0=o`H01?l600Go0P05o`<0
3?l400;o1002o`H00_l400;o1@05o`D00ol200[o4P05o`D00ol00`3oo`03o`D00ol300Co0`04o`80
1olE00Ko0`06o`802?l700So100<o`801_l300_o1@04o`802Ol400Go0`05oa00000C00;o2@03o`@0
0ol900;o3P02oaD00ol500?o1`02o`T00ol500?o0`04o`D00_l800;o2@02o`@01?l500;o1P02o`H0
1?l700?o1003o`H00_l600;o0`03o`@00ol400?o1003o`H00_l500?o0`03o`D00olC00;o1@03o`@0
0_l500?o1@02o`D00_l500;o6P02o`L00_l700;o3@02o`T00_l600;o1002o`L00_l400;o1@03o`<0
0ol500?o1002o`L00_lA00004`02o`T00_l600;o2@02o`h00_lE00;o1`02o`L00_l900;o1`02o`<0
0_l700;o2002o`T00_l400Co1@02o`H00_l600Co2003o`800ol700;o1P02o`<01?l300?o1004o`<0
0ol600;o1@02o`@00_l700;o4`02o`D00_l500;o1@02o`H00_l500;o1@02oaX00_l700;o1`02o`d0
0_l900;o1P02o`@00_l700;o1002o`D00_l400;o1`02o`@00_l700;o4@0001<00_l900;o1P02o`T0
0_l>00;o5002o`T00_l600;o2@02o`L00_l200?o1`02o`P00_l900;o0`05o`D00_l600;o1@02o`80
0_l800;o0P02o`P00_l200;o0P02o`<01?l200Co1004o`801?l600;o1002o`D00_l700;o4`02o`@0
0_l600;o1002o`L00_l500;o1@02o`800_lF00_o1`02o`d00_l900;o0P02o`800_l400_o1002o`@0
0_l400?o3@02o`<00_l200;o4@0001<00_l900;o1P02o`X000?o00003002oa@00_l900;o1P02oa40
0ol200;o1007o`L00_l900;o0`02o`030?oo00D00_l600;o1@02o`800_l900Co2@02o`800_l700;o
00@0o`001?l400;o00@0o`001?l600?o0P03o`d00olC00?o0P03o`H00ol200?o1`02o`D00_l500;o
0P02oaL02Ol800;o3@02o`T00_l200;o2@09o`D00_l300?o1002o`h00_l200?o0P02oa40000C00;o
2P02o`@00_l;00;o3@02oa@00_l900;o1P02o``01ol300;o1007o`L00_l900;o0P03o`030?oo00D0
0_l<00?o0P03o`P01?l900Ko1`02o`060?l00?l00_l400;o00H0o`00o`02o`H01ol900Oo5007o`L0
1ol800;o1@02o`D01_lG00;o1@02o`P00ol<00;o2@06o`T00_l500;o1@07o`D00_l>00;o0P000ol0
o`0200;o4@0001<00_l;00Oo2`02o`d00_lD00;o2@02o`H00_l:00Oo1@02oa800_l900;o0P02o`80
0_l500;o3002o`@00_l800?o2P06o`L00_l00`3oo`02o`030?oo00@00_l00`3oo`02o`030?oo00H0
1Ol900Oo5P05o`T01Ol:00Wo1@06oaP00_l300;o2004o``00_l900Ko2P02o`<00_l600Wo0`02o`h0
0_l0103oo`02o`030?oo0140000D00;o2P06o`d000?o00002P02oaD00_l900;o1P02o`T00ol:00;o
4P02o`T00_l00`3oo`0300;o1@02o``00_l400;o2004o`T00_l200;o1`02o`030?oo00;o00<0ool0
1002o`030?oo00;o00<0ool01P02o`040?ooo`L00olK00;o00@0oooo2002o`040?ooo`T02Ol500;o
0P02oaP00_l300;o1`06o`H00_l300;o0`02o`@00_l200;o2P02o`<00_l600;o1@03o`800_l>00;o
00<0ool00P001?l0oolA00005002o`T00_l400;o3002o`/00_lE00?o2002o`H00_l900;o1`001?l0
0002o`P00_l800;o2@05o`<00_l500;o2`02o`H00_l600Ko2002o`800_l200;o0P02o`<00_l300;o
0P02o`<00_l300;o1@02o`800ol600;o1`000ol0000B00;o0P03o`L00_l200?o2002o`D00_l500;o
0P02o`800_lE00;o00@0oooo1`02o`800_l600;o0`02o`<00_l400;o0P02o`800_l700;o00@0oooo
1P02o`H00_l200?o1`02o`@00_l00`3o00020004o`3ooa40000D00?o1`02o`H00_l;00;o2`02oaH0
0_l700;o1`02o`T00_l600;o1002o`H00ol800;o2@04o`@00_l500;o2`02o`H00_l500?o0P03o`L0
0_l600;o0P02o`<00_l300;o0P02o`<00_l300;o1@02o`<00ol500;o1P02oa@00_l300?o1P02o`<0
0ol700;o1@02o`D00_l600;o5@02o`030?oo00L00ol300;o1@02o`<00_l300;o1002o`H00_l700;o
00<0ool01`02o`H00_l300;o1`02o`@01?l300Co4@0001D00_l700;o1P02o``000?o00002002oaP0
0_l500;o2002o`T00ol400?o1003o`@01?l800;o2@04o`@00_l500;o2P03o`H00ol400;o1002o`L0
0_l600;o0P02o`P00_l200;o2002o`D00_l400?o1003o`@00olD00;o1003o`D00_l400?o1P02o`D0
0_l500;o1P02oaD01Ol700;o1002o`D00_l300;o0`02o`@00_l600;o1`05o`L00_l500?o0`03o`D0
0ol400Co1003oa40000F00;o1P03o`@00ol500;o1@02o`P00_lI00Wo100:o`H02Ol500[o100:o`@0
1?l200Ko00<0ool01_l600Ko0P06o`030?oo00?o0P05o`<03?l00`3oo`04o`803?l200Ko0P05o`<0
1Ol300Wo4P05o`<01Ol00`3oo`03o`<01Ol300Co0`04o`803?lB00Oo1P05o`801Ol300co0P0<o`@0
1ol600_o1@0:o`<01?l500Co400001L000?o00001@08o`H02Ol80003o`0001X01Ol600[o2005o`03
0?l000H01Ol00`3oo`0400[o1003o`<01_l00`3oo`06o`H01_l200Ko00<0ool00ol200Go0`0<o`03
0?oo00Co0P0<o`801_l200Go0`05o`D01Ol00`3o000A00Go0`05o`030?oo00?o0`05o`<01?l300Co
0P0<oa801ol600Go0P05o`<03?l200co1007o`H02Ol900Go00<0ool00`04o`D01?l@00008006o`L0
2Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(88\\) LDSGIPLWXIWWKS JKHF A SCBSCM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2`04o``00_lE00go0P08o`L00_l00`3oo`03o`T0
1_l600[o0`08o`H03Ol400;o1002o`@01Ol200Go100:o`D00_l400;o1P02o`@00_l500Go1P02o`80
0_l00`3oo`03oaH01_l600Go1P02o`<01?l300Co0P07oaD01_l300Ko4002o`030?oo00?o2@05o`H0
2_l500;o00<0ool00ol900Go1P05o`<01Ol@00004`02o`X02?l700So2`02oa@03Ol200[o1@0:o`D0
2_l400[o0`08o`H03Ol400;o1002o`@01Ol200Go100:o`D00_l400;o1P02o`@00_l500Go1@03o`80
2_lB00Wo1@05o`D00ol300Co0`04o`801olE00Ko0`06oa002_l500Wo100;o`@02_l500Wo1005o`<0
1Ol@00004`02o`T00ol400?o1@03o`@00ol:00;o5`02o`H00_l300;o1004o`@00ol500?o0`04o`D0
0_l800;o2@02o`d00_l600;o0`03o`@00ol400?o1003o`T00_l800?o1003o`@00ol400?o1P02o`D0
0ol300?o1@03oa400ol400?o1P02o`D00ol500;o1@02o`D00_lJ00;o1`02oa800ol500?o0`03o`D0
0ol500;o1@03o`<00ol500?o0`03o`D00ol400;o1`02oa40000C00;o2@02o`H00_l500;o1P02o`X0
0_lG00;o1P02o`<00_l600;o1002o`L00_l300;o1`02o`P00_l900;o3@02o`H00_l300Co0`03o`D0
0ol200?o2P02o`P01?l300?o1004o`<00ol600;o1@02o`@00_l700;o4@02o`H00_l600;o1@02o`H0
0_l500;o1@02oaX00_l700;o4P02o`L00_l300;o1`02o`D00_l600;o0`02o`L00_l300;o1`02o`@0
0_l700;o4@0001<00_l900;o1P02o`D00_l600;o2P02oaL00_l600;o0`02o`L00_l300;o1`02o`80
0ol700;o2002o`T00_l=00;o1P02o`<01?l200Co1P02o`800_l;00;o2004o`801?l400Co0P04o`H0
0_l400;o1@02o`L00_lA00;o1P02o`H00_l400;o1`02o`D00_l500;o0P02oaH02olB00;o1`02o`80
0ol>00;o1P02o`<00_l700;o0P03o`d00_l300;o0P02oa40000C00;o2@02o`H00_l500;o1P02o`X0
0_lG00;o1P02o`<00_l700;o2`03o`800_l400Oo1`02o`T01ol800;o1P02o`<00_l0103o0004o`L0
1?l<00;o2002o`040?l000Co1002o`040?l000Co1P03o`800ol=00?o4@02o`H00_l600?o0P03o`L0
0_l500;o1@02o`800_lG00Wo6`03o`800_l?00;o1P02o`/00ol200;o3P02o`800ol200;o4@0001<0
0_l:00;o1002o`L00_l400;o2`02oaL00_l;00;o1`02o`H01ol300;o1007o`L00_l900Wo1P02o`/0
0_l01P3o003o00;o1`04o``00_l800;o00H0o`00o`02o`@00_l01P3o003o00;o1P07o`T01olJ00;o
1P07o`P00_l500;o1@06oaL00_l500;o5P07o`<00_l?00;o1@03o`H01ol300;o3P02o`8000?o0?l0
0P02oa40000C00;o2`07o`P01ol;00;o5`02o`/00_l700;o1007o`D00_lB00;o2@02o`D00ol500;o
2`02o`030?oo00;o00<0ool01`03o`d00_l800;o00<0ool00_l00`3oo`0400;o00<0ool00_l00`3o
o`0600Go2@07oa`00_l600Go2P09o`D01_lH00;o0`02oaD01ol500;o3`09o`D01ol500;o3P02o`04
0?oo00;o00<0ool04@0001@00_l:00Ko2@06o`/00_lH00;o2`02o`L00_l300?o2P02oa800_l900;o
1P02o`D00_l;00;o00<0ool00_l00`3oo`0700Co3002o`P00_l00`3oo`02o`030?oo00@00_l00`3o
o`02o`030?oo00H00_l0103oool700?o8@02o`H00_l0103oool900Wo1@02o`800_lH00;o0`02oa@0
0ol:00;o3`08o`D00ol:00;o3P02o`030?oo008000Co0?oo4@0001@00_l900;o1002o`L00_l400;o
2P02oaP00_l;00;o1`02o`<00_l70004o`0000;o2002o`P00_l900;o1P02o`D00_l:00;o0`02o`<0
0_l500Ko2`02o`L00_l300;o0`02o`800_l300;o0`02o`D00_l200?o1P02o`L000?o00006002o`H0
0_l200?o2002o`D00_l500;o0P02o`800_lE00;o00@0oooo5002o`L000Co00000ol700;o1@02o`@0
0ol400;o1`001?l00003o`L00_l400;o00<0o`000P001?l0oolA00005003o`L00_l600;o1@02o`H0
0_l900;o6002o`/00_l600;o1002o`H00_l400;o1P03o`P00_l900;o1P02o`D00_l:00;o0`02o`<0
0_l400?o0P03o`X00_l700;o0`02o`<00_l200;o0`02o`<00_l500;o0`03o`D00_l600;o6P02o`H0
0_l300?o1`02o`D00_l500;o1P02oaD00_l00`3oo`0E00;o1P02o`@00_l700;o1@02o`D00_l400;o
1P02o`@00_l700;o1004o`<01?lA00005@02o`L00_l600;o1@02o`H00_l800;o6@02o`/00_l400Co
1003o`@00ol400?o1004o`P00_l900;o1@03o`D00_l:00;o2002o`@00_l400;o2P02o`L00_l800;o
0P02o`P00_l500;o1003o`@00ol400?o6P02o`H00_l400?o1P02o`D00_l500;o1P02oaD01OlE00?o
1003o`@00ol500?o1@02o`@00ol400?o1003o`@00ol500?o1004o`@00olA00005P02o`H00ol400?o
1@03o`@00ol700;o5`08o`L02_l600Wo1@0:o`@02_l300_o0`08o`H01_l200Ko00<0ool00ol200Go
100:o`801_l200co0P06o`801Ol300Go0`09oaD02_l00`3oo`03o`<01Ol300Co0`04o`803?lB00Oo
5`09o`D02_l300[o1P09o`D02_l300Co1@04oa00000G0003o`0000D02?l700So20000ol0000F00So
1`08o`X01Ol00`3o000600Go00<0ool0100:o`<02Ol500So1P06o`801_l00`3oo`03o`801Ol400[o
0P06o`803?l200Ko0P05o`<01Ol500Go00<0o`00500:o`030?oo00?o0`05o`<01?l300Co0P0<oa80
1olI00Go00<0o`001P05o`030?oo00<02Ol900Go00<0o`001P05o`030?oo00<01?l500Co40000200
1_l900Koo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(89\\) LISGIPLWZIWZHS KKHHXB SCBSCM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l;00Co2005o`h00_lE00go0P0:o`D00_l00`3oo`03o`T0
1_l600[o0`08o`H03Ol400;o1002o`D02_l500[o1@02o`@00_l500[o1@04o`<01?l300;o00<0ool0
0olD00Go1P02o`030?oo00?o1P02o`<01?l300Co0`04o`<01?l300Go0P05o`802_lD00;o00<0ool0
0ol900Go1P0:o`D00_l00`3oo`03o`T01Ol600Go0`05oa00000C00;o2P08o`H01ol=00;o500=o`80
2_l500[o1@0:o`@02_l300So1P0=o`@00_l400;o1@0:o`D02_l500;o1002o`D02_l500Co0`04o`<0
2_lB00Go1@03o`030?oo00?o1@03o`<01?l300Co0`04o`<01?l300Go0P05o`802olC00[o1@09o`@0
2ol400[o1@09o`@01Ol300Go400001<00_l900?o1003o`X00ol<00;o5`02o`H00_l600;o2@03o`D0
0ol300Co1@02o`P00_l900;o3@02o`H00_l300?o1003o`D00_l500;o2@02o`P00ol400?o1@02o`D0
0_l600;o1@02o`@00ol500?o4`02o`D00ol400;o1@03o`D00_l500;o1@02o`D00_l500?o1003o`D0
0_l500?o4P03o`D00ol300?o1@03o`D00_l500?o0`03o`D00ol300?o1@03o`@00_l700;o4@0001<0
0_l900;o1P02o`/00ol;00;o5`02o`H00_l600;o2@02o`L00_l300;o1`02o`P00_l900;o3@02o`H0
0_l300Co0`03o`D00ol400;o2@02o`P01?l300?o1@03o`@00_l600;o1@02o`@00_l700;o4`02o`D0
0_l500;o1@02o`H00_l500;o1@02o`D00_l600?o0P03o`H00_l600;o4P02o`L00_l300;o1`02o`D0
0_l600;o0`02o`L00_l300;o1`02o`@00_l700;o4@0001<00_l900;o1P02o``00_l;00;o5`02o`H0
0_l600;o2@02o`L00_l200?o1`02o`P00_l900;o3@02o`H00_l300Co0P04o`H00ol300;o2@02o`P0
1?l200Co1P03o`<00_l600;o1@02o`@00_l700;o4`02o`@00_l600;o1002o`L00_l500;o1@02o`D0
0_l700;o0P02o`L00_l600;o4P02o`L00_l200?o3P02o`H00_l300;o1`02o`800ol=00;o0`02o`80
0_lA00004`02o`T00_l600;o2004o`030?oo00X00_lG00;o1P02o`H00_lA00?o0P02o`@01ol700;o
2@07o`P00_l600;o0`02o`040?l000Co1`02o`<00_l900;o2002o`040?l000Co1`02o`<00_l600;o
1@02o``00olC00?o0P03o`H00ol200?o1`02o`D00_l500;o1@02o`P01?l800;o1P02oaX00ol200;o
3`02o`H00_l;00?o0P02o`h00_l200?o0P02oa40000C00;o2P02o`@00_l700Wo2P02oaL00_l>00;o
3007o`<00_l400Oo1`02o`T02Ol600;o2`02o`060?l00?l00_l700?o3@02o`P00_l01P3o003o00;o
1`03o`X00_l500;o1`07oa@01ol700Oo2002o`D00_l500;o1@02o`P01?l800;o1@03oaD01ol300;o
3`02o`D00ol600Oo0`02o`h00_l20003o`3o00800_lA00004`02o`/01ol700;o1003o`X00_lG00;o
3P02o`X01ol500;o4P02o`T00_l500?o1@02o`/00_l00`3oo`02o`030?oo00P00ol<00;o2002o`03
0?oo00;o00<0ool02003o`T02Ol500Oo5P05o`T01Ol:00Wo1@09o`P00ol900Wo5007o`D00_l?00Wo
1@07o`D00_l>00;o00@0ool00_l00`3oo`0A00005002o`X01_l700;o1P02o`T00_lH00;o3P02o`T0
0ol:00;o4P02o`T00_l600;o1@02o`/00_l00`3oo`02o`030?oo00@00_l300;o3002o`P00_l00`3o
o`02o`030?oo00@00_l300;o2@09o`@00olK00;o00@0oooo2002o`040?ooo`T02Ol500Wo2004o`P0
2?lD00?o2P02o`l02?l500?o2P02o`h00_l00`3oo`020004o`3ooa40000D00;o2@02o`@00_l600;o
1P02o`T00_lH00;o3P02o`T00_l70004o`0000;o2002o`P00_l900;o1P02o`D00_l:00;o0`02o`<0
0_l300;o0`03o`/00_l700;o0`02o`<00_l300;o0`03o`P00_l500;o1002o`L000?o00004P02o`80
0ol700;o0P03o`P00_l500;o1@02o`D00_l700Ko1`02o`@00olC00;o1`001?l00003o`L00_l500;o
1003o`@00_l70004o`0000?o1`02o`@00_l00`3o00020004o`3ooa40000D00?o1`02o`H00_l500;o
1P02o`T00_lH00;o3P02o`T00_l600;o1002o`H00ol800;o2@02o`H00_l500;o2P02o`<00_l300;o
0`02o`@00ol:00;o1`02o`<00_l300;o0`02o`@00ol700;o1@02o`@00_l600;o5002o`<00ol600;o
0`03o`L00_l500;o1@02o`D00_l600?o0P03o`H00_l500;o4`02o`H00_l400;o1`02o`D00_l500;o
1002o`H00_l400;o1`02o`@01?l300Co4@0001D00_l700;o1P02o`D00_l60003o`0000L00_lI00;o
3P02o`T00ol400?o1003o`@01?l800;o2@02o`D00ol500;o2P02o`P00_l300;o1@02o`X00_l700;o
2002o`<00_l500;o1`02o`D00_l400?o1003oa@00_l400?o1@02o`@00ol600;o1@02o`D00_l500;o
1P02o`@00_l600;o1003oa<00ol400?o1003o`D00ol500;o1003o`@00ol400?o1003o`D00ol400Co
1003oa40000F00;o1P03o`@00ol600;o1002o`P00_lG00So1`0:o`H02Ol500[o100:o`<02ol300So
1P06o`801_l200[o1@0:o`801_l200Ko0P0:o`D01?l300Co1009oa801Ol300Go00<0ool00ol300Go
0`04o`<01?l300Co0`04o`<01Ol200Go0P0:oaD02Ol500[o0`0:o`H02Ol500[o0`04o`D01?l@0000
5`000ol0000500So1`07o`T000?o00005P08o`L02_l800Go00<0o`001P05o`030?oo00@02_l300Wo
1@08o`H01_l200Ko0P0:o`D02_l200Ko0P06o`802_l500Co0`04o`H01Ol00`3o000A00Go0`05o`03
0?oo00?o0`05o`<01?l300Co0`04o`<01?l300Go0P05o`802OlH00Go00<0o`001P05o`030?oo00<0
2Ol900Go00<0o`001P05o`030?oo00<01?l500Co400002001_l:00Coo`360000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(90\\) LEPGIPKW IWZHRYMHHHXBZUCBTCM)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lE00go00<0ool02_l300So2P06o`H0
2_l300So1P05o`H00_l400;o1002oa@02_l500;o1002o`D02_l500Co0`04o`801Ol600?o0`08o`@0
1Ol300Go0P04o`<01?l400Co0`04o`<01?l300Co0`05o`801Ol200[o1@0:o`T01?l900Go1P0:o`H0
2?l800Go1P05o`<01Ol@00004`02o`T01ol:00Ko3002oa@03Ol00`3oo`0:o`<02?l800[o100:o`<0
2?l600Go1@03o`@00_l400;o500:o`D00_l400;o1@0:o`D01?l300Co0P05o`D01?l300So1005o`<0
1Ol200Co0`04o`@01?l300Co0`04o`<01?l300Go0P05o`802ol400[o1`08o`D02Ol400_o1@08o`H0
2Ol400Go0`05oa00000C00;o3P03o`P00ol200?o2`02oaL00_l600;o0`02o`H00_l500;o2`04o`D0
0_l800;o2@02o``00_l500?o1003o`@00olG00;o2003o`@00ol500;o1@02o`H00_l500;o1@02o`D0
0ol800;o2002o`L00_l400;o1@02o`H00_l500;o1@02o`D00_l500?o1003o`D00_l500?o1002o`D0
0_l700;o1002o`@00ol500?o1@02o`D00ol700;o2003o`D00ol400;o1`02oa40000C00;o3`03o`L0
0_l400;o2`02oaL00_l600;o0`02o`H00_l500;o2`02o`L00_l800;o2@02o``00_l500;o1@04o`<0
0olG00;o2004o`<00ol500?o1002o`H00_l500;o1@02o`D00_l900;o2002o`L00_l400;o1@02o`H0
0_l500;o1@02o`D00_l600?o0P03o`H00_l600;o1003o`@00_l600;o1P02o`<00_l700;o1@02o`H0
0_l700;o2002o`L00_l400;o1`02oa40000C00;o4002o`H00_l600;o2P02oaL00_l600;o0`02o`80
0_l200;o1@02o`X00ol700;o2002o`T00_l<00;o1002o`H01?l200Co5`02o`P01?l200Co1P03o`<0
0_l600;o1@02o`D00_l400;o2P02o`P00_l300;o0P02o`@00_l500;o1P02o`D00_l500;o1@02o`L0
0_l200;o1`02o`H00_l500?o0`02o`H00_l600;o0P03o`h00_l600;o1`02o`L00ol=00;o0`02o`80
0_lA00004`02o``01?l00`3oo`0500;o1P02o`X00_lG00;o1P02o`<00_l200;o2@07o`D00_l400Oo
1`02o`T01ol700?o0P03o`H00_l0103o0004oaL00_l800;o00@0o`001?l700;o0`02o`H00_l500;o
1@02o`<00ol:00;o2002o`800ol200;o1002o`D00_l600;o1@02o`D00_l500;o2004o`P00_l600;o
1P02o`<00_l600;o1P02o`800_l?00;o1P02o`L00_l700;o3P02o`800ol200;o4@0001<00_l:00Wo
1@02o`H00_l:00;o5`02o`/01_l900Wo0`02o`@01ol700;o2@09o`D01ol700;o00H0o`00o`02oaL0
0_l800;o00H0o`00o`02o`L00ol:00;o1@02o`D01ol;00?o1`02o`8000?o0?l00P02o`@00_l500;o
1P02o`D00_l500;o1@02o`P01?l800;o1@03o`H00ol:00;o1P02o`800_l?00;o1@03o`L00_l700;o
3P02o`8000?o0?l00P02oa40000C00;o2P02o`@00ol500;o1P02o`X00_lG00;o2`06o`T00_l500?o
0P02oa800_l900;o1@03o`@01Ol900;o00<0ool00_l00`3oo`0G00;o2002o`030?oo00;o00<0ool0
2003o`T02Ol500Wo2004o`L00_l0103oo`02o`030?oo00@02Ol600Wo1@09o`P00ol900Wo2003o`T0
0_l600;o0P02o`l02Ol800;o1`02o`h00_l0103oo`02o`030?oo0140000D00;o2002o`H00_l500;o
1P02o`T00_lH00;o2`02o`800_l900;o1P02o`800_lB00;o2@02o`H00_l400;o00@0oooo2002o`03
0?oo00;o00<0ool05`02o`P00_l00`3oo`02o`030?oo00@00_l300;o2@09o`D00_l500?o1P06o`H0
0_l00`3oo`020004o`3oo`@02Ol600Wo1@09o`P01?l800So1@02o`<00_l900;o1P02o`800_l?00So
1002o`<00_l300;o0P02o`h00_l00`3oo`020004o`3ooa40000D00;o2002o`H00_l500;o1P02o`T0
0_lH00;o2`02o`800_l200;o1@02o`H00_l200;o2002o`P00_l900;o1P02o`@00_l200?o1P02o`<0
0_l300;o5P02o`L00_l300;o0`02o`<00_l300?o2002o`D00_l500;o1P02o`H00_l200;o1P02o`03
0?l0008000Co0?oo1002o`D00_l600;o1@02o`D00_l500;o1`06o`L00_l400?o1002o`<00ol800;o
1P02o`800ol700;o1@02o`@00ol300;o0`02o`<00_l200?o1`02o`@00_l00`3o00020004o`3ooa40
000D00?o1`02o`H00_l500;o1P02o`T00_lH00;o2`02o`H00_l500;o1P02o`<00_l600?o2002o`T0
0_l600;o1002o`<00ol500;o0`02o`<00_lF00;o1`02o`<00_l300;o0`02o`@00ol700;o1@02o`D0
0_l600;o1@03o`<00_l500Co0`04o`@00_l500;o1P02o`D00_l500;o1@02o`H00ol200?o1P02o`D0
0_l400;o1003o`L00_l600;o0`02o`L00_l500;o1@02o`<00_l300;o0`02o`<00_l700;o1004o`<0
1?lA00005@02o`L00_l60003o`0000D00_l400;o2@02oaT00_l;00;o1P02o`D00_l500?o0`03o`@0
1?l800;o2@02o`D00ol400;o1003o`@00_l800;o5P02o`L00_l800;o0`02o`D00_l700;o1@02o`D0
0_l500?o1@02o`@00_l500Co1003o`@00_l500;o1P02o`D00_l500;o1@02o`H00_l400;o1P02o`@0
0ol400;o1@02o`L00_l600;o0`03o`D00ol500;o1003o`<00_l300;o0`02o`<00ol500?o1004o`@0
0olA00005P02o`L00_l400;o1`03o`800ol800;o5`08o`H03?l300_o1@0:o`@02_l300_o0`05o`<0
1Ol00`3oo`04o`801_lA00[o0P06o`801_l200[o1@04o`<01?l200_o1005o`801Ol200Co1@04o`80
1?l300Co1004o`<01?l300Co0`04o`<01Ol200Go0P0:o`D02_l500Co1004o`<02_l300[o100<o`@0
2_l300Co1@04oa00000G0003o`0000D01ol900Ko2@000ol0000F00So1P0<o`<02Ol900Go00<0ool0
100:o`<02Ol500Go0`05o`030?oo00Co0P06oa402_l200Ko0P06o`802_l500Co0`04o`802Ol600Go
0P05o`801?l500Co0P04o`<01?l400Co0`04o`<01?l300Co0`05o`801Ol200Wo1P0:o`D01?l400Co
1@05o`030?oo00<02Ol500co1P05o`030?oo00<01?l500Co400002401?l;00Coo`360000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(91\\) PEPGINJX HWZHP IHMD BZUDBTAN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2`09o`T00_lE00So1P0<o`<02?l:00Ko1P0:o`@0
1_l300;o1006o`L01Ol200Go4P04o`<01?l400;o1002o`D02_l500Co0`04o`802?lF00[o1004o`<0
1?l300Go0`05o`802?lD00[o1@0:o`T01?l600So1P0:o`H02?l300Ko0`06o`801_l300;o4@0001<0
0_l900Oo2@09o`X00_lD00So1P0<o`<02?l800[o100:o`@01_l200?o0P09o`H01Ol200Go4P04o`<0
1?l400;o1002o`D02_l500Co0`04o`802?lF00[o1004o`<01?l300Go0`05o`802_lB00_o100:o`L0
2?l400[o100;o`D02?l300Ko0`06o`801_l200?o4@0001<00_l>00?o3002o`d00_lF00;o3002o`H0
0_l500;o2`04o`D00_l800;o2@02o`@01?l200?o1003o`H00ol400?o5002o`D00_l400?o1003o`D0
0_l500;o1P02o`D00_l500;o7P02o`T00_l500;o1@02o`L00_l400;o1004oa<00_l500?o1002o`D0
0_l700;o1002o`D00_l400Co1@02o`D00ol700;o2002o`L00_l500;o1004oa40000C00;o3`03o`/0
0_l=00;o5P02o``00_l600;o1@02o`/00_l700;o2002o`T00_l400Co0P02o`H00_l700?o0P03oaD0
0_l500;o1004o`<00ol500?o1002o`H00_l500;o1@02oah00_l900;o1@02o`D00_l700;o1002o`H0
0_lC00;o1P02o`@00ol400;o1P02o`H00_l400;o1P02o`D00_l600;o1`02o`P00_l700;o1@02o`@0
1?lA00004`02oa000_l;00;o3@02oaH00_l<00;o0P02o`800_l500;o2P03o`L00_l800;o2@02o`<0
1Ol200;o1P02o`P00_l200;o5P02o`D00_l400Co0P04o`H00ol300;o1P02o`D00_l500;o7P02o`T0
0_l500;o1@02o`<00_l200;o1002o`L00_lB00;o1P02o`D00ol300;o1P02o`H00_l400;o1`02o`@0
0_l600;o1`02o`P02ol500;o0`05oa40000C00;o3004o`030?oo00X00_l=00;o5P07o`L00_l200;o
2@07o`D00_l400Oo1`02o`T00_l300;o00<0ool00P02o`H00_l900Co5`02o`D00_l400;o00@0o`00
1?l700;o0`02o`H00_l500;o1@07oaT00_l900;o1@02o`D00_l200?o0P02o`@00_l700;o4P02o`H0
0_l600;o0`02o`H00_l600;o1002o`L00_l400;o1P02o`L00_l900Wo1P02o`<00_l00`3oo`0A0000
4`02o`X02Ol:00;o3@02oaH02Ol500Ko2@09o`<00_l400Oo1`02o`T00_l200?o00<0ool02P02o`T0
1?lG00;o1@02o`@00_l01P3o003o00;o1`03o`X00_l500;o1@09oaL00_l900;o1@02o`D00_l20003
o`3o00800_l400;o1`02oa800_l500?o1P03o`X00_l600;o1002o`L00_l400;o1@03o`L00_l900;o
1@02o`H00_l200?o00<0ool04@0001<00_l:00;o1003o`X00_l=00;o5P02o`D00ol400Ko2@02o`D0
0ol200;o4P02o`T00_l200;o0P02o`X00_l900?o6009o`@00_l00`3oo`02o`030?oo00P00ol900Wo
1@02o`D00olF00;o2@09o`D00_l0103oo`02o`030?oo00@00_l700;o4P09o`P00ol900;o1P02o`@0
0_l700;o1009o`P00_l:00;o0`02o`L00_l200;o0P02oa40000D00;o2002o`H00_l:00;o3002oaL0
0_l600;o1002o`800_l900;o1P02o`800_lB00;o2@02o`030?oo00<00_l:00;o2@04oaL02Ol400;o
00<0ool00_l00`3oo`0400;o0`02o`T02Ol500;o1P02oaH00_l900Wo1@02o`030?oo008000Co0?oo
1002o`L00_lB00So1@02o`<00_l900;o1P02o`@00_l700;o1008o`@00_l300;o0`02o`D00_l300;o
1`02o`030?oo00<00_lA00005002o`P00_l600;o2P02o``00_lG00;o1P02o`@00_l200;o0P02o`D0
0_l600;o0P02o`P00_l800;o2@05o`<00_l:00;o2006oaH00_l500;o0`02o`<00_l300;o0`02o`<0
0ol800;o1@02o`D00_l600;o5P02o`T00_l500;o1@02o`030?l0008000Co0?oo1002o`L00_lB00;o
1003o`@00_l300?o2002o`H00_l400;o1`02o`@00_l400?o0`02o`<00_l300;o1P02o`040?ooo`L0
1Ol300;o4@0001@00ol700;o1P02o`X00_l<00;o5`02o`H00_l400;o1P02o`D00_l600;o0`02o`H0
0ol800;o2@04o`@00_l:00;o1`03o`800olE00;o1@02o`<00_l300;o0`02o`<00_l400?o1`02o`D0
0_l500;o1P02oaH00_l900;o1@02o`D01?l300Co1002o`H00_lC00;o1@02o`@00_l400?o1`02o`H0
0_l400;o1P02o`D00_l500;o0`02o`<00_l300;o1P02o`030?oo00P01?l400;o4@0001D00_l700;o
1P000ol0000900;o2`02oaP00_l500?o1002o`H00_l500;o1@03o`<00ol400Co2002o`T01?l400;o
2P02o`L00_l400;o5@02o`D00_l300;o2002o`<00_l500;o1`02o`D00_l500;o1@03oaH00_l900;o
1@02o`D01?l400?o1002o`@01?lC00;o1003o`@00_l500;o1`02o`H00_l400;o1004o`D00_l400?o
0`02o`<00_l300;o1P05o`P01?l400;o4@0001H00_l700;o1002o`L00ol00`3oo`0:00;o5`0;o`<0
3?l300_o1@0:o`@02_l400Co0P06o`@02_l200Go0P05oa801?l300Co00<0ool01?l200Ko0P0:o`D0
1?l300Co0P0;oa<02_l400Co0`04o`<01?l500Co0P0:oa802_l500[o1@04o`@01?l200[o100:o`@0
3?l300Oo2004o`801_l@00005`000ol0000500Oo2006o`X000?o00005P09o`D03?l300Wo2@05o`03
0?oo00@02_l400?o0`06o`@02_l200Go0P05oa801?l300Co00<0ool01?l200Ko0P0:o`D01?l300Co
0P09oaD02_l400Co0`04o`<01?l500Co0P08oa@02Ol600[o1@04o`@01?l200So1P09o`D03?l300Oo
2003o`<01_l@00008@04o``00ooo0<H0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(92\\) PIPGILJV IWZHP LHHG AZUDATFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go2P0:o`T00_lE00So1`0:o`@02?l:00Ko1P0:o`<0
3Ol300Ko3002oaL02_l500;o1002o`D02_l500Co0`04o`802?lE00go0P04o`<01?l400Co0`04o`H0
1_lB00Ko0`06o`030?oo00So2@04o`H02?l500Ko0`06o`802?l400Oo3005oa@0000C00;o2@07o`P0
2_l:00;o5008o`L02_l400So200:o`@02_l300go00<0ool01ol:00Co5P0:o`D00_l400;o1@0:o`D0
1?l300Co0P08oaD03Ol200Co0`04o`@01?l300Co100:oa001_l300Ko00<0ool02?l700So100:o`<0
1_l300Ko0P08o`@01ol:00Wo4P0001<00_l>00?o2002o`D00_l:00;o5P02o`l00_l:00;o2`04o`D0
0_l800;o2P02o`H00_l0103oool400?o2@04oaX00_l800?o1003o`D00_l500;o1P02o`D00_l500;o
7002o`H00_l300;o1@02o`H00_l500;o1004o`D00_lB00;o1`02o`@00_l500;o1`02o`@00_l500;o
1004o`@00_l700;o1`02o`T00_l<00?o1@03oa40000C00;o3`03o`P00ol?00;o5P02o`l00_l:00;o
2`02o`L00_l800;o2P02o`H00_l00`3oo`0600;o2@04oaX00_l800Co0`03o`D00ol400;o1P02o`D0
0_l500;o7002o`H00_l300;o1@02o`H00_l500;o1002o`L00_lB00;o1`02o`@00ol400;o1P02o`H0
0_l400;o1P02o`@00_l700;o1`02o`T00_l<00;o1`02oa40000C00;o4002o`T00ol>00;o5P02o`l0
0_l:00;o2P03o`L00_l800;o2P02o`H00_l00`3oo`0600;o2002o`800_lI00;o2004o`801?l600?o
0`02o`H00_l500;o1@02oa`00_l600;o0`02o`D00_l600;o1@02o`<00ol700;o4P0;o`D00ol300;o
1P02o`H00_l400;o1`02o`<02ol700;o2@02o`800_l700;o2@02oa00000C00;o3004o`030?oo00T0
0ol=00;o5P07o`X00_l:00Oo1@02o`@01ol700;o2P02o`H00_l00`3oo`0600;o2002o`800_lI00;o
2002o`040?l000Co1`02o`<00_l600;o1@02o`D01olG00;o1P02o`<00_l500;o1P02o`D00_l300;o
1007oa802Ol700;o0`02o`H00_l600;o1002o`L00_l400Wo2002o`T00_l200;o1`02o`T00_l@0000
4`02o`X02Ol:00?o3002oaH02Ol800;o2P09o`<00_l400Oo1`02o`X00_lA00;o1`03o`800olH00;o
2002o`060?l00?l00_l700?o2P02o`D00_l500Wo5@02o`/00_l500;o1P02o`D00_l300;o1007oa80
0_l500;o1`03o`X00_l600;o1002o`L00_l400;o1@02o`P00_l900Ko1`02o`T00_l@00004`02o`X0
0_l400?o2`03o`/00_lF00;o1@03o`L00_l:00;o1@03o`800_lB00;o2P02oa400_l700;o1002oaP0
0_l800;o00<0ool00_l00`3oo`0800?o2@09o`D00_l500?o5002o`/02Ol600Wo0`02oah00_l300;o
2@03o`T00_l600;o1002o`L00_l500;o0`02o`T00_l900Ko1`02o`T00_l@00005002o`P00_l600;o
3002o`X00_lG00;o1P02o`L00_l:00;o1P02o`800_lB00;o2P02oa400_l700;o1002oaP00_l800;o
00<0ool00_l00`3oo`0400;o0`02o`T02Ol500;o1P02oa@00_l;00Wo1P09o`<00_lN00;o0`02o`D0
0_l300;o2@02o`H00_l400;o1`02o`D00_l300;o1002o`<00_l300;o1002o`800_l700;o2@02oa00
000D00;o2002o`H00_l=00;o2@02oaL00_l600;o1`02o`X00_l600;o0P02o`P00_l800;o2P02oa40
0_l600;o1P02oaL00_l700;o0`02o`<00_l300;o0`03o`P00_l500;o1@02o`H00_lD00;o2`02o`D0
0_l600;o1@02o`<00_l800;o5@02o`040?ooo`D00_l300?o2002o`H00_l400;o1`02o`H00_l0103o
ool400;o0`02o`<00_l400;o0P02o`800_l300;o2@02oa00000D00?o1`02o`H00_l=00;o2@02oaL0
0_l600;o1`02o`X00_l600;o0`02o`H00ol800;o2P02oa400_l600;o1P02oaL00_l700;o0`02o`<0
0_l300;o1003o`L00_l500;o1@02o`H00_lD00;o2`02o`D00_l600;o1@02o`@00_l600?o5@02o`03
0?oo00H00_l400?o1`02o`H00_l400;o1P02o`L00_l00`3oo`0500;o0`02o`<00_l400;o1P02o`@0
0_l700;o4@0001D00_l700;o1P000ol0000500;o1@02o`P00_lH00;o1@03o`L00_l:00;o1@03o`<0
0ol400Co2002o`X00_lA00;o1@03o`H00olF00;o1`02o`P00_l300;o1@02o`L00_l500;o1@02o`D0
0olD00;o2`02o`D00_l600;o1@02o`@00ol400Co5@05o`H00_l500;o1`02o`H00_l400;o1004o`L0
1Ol500;o0`02o`<00_l400;o1P02o`@00ol500?o4@0001H00_l700;o1002o`L00ol300?o1`02oaL0
2ol400[o100;o`D02_l400[o0`08o`T02_l00`3oo`04o`801_lA00[o0P06o`801_l200[o1@04o`<0
1?l200_o4P08o`L01?l300Co1004o`<01?l400[o4P07o`L02_l500Co1004o`802_l500Oo1P0<o`80
3?l500Wo4P0001L000?o00001@07o`T01ol80003o`0001H02Ol600[o1009o`T01Ol00`3oo`0400[o
0`08o`T02_l00`3oo`04o`801_lA00[o0P06o`801_l200[o1@04o`<01?l200Wo5008o`L01?l300Co
1004o`<01?l600Go00<0ool04P07o`L02_l500Co1004o`802?l700Oo1P0<o`803?l700Go50000240
1?l;00Goo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(93\\) LIRGILJTVFW HN LHHG AZUDATFO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3005o``00_lE00go0P0:o`@01Ol600?o1006o`H0
2_l300go0`06o`T02?l900;o2007o`T00_l400;o5004o`<01?l300Ko0`02oa403Ol200Co0`04o`@0
1?l300Co1P06oa801_l300Ko00<0ool02?l900Co1P08o`D01_l300Ko0P08o`@01ol<00Go500001<0
0_l900Oo2009o`/00_lD00go0P0:o`@01Ol500Co0P0:o`@02_l300go00<0ool01ol800So2004o`L0
1ol900;o1002oa@01?l300Co0`06o`800olA00go0P04o`<01?l400Co0`04o`@02_l@00Ko0`06o`03
0?oo00So1`08o`@02_l300Ko0`06o`802?l400Oo2P09oa80000C00;o3P03o`L00_l500;o2`02oaL0
0_l600;o1P02o`X00_l500?o0`04o`D00_l800;o2P02o`H00_l0103oool400?o2P02o`/01?l900;o
2`03o`@00olD00;o1@02o`D00_l400Co5002o`H00_l300;o1@02o`H00_l500;o1004o`D00_lB00;o
1`02o`@00_l500;o1`02o`@00_l500;o1004o`@00_l700;o1`02o`T00_l<00?o1@03oa40000C00;o
3`03o`h00_l:00;o5`02o`H00_l600;o2P02o`D00_l400;o1`02o`P00_l:00;o1P02o`030?oo00H0
0_l:00;o2`04o`T00_l;00Co0`03oa@00_l500;o1@02o`@01?lD00;o1P02o`<00_l500;o1P02o`D0
0_l400;o1`02oa800_l700;o1003o`@00_l600;o1P02o`@00_l600;o1002o`L00_l700;o2@02o``0
0_l700;o4@0001<00_l@00;o3P02o`X00_lG00;o1P02o`H00_l:00;o1002o`@00ol700;o2002o`X0
0_l600;o00<0ool01P02o`X00_l:00;o0P02o`P00_l200;o1`04o`801?lD00;o1@02o`D00_l300Go
5002o`H00_l300;o1@02o`H00_l500;o0`03o`L00_lB00_o1@03o`<00_l600;o1P02o`@00_l700;o
0`0;o`L00_l900;o0P02o`L00_l900;o400001<00_l<00Co00<0ool03@02o`X00_lG00;o1P02o`H0
0_l:00;o0`03o`@00_l400Oo1`02o`X00_l600;o00<0ool01P02o`X00_l:00;o0P02o`P00_l200;o
1`02o`040?l000Co5002o`D00_l500;o0`02o`030?oo01@00_l600;o0`02o`D00_l600;o1@02o`<0
0_l400Oo4P09o`L00_l300;o1P02o`H00_l400;o1`02o`@02Ol800;o2@02o`800_l700;o2@02oa00
000C00;o2P09o``00_l;00;o5`02o`h00_l:00Oo1@02o`@01ol700;o2P02oa400_l:00;o2@03o`80
0ol700Ko1`02o`060?l00?l00_lD00;o1@02o`D00_l200?o00<0ool05002o`/00_l500;o1P02o`D0
0_l300;o1007oa800_l500;o1`03o`X00_l600;o1002o`L00_l400;o1@02o`P00_l900Ko1`02o`T0
0_l@00004`02o`X00_l400?o2@04o``00_lG00;o3P02o`X02Ol300;o4P02o`X00_lA00;o2P02o`T0
0_l400;o1`06o`L00_l00`3oo`02o`030?oo01@02Ol500;o0P02o`800_lD00;o2`09o`H02Ol300;o
7P02o`<00_l900?o2@02o`H00_l400;o1`02o`D00_l300;o2@02o`T01_l700;o2@02oa00000D00;o
2002o`H00_l900?o3002oaP00_l>00;o2P02o`D00ol200;o4P02o`X00_lA00;o1@02o`<00_l300;o
1002o`@00_l700;o0P02o`L00_l00`3oo`02o`030?oo01@02Ol500;o00<0ool00`02oa@00_l;00Wo
1P09o`<00_lN00;o0`02o`D00_l300;o2@02o`H00_l400;o1`02o`D00_l300;o1002o`<00_l300;o
1002o`800_l700;o2@02oa00000D00;o2002o`H00_l;00;o2`02oaP00_l>00;o2P02o`H00_l200;o
2002o`P00_l:00;o4@02o`D00_l300;o0`02o`<00_l600;o1P02o`800_l200;o0P02o`<00_l300;o
4`02o`D00_l500Go0`02oa@00_l;00;o1@02o`H00_l500;o0`02o`P00_lE00;o00@0oooo1@02o`<0
0ol800;o1P02o`@00_l700;o1P02o`040?ooo`@00_l300;o0`02o`@00_l200;o0P02o`<00_l900;o
400001@00ol700;o1P02o``00_l:00;o6002o`h00_l:00;o1P02o`<00_l600?o2002o`X00_lA00;o
1@02o`<00_l300;o0`02o`H00_l600;o1P02o`800_l300;o0`02oa<00_l500;o1@04o`@00_lD00;o
2`02o`D00_l600;o1@02o`@00_l600?o5@02o`030?oo00H00_l400?o1`02o`H00_l400;o1P02o`L0
0_l00`3oo`0500;o0`02o`<00_l400;o1P02o`@00_l700;o4@0001D00_l700;o1P000ol0000;00;o
2@02oaT00_l>00;o2P02o`D00ol300?o1004o`P00_l:00;o4@02o`D00_l300;o0`02o`800ol600?o
1@02o`H00_l200;o2002oa<00_l500;o1@04o`@00_lD00;o2`02o`D00_l600;o1@02o`@00ol400Co
5@05o`H00_l500;o1`02o`H00_l400;o1004o`L01Ol500;o0`02o`<00_l400;o1P02o`@00ol500?o
4@0001H00_l700;o1002o`L00_l300?o2002oaL02?l700[o100;o`D02_l400[o0`08o`T02_l200co
00<0ool01?l200Ko0P0<o`030?oo00Co0P06oa401?l300Co0`04o`801_l@00So1`04o`<01?l400Co
0`04o`@02_lB00Oo1`0:o`D01?l400Co0P0:o`D01ol600co0P0<o`D02OlB00005`000ol0000500Oo
2007o`T000?o00005P08o`L02_l400Wo2@05o`030?oo00@02_l300So2@0:o`803?l00`3oo`04o`80
1_l200co00<0ool01?l200Ko4@04o`<01?l300?o0`06oa002?l700Co0`04o`@01?l300Co1P05o`03
0?oo01801ol700[o1@04o`@01?l200So1`07o`H03?l200co1`05oa@0000Q00Co2`04ool0aP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(94\\) PDWHNLJTVIX GR HHKG A YDATBP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3P06o`T00_lE00So1`08o`P00_l400;o1@04o`<0
1?l400Ko0`02o`803Ol300Ko2@08o`T00_l900[o0`05o`801OlE00Ko1005o`H00ol@00Co0`04o`<0
1?l300Co0`05o`H00_l500Ko4P06o`<01_lA00So1@08o`D01_l300Ko0P08o`@02_l500So5@0001<0
0_l900Oo3006o`X00_lD00So1`0:o`H00_l400;o1@04o`<01?l400Ko0P03o`803Ol00`3oo`07o`P0
2?l800Co200:o`<01Ol200Go4`0:o`801Ol500Co4004o`<01?l300Co0`04o`<01Ol500?o0`0:oa00
1_l300Ko4@08o`D02_l300Ko0`06o`802?l400_o1008oaD0000C00;o3P03o`d00_l<00;o5P02o``0
0_l400Co1003o`@00ol500;o1@02o`H00_l400Co1@02o`H00_l0103oool400?o2P02o`/01?l<00;o
2003o`@00olC00Co1@02o`@00_l500?o4`02o`D00_l500;o1@02o`H00_l500?o0`04o`D00_lB00;o
1`02oaH00_l900;o1004o`@00_l700;o1`02o`T00_l500?o1@02oaT0000C00;o3`03o``00_l<00;o
5P02o``00_l600;o1004o`<00ol500;o1@02o`H00_l400Co1@02o`H00_l00`3oo`0600;o2P02o`/0
1?l<00;o2@03o`800olD00;o1`02o`@00_l500;o5002o`D00_l500;o1@02o`H00_l500;o1002o`L0
0_lB00;o1`02oaH00_l900;o1P02o`@00_l700;o1`02o`T00_l600;o1@02oaT0000C00;o4002o`H0
2_l:00;o5P02o``00_l700;o0`04o`801?l500;o1@02o`H00_l300Go1@02o`H00_l00`3oo`0600;o
2P02o`X00_l200;o2`02o`X00_l200;o5003o`L00_l400;o1002oaD00_l500;o1@02o`D00_l600;o
1002o`@00ol700;o4P0;oaH00_l900;o1`02o`<02ol700;o2@02o`H00_l500;o6@0001<00_l<00Co
00<0ool01@0:o`X00_lF00Oo1`02o`L00_l300;o00@0o`001?l500;o1@02o`H00_l300;o00<0ool0
1@02o`H00_l00`3oo`0600;o2P02o`X00_l200;o2`02o`/01?lE00;o1007o`<00_l300?o5@02o`D0
0_l500;o1@02o`H00ol200?o1002o`@01olB00Wo5`02o`T00_l700;o1009o`P00_l900;o1P02o`D0
1olD00004`02o`X02Ol500;o1002o``00_lF00Wo1@02o`L00_l300;o00H0o`00o`02o`D00_l500;o
1P02o`800ol00`3oo`0500;o4@02o`X00_l900?o0P03o`X00_l;00Co5@02o`@01ol300Oo5P02o`D0
0_l500;o1@02o`H01ol500;o1007oa800_l500;o5`03o`P00_l700;o1002o`D00_l800;o2@02o`D0
0ol500Wo4P0001<00_l:00;o1003o`H00_l300;o3002oaH00_l500?o1002o`L00_l300;o00<0ool0
0_l00`3oo`0500Wo1P02o`800_l200;o1@02oa400_l:00;o2@02o`@00_l:00;o2`03oaH00_l>00Wo
5009o`D02Ol600Go1`02oah00_l300;o5`04o`P00_l700;o1@02o`<00_l900;o2@09o`H00_l500?o
4@0001@00_l800;o1P02o`L000Co00000_l;00;o5`02o`H00_l400;o1`02o`<00_l00`3oo`02o`03
0?oo00D02Ol600;o00<0ool00`02o`D00_lA00;o1@02o`<00_l300;o1002o`@00_l:00;o2`04oaD0
0_l>00;o1@03oa<02Ol500Wo1P02o`040?ooo`H00_lN00;o0`02oaH01_l700;o1`02o`D00_l300;o
1002o`<00_l300;o1008o`L00_l600;o4@0001@00_l800;o1P02o`L00_l200;o2`02oaL00_l600;o
1002o`L00_l200;o0`02o`<00_l400;o1@02o`H01Ol300;o1@02oa400_l500;o0`02o`<00_l300;o
1P02o`T00_l:00Ko5002o`P00_l400;o1P02oa<00_l500;o1@02o`D00_l600;o0P03o`D00_l800;o
5@02o`040?oooaH00_l200;o1`02o`L00_l600;o00@0oooo1002o`<00_l300;o1002o`@00ol600;o
1P02oa40000D00?o1`02o`H00_l80003o`0000;o2`02oaL00_l600;o1002o`H00_l300;o0`02o`<0
0_l400;o1@02o`H01?l400;o1@02oa400_l500;o0`02o`<00_l300;o1P02o`T00_l900?o0P03oa@0
0_l600?o1002o`H00_lC00;o1@02o`D00_l500;o1P02o`<00ol500;o1P03oaD00_l00`3oo`0F00?o
0`02o`H00_l600;o1`02o`030?oo00D00_l300;o0`02o`@00_l500;o1P02o`H00_lA00005@02o`L0
0_l60003o`0000P000Co0?oo2P02oaP00_l500?o1002o`@01?l300;o2002o`@00_l500;o1P04o`@0
0_l500;o4@02o`D00_l300;o0`02o`800ol600?o2002o`T00_l400;o5003o`@01?l400;o1@03oa<0
0_l500;o1@02o`D00_l600;o1003o`@00ol400Co5@05oaH00_l400;o1P02o`@01?l700Go1@02o`<0
0_l300;o1002o`@00ol600;o1@03oa40000F00;o1`02o`@00_l:00Co2@02oaL02ol400[o0`06o`80
1_l200Co0`04o`@01?l200Ko00<0ool01_l900[o0P0<o`030?oo00Co0P06o`<02_l300Go0P05oa<0
2_l200_o4`04o`<01?l300Co0`04o`<01Ol300Go0`0:oa801olE00Go0P05o`<02_l500Oo1P0<o`80
2_l500_o4P0001L000?o00001@07o``00ol90003o`0001H02Ol600So1@06o`801_l200Co0`04o`@0
0ol300Ko00<0ool01_l900[o0P0<o`030?oo00Co0P06o`<02_l300Go0P05oaD01Ol00`3oo`0200Wo
5@04o`<01?l300Co0`04o`<01Ol300Go1@05o`030?oo01801olE00Go0P05o`<02?l700Oo1P0<o`80
2Ol600Wo500002401?l=00?oo`350000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(95\\) ODWHNJJTWISZGR HIKG A  EATEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3005o``00_lI00Go1P08o`P00_l400;o1@04o`<0
1?l400Ko0`02o`@01_l800Ko2@08o`H00_l400;o1P0:o`@00_l00`3oo`03o`H02_l800Ko1005o`H0
0ol@00Co0`04o`<02_l400Go1P02o`D01_lB00Ko0`06oad03?l200Ko0`06o`802?l400co0`0=oa00
000C00;o2@07o`P02Ol;00;o5P09o`@02_l600;o1002o`D01?l300Co1006o`800ol200Wo1@09o`P0
2?l600;o1002o`H02_l400[o100:o`H02_l200Go1@04oa001?l300Co0`0:o`@01Ol500?o0`0:oa00
1_l300Ko7@0<o`801_l300Ko0P08o`@03?l300go400001<00_l>00?o1`02o`D00_l;00;o5@03o`D0
0ol400;o1004o`@00ol400?o1@02o`D00_l600;o1004o`800ol400?o1003o`@00ol:00;o2003o`@0
0ol900;o2003o`D00ol400;o1@02o`D01?l500;o1002o`D00olC00;o1@02o`P00_l:00;o1@03o`<0
1?l500;o4P02o`L00_lQ00;o1P02o`@00_l700;o1`02o`T00_l600;o1P02o`H00_l@00004`02o`l0
0ol>00;o2P02oaD00_l700;o1002o`H00_l400Co0`03o`D00_l500;o1P02o`@01?l200;o1P02o`@0
0_l600;o2P02o`P01?l300?o2@02o`P00_l700;o1003o`@00_l500;o1`02o`@00_l500;o5002o`D0
0_l800;o2P02o`D00_l400;o1`02oa800_l700;o8@02o`H00_l400;o1`02o`L00_l900;o1P02o`H0
0_l600;o400001<00_l@00;o3P02o`X00_lD00;o2@02o`<00_l700;o0`04o`801?l500;o1@02o`H0
0_l300Go0P02o`H00_l400;o1P02o`X00_l800Co0P04o`T00_l800;o1`02o`D00ol300;o1003o`L0
0_l400;o1002oaD00_l500;o2002o`X00_l400;o1003o`L00_lB00_o8@02o`800_l200;o100;o`L0
0_l900;o0P02o`800_l600;o1P02oa00000C00;o3004o`030?oo00d00_l:00;o5002o`T00_l300;o
1`02o`<00_l0103o0004o`D00_l500;o1P02o`<00_l00`3oo`0200;o1P02o`@00_l600;o2P02o`P0
0_l0103o0004o`T00_l@00?o1P02o`<00_l400;o1007o`<00_l300?o5@02o`D00_l800;o2P03o`80
0ol400;o1007oa802OlR00;o0P02o`T02Ol800;o2@02o`800_l:00;o1P02oa00000C00;o2P09o`d0
0_l:00;o5002o`T00_l300;o1`02o`<00_l01P3o003o00;o1@02o`D00_l600;o0P03o`030?oo00X0
0_l<00;o2P02o`P00_l01P3o003o00;o2@02o`/01ol700?o2002o`@01ol300Oo5P02o`D00_l800;o
2P07o`D00_l400Oo4P02o`D00_lR00Ko2@02o`D00_l800;o2@06o`X00_lH00004`02o`X00_l400?o
1P02o`@00_l;00;o5002o`T00_l300;o1`02o`<00_l00`3oo`02o`030?oo00D02Ol600;o0P02o`80
0_l:00;o3002o`X00_l800;o00<0ool00_l00`3oo`0900;o2@07o`X00ol700;o3P09oa@02Ol800;o
2P05o`L00_lN00;o0`02ob<01_l:00;o0`02o`T00_l900Ko2P02oaP0000D00;o2002o`H00_l600So
2P02oaD00_l900;o0`02o`L00_l300;o00<0ool00_l00`3oo`0500Wo1P02o`030?oo00<00_l:00;o
3002o`D00_l300;o0`02o`<00_l00`3oo`02o`030?oo00T00_l800?o2`02o`<00_l700;o3P02o`D0
0olC00Wo2002o`X00_l0103oool600;o7P02o`<00_lS00;o0P02o`X00_l300;o1002o`<00_l300;o
1002o`800_l:00;o600001@00_l800;o1P02o`H01ol;00;o5@02o`T00_l300;o1`02o`800_l300;o
0`02o`@00_l500;o1P05o`<00_l:00;o3002o`D00_l300;o0`02o`800_l300;o0`02o`P00_l800;o
1`000ol0000200;o0`03o`H00_l800;o1002o`H00_lC00;o1@02o`P00_l:00;o0P03o`D00_l800;o
5@02o`040?ooob<00_l200;o0P02o`L00_l0103oool400;o0`02o`<00_l400;o0P02o`800_l600;o
600001@00ol700;o1P02o`H00_l@00;o5P02o`L00_l400;o1P02o`<00_l300;o0`02o`@00_l500;o
1P04o`@00_l:00;o3002o`D00_l300;o0`02o`800_l300;o0`02o`P00_l800;o1P02o`@00_l400?o
1P02o`H00ol400;o1P02oa<00_l500;o2002o`X00_l300?o1@02o`H00olE00;o00<0ool09002o`H0
0_l700;o00<0ool01@02o`<00_l300;o1002o`H00_l600;o600001D00_l700;o1P000ol0000500;o
3`02oaL00ol500?o1002o`@01?l300;o2002o`@00_l500;o1P04o`@00_l:00;o3002o`D00_l300;o
0`02o`800_l800;o2002o`P00ol400?o1002o`D00_l600?o1004o`@00_l500?o4`02o`D00_l800;o
2P02o`@00ol400?o1004oaD01OlT00;o1P02o`L01Ol500;o0`02o`<00_l400;o1P02o`H00_lH0000
5P02o`L00_l400;o1`02o`h00_lI00Wo100:o`<01_l200Ko0P04o`<01?l400Co0P06o`@02_l400[o
0P0<o`030?oo00Co0P06o`<02_l500Wo100:o`H02_l200_o4`04o`<01?l300[o1005o`<01Ol300[o
4P07ob<03?l400Oo1P0<o`803?l300So5@0001L000?o00001@07o`P02?l80003o`0001X01Ol600So
1@06o`801_l200Co0`04o`@00ol300Ko100:o`@02_l200co00<0ool01?l200Ko0`0:o`L01Ol00`3o
000300[o2005o`030?oo00802OlE00Co0`04o`<02_l400Go0`05o`D01Ol00`3oo`0B00Oo8`0<o`@0
1ol600co0P0<o`<02?lE00008@04o`T02?oo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(96\\) OAWHKOJT ISZGO HIKG A  BBREL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lI00Go1006o`<01_l300;o1002o`D0
1?l300Co0`05o`H00_l500Go1`06o`T02?lD00[o1002o`030?oo00?o1P0:o`P01_l800Go5@04o`<0
1?l300[o1005o`H00_l500Ko4P06o`<01_lM00[o1@0:o`@01Ol600oo0`0=oa00000C00;o2@07o`X0
1ol;00;o5P09o`801_l300Ko0`02o`@00_l500Co0`04o`<01Ol500?o0`09o`<02Ol800So500:o`@0
2_l400[o1P0:o`@02OlC00Co0`04o`<02_l400Go1@03o`<02_l@00Ko0`06oad02ol400_o0`05o`D0
4?l300go400001<00_l>00?o2002o`@00_l;00;o5@03o`D00ol300;o1`02o`@00ol400?o1@02o`D0
0_l600;o1@03o`<00ol500?o0P03o`@00ol:00;o6`02o`P00ol500?o1002o`D00_l500Co1@02o`<0
0ol500?o4`02o`D00_l800;o2P02o`D00ol300Co1@02oa800_l700;o8@02o`D00ol500;o1@03o`@0
0_l500?o1002o`H00_l600;o1P02oa00000C00;o3`03o`H00_l600;o2P02oaD00_l700;o0`02o`L0
0_l400Co0`03o`D00_l500;o1P02o`D00_l400;o1`02o`800_l600;o2P02oa/00_l800;o1`02o`@0
0ol400;o1@02o`L00_l300;o1`02oa<00_l500;o2002o`X00_l500;o1002o`L00_lB00;o1`02ob40
0_l600;o1@02o`H00_l400;o1@02o`D00_l600;o1P02o`H00_l@00004`02oa000_l600;o1P02o`X0
0_lD00;o2@02o`802ol400Co0P04o`D00_l500;o1P02o`@00_l400;o2@02o`030?oo00H00_l:00;o
6`02o`P00_l700;o1@03o`<00_l400?o1`02o`800_l900;o4P02o`D00_l800;o2P02o`@00_l400?o
1`02oa802olQ00;o1P02o`D00_l600;o1002o`@00_l600;o0P02o`800_l600;o1P02oa00000C00;o
3004o`030?oo00D00_l600;o2P02oa@00_l900;o0`09o`D00_l0103o0004o`D00_l500;o1P03o`80
0ol400;o2@02o`030?oo00H00_l:00;o6`02oa000ol600;o0`02o`@00_l400Oo00<0ool02@02oa80
0_l500;o2002o`X00ol200?o1002o`@01olB00Wo8P02o`H00_l500;o1P02o`@00_l300?o1P02o`80
0_l:00;o1P02oa00000C00;o2P09o`D00_l600;o2P02oa@00_l900;o0`02o`D00_l500;o00H0o`00
o`02o`D00_l500;o1P07o`D00_l900;o2@02o`X00_lK00;o2`07o`L00ol800;o1007o`030?oo00T0
0_lB00;o1@02o`P00_l:00Oo1@02o`@01olB00;o1@02ob800_l500?o1@02o`D00ol400Oo1`06o`X0
0_lH00004`02o`X00_l400?o1@03o`@00_l;00;o5002o`T00_l400;o0`02o`H00_l00`3oo`02o`03
0?oo00D02Ol600Go1`02o`T00_l900;o2P02oa/00_l900Oo2P03o`L00_l<00;o2@02oa802Ol800;o
2P05o`L00_lN00;o0`02ob<02Ol600Wo1@09o`D01_l:00;o600001@00_l800;o1P02o`D02Ol:00;o
5@02o`T00_l400;o0`02o`H00_l00`3oo`02o`030?oo00D02Ol600;o00@0oooo1P02o`T00_l900;o
1@02o`<00_l300;o5P02o`P00ol;00;o0`02o`L00_l<00;o2@02oa802Ol800;o2P02o`040?ooo`H0
0_lN00;o0`02ob<02?l700So1P02o`D00ol400;o0P02o`X00_lH00005002o`P00_l600;o1@02o`03
0?oo00;o3002oaD00_l900;o1@02o`040?ooo`D00_l300;o0`02o`@00_l500;o1P02o`800ol500;o
2@02o`T00_l500;o0`02o`<00_lF00;o2002o`L000?o00000P02o`<00ol600;o2002o`800_l900;o
4P02o`D00_l800;o2P02o`800ol500;o2002oaD00_l0103ooolS00;o1003o`H00_l400?o1@02o`H0
0_l400;o0P02o`800_l600;o600001@00ol700;o1P02o`H00_l@00;o5P02o`L00_l600;o00<0ool0
1P02o`<00_l300;o1002o`D00_l600;o0`03o`D00_l700;o2P02o`D00_l300;o0`02oaH00_l800;o
1P02o`@00_l400?o1P02o`H00ol300;o1`02oa<00_l500;o2002o`X00_l300?o1@02o`H00olE00;o
00<0ool09002o`D00_l600;o1@02o`D00_l600;o1002o`H00_l600;o600001D00_l700;o1P000ol0
000500?o3P02oaL00ol500?o1P05o`H00_l800;o1002o`D00_l600;o1003o`@00ol500?o2P02o`D0
0_l300;o0`02oaH00_l800?o1003o`@00_l500;o1P03o`@01?l300?o1@03oa<00_l500;o2002o`X0
0_l400?o1003o`@01?lE00Go9002o`@00ol600;o1003o`D00_l500?o1002o`H00_l600;o600001H0
0_l700;o1002o`P00ol<00;o6@09o`@01ol600Ko0P06o`801?l300Co0`05o`<01Ol300Wo1P0:o`80
3?lB00[o1@09o`@02_l600[o1009oa<01?l300Co0`0:o`@01Ol300Go0`0:oa801olS00[o1@0:o`@0
2ol300co0`08oaD0000G0003o`0000D01ol:00Oo1`000ol0000J00Go1P07o`H01_l200Ko0P04o`<0
1?l300Go0`05o`D01Ol800[o0P0<oa802_l700Go00<0o`000`0:o`P01Ol00`3oo`0600Go5@04o`<0
1?l300[o1005o`<01Ol500Go00<0ool04P07ob<02Ol600Wo1@09o`D03?l300So5@0002401?l=00Go
o`330000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(97\\) RFWFGOMR ISZGO MKKG A  DBREI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@02o`h00_lE00Go1P0:o`X00_l400;o1007o``0
1_l800Go1@05o`<01Ol200Go1P03oa002_l400;o00<0ool00ol600[o2006o`P01OlD00Go0`05o`03
0?oo00?o1P02o`801Ol600;o1@06oa801_l300Ko7P08o`H02_l400Go1P0?o`@02_lB00004`02o`T0
1ol;00;o3`02oa@01Ol500_o2P02o`@00_l400Oo2P0:o`@02Ol300Go0`05o`801Ol500Co400:o`@0
2_l400[o1P0:o`@02OlB00Go0`05o`030?oo00?o1@03o`801Ol500?o0`0:oa001_l300Ko7P0:o`@0
2ol300Go1@0@o`@02_lB00004`02o`h00ol;00;o3P02oaH00_l500?o1002o``00ol400?o1@02o``0
1?l500;o0`03o`D00ol300;o1`02o`D00_l500?o5P02o`P00ol500?o1002o`D00_l500Co1@02o`<0
0ol500?o4P02o`L00_l400;o1@03o`D00_l500?o0`04o`D00_lB00;o1`02ob400_l400Co1@02o`D0
0ol400;o1@03o`@00_l600;o2002oaH0000C00;o3`03o`X00_l>00;o5P02o`D00_l500;o3004o`<0
0ol500;o3002o`L00_l300;o1`02o`<00_l700;o1@02o`D00_lG00;o2002o`L00_l400?o1002o`D0
0_l700;o0`02o`L00_lB00;o1`02o`@00_l500;o1P02o`D00_l400;o1`02oa800_l700;o8@02o`H0
0_l500;o1P02o`@00_l500;o1@02o`H00_l800;o5P0001<00_l@00;o2P02o`h00_lF00;o1002o`H0
0_l200;o2004o`801?l500;o0P02o`L00ol700;o0P02o`T00_l200;o0`02o`800_l500;o1002oaP0
0_l800;o1`02o`D00ol300;o1003o`L00_l200;o2@02oa400_l300;o0P02o`@00_l400;o1`02o`@0
0_l400?o1`02oa802olQ00;o1`02o`@00_l600;o1002o`@00_l600;o0P02o`800_l800;o5P0001<0
0_l<00Co00<0ool02P000ol0000<00;o5P02o`<00ol600;o0P02o`P00_l0103o0004o`D00_l200;o
1`02o`@01ol00`3oo`0900;o0P02o`800ol200;o1@02o`<00olH00;o4003o`H00_l300;o1002o`@0
1ol00`3oo`0900;o4@02o`800ol200;o1003o`800ol700?o0P03o`@00_l400Oo4P09ob800_l700;o
1002o`H00_l400;o0`03o`H00_l200;o3002oaH0000C00;o2P09o`X00_l=00;o5P07o`L01_l800;o
00H0o`00o`02o`D01_l700;o1007o`030?oo00T00_l200;o0P000ol0o`0200;o1@07oaT00_l;00Oo
1`03o`P00_l400Oo00<0ool02@02oa400_l20003o`3o00800_l400Oo2007o`D00_l400Oo4P02o`D0
0_lR00;o1`02o`@00_l500?o1007o`L01_l<00;o5P0001<00_l:00;o1003o`X00_l=00;o5P09o`D0
1_l800;o00<0ool00_l00`3oo`0500Ko1`02o``00_l900;o0P02o`040?oo00;o00<0ool01@09oaL0
0_l900Oo2P03o`L00_l<00;o2@02oa400_l0103oo`02o`030?oo00@01Ol:00Go1`02oah00_l300;o
8`02o`L00_l400Wo1@09o`D01_l<00;o5P0001@00_l800;o1P02o`/000?o00002P02oaL00_l500?o
1002o`800_l800;o00<0ool00_l00`3oo`0500;o0P02o`L00_l<00;o2@02o`800_l00`3oo`020004
o`3oo`D00_l500?o5P02o`P00ol;00;o0`02o`L00_l<00;o2@02oa400_l00`3oo`020004o`3oo`@0
0_l0103oool900;o00@0oooo1P02oah00_l300;o8`02o`L00_l400So1P02o`D00ol400;o0P02o``0
0_lF00005002o`P00_l600;o2`02o`/00_lG00;o1P02o`@00_l200;o0P02o`<00_l300;o0`02o`@0
0_l200;o0P02o`<00_l800;o0P02o`T00_l200;o00<0o`000P001?l0ool500;o1P02oaH00_l800;o
1`000ol0000200;o0`03o`H00_l800;o0P02o`T00_lA00;o00<0o`000P001?l0ool400;o0P03o`P0
0_l200?o1@02o`P00_lE00;o00@0oooo8`02o`L00_l400;o1003o`D00_l600;o1002o`800_l200;o
2002oaH0000D00?o1`02o`H00_l;00;o2`02oaL00_l600;o1002o`H00_l300;o0`02o`<00_l400;o
1P02o`@00_l600?o0`02o`L00_l300Co0`04o`D00_l600;o5P02o`P00_l600;o1002o`@00ol600;o
1P03o`<00_l700;o4P04o`<01?l400;o0`03o`L00_l300?o1@02o`H00olE00;o00<0ool09002o`H0
0_l500;o1@02o`D00_l600;o1002o`H00_l800;o5P0001D00_l700;o1P000ol0000;0003o`0000P0
0_lH00;o1@03o`@00_l600;o0`02o`P00_l400;o1P02o`@00ol400Co0`03o`D00ol300Co1003o`D0
0_l500?o5P02o`P00ol400?o1002o`D00_l600?o1004o`<00ol500?o4P04o`@00ol400;o1003o`H0
0_l400?o1003o`@01?lE00Go9002o`@01?l500;o1003o`D00_l500?o1002o`H00_l800;o5P0001H0
0_l700;o1002o`H00_l500;o2002oaL02ol300co0P06o`801_l00`3oo`0:o`D02_l400Wo0`04o`D0
1?l200_o4`0:o`D02Ol400[o1P0:o`@02OlB00Co1@04o`030?oo00?o0`05o`801Ol300Go0`0:oa80
1olT00[o100:o`@02ol300co100:oa80000G0003o`0000D01ol700Wo20000ol0000F00Wo1@0<o`80
1_l200Ko00<0ool02_l700Go00<0ool01P05o`D01?l500Co0P09oaD02_l700Go00<0o`000`0:o`P0
1Ol00`3oo`0600Go5004o`D01?l00`3oo`03o`<01Ol200Go0`05o`D01Ol00`3oo`0B00Oo9008o`H0
2Ol500Wo1@0<o`@02_lB00008@04o`P02Ooo0<@0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(98\\) NGWFGOJT IVZGOWMKJC A  DAUEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02ool0^P0001D00_lX00;oo`2i00005002obX0
0_oo0;P0000D00;o:P02ool0^00001@00_l800Go3@04o``00_lF00Ko0`02o`H01_l700;o1002o`@0
1ol<00Ko2005o`L01_l900So500:o`P00_l800[o2006o`P01Ol800;o1002o`@01Ol300Go00<0ool0
0ol600;o1006o`X01OlC00Ko0`06oah02?l500Ko0`06o`D01?l500co0`0=oa00000C00;o2@07o`T0
2?l;00;o5@06o`800ol400[o1@02o`@00_l400Oo2P0:o`@02Ol300Wo2008oa@02_l700Co1`0:o`H0
2_l400Wo1P02o`@00_l400Go0`05o`030?oo00?o1@03o`802Ol700Wo4@06o`<01_lN00[o0`06o`<0
1_l300So0`0<o`<03Ol@00004`02o`h00ol700?o1003o`X00_lF00;o1004o`<01?l500;o1003o`@0
0ol500;o3004o`D00_l300?o1@03o`800ol400?o2P02oa/00_l;00Co2002o`D00_l500Co1@02o`<0
0ol500?o1003o`@00ol400;o1`02o`@00_l500?o0`03o`@00ol500?o1@03oa800_l700;o8@02o`@0
1?l400;o1`02o`D00_l400;o1@02o`H00_l600;o1P02oa00000C00;o3`03o`H00_l600;o2P02oaH0
0_l400Co0`02o`L00_l400Co0`03o`D00_l<00;o1`02o`<00_l700;o0P02o`H00_l:00;o6`02o`/0
1?l800?o1002o`D00_l700;o0`02o`L00_l400Co0`03o`@00_l700;o1002o`D00_l400;o1P02o`D0
0_l700;o4P02o`L00_lQ00;o1P02o`@00_l700;o1002o`H00_l400;o1P02o`H00_l600;o400001<0
0_l@00;o1P02o`H00_l:00;o5P02o`<01Ol200?o1`02o`@01?l200Co1@02o`800_l700?o1`02o`80
0_l900;o00<0ool01P02o`X00_lK00;o2P02o`800_l800?o0`02o`@00ol700;o0P02o`T00_l300Co
0P04o`@00_l300;o0P02o`@00_l400;o1@02o`H00_l400?o6`0;ob400_l700;o0`0;o`@00_l600;o
1002o`800_l200;o1P02o`H00_l@00004`02o``01?l00`3oo`0500;o1P02o`X00_lF00;o0`02o`03
0?oo00800_l400Oo0`02o`040?l000Co1@02o`800_l700;o1007o`030?oo00T00_l00`3oo`0600;o
2P02oa/00_l:00;o0P02o`T00_l300;o1002o`@01ol00`3oo`0900;o0`02o`040?l000Co1002o`80
0ol200;o1003o`800ol500;o1P02o`@00_lM00Wo8P02o`L00_l400Wo1@02o`H00_l400;o0P02o`X0
0_l600;o400001<00_l:00Wo1P02o`@00_l;00;o5P02o`800ol00`3oo`0200;o1007o`<00_l01P3o
003o00;o1@06o`L00_l400Oo00<0ool02@02o`T00_l:00;o6`02o`T00ol200?o2003o`P00_l400Oo
00<0ool02@02o`<00_l01P3o003o00;o1002o`8000?o0?l00P02o`@01ol>00;o1002oad00_l500;o
8P02o`L00_l400;o1@02o`D00_l600;o1006o`X00_lH00004`02o`X00_l400?o1`07o`/00_lF00;o
0P02o`800_l200;o3P02o`030?oo00;o00<0ool01@06o`L00_l<00;o2@02o`T00_l:00;o6`02o`T0
0_l400;o2@03o`L00_l<00;o2@02o`<00_l00`3oo`02o`030?oo00@00_l0103oo`02o`030?oo00@0
1Ol@00;o1002oah00_l300;o8`02o`L00_l500;o0`02o`H00_l600;o1006o`X00_lH00005002o`P0
0_l600;o1`06o`/00_lG00;o00<0ool00`02o`800_l>00;o00<0ool00_l00`3oo`0500;o0P02o`L0
0_l<00;o2@02o`T00_l500;o0`02o`<00_lF00;o2@02o`@00_l500;o0`02o`L00_l<00;o2@02o`<0
0_l00`3oo`02o`030?oo00@00_l00`3oo`020004o`3oo`@00_l0103oool?00;o1002oah00_l300;o
8`02o`L00_l500;o0`02o`H00_l600;o1002o`800_l:00;o600001@00_l800;o1P02o`H00_l400;o
2P02oaL01Ol300;o0P02o`P00_l300;o0`02o`<00_l400;o0P02o`800_l300;o2002o`800_l900;o
2@02o`D00_l300;o0`02oaH00_l800;o1P02o`@00_l300?o1P02o`P00_l200;o2@02o`800_l300;o
0`02o`<00_l00`3o00020004o`3oo`@00_l200?o3P02o`@00ol700;o5@02o`040?ooob<00_l700;o
1P02o`040?ooo`H00_l600;o1002o`800_l200;o1P02oaP0000D00?o1`02o`H00_l500;o1P02o`T0
0_lG00Co1002o`<00_l600?o0`02o`<00_l300;o1002o`H00_l400;o1P03o`<00_l700;o2P02o`D0
0_l300;o0`02oaH00_l800;o1P02o`@00_l400?o1P02o`H00ol300;o1`02o`<00_l300;o0`02o`<0
1?l300Co1002o`<00ol=00;o1@02o`L00_lE00;o00<0ool09002o`H00_l700;o00<0ool01`02o`H0
0_l400;o1P02o`H00_lH00005@02o`L00_l60003o`0000@00_l600;o2002oaP01?l400;o0`03o`@0
1?l300;o2002o`@00_l600;o1003o`@01?l300?o1@03o`X00_l500;o0`02o`<00_lF00;o1`03o`H0
0ol300;o1@02o`H00ol400Co0`03o`D00ol300;o2002o`<01?l400?o1002o`@00ol<00;o1@03o`D0
0olE00Go9002o`@01?l700Go1`02o`H00_l400;o1P02o`H00_lH00005P02o`L00_l400;o1P03o`@0
0ol700;o6004o`801_l300[o0P06o`801_l00`3oo`0:o`D02_l400Wo1P0:o`803?lB00[o0P06o`80
1_l200[o1P0:o`@02Ol300Ko0P06o`030?oo00;o1@04o`030?oo00?o0`05o`D02_l300[o4P07ob@0
2_l500Oo1`04o`@01?l00`3oo`0:o`<02?lE00005`000ol0000500Oo2008o`P000?o00005`03o`<0
1_l500Go00<0ool00P06o`801_l00`3oo`0:o`L01Ol00`3oo`0600Go200:o`803?lB00[o0P06o`80
1_l200[o2005o`030?oo00H01Ol500Ko0P06o`030?oo00;o1@04o`030?oo00?o0`05o`D02_l500Go
00<0ool04P07ob@02?l700Oo1`04o`@01?l00`3oo`0:o`<02?lE00008@04o`X01_oo0<D0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(99\\) NGWFIQJT IVZGOYMKJC A  BEUEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP0001L000?o000090000ol0003o0;T0000F00;o9P02of800_l400?oo`1?00005@02obP00_mQ00[o
o`1>00005002obX00_mQ00Go0P02ool0CP0001@00_lZ00;oH@000ol0003o05@0000D00;o2005o`X0
1Ol>00;o5P06o`<00_l600Ko1`02o`@00_l400Oo2@0:o`L01Ol700Ko2@08oa@02_l800;o200:o`P0
1_l800Go2008o`@01Ol300Go00<0ool00ol600;o1006o`X01OlC00Ko0`06oad02_l500co1`04o`D0
3?l300go400001<00_l900Oo2007o`d00_lE00Ko0P03o`@02_l500;o1002o`@01ol900[o1@09o`<0
2Ol800So500:o`L01?l700[o1P0:o`@02Ol600So1005o`<01Ol00`3oo`03o`D00ol200Wo1`09oa40
1_l300Ko7@0;o`@03?l500So0`0<o`<03Ol@00004`02o`h00ol<00?o3002oaH00_l400Co0`04o`D0
0_l400?o1003o`D00_l@00;o2003o`D00ol200?o1003o`X00_lK00;o2`04o`P00_l500;o1@04o`D0
0_l300?o1@03o`P00_l800;o1`02o`@00_l500?o0`03o`@00ol500?o1@03oa800_l700;o8@02o`D0
0ol500;o1P02o`D00_l400;o1@02o`H00_l600;o1P02oa00000C00;o3`03o``00ol;00;o5P02o`@0
1?l300;o1`02o`@01?l300?o1@02oa000_l800;o1`02o`800_l600;o2P02oa/00_l;00Co2003o`@0
0_l500;o1`02o`<00_l700;o2002o`P00_l700;o1002o`D00_l400;o1P02o`D00_l700;o4P02o`L0
0_lQ00;o1P02o`D00_l600;o1002o`H00_l400;o1P02o`H00_l600;o400001<00_l@00;o3@02o`/0
0_lF00;o0`05o`800ol700;o1004o`801?l500;o0P02o``00_l700;o2@02o`030?oo00H00_l:00;o
6`02o`X00_l200;o2003o`<00_l400?o1`02o`800_l900;o1`02o`P00_l300;o0P02o`@00_l400;o
1@02o`H00_l400?o6`0;ob400_l600;o1@02o`800_l200;o1002o`H00_l400;o0P02o`800_l600;o
1P02oa00000C00;o3004o`030?oo00P01?l00`3oo`0:00;o5P02o`<00_l00`3oo`0200;o1007o`<0
0_l0103o0004o`D00_l200;o3002o`L00_l900;o00<0ool01P02o`X00_lK00;o2P02o`800_l900;o
0`02o`@00_l400Oo00<0ool02@02o`L00_l800;o0P03o`800_l400?o0P03o`D00_l600;o1002oad0
2OlR00;o1P02o`D00_l200;o2002o`H00_l400;o0P02o`X00_l600;o400001<00_l:00Wo1P09o`X0
0_lF00;o0P03o`030?oo00800_l400Oo0`02o`060?l00?l00_l500Ko3002o`L00_l900;o2@02o`X0
0_lK00;o2@03o`800ol800?o2002o`@01ol00`3oo`0900;o1`03o`L00_l20003o`3o00800_l400Oo
3P02o`@00_lM00;o1@02ob800_l500?o1@06o`P00_l600;o1006o`X00_lH00004`02o`X00_l400?o
1P02o`@00ol:00;o5P02o`800_l200;o0P02o`h00_l00`3oo`02o`030?oo00D01_l<00;o1`02o`T0
0_l900;o2P02oa/00_l900;o1002o`T00ol700;o3002o`T00_l600Co1`02o`040?oo00;o00<0ool0
1005oa000_l400;o7P02o`<00_lS00Wo1P06o`P00_l600;o1006o`X00_lH00005002o`P00_l600;o
1@02o`H00_l900;o5`02o`030?oo00<00_l200;o3P02o`030?oo00;o00<0ool01@02o`800_l<00;o
1`02o`T00_l900;o1@02o`<00_l300;o5P02o`T00_l400;o1@02o`<00_l700;o3002o`T00_l500Ko
1P02o`030?oo008000Co0?oo1002o`040?ooo`l00_l400;o7P02o`<00_lS00So1`02o`800_l800;o
1P02o`@00_l200;o2P02oaP0000D00;o2002o`H00_l500;o1P02o`T00_lG00Go0`02o`800_l800;o
0`02o`<00_l300;o1002o`800_l200;o2002o`L00ol800;o2@02o`D00_l300;o0`02oaH00_l800;o
1P02o`@00_l300?o1P02o`P00_l200;o2@02o`D00_l200;o1P02o`030?l0008000Co0?oo1002o`80
0ol>00;o1003o`L00_lE00;o00@0oooo8`02o`@00ol600;o0P02o`800_l400;o1P02o`@00_l200;o
0P02o`H00_lH00005003o`L00_l600;o1@02o`H00_l900;o5`04o`@00_l300;o1P03o`<00_l300;o
0`02o`@00_l600;o2002o`P00_l700;o2P02o`D00_l300;o0`02oaH00_l800;o1P02o`@00_l400?o
1P02o`H00ol300;o1`02o`D00ol300;o1@04o`<01?l400;o0`03o`d00_l500;o1`02oaD00_l00`3o
o`0T00;o1@02o`H00_l600;o1002o`H00_l400;o1P02o`H00_lH00005@02o`L00_l60003o`0000@0
0_l60003o`0000L00_lH00Co1002o`<00ol400Co0`02o`P00_l400;o1P02o`P00_l900;o1@02o`/0
0_l500;o0`02o`<00_lF00;o1`03o`H00ol300;o1@02o`H00ol400Co0`03o`D00ol500;o1002o`D0
1?l400?o1002o`@00ol<00;o1@03o`D00olE00Go9002o`@00ol600;o1P02o`@00_l600;o1002o`H0
0_l600;o600001H00_l700;o1002o`L00_l400;o2002oaP01?l200Ko0`0:o`801_l200Ko00<0ool0
2_l400[o1@09o`H02_l200co4P0:o`801_l200Ko0P0:o`H02_l400Wo1005o`801Ol200Co1@04o`03
0?oo00?o0`05o`D02_l300[o4P07ob<02_l500co0`04o`@01?l00`3oo`0:o`<02?lE00005`000ol0
000500Oo2007o`T000?o00005`03o`<01_l500Go00<0ool00P06o`801_l00`3oo`0:o`@02_l700Go
200:o`803?lB00[o0P06o`801_l200[o2005o`030?oo00H01Ol600Go0P05o`801?l500Co00<0ool0
0ol300Go1@0:o`D01Ol00`3oo`0B00Oo8`09o`H03?l300Co1004o`030?oo00[o0`08oaD0000Q00Co
2`04ool0aP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(100\\) NGSFIQJR IVZJOYMKJA A  EEUEL)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02of400_l400?oo`1800003P02ocL00_mP00[o
o`1700003@02ocT00_mP00Go0P02ool0A`0000d00_li00;oH0000ol0003o04d0000=00;o2@09o`P0
1?l:00Co3@02oaD01_l300;o1`06o`D00_l00`3oo`03o`H01ol800[o1`05o`P01_l600Go1P03oa00
2_l800;o2@0:o`D01_l;00Go1`08o`@01Ol300Go0P05o`H00_l300Ko1P06o`<01_l=00Ko0`06oah0
3?l200co1`04o`H03?l200go2@0000`00_l:00Wo1`06o`P01_l=00;o5006o`800ol500[o0`0:o`@0
1ol800[o1@09o`@02Ol500Go1@04oa002_l700Co200:o`<02Ol800Wo1@08o`@01Ol300Go0P05o`D0
0ol00`3oo`07o`D01_l300Ko3@06o`<01_lN00co0P0<o`D02?l400co0P0=o`T0000<00;o3P02o`T0
0ol200?o1P03o`800ol<00;o5@02o`@01?l400Co1@02o`<00ol500?o1@02o`l00_l800?o1@03o`<0
0ol400?o1P02o`D00olF00;o2`04o`T00_l500;o0`03o`@00ol600?o1@03o`L00_l800;o1`02o`D0
0_l500?o0P03o`@00ol600;o1`02oa400_l700;o8P02o`H00_l400;o1P02o`D00_l400;o1P02o`H0
0_l500;o1P02o`T0000<00;o3P02o`T00_l400;o1P02o`@00_l<00;o5@02o`@01?l400;o1`02o`<0
0_l700;o1@02o`l00_l800;o1`02o`<00_l600;o1P02o`D00_lG00;o2`04o`T00ol400;o0`02o`H0
0_l600;o1`02o`L00_l800;o1`02o`D00_l500;o0`02o`H00_l600;o1`02oa400_l700;o8P02o`H0
0_l400;o1P02o`@00_l600;o1@02o`H00_l500;o1P02o`T0000<00;o3P02o`P00_l600;o1002o`H0
0_l;00;o5@02o`<01Ol300?o1`02o`<00_l700;o1@02o`800_l;00;o1`02o`T00_l200;o1P02o`H0
0_l400;o6002o`X00_l200;o2@03o`<00_l300;o1P02o`D00_l900;o1P02o`P00_l300;o0P02o`D0
0_l400;o1002o`H00_l600_o4@0;ob800_l200;o0P02o`@00_l200;o0P02o`@00_l600;o1@02o`80
0_l200;o1@02o`H00_l900003002o`h00_l800;o1P02o`@00_l600;o2`02oaD00_l300;o00<0ool0
0`02o`@01ol:00?o1@02o`800_l;00;o1`02o`T00_l200;o1P02o`H00_l300?o6002o`X00_l200;o
2P02o`<00_l300;o1P02o`D00_l900;o1P02o`P00_l200?o0P02o`D00ol200?o1002o`H00_l700Wo
4`09ob<00_l200;o2002o`800_l800;o1P02o`D00_l200;o2@02o`H00_l900003002o`h00_l800;o
1P02o`@00_l600;o2`02oaD00_l200?o00<0ool00`02o`@01ol500Oo1P06o`/00_l700;o2@02o`X0
0_l600Oo6@02o`T00ol200?o2@03o`l00_l500;o2@02o`H00ol700;o0P000ol0o`0200;o1@07o`d0
0_l700;o1@02oa<00_l500;o8`06o`P01_l800;o1P02o`D01_l900;o4@0000`00_l>00;o2002o`H0
0_l400;o1P02o`/00_lE00;o0P02o`800_l300;o3P07o`P01_l;00;o1`02o`T00_l:00;o1P09oaL0
0_l900;o1002o`X00ol>00;o1@02o`T00_l500Co1`02o`040?oo00;o00<0ool01@05o`l00_l800;o
0`02oaD00_l300;o9006o`P01_l800;o1P02o`D01_l900;o4@0000d00_l=00;o2002o`H00_l400;o
1P02o`X00_lF00;o00<0ool00`02o`<00_l=00?o3@02o`800_l;00;o1`02o`T00_l:00;o1P02o`D0
0olF00;o2@02o`@00_l600;o0`02o`h00_l500;o2@02o`@01_l600;o00<0ool00P001?l0ool500;o
00@0oooo3P02o`P00_l300;o5@02o`<00_lT00;o0P02o`P00_l200;o2002o`H00_l500;o0P02o`T0
0_lA00003@02o`d00_l800;o1P02o`@00_l600;o2P02oaH01Ol300;o0`02o`P00_l300;o1`000ol0
000400;o0P02o`800_l700;o1`03o`P00_l:00;o1P02o`H00_lF00;o2002o`H00_l500;o0`03o`d0
0_l500;o2@02o`@00_l200;o1P02o`030?l0008000Co0?oo1@02o`800ol=00;o2@02o`040?oooaH0
0_l0103ooolT00;o0P02o`800_l400;o0P02o`800_l400;o1P02o`D00_l200;o0P02o`D00_lA0000
3@03o``00_l800;o1P02o`@00_l600;o2P02oaH01?l400;o1002o`H00ol300;o1P02o`H00_l600;o
1`02o`P00_l700;o2`02o`H00_l600;o5P02o`P00_l600;o1@02o`@00ol<00;o1P02o`L00_l400?o
0`02o`D01?l300Co1@02o`<00ol<00;o2@02o`030?oo01L00_l00`3oo`0U00;o1P02o`@00_l600;o
1002o`H00_l500;o1P02o`D00_lA00003P02o``00_l900;o1002o`H00_l400;o2P02oaL01?l400;o
1003o`@01?l300?o1003o`H00_l600;o1`02o`T00_l500;o3002o`H00_l500?o5P02o`L00ol600?o
1002o`D00_l<00;o1P03o`D00ol400;o1002o`D01?l400?o1@02o`@00ol;00;o2@05oaL01OlU00;o
1P02o`@00_l600;o1002o`H00_l500;o1P02o`D00_lA00003`02o`L00ol00`3oo`0900?o0P03o`H0
0ol200?o2@02oaL01?l200Ko100:o`@02Ol400co0`0:o`D02Ol700[o00<0ool02OlC00[o0P06o`80
1_l300[o1P0:o`@02Ol300Go0P05o`801?l500Co0P05o`<01Ol400[o0`07oaD01olT00co0P0<o`<0
1?l400Co0P0<o`802?l>000040000ol0000500Ko2P06o`P01_l:0003o`0001H00ol300Ko1P05o`03
0?oo00H01Ol00`3o000300co0`0:o`L01Ol900[o00<0ool01olE00[o0P06o`801_l300[o1P0:o`H0
1Ol500Go0P05o`801?l500Co0P05o`<01Ol400[o0`07oaD01olT00co0P0<o`<01?l400Co0P0<o`80
2?l>00006`03o`/01?l:00Coo`2o0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(101\\) NGSFIMIR IWZMPYOKJC A  EAVGK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`P02Ol:00;o5@06o`<00_l700Ko1@02o`03
0?oo00?o1P07o`P02_l300Go0`05o`<02_l300Go1P03oa002_l500;o1002o`H02_l300Go0`05o`80
2?l800So2005o`H01Ol600;o0`06o`/01OlB00Ko0`06oah03?l00`3oo`04o`<01_l500;o3006o`@0
1Ol600;o2@0000`00_l:00Wo1`06o`L02Ol;00;o5006o`800ol500[o0`0:o`@01ol800[o0`05o`<0
1Ol300[o0`05o`D01?l@00[o1@02o`@00_l600[o0`05o`<01Ol200So2008o`H02Ol400Go1@03o`03
0?oo00Oo2009oa001_l300Ko7P0<o`030?oo00Co0`06o`@01?l900[o0P05o`D00ol900003002o`h0
0_l900?o0P03o`X00_l>00;o5@02o`@01?l400Co1@02o`<00ol500?o1@02o`l00_l800;o1`02o`P0
0_l900;o1@03oaH00_l800?o1003o`H00_l500;o1002o`L00_l500;o3`02o`P00ol500?o1@02o`D0
0ol200?o1003o`H00ol500?o4@02o`L00_lR00;o1P02o`<00_l700;o1P04o`P01?l500;o1002o`D0
0ol:00003002o`h00_l900;o1002o`X00_l>00;o5@02o`@01?l400;o1`02o`<00_l700;o1@02o`l0
0_l800;o1`02o`P00_l900;o1@02oaL00_l800Co0`03o`H00ol400;o1002o`L00_l500;o3`02o`P0
0_l700;o1@02o`D00_l300;o1P02o`H00_l700;o4@02o`L00_lR00;o1P02o`<00_l700;o1P04o`P0
0_l700;o1002o`D00_l;00003002o`h00_l800;o1P02o`T00_l>00;o5@02o`<01Ol300?o1`02o`<0
0_l700;o1@02o`800_l;00;o2002o`<00_l200;o2002o`T00_l400;o6002o`P01?l200Co1`03o`<0
0_l400;o0`02o`800_l500;o3`02o`L00_l900;o1002o`@00_l400;o1P02o`D00olJ00_o8P02o`80
0_l200;o0`0;o`D00_l200;o1P03o`L00_l400;o1002o``0000<00;o3P02o`P00_l600;o2@02o`h0
0_lE00;o0`02o`030?oo00<00_l400Oo2P03o`D00_l200;o2`02o`P00_l200?o0P02o`P00_l900;o
0`03oaP00_l800;o00@0o`001?l800;o0`02o`@00_l200?o0P02o`D01ol:00;o1`02o`T00_l400?o
0P03o`@00_l600;o1@02oa`02OlS00;o0P02o`P02Ol600;o0P02o`H00_l400Oo0`03o`800ol<0000
3002o`h00_l800;o1P02o`T00_l>00;o5@02o`800ol00`3oo`0300;o1007o`D01ol600Ko2`02o`P0
0_l20003o`3o00800_l800;o2@07oaT00_l800;o00H0o`00o`02o`P00ol800;o0P000ol0o`0200;o
1@09o`P00ol600;o2@02o`@01ol=00;o1@02oa`00_l500;o8`06o`P00_l500;o1@03o`800ol500;o
1007o`<01ol=00003002o`h00_l800;o1P02o`T00_l>00;o5@02o`800_l200;o0`02o`h01ol800Ko
2`02o`P00_l0103oo`02o`030?oo00P00_l900Wo5`02o`P00_l00`3oo`02o`030?oo00T00ol700;o
00@0ool00_l00`3oo`0500;o1@03o`H01?l600;o2@02o`@01Ol?00;o1@02oad00_l300;o9006o`T0
0_l300;o1P02o`@00_l500;o3P05o`l0000=00;o3@02o`P00_l600;o2@02o`d00_lF00;o00<0ool0
0`02o`<00_l=00?o3@02o`800_l;00;o2002o`030?oo008000Co0?oo2002o`T00_l500?o5P02o`P0
0_l00`3oo`02o`030?oo00D00_l300;o1`02o`030?oo008000Co0?oo1@02o`H00_l500Ko1@02o`T0
0_l400;o00@0oooo3P02o`D00_lM00;o0`02ob@00_l200;o2@02o`<00_l600;o1002o`D00_l>00;o
00@0oooo3P0000d00_l=00;o2002o`H00_l900;o3@02oaH01Ol300;o0`02o`P00_l300;o1`000ol0
000400;o0P02o`800_l700;o2002o`030?l0008000Co0?oo2002o`T00_l600;o5P02o`L00_l300;o
0`02o`@00_l300?o1P02o`030?l0008000Co0?oo1@02o`H00_l500;o0P02o`D00_l900;o1002o`80
0ol=00;o1@03o`L00_lD00;o00@0oooo9002o`800_l200;o1P02o`040?ooo`D00_l600;o1002o`P0
0_l400;o0P03o`d0000=00?o3002o`P00_l600;o2@02o`d00_lF00Co1002o`@00_l600?o0`02o`H0
0_l600;o1P02o`L00_l800Co0`04o`P00_l900;o1P02oaH00_l700;o0`02o`<00_l400;o1003o`D0
1?l300Co1@02o`H00_l400?o0`02o`D00_l700;o1@02o`<00ol<00;o1P02o`L00_lD00;o00<0ool0
9@02o`H00_l600;o00<0ool01P02o`H00_l500;o1P03o`@00_l300?o300000h00_l<00;o2@02o`@0
0_l:00;o3002oaL01?l400;o1003o`@01?l300?o1003o`H00_l600;o1`02o`P01?l400?o2002o`T0
0_l500?o5P02o`L00_l800;o1002o`D00_l500Co1003o`D00_l500?o1002o`@00_l500?o1@03o`D0
0_l400?o2`02o`H00ol500?o5005obD00_l600;o1P05o`D00ol600?o1003o`@01?l400;o1003o`/0
000?00;o1`03o`030?oo00T00ol200?o1P03o`030?oo00/00_lG00Co0P06o`@02_l400Wo100<o`<0
2_l300Co1@04o`<02_l300_o4`0:o`801_l200Ko0`0:o`<01?l500Co0P0;o`<01Ol200Go1009o`@0
1Ol300Go100:o`@02_lA00Oo900<o`<01ol500Ko0P06o`@02_l200Go0`05o`T0000@0003o`0000D0
1_l:00Ko1`06o`/000?o00005P03o`<01_l600Go00<0ool01P05o`030?l000<03?l300[o0`04o`D0
1?l300[o0`09oaD02_l200Ko0P06o`<02_l300Co1@04o`802Ol500Go0P05o`H01Ol600Go0`05o`@0
2_l600Go00<0ool04@07ob@03?l300Oo1@06o`801_l600Go00<0ool00P05o`<01Ol900006`03o`/0
1?l;00?oo`2o0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(102\\) NGUFELJR ITZMP OKMCZAZ EAQGI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`P0
1?l700[o2P02oaD01_l300;o1`06o`T01?l600Oo1`0<o`803Ol400Ko1P05o`H00ol@00[o1@08o`H0
2_l300Go0`05o`802?lH00Go1P05o`H00_l00`3oo`03o`<01Ol600Go1P0:o`801_l300Ko0P0:oa80
3?l00`3oo`04o`<01_l400Go2P06o`D02_l;00003002o`X02Ol700Ko1P0:o`/00_lD00Ko0P03o`D0
2_l500So1007o`L03?l200go0P09o`D01Ol500Co400:o`D02?l600[o0`05o`<01Ol200So5P09o`@0
1Ol500?o00<0ool00ol300Go1009o`@02_l200Ko0`06o`802_lB00co00<0ool01?l300Ko0P09o`H0
2_l300[o2`0000`00_l>00;o2@03o`800ol600;o1@02o`/00_lE00;o1004o`@01?l500;o1@02o`@0
0_l600;o3002o`H00_l500;o1P02o`800ol400?o1P02o`D00olF00;o3002o`X00_l500;o1002o`L0
0_l500;o6@03o`D00ol500;o1@03o`<00_l700;o1003o`D00ol400;o1@02o`@00_l700;o1@02o`D0
0_lD00;o1P02o`<00_l700;o0`03o`D00ol400Co1@02o`L00_l?00003002o`h00_l900;o1002o`L0
0ol@00;o5@02o`@01?l400;o1`02o`@00_l600;o1@02o``00_l600;o1@02o`H00_l200;o1P02o`H0
0_l500;o5`02o``00_l:00?o1002o`@00_l700;o1@02oaT00_l700;o1@02o`D00_l400;o1`02o`@0
0_l700;o1003o`@00_l400;o1`02o`D00ol400;o5002o`H00_l300;o1`02o`<00_l700;o1002o`L0
0_l700;o3`0000`00_l>00;o2002o`H00_l700?o3`02oaD00_l300Go0`03o`L00_l400;o1P02o`D0
0_l200;o2002o`800_l200;o1@02o`H00_l200;o1P02o`H00_l400;o6002o``00_l;00?o0`02o`@0
0_l300;o0P02o`D00_lH00;o2@02o`@00_l400;o1@02o`<00_l200;o0`03o`h00ol300;o100;o`H0
0ol300;o5002o`800_l200;o0`0;o`800_l900;o0P03o`L00_l700;o3`0000`00_l>00;o2002o`H0
0_l800?o3P02oaD00_l300;o00<0ool00`02o`@01ol300;o1P02o`D00_l200;o2002o`800_l900;o
1P02o`800_l600;o1P02o`<00olH00;o3002o``00_l300;o1002o`800ol200;o1@07oa<00_l900;o
1003o`800ol500;o0P03o`800_l300;o4002o`<00_l500Wo2002o`<00_lD00;o0P02o`P02Ol300;o
2@02o`800_l400Oo1P02o`l0000<00;o3P02o`P00_l600;o2@03o`d00_lE00;o0P03o`030?oo00<0
0_l400Oo0`02o`H00_l500Ko2006o`T00_lB00;o1P07oaT00_l<00;o3003o`P00_l20003o`3o0080
0_l500Wo4@02o`T00_l400Oo1P02o`8000?o0?l00P02o`<00_l@00?o2@02o`D00_l800?o6006o`P0
0_l500;o0`02o`T00_l200;o1007o`H00_l?00003002o`h00_l800;o1P02o`X00ol<00;o5@02o`80
0_l200;o0`02o`h00_l600;o1@06o`P01_l900;o4P02o`H02OlG00;o3002o`d00ol700;o00@0ool0
0_l00`3oo`0500;o1@03oa000_l900;o1005o`P00_l0103oo`02o`030?oo00<00_lA00?o2@02o`<0
0_l:00?o5`06o`T00_l300;o1002o`T00_l200;o4@02o`l0000=00;o3@02o`P00_l600;o2`02o`/0
0_lF00;o00<0ool00`02o`<00_l>00;o1P02o`D00_l200;o2002o`800_l900;o4P02o`H00_l500?o
5P02o`L00_l300;o0`02o`@00_l300;o1`02o`030?oo008000Co0?oo1@02o`H00_l@00;o2@02o`@0
0_l0103oool700;o00<0ool00P001?l0ool300;o3@02o`<00_l900;o0`02o`H00_l300;o5`02o`80
0_l900;o0`02o`@00_l900;o0P02oa400_l?00003@02o`d00_l800;o1P02o``00_l:00;o5P05o`<0
0_l300;o2002o`@00_l600;o1@02o`800_l200;o1002o`800_l200;o1@02oa800_l600;o1P02oaH0
0_l700;o0`02o`<00_l400;o0`03o`H00_l00`3o00020004o`3oo`D00_l600;o4002o`T00_l400;o
0P03o`H00_l00`3o00020004o`3oo`<00ol700;o0`02o`<00ol900;o00@0oooo1P02o`<00olF00;o
0P02o`800_l600;o00@0oooo1003o`P00_l200;o2002o`L00_l?00003@03o``00_l800;o1P02o``0
0_l:00;o5P04o`@00_l400;o1P03o`@00_l600;o1@02o`H00_l400;o1P02o`D00_lB00;o1P02o`H0
0_lF00;o1`02o`<00_l300;o1002o`@00ol500Co0`04o`D00_l600;o4@02o`L00_l500;o0`03o`D0
1?l300Co1002o`L00_l300;o1003o`P00_l00`3oo`0700;o1003oaD00_l600;o1P02o`030?oo00H0
0_l700;o1002o`H00ol700;o3`0000h00_l<00;o2@02o`@00_l600;o1@02o`T00_lG00Co1002o`@0
0ol400Co1002o`H00_l500;o1P02o`@00_l600;o1@02oa800_l600;o1@03oaH00_l700;o0`02o`<0
0_l400;o1@02o`D01?l400?o1@02o`D00olA00?o1@03o`D00_l400?o1004o`@00ol400?o1@03o`<0
0_l500;o2005o`L00_l500;o5@02o`H00_l600Go1`02o`D00_l500?o1004o`L00_l?00003`02o`L0
0ol00`3oo`0900?o0P03o`H00ol300?o2002oaL01?l200Ko100:o`<01?l400Co0P0<o`803?l200So
2P0:o`030?oo00Wo4`0:o`<03?l400[o0`04o`D01?l200_o4`09o`@01Ol300Go00<0ool00_l500Co
100:o`<02_l400Oo200:oa803?l300Oo2009o`H02_l300[o2`00010000?o00001@06o`X01_l800Oo
2@000ol0000F00?o0`06o`H01Ol00`3oo`0300Co1004o`803?l200co0P08o`X02_l00`3oo`07oaD0
2_l300co100:o`<01?l500Co0P09oaL01Ol600Go0`05o`030?oo00;o1@04o`H01Ol00`3oo`0300[o
1007o`P02_lB00co0`07o`X01Ol:00Go00<0ool00`0:o`/0000K00?o2`04o`X01Ooo0;h0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(103\\) NGUFGMLR IT MQ PKMAZBZVEAQHI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02omD00_l400?oX`02o`@00olW00003P02ocL0
0_oD00[oXP0:obH0000=00;o>@02om@01Ol200;oX`05o`800_lV00003@02ocT00_oD0003o`000:T0
00?o0000;00000d00_l900Wo2004o`T01Ol=00;o5@06o`<00_l700Ko2@04o`H01ol;00Ko1005o`<0
1Ol200go00<0ool00ol600?o400:o`D02?lC00Go0`05o`H01OlC00So1`05o`H00_l00`3oo`03o`<0
1Ol00`3oo`04o`<01_l00`3oo`08o`<02_l600[o2002o`P03?l00`3oo`04o`<01_l400Go1`04o`<0
1?l300[o2`0000`00_l:00Wo1`06o`H02Ol<00;o5006o`800ol500[o1@08o`@01ol900[o0P05o`<0
1Ol200go00<0ool00ol500Co400:o`D02?lC00Go0`05o`@02OlA00So1`05o`D00ol00`3oo`03o`<0
1Ol00`3oo`04o`<01_l00`3oo`08o`<02ol500[o1`04o`L03?l00`3oo`04o`<01_l200Wo1@04o`<0
1?l300[o2`0000`00_l>00;o2@03o`800ol500;o1@02o``00_lE00;o1004o`@01?l500;o1@02o`@0
0_l600;o2`04o`D00_l300;o1`02o`H00_l600;o0`02o`D00olF00;o3002oaL00_l700;o1003o`D0
0olB00;o3@02o`D00ol300;o1`02o`@00_l700;o1002o`D00_l500;o1@03o`D00_l500;o1`04o`T0
0_l600;o0`02o`L00_l300?o1@03o`D00_l500;o2002o`l0000<00;o3P02o`T00_l400;o3@02o`/0
0_lE00;o1004o`@00_l700;o1002o`H00_l500;o2`02o`L00_l300;o1`02o`H00_l600;o0`02o`D0
0_lG00;o3002oaL00_l700;o1002o`L00_lB00;o3@02o`D00_l400;o1`02o`@00_l700;o1003o`@0
0_l500;o1P02o`D00ol400;o1`04o`T00_l600;o0`02o`L00_l300;o1`02o`D00_l500;o2002o`l0
000<00;o3P02o`P00_l600;o3002o`/00_lE00;o0`05o`<00ol700;o1002o`H00_l500;o0P02o`H0
0ol700;o0`02o`<00_l200;o1P02o`H00_l300;o1002oaP00_l<00;o5`02o`<00_l200;o0`02o`T0
0_lA00;o3@02o`@00_l500;o0`02o`800_l400_o1@03o`<00_l500;o1P02o`H00ol300;o1P02o`80
0_l800;o0P02o`800_l300_o0P02o`T00_l400;o1@02o`P00_l?00003002o`h00_l800;o1P02o``0
0_l;00;o5@02o`<00_l00`3oo`0300;o1007o`<00_l600;o1@02o`800_l600;o1007o`800_l200?o
0P02o`H00_l600;o0`02o`<00olH00;o3002oaL00_l200?o0P02o`<00_l900;o4@07o`P00ol200?o
1@02o`800ol200;o1@09o`L00_l300;o1@02o`H00_l700;o0`02o`H00_l200;o2002o`800_l800Wo
0`02o`T00_l400;o1@02o`P00_l?00003002o`h00_l800;o1P02o`/00_l<00;o5@02o`800ol00`3o
o`0300;o1007o`<00_l600;o1@06o`H00_l400Oo0P02o`8000?o0?l00P02o`H00_l;00Oo6@02o``0
0_lG00;o0P000ol0o`0200;o0`02o`T00_lA00Wo1P07o`H00_l20003o`3o00800_l500;o1@02o`L0
0ol900;o1@03o`L00ol900?o0P03o`L01_l800;o1@02o`<00_l900;o1002o`D00_l800;o3`0000`0
0_l>00;o2002o`H00_l800Co3@02oaD00_l200;o0P02o`<00_l>00;o1P02o`D01_l600;o3@02o`04
0?oo00;o00<0ool01P02o`/02OlG00;o3002oaL00_l0103oo`02o`030?oo00<00_l900;o4@02o`D0
0ol500Go2002o`040?oo00;o00<0ool01P02o`<00_l900?o2009o`T00ol800;o1002o`L01_l900;o
0`02o`@00_l900;o1009o`P00_l?00003@02o`d00_l800;o1P02o`P00ol=00;o5P02o`030?oo00<0
0_l300;o3P02o`H00_l500;o0P02o`H00_l=00;o00<0ool00P001?l0ool600;o2`02o`D00olF00;o
1`02o`<00_l300;o4P02o`030?oo008000Co0?oo0`02o`T00_lA00;o1P02o`D00_l0103oool700;o
00<0ool00P001?l0ool600;o0`02o`D00_l300;o2008o`H00_l300;o2002o`@00_l700;o0P02o`T0
0_l300;o1002o`T00_l400Wo2002o`l0000=00;o3@02o`P00_l600;o2P02o``00_lF00Go0`02o`<0
0_l800;o1002o`H00_l500;o0P02o`800_l200;o2002o`<00_l00`3o00020004o`3oo`H00_l;00;o
1P02oaH00_l700;o0`02o`<00_lB00;o00<0o`000P001?l0ool300?o2002oa400_l600;o1@02o`80
0ol600;o00<0o`000P001?l0ool700;o00@0oooo1@02o`<00ol700;o1003o`D00_l300?o1P02o`H0
0_l600;o0P02o`800_l600;o00@0oooo1003o`P00_l400;o1@02o`P00_l?00003@03o``00_l800;o
1P02o`/00_l;00;o5P04o`@00_l400;o1P03o`@00_l600;o1@02o`H00_l300;o1P03o`<01?l300Co
1P02o`/00_l600;o5P02o`L00_l300;o0`02oa801?l300Co1002o`L00_lB00;o1P02o`D00_l300?o
1@04o`<01?l700;o00<0ool01P02o`@00ol600;o1@02o`D00_l400?o1@02o`H00_l600;o1P02o`H0
0_l00`3oo`0600;o1`02o`D00_l500;o2002o`l0000>00;o3002o`T00_l400;o3002o`X00_lG00Co
1002o`@00ol400Co1002o`H00_l500;o1P02o`<00ol400Co0`04o`@00ol600;o2`02o`D00olF00;o
1`02o`<00_l300;o4P04o`@00ol500;o1@02oa<00_l500?o1@02o`@00ol400Co1003o`L01Ol600;o
1@02o`H00_l400?o1@02o`D00_l400?o1P03o`D00_l600;o1P05o`L00_l500;o1P02o`D00_l800;o
3`0000l00_l700?o00<0ool02@03o`800ol600;o0`03o`T00_lG00Co0P06o`@02_l300Co1004o`80
3?l400[o0P04o`D01?l200So1P0;oa<02_l300co4@04o`D01?l400Wo4@0;o`@01Ol300Go00<0ool0
0_l500Co0`07o`L02_l300[o1P0:o`801_l200Ko0P0<o`<01ol800Wo1@04o`<01?l300[o2`000100
00?o00001@06o`X01_l700Oo2P000ol0000F00?o0`06o`H01Ol00`3oo`0300Co1004o`803?l600Go
00<0ool00P04o`D01?l200So1P09oaD02_l300co4@04o`D01?l600Go4`09o`H01Ol300Go00<0ool0
0_l500Co0`07o`L02_l300Wo1`0:o`801_l200Ko0P0<o`<01ol:00Go1`04o`<01?l300[o2`0001/0
0ol;00Co2P04ool0_`000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(104\\) NGUFGQLR IT LV PKIAZAZVCAQCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02of400_l400?oo`0H00;o1003obL0000>00;o
=`02of002_oo01L02_lV00003@02ocT00_mP00Go0P02ool06005o`800_lV00003@02ocT00_mP0003
o`000?l07P000ol0000/00003@02o`T02Ol800Co2`06o`X00_lE00Ko0`02o`L01_l900Co1P07o`/0
1_l800Go1P0=o`030?oo00?o1P03oa002_l500So4`0=o`L00_lE00So1`05o`H00_l200[o0`06o`<0
1_l00`3oo`08o`801_l300Ko0P0:o`P00_l<00Go1006o`<01_l400Go2P05o`H02_l;00003002o`X0
2Ol700Ko2P06o`/00_lD00Ko0P03o`D02_l500So1007o`T02_l400Wo100=o`030?oo00?o1@04oa00
2_l500So4`0=o`H01?lD00So1`05o`D00ol200[o0`06o`<01_l00`3oo`08o`801_l300Ko0P0:o`L0
1?l900Wo0P06o`<01_l200Wo1P09o`@02_l;00003002o`h00_l900?o0P03o`/00_l=00;o5@02o`@0
1?l400Co1@02o`D00_l400;o1P02o`/01?l500;o0`03o`D00ol600;o1P02o`<00_l500?o5P02o``0
0_lI00;o1P02o`H01?lF00;o3@02o`D00ol700;o2@02o`L00_l400;o1@02o`@00_l700;o1@02o`D0
0_l700Co2003o`D00ol300;o1`02o`<00ol500?o1003o`D00ol700;o3`0000`00_l>00;o2@02o`@0
0_l;00;o3@02oaD00_l400Co1002o`L00_l400;o1P02o`D00_l;00;o1`02o`<00_l700;o1P02o`H0
0_l300;o1@02oaL00_l<00;o6@02o`H00_l600Co5P02o`d00_l500;o2002o`T00_l700;o1003o`@0
0_l400;o1`02o`D00ol400;o1`04o`P00_l700;o0`02o`L00_l300;o1`02o`@00_l700;o1`02o`l0
000<00;o3P02o`P00_l600;o100:o`/00_lE00;o0`05o`<00ol700;o1002o`H00_l500;o0P02o`H0
0ol700;o0P02o`T00_l500;o1P02o`<00_l400;o6002o``00_lI00;o1P02o`D00_l200;o5@02o`d0
0_l400;o2@02o`T02ol500?o0`02o`@02ol600?o0`02o`H00_l200;o1P03o``02ol200;o2@02o`80
0ol@00;o3`0000`00_l>00;o2002o`H00_l400[o2`02oaD00_l300;o00<0ool00`02o`@01ol300;o
1P02o`D00_l200;o1P02o`@01ol00`3oo`0900;o1@02o`H00_l300;o0`03oaP00_l<00;o6@02o`H0
0_l500;o0P02oaD01ol800?o0P03o`T00_l:00Wo1`02o`<00_l500Wo2002o`<00_l600;o0P02o`H0
0_l>00Wo0`02o`T00_l200;o4@02o`l0000<00;o3P02o`P00_l600;o1002o`@00_l=00;o5@02o`80
0ol00`3oo`0300;o1007o`<00_l600;o1@06o`H00_l400Oo00<0ool02@02o`D00_l;00Oo6@02o``0
0_lI00;o3003o`800olD00Wo1P07o`X00_l:00;o1@02o`L00ol900;o1@02o`P00ol900?o0P03o`D0
0_l>00;o1@02o`<00_l900;o0P02oa400_l?00003002o`h00_l800;o1P02o`D00_l300;o3@02oaD0
0_l200;o0P02o`<00_l>00;o1P02o`D01_l600;o3002o`T00_l500;o2`09oaL00_l<00;o6@02o``0
0_l400;o5002o`D00ol500Go3002o`/00_l300;o2@03o`T00_l300;o2P03o`P00_l400;o1@02o`l0
0_l300;o1002o`T00_l200;o4@02o`l0000=00;o3@02o`P00_l600;o1P001?l00002o``00_lF00;o
00<0ool00`02o`<00_l>00;o1P02o`D00_l200;o1P02o``00_l900;o1@02o`/00_l500?o5P02o`L0
0_l300;o0`02oa@00_l<00;o1002oa@00_l600;o1@02o`040?ooo`/00_l;00;o0`02o`D00_l300;o
2@02o`<00_l600;o0`02o`P00_l400;o1@02o`l00_l300;o1002o`T00_l200;o4@02o`l0000=00;o
3@02o`P00_l600;o1P02o`800_l<00;o5P05o`<00_l300;o2002o`@00_l600;o1@02o`800_l200;o
0P02o`P00_l200?o2002o`D00_l;00;o1P02oaH00_l700;o0`02o`<00_lD00;o2`02o`H00_lC00;o
1P02o`D00_l200?o2P02o``00_l0103oool500;o0`03o`T00_l0103oool600;o0`03o`H00_l600;o
1003o`L00_l600;o00@0oooo1003o`P00_l200?o1`02o`L00_l?00003@03o``00_l800;o1P02o`L0
00?o00000_l<00;o5P04o`@00_l400;o1P03o`@00_l600;o1@02o`H00_l300;o1P03o`<00_l700;o
1P02o`/00_l600;o5P02o`L00_l300;o0`02oa@00_l;00;o1P02oa<00_l600;o1@02o`<00ol900;o
3002o`030?oo00H00_l400?o2002o`030?oo00L00_l400?o1@02o`H00_l500;o1`02o`H00_l00`3o
o`0600;o1`02o`@00_l700;o1`02o`l0000>00;o3002o`T00_l400;o2@001?l0ool;00;o5`04o`@0
0_l400?o1004o`@00_l600;o1@02o`H00_l300?o1004o`@00_l500;o1`02o`/00_l500?o5P02o`L0
0_l300;o0`02oa@00_l:00?o1P03oa800_l500?o1@02o`@00ol800;o3005o`H00_l500;o2005o`L0
0_l500;o1003o`H00ol400?o1@03o`H01Ol700;o1@02o`D00ol500?o1`02o`l0000?00;o1`03o`03
0?oo00T00ol200?o2@04o`X00_lG00Co0P06o`@02_l300Co1004o`803?l400[o1009o`@02?l600_o
4`0:o`<03?lA00So1P06o`801_l?00_o1005o`<01Ol200[o1@07o`L02_l400Oo200:o`801_l200Ko
100:o`<01ol800Wo1P0:o`<02_l;000040000ol0000500Ko2P06o`/00ol:0003o`0001H00ol300Ko
1P05o`030?oo00<01?l400Co0P0<o`H01Ol00`3oo`0600Go1P08o`H02OlE00[o0`0<oa402?l600Ko
0P06o`l02Ol600Go0`05o`802_l500Oo1`0:o`@01ol800[o0P06o`801_l600Go00<0ool00`07o`X0
1Ol:00Go00<0ool00`0:o`/0000K00?o2`04o``00ooo0;h0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(105\\) NGUFGNIR FTZKT PKMAZA SCAQCI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`P0
1?l900Go3@02oaD01_l300;o1`06o`T01?l600Oo2`06o`D01_l300;o100:o`<01Ol600?o3`07o`T0
2?l600[o0`05o`H00_l400So4P08o`L01Ol600;o00<0ool00ol300Go00<0ool01?l300Ko00<0ool0
2?l200Ko0`06oa000_l00`3oo`03o`X01Ol400Ko0`06o`@01Ol:00Go1P0:o`/0000<00;o2P09o`L0
1_l600Wo3002oa@01_l200?o1@0:o`D02?l400Oo2@0:o`<01_l200?o100:o`<01Ol500Co3`07o`T0
2?l600[o0`05o`D00ol400So4P08o`L01Ol500?o00<0ool00ol300Go00<0ool01?l300Ko00<0ool0
2?l200Ko0`06oa002_l600Wo0P06o`<01_l200Wo1P09o`@02_l;00003002o`h00_l900?o0P03o`D0
0_l500;o3002oaD00_l400Co1004o`D00_l500;o1002o`H00_l;00Co1@02o`@00_l400Co2002o`T0
0_l500?o4`02o`l00_l:00;o1@02o`D00_l500?o2002oaL00_l=00;o1@03o`<00_l700;o1002o`L0
0_l400;o1@02o`@00_l700;o4P03o`D00ol400?o1@03o`<00_l700;o0`03o`D00ol400?o1@03o`L0
0_l?00003002o`h00_l900;o1002o`d00_l;00;o5@02o`@01?l400;o1`02o`@00_l600;o1@02o`/0
0_l700;o1002o`@01?l800;o2@02o`D00_lD00;o3`02o`X00ol400;o1@02o`D00_l900;o5`02o`d0
0_l500;o1002o`L00_l400;o1`02o`@00ol400;o1002o`L00_lB00;o1`02o`@00_l700;o0`02o`L0
0_l300;o1`02o`@00_l700;o1`02o`l0000<00;o3P02o`P00_l600;o3002o`/00_lE00;o0`05o`<0
0ol700;o1002o`H00_l500;o0P02o`H00ol700;o1002o`<01Ol800;o2@02o`@00_lE00;o0P02o`/0
0_l;00?o0`02o`D00_l400;o2P02oaL00_l=00;o1002o`D00_l300;o0P02o`@02ol500?o0`02o`@0
2olB00;o1`02o`<00ol<00_o0P02o`T00_l200?o4002o`l0000<00;o3P02o`P00_l600;o3002o`/0
0_lE00;o0`02o`030?oo00<00_l400Oo0`02o`H00_l500;o0P02o`H00_l400Oo0`02o`<00_l00`3o
o`0800;o2@02o`<00olE00;o0P02o`/00_l<00;o0`02o`D00ol200?o2P02oaL01ol800?o0P03o`D0
0_l200?o0P02o`D02Ol700;o0`02o`D02OlK00?o0`02o`h02Ol300;o2@02o`800_lA00;o3`0000`0
0_l>00;o2002o`H00_l<00;o2`02oaD00_l200?o00<0ool00`02o`@01ol300;o1P02o`D01_l600;o
1007o`<00_l200?o00<0ool02002o`T01olF00Ko2`02o``00ol900Oo2`02oaL02Ol600Oo1P02o`80
00?o0?l00P02o`D00_l500;o1`03o`T00_l500;o5P07o`@00_l>00;o1@02o`<00_l900;o0P02oa40
0_l?00003002o`h00_l800;o1P02o`D00_l400;o3002oaD00_l200;o0P02o`<00_l>00;o1P02o`D0
1_l600;o3P02o`800_l200;o2002o`T02OlD00Ko2`02o`d00ol800Go3@02oaL00_l500?o1@05o`P0
0_l0103oo`02o`030?oo00H00_l300;o2@03o`T00_l300;o5@07o`H00_l?00;o0`02o`@00_l900;o
0P02oa400_l?00003@02o`d00_l800;o1P02o`D02?l;00;o5P02o`030?oo00<00_l300;o3P02o`H0
0_l500;o0P02o`H00_l>00;o00<0ool00`02o`P00_l900;o1@03oa<00_l200;o1P02o`<00_l300;o
1002o`<00_l800;o00@0oooo1`02o`<00_l300;o4P02o`H00_l500;o00@0oooo1`02o`030?oo0080
00Co0?oo1P02o`<00_l500;o0`02o`T00_l300;o5003o`/00_l?00;o0`02o`@00_l900;o0P02oa40
0_l?00003@02o`d00_l800;o1P02o`D01ol<00;o5P05o`<00_l300;o2002o`@00_l600;o1@02o`80
0_l200;o0P02o`P00_l400Go0`02o`P00_l900;o1P02oa<00_l200;o0P02o`800_l300;o0`02o`@0
0_l300?o1`02o`800ol600;o0`02o`<00_lB00;o1P02o`D00_l200?o1P02o`030?l0008000Co0?oo
1`02o`040?ooo`D00_l300?o2@02o`040?oooa@00_l70003o`0000800ol700;o1P02o`040?ooo`@0
0ol800;o0P03o`L00_l700;o3`0000d00ol<00;o2002o`H00_l500;o4@02oaH01?l400;o1002o`H0
0ol400;o1P02o`D00_l600;o0`02o`H00ol400Co1002o`P00_l900;o1P02oa<00_l600;o0P02o`<0
0_l300;o1002o`@00ol600;o0`03o`D00_l300;o0`02oa800_l600;o1@02o`<00ol500Co0`04o`L0
0_l00`3oo`0600;o1003o`P00_l00`3oo`0E00;o1P02o`D00_l700;o1P02o`030?oo00H00_l700;o
1002o`L00_l700;o3`0000h00_l<00;o2@02o`@00_l600;o4002oaL01?l400;o1003o`@01?l400;o
1P02o`D00_l600;o0`03o`@01?l400Co1002o`P00_l900;o1@03oa<00_l600;o0P02o`<00_l300;o
1002o`D00_l600;o1003o`@00_l300;o0`02oa800_l500?o1@02o`@00ol400Co1003o`L01Ol600;o
1@02o`P01OlE00?o1003o`D00ol500?o1P05o`L00_l500;o1@03o`D00ol700;o3`0000l00_l700?o
00<0ool02@03o`800ol600;o3`02oaL01?l200Ko100:o`<01?l400Co0P0<o`@02_l300Co0P06o`<0
2_l300_o4P0<o`803?l400[o0`05o`<01Ol200co400;o`@01Ol300Go00<0ool00_l500Co0`07o`L0
2_l400Oo5`09o`H02_l300Oo2009o`H02_l300[o2`00010000?o00001@06o`X01_l700So2@000ol0
000F00?o0`06o`H01Ol00`3oo`0300Co1004o`803?l600Go00<0ool00`03o`<01_l300[o0`09oa@0
3?l200co100:o`<01Ol300Go0P0<oa002Ol600Go0`05o`030?oo00;o1@04o`<01ol700[o1007oaT0
1Ol00`3o000700Go00<0ool00`07o`X01Ol:00Go00<0ool00`0:o`/0000K00?o2`04o`P02?oo0;d0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(106\\) NBSFHNIR HTZKT OIME AWSCAQAI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`P0
1?l:00Co3@02oaD01_l300;o0`0:o`D00_l00`3oo`03o`H01ol800Co0`04o`<01_l300;o100:o`<0
1Ol600?o4004o`<01?l400So1P0:o`<01Ol600;o1008oaH01Ol700[o0`05o`<01Ol200co3`06o`<0
1_l300;o1002o`D00_l00`3oo`03o`X01Ol400Ko0`06o`@01Ol500Ko0`06o`030?oo00So2`0000`0
0_l:00Wo1`06o`P01ol<00;o5006o`800ol300_o100:o`@01ol800Co0`04o`<01_l200?o100:o`<0
1Ol500Co4004o`<01?l400So1P0:o`<01Ol500?o1008oa@02Ol500[o0`05o`<01Ol200co3`06o`<0
1_l300;o1002o`D02_l600Wo0P06o`<01_l200Wo0`06o`<01_l00`3oo`08o`/0000<00;o3P02o`T0
0ol200?o1P02o`@00_l<00;o5@02o`@01?l500;o1@03o`<00ol500?o1@02o``00_l500;o1@02o`@0
1?l800;o2@02o`D00olC00;o1@02o`P00_l:00;o1@02o`D00_l500?o2002oaH00ol500?o2002o`P0
0_l700;o1@02o`H00_lA00;o1`02o`@00ol400?o1003o`D00ol400?o1@03o`<00_l700;o0`03o`D0
0ol400;o1`02o`L00_l?00003002o`h00_l900;o1002o`D00_l600;o2`02oaD00_l400Co1@02o`H0
0_l300;o1`02o`D00_l<00;o1@02o`D00_l400Co2002o`T00_l500;o5002o`D00_l800;o2P03o`@0
0_l500;o1@02o`T00_lF00;o1`02o`P00_l800;o1`02o`D00_l600;o4@02o`L00_l400Co0`03o`@0
0_l700;o1002o`L00_l300;o1`02o`<00_l700;o1002o`L00_l700;o3`0000`00_l>00;o2002o`H0
0_l400;o1P02o`/00_lE00;o0`05o`D00_l600;o0`02o`L00_l500;o0P02o`P00_l500;o1@02o`<0
1Ol800;o2@02o`@00_lE00;o1@02o`P00_l;00?o0`02o`D00_l400;o2P02oaD00_l900;o1`02o`P0
0_l300;o0P02o`D00_l200;o0P02oa402ol400Co0P04o`@00_l700;o0`03o``02ol200;o2@02o`<0
2ol700;o3`0000`00_l>00;o2002o`H00_l400;o1P02o`/00_lE00;o0`02o`030?oo00D00_l600;o
2`03o`D00_l200;o2002o`D00_l500;o0`02o`030?oo00P00_l900;o0`03oaD00_l500;o2002o``0
0_l300;o1@03o`800ol:00;o5@02o`T00_l700;o2002o`800ol200;o1@02o`800_lF00Wo1@02o`04
0?l000Co3003o`<00_l>00Wo0`02o`T00_l400Wo2002o`l0000<00;o3P02o`P00_l600;o1002o`H0
0_l;00;o5@02o`800ol00`3oo`0500;o1@03o`H01ol600Ko2002o`D00_l500;o0P03o`030?oo00P0
0_l900Oo5P02o`D00_l800;o3003o`T01ol;00;o5@02o`T00_l700;o2002o`8000?o0?l00P02o`D0
1_lF00;o1@02o`D00_l01P3o003o00;o1`07o`@00_l>00;o1@02o`<00_l900;o1002o`D00_l800;o
3`0000`00_l>00;o2002o`H00_l400?o1002o``00_lE00;o0P02o`800_l500Wo1@07o`P01_l800Wo
1@02o`800_l200;o2002o`T02OlD00Wo2002o`d00ol800Go3@02oaD00_l900;o1`02o`P00_l0103o
o`02o`030?oo00D01_lG00;o0`02o`H00_l00`3oo`02o`030?oo00D01ol600;o3`02o`<00_l400;o
2@02o`D00_l300;o2@02o`l0000=00;o3@02o`P00_l600;o1009o`/00_lF00;o00<0ool00`02o`D0
2?l500?o3@02o`800_l800Wo1@02o`030?oo00<00_l800;o2@02o`D00olC00Wo0`02o`<00_l300;o
1002o`<00_l800;o00@0oooo1`02o`<00_l300;o4002o`T00_l700;o2002o`030?oo008000Co0?oo
1@02o`800_lG00;o0`02o`H00_l00`3oo`02o`030?oo00@00ol;00;o3`02o`<00_l400;o2@02o`D0
0_l300;o2@02o`l0000=00;o3@02o`P00_l600;o1002o`030?oo00;o3@02oaH01Ol300;o1@02o`@0
0ol400;o1`000ol0000400;o0P02o`800_l400;o1@02o`D01Ol300;o2002o`T00_l600;o4`02o`D0
0_l300;o0`02o`<00_l400;o0`03o`L00_l200?o1P02o`<00_l300;o4002o`T00_l700;o2002o`03
0?l0008000Co0?oo1@02o`800_l200;o5002o`040?ooo`D00_l300;o0`02o`<00_l70003o`000080
0ol700;o1P02o`040?ooo`@00ol800;o1P02o`040?ooo`T00_l?00003@03o``00_l800;o1P02o`D0
0_lA00;o5P04o`@00_l500;o1@02o`@00_l600;o1P02o`H00_l400;o1@02o`D01?l400;o2002o`T0
0_l600;o4`02o`D00_l300;o0`02o`<00_l400;o1003o`H00_l300?o1@02o`<00_l300;o4@02o`L0
0_l800;o2004o`<01?l500;o1P02oa@00_l00`3oo`0600;o0`02o`<00_l300;o1P02o`D00_l700;o
1P02o`030?oo00H00_l700;o1`02o`030?oo00X00_l?00003P02o``00_l900;o1002o`H00ol?00;o
5`04o`@00_l500;o1003o`@00ol400?o1P02o`H00_l400;o1@02o`D01?l400;o2002o`T00_l500?o
4`02o`D00_l300;o0`02o`<00_l400;o1@02o`H00_l400?o1002o`<00_l300;o4@03o`D00ol800;o
2004o`@00ol500;o1P02oa@01Ol600;o2002o`<00ol400?o1@03o`D00ol600Go1`02o`D00_l800Go
2P02o`l0000?00;o1`03o`030?oo00T00ol200?o1`03o`d00_lG00Co0P06o`802_l600Wo100<o`<0
1?l300Co0`04o`801_l300[o0`0;oa<01?l300Co0P0<o`@02_l300Go0`05o`803?lB00Wo1@0:o`<0
1?l500Co0P0<oa401ol600Ko0P06o`<02Ol600[o0`07o`P02Ol500Oo1`0:o`/0000@0003o`0000D0
1_l:00Ko2@07o`P000?o00005P03o`<01_l200Wo2@05o`030?l000<03?l300Co0`04o`<00ol300Ko
0`0:o`<02OlE00Co0`04o`803?l400[o0`05o`<01Ol200co5005o`L02_l300Co1@04o`803?lA00Oo
1P06o`801_l500Go00<0o`001`05o`030?oo00<01ol:00Go1`07o`L02_l;00006`03o`/01?l<00Go
o`2l0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(107\\) NCSFHNIT JT KSVNIME AWSCAQAI)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`P0
1?l:00;o3`02oaD01_l300;o1`05o`H00_l00`3oo`03o`H01ol800Co0`04o`<01_l300;o100:o`D0
2?lE00Ko2008oa<01Ol600;o0`02o`030?oo00?o2P02o`P01_l300;o100:o`<01Ol300Go0P0<o`l0
1_l300Ko0`02o`@00_l500;o00<0ool00ol:00Go1006o`<01_l400Go1@06o`<01_l00`3oo`08o`/0
000<00;o2P09o`L01_l900;o4002oa@01_l200?o1@09o`@02_l400Oo2004o`<01?l300Ko0P03o`@0
2_l500So4`09o`L02?lC00Go1@03o`<02_l700Co1`06o`800ol400[o0`05o`<01Ol200co3`06o`<0
1_l300;o1002o`D02_l600Wo0P06o`<01_l200Wo0`06o`<01_l00`3oo`08o`/0000<00;o3P02o`T0
0ol200?o2@02o`l00_lE00;o1004o`@00ol500?o0`03o`D00ol500;o3002o`D00_l500;o1004o`P0
0_l<00;o5P03o`@00ol900;o6002o`D00ol400?o1@03o`H01?l800;o1004o`P00_l800;o1`02o`D0
0_l600;o4@02o`L00_l400?o1003o`@00ol500?o1003o`D00ol300;o1`02o`<00ol500?o1002o`L0
0_l700;o3`0000`00_l>00;o2@02o`@00_l900;o3`02oaD00_l400Co1002o`L00_l300;o1`02o`D0
0_l<00;o1@02o`D00_l400Co2002o``00_lF00;o1P02o`T00_lH00;o1@02o`D00_l700;o1P04o`P0
0_l400Co2002o`P00_l700;o1@02o`H00_lA00;o1`02o`@01?l300?o1002o`L00_l400;o1`02o`<0
0_l700;o0`02o`L00_l400;o1`02o`L00_l?00003002o`h00_l800;o1P02o`P00_l?00;o5@02o`<0
1Ol300?o3002o`L00_l500;o0P02o`P00_l500;o1@02o`<01Ol800;o3002oaH00_l600;o2@02oaP0
0_l400;o1P02o`L00_l500;o0P02o`L00_l300Go2002o`P00_l300;o0P02o`D00_l200;o0P02oa40
2ol400Co0P04o`@00_l700;o0`03o``02ol200;o2@02o`<02ol700;o3`0000`00_l>00;o2002o`H0
0_l90003o`0000d00_lE00;o0`02o`030?oo00<00_lE00?o1@02o`800_l800;o1@02o`D00_l300;o
00<0ool02002o``00_lF00;o1P02o`T00_lH00?o0P03o`h00ol500;o0P02o`L00_l300;o00<0ool0
2002o`P00_l200?o0P02o`D00_l200;o5P09o`D00_l0103o0004o``00ol300;o3P09o`<00_l900;o
1009o`P00_l?00003002o`h00_l800;o1P02o`T00_l>00;o5@02o`800ol00`3oo`0300;o4007o`H0
1_l800;o1@02o`D00_l200?o00<0ool02002o``00_lN00;o2@02oaP01ol:00Oo1@03o`800ol600;o
0P03o`030?oo00P00_l800;o0P000ol0o`0200;o1@06oaH00_l500;o1@02o`060?l00?l00_l700Oo
1002o`h00_l500;o0`02o`T00_l400;o1@02o`P00_l?00003002o`h00_l800;o1P02o`T00_l>00;o
5@02o`800_l200;o0`02o`h01ol800Ko2009o`D00_l200;o0P02o`P00_l<00;o7P02o`T00_lH00Go
2P07o`L00_l400;o1P02o`800_l200;o2002o`P00_l0103oo`02o`030?oo00D01_lG00;o0`02o`H0
0_l00`3oo`02o`030?oo00D01ol600;o3`02o`<00_l400;o2@02o`D00_l300;o2@02o`l0000=00;o
3@02o`P00_l600;o2P000ol0000;00;o5P02o`030?oo00<00_l300;o3@03o`d00_l200;o2009o`D0
0_l00`3oo`0300;o2002o`L00_l300;o0`02oaT00_l400;o0`02o`<00_lC00;o00@0oooo2003o``0
0_l400;o1P02o`030?oo00<00_l800;o2002o`030?oo008000Co0?oo1@02o`800_lG00;o0`02o`H0
0_l00`3oo`02o`030?oo00@00ol;00;o3`02o`<00_l400;o2@02o`D00_l300;o2@02o`l0000=00;o
3@02o`P00_l600;o2P02o``00_lF00Go0`02o`<00ol700;o0`02o`L000?o00001002o`800_l200;o
1002o`D00_l500Go0`02o`P00_l700;o0`02o`<00_lI00;o1002o`<00_l300;o4`02o`800ol700;o
1`000ol0000200;o1P02o`D01Ol300;o2002o`P00_l00`3o00020004o`3oo`D00_l200;o0P02oa@0
0_l0103oool500;o0`02o`<00_l300;o1`000ol0000200?o1`02o`H00_l0103oool400?o2002o`H0
0_l0103oool900;o3`0000d00ol<00;o2002o`H00_l:00;o3002oaH01?l400;o1002o`L00_l300;o
1P02o`H00_l600;o1002o`D00_l500Co1002o`P00_l700;o0`02o`<00_lI00;o1002o`<00_l300;o
4`02o`<00ol600;o1P02o`@00_l600;o1@04o`@00_l800;o2004o`<01?l500;o1P02oa@00_l00`3o
o`0600;o0`02o`<00_l300;o1P02o`D00_l700;o1P02o`030?oo00H00_l700;o1`02o`030?oo00X0
0_l?00003P02o``00_l900;o1002o``000?o00002@02oaL01?l400;o1003o`D00ol300?o1003o`H0
0_l600;o1002o`D00_l500Co1002o`P00_l700;o0`02o`<00_lI00;o1002o`<00_l300;o4`02o`@0
0ol500?o1003o`<00ol600?o1004o`@00_l800;o2004o`@00ol500;o1P02oa@01Ol600;o2002o`<0
0ol400?o1@03o`D00ol600Go1`02o`D00_l800Go2P02o`l0000?00;o1`03o`030?oo00T00ol200?o
1@02o`D00_l900;o5`04o`801_l400[o1009o`@03?l300Co0`04o`<01?l200Ko0`0:o`<03?lD00[o
00<0ool02_lA00Go0`05o`@02Ol200Ko0P06o`801?l200Ko0`0:o`<01?l500Co0P0<oa401ol600Ko
0P06o`<02Ol600[o0`07o`P02Ol500Oo1`0:o`/0000@0003o`0000D01_l:00Ko1P09o`T000?o0000
5P03o`<01_l600Go00<0ool01P05o`030?l000<03?l300Co0`04o`<00ol300Ko0`0:o`<03?lD00[o
00<0ool02_lA00Go0`05o`H01Ol0103o0006o`801_l200?o0`06o`<02_l300Co1@04o`803?lA00Oo
1P06o`801_l500Go00<0o`001`05o`030?oo00<01ol:00Go1`07o`L02_l;00006`03o`/01?l700Wo
o`2m0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(108\\) KCSEHNIT JT GSVNHNE AWTBAPAK)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`X01?l=00;o5005o`H00_l600Go1P02o`03
0?oo00?o1P0<o`<01?l300Co0`06o`<00_l400[o1@08oaD01_l800So5`06o`H00_l00`3oo`03o`X0
0_l800Ko0`02o`@01?l300Co0`06o`<00_l300co3`06o`<01_l300;o1002o`H02?l500[o0`06o`<0
3_l600Ko0`0;o`H00_l900003002o`X02Ol700Ko1`08o``00_lC00Go1@03o`@02Ol400[o100<o`<0
1?l300Co0`06o`800ol400[o1@08oa<02Ol700So5@0:o`@02_l700Co1`06o`800ol400Co0`04o`<0
1_l200?o0`0<o`l01_l300Ko0`02o`@00_l600So1@0;o`801_l300ko1P06o`<02ol500?o2@0000`0
0_l>00;o2@03o`800ol500?o1003o`/00_lE00;o1@03o`@00ol500?o0`03o`D00ol500;o1P02o`@0
0_l500;o1@02o`@01?l800;o3002oaH00ol400?o2@02oaL01?l500;o1003o`D00ol600Co2002o`@0
1?l500;o1@02o`D00_l400Co1@02o`H00_lA00;o1`02o`@00ol400?o2002o`X00_l500?o0`02o`L0
0_l400;o3002o`L00_l400;o1@03o`X0000<00;o3P02o`T00_l400;o1@02o`H00_l;00;o5@02o`D0
0_l500;o1`02o`<00_l700;o1@02o`H00_l400;o1@02o`D00_l400Co2002o``00_lF00;o1P02o`T0
0_lG00;o1`02o`@00_l700;o1P04o`P00_l400Co1@02o`D00_l500;o1004o`D00_l600;o4@02o`L0
0_l400Co0`03o`P00_l:00;o1P02o`<00_l700;o1002o``00_l700;o1002o`D00_l;00003002o`h0
0_l800;o1P02o`@00_l600;o2`02oaD00_l400;o1@03o``00_l700;o1@02o`800_l200;o1002o`D0
0_l500;o0`05o`P00_l<00;o5P02o`H00_l900;o5P03o`L00_l400;o1`02o`D00_l200;o1`02o`<0
1Ol500;o1@02o`D00_l300Go1@02o`800_l200;o4@0;o`@01?l200Co2002o`X00_l600;o0`0;o`@0
0_l<00_o1002o`@00_l<00003002o`h00_l800;o1P02o`@00_l600;o2`02oaD00ol200?o1@02oaD0
0ol500;o0P02o`P00_l500;o1@02o`<00_l00`3oo`0800;o3002oaH00_l600;o2@02oaH00_l400Oo
2`03o`D00_l200;o1`02o`<00_l00`3oo`0500;o1@02o`D00_l300;o00<0ool01@02o`800_lF00Wo
1@02o`040?l000Co2002o`X00_l600;o1009o`D01ol800Wo1@03o`800ol<00003002o`h00_l800;o
1P02o`D00_l400;o3002oaD01ol600;o4007o`H01_l800;o1@02o`D00_l200?o00<0ool02002o``0
0_lN00;o2@02oaH00_l400Oo1P07o`D00ol200?o1P02o`800ol00`3oo`0500;o1@02o`D00_l200?o
00<0ool01@06oaH00_l500;o1@02o`060?l00?l00_l800;o2P02o`D00ol400;o1@02o`D02Ol600;o
1@02o`D01ol=00003002o`h00_l800;o1P02o`H01ol<00;o5@05o`P00_l>00Oo2006o`P02Ol500;o
0P02o`800_l800;o3002oah00_l900;o5P02o`l01ol700;o1002o`H00_l200;o0P02o`D02Ol500;o
0P02o`800_l500Ko5`02o`<00_l600;o00<0ool00_l00`3oo`0800;o2P09o`H00_l300;o1P02o`D0
0ol600;o0`02o`H01Ol?00003@02o`d00_l800;o1P02o`H01_l<00;o5P02o`040?ooo`L00_l=00?o
3@02o`800_l800Wo1@02o`030?oo00<00_l800;o1`02o`<00_l300;o6@02o`@00_l300;o0`02oa40
0_l>00?o3002o`@00_l600;o00<0ool00`02o`D02Ol500;o00<0ool00`02o`D00_l200;o5`02o`<0
0_l600;o00<0ool00_l00`3oo`0300;o0`02o`<00_l500So1`02o`<00_l600;o1P02o`H00_l300;o
1P02o`040?ooo`h0000=00;o3@02o`P00_l600;o1@02o`@00_l;00;o5P02o`800ol600?o1`02o`<0
0_l70003o`0000@00_l200;o0P02o`@00_l500;o1@05o`<00_l800;o1`02o`<00_l300;o6@02o`@0
0_l300;o0`02oa400_l800;o1002o`L000?o00000P02o`H00_l500Go0`02o`D00_l500;o1@05o`<0
0_l500;o0P02o`800_lD00;o00@0oooo1@02o`<00_l300;o0P02o`<00_l300;o1@02o`@00ol700;o
00@0oooo1P02o`H00_l700;o00@0oooo1P02o`800ol=00003@03o``00_l800;o1P02o`@00_l600;o
2P02oaH00_l300?o1P02o`L00_l300;o1P02o`H00_l600;o1002o`D00_l500Co1002o`P00_l700;o
0`02o`<00_lI00;o1002o`<00_l300;o4P02o`H00ol400;o1P02o`@00_l600;o1@04o`@00_l500;o
1@02o`D01?l400;o1@02o`H00_lD00;o00<0ool01P02o`<00_l300;o0P02o`<00_l300;o1@02o`D0
0_l700;o00<0ool01`02o`H00_l700;o00<0ool01`02o`<00ol<00003P02o``00_l900;o1002o`D0
0_l600;o2@02oaL00_l400?o1@03o`D00ol300?o1003o`H00_l600;o1002o`D00_l500Co1002o`P0
0_l700;o0`02o`<00_lI00;o1002o`<00_l300;o4P03o`@01?l400?o1003o`<00ol600?o1004o`@0
0_l500;o1@02o`D01?l400;o1@02o`H00_lD00Go1P02o`P00_l200;o0`02o`<00_l500;o1003o`L0
1Ol700;o1@03o`L01Ol700;o1003o`/0000?00;o1`03o`030?oo00T00ol200?o1@03o`@00ol800;o
5P05o`<01Ol400[o1009o`@03?l300Co0`04o`<01?l200Ko0`0:o`<03?lD00[o00<0ool02_lC00[o
1@09o`801_l200Ko0P04o`801_l300Co0`04o`<01?l200Ko0P0<oa401ol600Ko0P06o`030?oo00[o
0`0:o`D01ol600_o1@07o`H01Ol300Go2@00010000?o00001@06o`X01_l700So2@000ol0000E00Go
0`05o`H01Ol00`3oo`0600Go00<0o`000`0<o`<01?l300Co0`03o`<01_l300[o0`0<oa@02_l00`3o
o`0:oaD01Ol00`3oo`0700Go00@0o`001_l200Ko0P03o`<01_l300Co0`04o`<00ol300Ko0P0<oa40
1ol600Ko0P06o`030?oo00[o0`09o`H01ol600Wo1`07o`H01Ol300Go2@0001/00ol;00Co2@06ool0
_P000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(109\\) KCSEHKJT JTZGSYKGNE AWXBAPAO)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo2004o`L01Ol?00;o5005o`H00_l600Go1P02o`03
0?oo00?o1P0<o`<01?l300Co0P05o`H00_l400Ko2008oaD01_l800So1P0:o`L01_l600;o00<0ool0
0ol700So1005o`H00_l600Ko1@06o`<00_l300co3`06o`<01_l300;o1002o`@01Ol200Go0`0:o`<0
1_l300ko1P06o`<01_l400Go3@0000`00_l:00Wo1`06o`H01ol>00;o4`05o`D00ol400Wo100:o`@0
3?l300Co0`04o`801Ol500?o0P09o`L02?lC00Wo1`08o`H02_l500[o100:o`D02?l400Go1@03o`@0
2_l300Ko0P03o`<03?l?00Ko0`06o`<00_l400;o1005o`801Ol300_o0P06o`<03_l600Ko0`06o`80
2Ol;00003002o`h00_l900?o0P03o`X00ol=00;o5@02o`D00ol400?o1@03o`<00ol500?o1@02o`H0
0_l400;o1@02o`D00_l500?o0`03o`@00ol900;o5P03o`@00ol900;o2P02o`D00_l400Co1@02o`@0
0ol500?o1`02o`T00_l500?o1004o`D00_l400;o1004o`D00_l600;o4@02o`L00_l400?o1003o`@0
0ol400?o1P02o`D00ol300;o1`02o`@00_l<00;o1`02o`<00ol500?o2P0000`00_l>00;o2@02o`@0
0_l;00?o3002oaD00_l500;o1@02o`L00_l300;o1`02o`D00_l600;o1002o`D00_l500;o1@02o`@0
0_l600;o2@02oaH00_l600;o2@02o`X00ol400;o1002o`L00_l400;o1`02o`L00_l900;o1@02o`D0
0_l700;o1002o`@01?l500;o1P02oa400_l700;o1004o`<00ol500?o0P03o`L00_l600;o0`02o`L0
0_l400;o3002o`L00_l300;o1`02o`X0000<00;o3P02o`P00_l600;o2`02o``00_lE00;o1002o`D0
0ol<00;o1`02o`D00_l200;o0P02o`@00_l500;o1@02o`@00_l500;o1P02o`T00_lF00;o1P02o`T0
0_l;00?o0`02o`<00ol700;o1002o`L00_l700;o2@02o`@00_l500?o1`02o`@00_l300Go1@02o`80
0_l200;o4@0;o`@01?l200Co1P02o`800_l800;o1P02o`<02ol400;o300;o`800_l900;o2@0000`0
0_l>00;o2002o`H00_l700Co00<0ool02`02oaD00ol200?o1@02oaD00ol500;o0P02o`P00_l500;o
1@03o`800ol500;o1P02o`T00_lF00;o1P02o`T00_l<00;o0`02o`<00_l400Oo2`03o`L00_l900?o
0P03o`D00_l400Oo0`02o`<00_l00`3oo`0500;o0P02oaH02Ol500;o00@0o`001?l700Co2@02o`H0
0_l400Wo1@07o`P02Ol300;o2@02o`T0000<00;o3P02o`P00_l600;o1@09o`/00_lE00Oo1P02oa00
1ol600Ko2002o`D00_l500Oo3P02o`T00_lN00;o2@02o``00ol700;o1007o`H01ol800?o2007o`H0
0_l400Oo0`02o`800ol00`3oo`0500Ko5P02o`D00_l500;o00H0o`00o`02o`L01?l900;o1@03o`@0
0_l500;o1@09o`H00_l500;o0`02o`T00_l900003002o`h00_l800;o1P02o`D00_l400?o2`02oaD0
1Ol800;o3P07o`P01_l800Wo1@05oa000_l900;o7P02o`T00_l=00?o1P02o`l01ol900Co2005o`P0
0_l>00;o0P02o`800_l500Ko5`02o`<00_l600;o00<0ool00_l00`3oo`0700?o2P09o`H00_l300;o
1P02o`D00ol600;o0`02o`@00_l900;o2@0000d00_l=00;o2002o`H00_l400;o1P02o`X00_lF00;o
00@0oooo1`02o`d00ol=00;o0P02o`P02Ol500;o00@0oooo3`02o`@00_l300;o0`02oaT00_l400;o
0`02o`<00_l400;o0`02o`H00_l>00?o3@06o`L00_l0103oool700;o3P02o`030?oo00<00_l500;o
0P02oaL00_l300;o1P02o`030?oo00;o00<0ool01`04o`T02?l700;o0`02o`H00_l600;o1P02o`<0
0_l400;o2@02o`T0000=00;o3@02o`P00_l600;o1002o`H00_l:00;o5P02o`800ol600?o1`02o`<0
0_l70003o`0000@00_l200;o0P02o`@00_l500;o1@02o`800ol>00;o1002o`<00_l300;o6@02o`@0
0_l300;o0`02o`@00_l300?o1@02o`P00_l400;o1`000ol0000400;o0P02o`L00_l200?o1P02o`P0
0_l400Go0`02o`D00_l200;o0P02oa@00_l0103oool500;o0`02o`<00_l500Ko2002o`@00ol700;o
00@0oooo1P02o`H00_l700;o00@0oooo1002o`T00_l900003@03o``00_l800;o1P02o`@00_l600;o
2P02oaH00_l300?o1P02o`L00_l300;o1P02o`H00_l600;o1002o`D00_l500;o0`03o`d00_l400;o
0`02o`<00_lI00;o1002o`<00_l300;o1002o`@00ol500;o1P03o`@00_l600;o1@03o`<00_l600;o
0`03o`H00_l600?o1004o`@00_l500;o1P02oa@00_l00`3oo`0600;o0`02o`<00_l400?o0P03o`L0
0_l500;o1`02o`030?oo00L00_l600;o1`02o`030?oo00H00_l700;o2P0000h00_l<00;o2@02o`@0
0_l500;o1P000ol0000800;o5`02o`@00ol500?o1@03o`<00ol400?o1P02o`H00_l400;o1@02o`D0
0_l400?o3002o`@00_l300;o0`02oaT00_l400;o0`02o`<00_l400;o1@02o`D00ol400Co1003o`@0
0ol500;o1002o`H00_l400?o1@03o`@01?l400Co1002o`D00_l600;o5005o`H00_l800;o1002o`@0
0_l700;o1003o`L01Ol700;o1@03o`L01Ol600?o1@03o`X0000?00;o1`03o`030?oo00T00ol200?o
1P02o`@00_l900;o5P05o`<01Ol400[o1009o`@03?l300Co0`04o`801Ol300Go1@0:o`030?oo00[o
500:o`030?oo00[o100:o`D02_l500Wo0`05o`801Ol200Go0`05o`@02_l300Co0P06o`803?lA00Oo
1P06o`801_l00`3oo`03o`801Ol300[o1@07o`H02ol500Oo2009o`/0000@0003o`0000D01_l:00Ko
1`07o`X000?o00005@05o`<01Ol600Go00<0ool01P05o`030?l000<03?l300Co0`04o`801Ol300Go
1@0:o`030?oo00[o500:o`030?oo00[o100:o`L01Ol00`3oo`0700Go00<0o`000P05o`801Ol200Go
0`05o`H01Ol00`3oo`0300?o0`06o`803?lA00Oo1P06o`801_l00`3oo`03o`801Ol300Wo1P07o`H0
2Ol700Oo2P05o`d0000K00?o2`04o`X01?oo0;l0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(110\\) KASEGMMQ JTYHSZKGNA AWXAAPFN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?oo`0[00003P02ocL00_mm00[o
o`0Z00003@02ocT00_mm00Go0P02ool0:P0000d00_li00;oO@000ol0003o0300000=00;o2@09o`H0
2Ol700Co3@02oa@01Ol600;o00<0ool01?l300Ko00@0ool01Ol600co1P06o`@01Ol300Go0P05o`<0
1Ol500Go5P06o`P02?l700So1@04o`<01?l400;o00<0ool00ol600[o0`05o`H00_l600Ko1@06o`<0
0_l200Ko0`06o`d01_l300Ko0`02o`@00_l400Go0P05o`801_l300_o0`0>o`L01ol800Ko0`02o`X0
000<00;o2P09o`H02Ol600Ko3@02oa<01Ol500?o00<0ool01?l300Ko00<0ool02?l400co100:o`80
1Ol300Go0P05o`<01Ol300Wo4P09o`L02?l700So1@04o`<01?l400[o100:o`<01Ol500?o100:o`<0
1_l200?o0P06o`<01_l=00Ko0`06o`<00_l400;o1005o`801Ol200Ko0`0;o`<03_l700Oo2006o`80
0ol:00003002o`h00_l=00;o2003o`800ol<00;o5@02o`D00ol400;o1`02o`<00ol500?o1@02o`H0
0_l300Co1@02o`<00_l700;o1002o`L00_l300?o1@03oa400ol400?o2@02o`d00_l900;o1@02o`D0
0ol500?o1002o`D00_l500;o1@03o`@01?l500;o1002o`@01?l400;o1`02oa400_l700;o1003o`@0
0ol400?o1003o`D00_l700;o0`02o`L00_l400;o3@02o``00_l400Co2P0000`00_l>00;o3@02o`P0
0_l400;o3002oaD00_l500;o1@02o`L00_l300;o1`02o`D00_l600;o0`02o`L00_l300;o1`02o`@0
0_l700;o0`02o`L00_lA00;o1P02o`T00_l=00;o2@02o`D00_l500;o1`02o`@00ol400;o1@02o`D0
0_l500;o1`02o`@00_l400Co1002o`L00_lA00;o1`02o`@01?l300?o1@03o`800ol600;o1`02o`<0
0_l700;o1002o`d00_l<00;o1004o`X0000<00;o3P02o`d00_l700;o1P02o`/00_lE00;o1002o`H0
2ol300;o1`02o`D00_l200;o0P02o`800ol700;o0`02o`<00_l200;o1002o`<00_l200;o0P02o`T0
0_l@00;o1P02o`T00_l=00;o2@02o`D00_l500;o1`02o`D00ol300;o1@02o`@00_l500?o1`02o`@0
0_l300Go100;oa402ol400Co0P04o`H00_l200;o1`0;o`<02ol400;o3@02o`800_l800;o0`05o`X0
000<00;o3P02o`d00_l700;o1P02o`/00_lE00?o0P03o`L02Ol<00?o1@02o`800_l600;o1007o`80
0_l200?o0P02o`@00_l200?o0P02o`800_l900;o4002o`H00_l900;o3@02o`T00_l500;o3@03o`H0
0_l300;o1@03o`800ol500;o1007o`<00_l300;o00<0ool01@09oa<02Ol500;o00@0o`001?l700Co
2@09o`D02Ol500Oo2002o`800_l800;o0`02o`030?oo00X0000<00;o3P02o`d00_l700;o1P02o`/0
0_lE00Oo2002o`D00_l700Oo1P06o`H00_l400Oo0P02o`8000?o0?l00P02o`@00_l20003o`3o0080
0_l200;o2@02oaP00_l900;o3@03o`P00_l500;o2007o`L00ol900Oo1P02o`@01ol300;o0P03o`03
0?oo00D00_l500;o4`02o`D00_l500;o00H0o`00o`02o`L01?l900;o1@02o`D00_l500;o1@09o`H0
1_l800;o0P03o`030?oo00X0000<00;o3P02o`d00_l700;o1P02o`/00_lE00Go2`02o`<00_l600Oo
2006o`H00_l=00;o00@0ool00_l00`3oo`0400;o00@0ool00_l00`3oo`0200;o2@02oaP00_l900;o
3004o`P02Ol600Oo2P03o`P01Ol800;o3P02o`800_l200;o1P02o`<00_lE00;o0`02o`H00_l00`3o
o`02o`030?oo00L00ol;00;o0`02o`L00_l300;o1P02o`D00ol500Ko2002o`800_l200;o2P0000d0
0_l=00;o3@02o`L00_l600;o2P02oaH00_l0103oool:00;o0`02o`D00ol=00;o0P02o`H00_l=00;o
00<0ool00P001?l0ool400;o00<0ool00P001?l0ool200;o2@02oaP00_l400;o0`02o`<00_l600Ko
1`09o`D00ol;00;o0`02o`P00_l0103oool700;o3P02o`030?oo00<00_l600;o0`02oaD00_l300;o
1P02o`030?oo00;o00<0ool01`04o`X00_l300;o1`02o`<00_l600;o1P02o`D00_l200;o2002o`03
0?oo00<00_l:00003@02o`d00_l=00;o1`02o`H00_l:00;o5P02o`800ol:00;o00@0oooo1@02o`L0
00?o00001002o`800_l200;o0P02o`P00_l300;o00<0o`000P001?l0ool400;o00<0o`000P001?l0
ool200?o2002oaP00_l400;o0`02o`<00_l600;o0P02o`L00_l500;o1@02o`L000?o00000P02o`<0
0ol700;o0P03o`H00_l800;o1005o`<00_l700;o00@0oooo5P02o`040?ooo`D00_l300;o0`02o`D0
1_l:00;o00@0oooo2002o`040?ooo`H00_l600;o1@02o`800_l200;o1005o`<00_l:00003@03o``0
0_l=00;o1`02o`H00_l:00;o5P02o`<00ol900;o00<0ool01P02o`H00_l600;o1P02o`<00_l600?o
0`04o`<01?l400Co0`04o`<00_l700;o6@02o`@00_l300;o0`02o`D00ol300;o1P02o`D00_l500;o
1P02o`@00_l400?o1P02o`<00ol600;o1P03o`@01?l400;o1`02o`030?oo01L00_l00`3oo`0600;o
0`02o`<00_l400?o0P03o`T00_l00`3oo`0900;o00<0ool01`02o`H00_l500;o1P02o`@01?l400;o
2P0000h00_l<00;o3@02o`P00_l400;o2P02oaL00_l400?o2005o`H00ol400?o1P02o`H00_l300?o
1004o`<01?l400?o1004o`@00ol400;o1@02oaX00_l400;o0`02o`<00_l500;o1002o`H00_l500;o
1@03o`@00ol400;o1@02o`H00_l400?o1@03o`@01?l400Co1002o`L01OlG00Go1P02o`P00_l400;o
1002o`T01Ol900Go1`02o`D00ol500;o1P02o`@01?l400;o2P0000l00_l700?o00<0ool02@03o`03
0?oo00P00ol200?o2@02oaH01Ol300Go0`07o`P02Ol400co100:o`801?l500Co0P04o`D01?l300Wo
5@0:o`030?oo00[o0`05o`801Ol300Co0`04o`D02Ol400[o0`05o`<01Ol400[o0`04o`801_l300Oo
5@07o`H01_l200Ko00<0ool00ol200Go1007o`L01ol600_o100<o`<01?l200Ko2@00010000?o0000
1@06o`T01_l900Ko2P000ol0000E00Go0`05o`<01ol:00Go00<0o`000`0<o`H01Ol00`3oo`0200Co
1@04o`801?l500Co1@05oaL02_l00`3oo`0:o`<01Ol200Go0`04o`<01?l700Go00<0o`000`0:o`<0
1Ol300Go1P05o`030?oo00<00ol300Ko0`07oaD01ol600Ko0P06o`030?oo00?o0P05o`@01ol700Oo
1P09o`H03?l300?o0`06o`T0000K00?o3003o`X01?oo0;l0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(111\\) NASIGMMQ JSYHS KDJC A SECPEP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?oo`0[00003P02ocL00_mm00[o
o`0Z00003@02ocT00_mm00Go0P02ool0:P0000d00_li00;oO@000ol0003o0300000=00;o2@09o`H0
2Ol500Wo2P02oaD01_l300;o0P06o`<01_l0103oo`05o`L02_l700Ko1005o`<01Ol200Go0`05o`D0
1OlF00Ko1`02o`030?oo00?o2008o`D01?l300Co1002o`030?oo00?o4`05o`H00_l300So1`06o`/0
1OlB00Ko0`06oa000_l00`3oo`03o`H03?l600Go1@08o`L03?l200So3P0000`00_l:00Wo1P09o`D0
2Ol;00;o5006o`800ol200Ko0`06o`030?oo00So1@0:o`D02_l200Go0`05o`801Ol300Go0`09oa80
2Ol600[o1P08o`D01?l300Co100:oa401Ol500?o0`0:o`<02Ol800Wo4006o`<01_l@00[o100<o`@0
2Ol300So1`0<o`802?l>00003002o`h00_l=00;o3002o`h00_lE00;o1004o`@00_l700;o0`03o`D0
0ol800;o2004o`D00_l300;o1`02o`@00_l700;o0`03o`D00olA00?o1003o`D00ol500?o2002o`T0
0_l500;o1@03o`D00olB00;o1@03o`D00_l400Co0P03o`@00ol600?o1@03oa400_l700;o4P03o`D0
0ol500;o1P02o`<00ol500?o1002o`d00_l600;o1002oa80000<00;o3P02o`d00_l<00;o3P02oaD0
0_l400Co1002o`L00_l300;o1`02o`P00_l800;o1`02o`<00_l700;o1002o`L00_l300;o1`02oa40
0_l600;o1@02o`L00_l800;o2@02o`D00_l500;o1`02oa800_l500;o1P02o`H00_l200;o1P02o`H0
0_l700;o4@02o`L00_lB00;o1`02o`D00_l600;o0`02o`L00_l400;o3@02o`H00_l400;o4P0000`0
0_l>00;o3@02o``00_l>00;o5@02o`<01Ol400_o0`02o`L00_l800;o1`03o`L00_l300;o0`02o`80
0_l400;o0`02o`800_l200;o2@02oa000_l600;o1@02o`L00_l800;o2@02o`D00_l500;o1`02oa80
0_l400;o1`02o`L00_l00`3oo`0600;o1@03oaX02olB00;o1`02o`D00_l200;o0P02o`800ol=00;o
3@02o`800_l200;o1002oa80000<00;o3P02o`d00_l<00;o3P02oaD00_l300;o00<0ool01@09o``0
0ol800;o1`02o`@01ol200;o0P03o`800_l400;o0P03o`800_l200;o2@02oa000_l600;o3@03o`P0
0_l900;o1@02o`d00olB00?o0P03o`L00_l700;o00<0ool01P02o`D00_lL00Wo6`03o`D00_l200;o
1P02o`h01ol800;o0P02o`P01ol=00003002o`h00_l=00;o3002o`h00_lE00;o0P03o`030?oo00D0
0_l500;o1`07o`T00_l700;o1007o`800_l20003o`3o00800_l400;o0P000ol0o`0200;o0P02o`T0
0_lH00;o2007o`T00ol800;o1@02o`P01olC00Oo2002o`L00_l900;o1@02oa`00_l500;o5P07o`H0
1_l600;o3P09o`H01_l800Wo2`0000`00_l>00;o3@02o``00_l>00;o5@02o`800_l200;o1P02o`<0
0_l600Oo2`02o`L00_l=00;o00@0ool00_l00`3oo`0400;o00@0ool00_l00`3oo`0200;o2@02oaP0
0_l600Oo2P04o`P02Ol600Oo5@05o`X00_l700;o2@02o`D00_lM00;o0`02oaD01ol800Ko1P02o`h0
0_l500?o1@06o`P00_l500?o2P0000d00_l=00;o3@02o``00_l=00;o5P02o`030?oo00<00_l600;o
0`02o`D00ol@00;o1`02o`d00_l00`3oo`020004o`3oo`@00_l00`3oo`020004o`3oo`800_l900;o
6002o`D00ol>00Ko1`09o`D00olJ00;o00@0oooo2@02o`L00_l900;o1@02oad00_l300;o5003o`d0
0_l200;o1P02o`h00_l600;o1@02o`800_l800;o1P02o`X0000=00;o3@02o`d00_l<00;o3@02oaH0
1Ol300;o1`02o`040?ooo`D00_l70003o`0000L00_l700;o2002o`<00_l00`3o00020004o`3oo`@0
0_l00`3o00020004o`3oo`800ol800;o6002o`D00_l70003o`0000D00_l200;o1`02o`D00_l500;o
1`000ol0000A00;o0P03o`P00_l700;o2@02o`D00ol700;o5002o`040?oooa@00_l70003o`0000@0
0_l200;o0P02o`800ol700;o1002o`H00_l500;o0P02o`800_l400;o1P02o`X0000=00?o3002o`d0
0_l<00;o3@02oaH01?l400;o1`02o`030?oo00H00_l600;o2@02o`P00_l600?o0`04o`<01?l400Co
0`04o`<00_l700;o6@02o`D00_l600;o1P03o`<00_l600;o1@02o`D00_l600;o4`02o`<00ol700;o
1P02o`X00_l600;o1`02oa@00_l00`3oo`0E00;o1P02o`H00_l600;o0`02o`L00_l400;o1P02o`D0
0_l600;o1002o`H00_l:00003P02o``00_l=00;o3002o``00_lG00Co1002o`L01Ol600?o1003o`T0
0_l800?o1004o`<01?l400?o1004o`@00ol400;o1@02oaX00_l500?o1003o`H00_l400;o1P02o`D0
0_l500?o1003oa<00_l400?o1P02o`@01?l:00;o1P03o`D00olD00Go5@03o`@00ol600;o1P02o`<0
0ol500?o1002o`D00ol500;o1P02o`@00_l500?o2P0000l00_l700?o00<0ool02@03o`030?oo00P0
0ol00`3oo`0;00;o5`04o`801_l300Oo2009o`D02_l500[o0P04o`D01?l200Co1@04o`<02OlE00[o
0`09o`@01Ol200Go0`04o`<01?l500Wo4@05o`<01Ol300[o1P0:o`@02_lA00Oo5`09o`@03?l400[o
0P0;o`@03?l200_o2`00010000?o00001@06o`T01_l800Ko2`000ol0000F00?o0`06o`<01ol:00Go
00<0o`00100:o`L01Ol00`3oo`0200Co1@04o`801?l500Co1@05oaL02_l500Go00<0o`000`05o`80
1Ol300Co0`04o`L01Ol00`3o000@00Go0`05o`<02?l800[o1P05o`030?oo01401olI00Go00<0o`00
0`0<o`H01Ol00`3oo`0200Wo1P0<o`802Ol=00006`03o``00ol;00?oo`2o0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(112\\) NASIGMMQYJS HS KIJA A SECPEP)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?oo`0[00003P02ocL00_mm00[o
o`0Z00003@02ocT00_mm00Go0P02ool0:P0000d00_li00;oO@000ol0003o0300000=00;o2@09o`H0
2Ol400[o2P02oaD01_l300;o0P06o`<01_l0103oo`05o`L02_l700Ko1005o`<01Ol200Go0`05o`D0
1Ol800So1P06o`L00_l00`3oo`03oaD01?l300Co1002o`030?oo00?o4`05o`H00_l300[o1@06o`H0
1_l300Ko3@06o`<01_l@00;o00<0ool00ol600co1P05o`D02?l700co0P08o`h0000<00;o2P09o`H0
2Ol400[o2`02oa@01_l200?o0P06o`<01_l00`3oo`08o`D02_l500[o0P05o`<01Ol200Go0`05o`<0
2Ol600So1009o`H02_lC00Co0`04o`@02_lA00Go1@03o`<02_l300Wo1@06o`<01_l=00Ko0`06oa00
2_l400co1009o`<02?l700co0P08o`h0000<00;o3P02o`d00_l800;o1@02o`/00_lE00;o1004o`@0
0_l700;o0`03o`D00ol800;o2004o`D00_l300;o1`02o`@00_l700;o0`03o`D00ol800;o1`03o`@0
0ol500?o1@03oa<00_l500;o1@03o`D00olB00;o1@03o`P00_l700?o1003o`H00_l700;o4@02o`L0
0_lB00?o1@03o`D00_l600;o0`03o`D00ol400;o3@02o`H00_l400;o4P0000`00_l>00;o3@02o`T0
0ol@00;o5@02o`@01?l400;o1`02o`<00_l700;o2002o`P00_l700;o0`02o`L00_l400;o1`02o`<0
0_l700;o2002o`L00_l600;o1@02o`L00_lC00;o1@02o`D00_l700;o4P02o`D00_l900;o1`02o`H0
0_l600;o1`02oa400_l700;o4P02o`L00_l500;o1P02o`<00_l700;o1002o`d00_l600;o1002oa80
000<00;o3P02o`d00_l:00?o3`02oaD00_l300Go100;o`<00_l700;o2002o`L00ol700;o0`02o`<0
0_l200;o1002o`<00_l200;o0P02o`T00_l700;o1`02o`H00_l500;o1`02oa<00_l500;o1@02o`L0
0_lB00;o1002o`X00_l700;o1P02o`H02olA00_o4P02o`L00_l500;o0P02o`800_l200?o3@02o`d0
0_l200;o0P02o`@00_lB00003002o`h00_l=00;o2`03o`h00_lE00;o0`02o`030?oo00D02Ol<00?o
2002o`L00_l400Oo0P02o`800ol200;o1002o`800ol200;o0P02o`T00_l700;o1`02o`H00_l=00?o
4`02o`D00_l=00?o4P03o`800ol:00;o1`02o`H00_l700Wo4`09oa/00ol500;o0P02o`H00_l>00Oo
2002o`800_l800Oo3@0000`00_l>00;o3@02o``00ol=00;o5@02o`800ol00`3oo`0500;o1@02o`L0
1ol900;o1`02o`@01ol200;o0P000ol0o`0200;o1002o`8000?o0?l00P02o`800_l900;o1`03o`h0
0_l800Oo5002o`D00_l800Oo4`07o`/00_l?00;o1`02o`D00_lC00;o1@02oaH01ol600Ko1P02o`h0
2Ol600Ko2009o`/0000<00;o3P02o`d00_l=00?o3002oaD00_l200;o0P02o`H00_l300;o1P07o`/0
0_l700;o3@02o`040?oo00;o00<0ool01002o`040?oo00;o00<0ool00P02o`T00_l600Co3P02o`H0
1olF00Wo1P07oaD01Ol=00;o3`02o`P00_l300;o5@02o`<00_lE00Oo2006o`H00_l>00;o1@03o`D0
1_l800;o1@03o`X0000=00;o3@02o`d00_l>00;o2`02oaH00_l00`3oo`0300;o1P02o`<00_l500?o
4002o`L00_l=00;o00<0ool00P001?l0ool400;o00<0ool00P001?l0ool200;o2@02o`D01_l=00;o
1@03oa/02Ol500?o6P02o`040?ooo``00_l?00;o2002o`<00_lE00;o0`02oa@00ol=00;o0P02o`H0
0_l>00;o1P02o`D00_l200;o2002o`H00_l:00003@02o`d00_l=00;o3`02o`X00_lF00Go0`02o`L0
0_l0103oool500;o1`000ol0000700;o1`02o`P00_l300;o00<0o`000P001?l0ool400;o00<0o`00
0P001?l0ool200?o2002o`D00_l200;o3@02o`D00_l70003o`0001800_l500;o1@02o`L000?o0000
4@02o`800ol;00;o3`02o`T00_l0103ooolF00;o00@0oooo5002o`L000?o00001002o`800_l200;o
0P03o`L00_l400;o1P02o`D00_l200;o0P02o`@00_l600;o2P0000d00ol<00;o3@02o`l00_l:00;o
5P04o`@00_l700;o00<0ool01P02o`H00_l900;o2002o`H00ol300Co0`04o`@01?l300Co0`02o`L0
0_l500?o0`02o``00_l500;o1P02oa@00_l500;o1@02o`H00_lC00;o0`03o`X00_l?00;o2@02o`03
0?oo01L00_l00`3oo`0E00;o1P02o`H00_l600;o0`02o`L00_l400;o1P02o`D00_l600;o1002o`H0
0_l:00003P02o``00_l=00;o2002o`D00_l900;o5`04o`@00_l700Go1P03o`@00ol900;o2003o`@0
1?l300Co1003o`@01?l400?o1002o`D00_l600;o1002o``00_l500?o1003oa@00_l500;o1@03o`@0
0olC00;o1003o`T00_l?00;o2@05oaL01OlE00?o1003o`H00_l600;o0`03o`D00ol400;o1@03o`D0
0_l600;o1002o`D00ol:00003`02o`L00ol00`3oo`0900?o00<0ool02003o`<00ol800;o5`04o`80
1_l300Oo2009o`D02_l500[o0P04o`D01?l200Co1@04o`<02Ol400Go0P05o`D02_l300Wo4`04o`<0
1?l500Wo4@05o`<01Ol300[o1P0:o`<01olE00Oo5`09o`@03?l400[o0P0;o`@03?l200_o2`000100
00?o00001@06o`T01_l900Oo2@000ol0000F00?o0`06o`<01ol:00Go00<0o`00100:o`L01Ol00`3o
o`0200Co1@04o`801?l500Co1@05o`H01Ol200Go1@0:o`D01Ol00`3o000B00Co0`04o`L01Ol00`3o
000@00Go0`05o`<02_l600[o0`07oaD01olI00Go00<0o`000`0<o`H01Ol00`3oo`0200Wo1P0<o`80
2Ol=00006`03o``00ol:00Goo`2n0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(113\\) KASIFKMQYIW GT KIJA CYVCCPEN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?oo`0[00003P02ocL00_mm00[o
o`0Z00003@02ocT00_mm00Go0P02ool0:P0000d00_li00;oO@000ol0003o0300000=00;o2@09o`H0
2Ol600Go3@02oa@01Ol600;o00<0ool01?l300Ko00@0ool01Ol700[o0`07o`L01Ol600;o0P05o`<0
1Ol500Go2008o`D02_l500;o1002oaL01_l700So4P05o`H00_l300[o1@06o`H01_l300Ko4P05o`P0
2?l900;o3005o`T01Ol500So1`0<o`<01_l300;o2P0000`00_l:00Wo1P09o`@02Ol<00;o4`05o`D0
0ol00`3oo`04o`<01_l00`3oo`08o`D02_l300Oo1`05o`D00ol200Go0`05o`<02Ol600So1@0:o`D0
0_l400;o5@0:o`D02?lB00Go1@03o`<02_l300Wo1@06o`<01_l@00Wo1P08o`P01?l900Wo1@09o`<0
2?l700co0`06o`800ol:00003002o`h00_l=00;o1`02o`D00_l<00;o5@02o`D00ol400;o1`02o`<0
0ol500?o2002o`T00_l<00;o1@03o`@00_l700;o0`03o`D00ol800;o3002o`P00ol400?o4`04o`D0
0_l800;o5`02o`D00ol800;o1`03o`@00ol600;o1`02oa400ol500?o2002o`/01?l800?o1@03o`<0
0ol500?o1002o`d00_l600;o1002o`@01?l:00003002o`h00_l=00;o3`02o`/00_lE00;o1@02o`D0
0_l700;o0`02o`L00_l800;o2@02o``00_l500;o1@02o`L00_l300;o1`02o`P00_l<00;o2004o`<0
0olC00;o1`02o`P00_lG00;o1@02o`T00_l700;o1P02o`H00_l700;o4@02o`L00_l800;o2`04o`P0
0_l700;o0`02o`L00_l400;o3@02o`H00_l400;o1004o`X0000<00;o3P02o`d00_l?00;o2`02oaD0
0_l400;o1P0;o`<00_l700;o2002o`T00_l200;o2002o`@00_l600;o0`02o`800_l200;o2@02o`L0
0_l<00;o2004o`801?lB00?o1`02o`P00_lG00;o1002o`X00_l700;o1P02o`H02ol@00?o4@02o`X0
0_l200;o1P03o`/00ol=00;o3@02o`800_l200;o1002o`<01Ol:00003002o`h00_l=00;o3`02o`/0
0_lE00?o0P03o`L02Ol<00?o2002o`T00_l200;o2003o`800ol600;o0P03o`800_l200;o2@02o`L0
0_l<00;o2002o`040?l000Co4P02o`@01ol700;o5`03o`800ol:00;o1`02o`H00_l700Wo4@02oa80
0_l:00;o0P02o`H00_l<00;o3P07o`P00_l200;o2002o`<00_l00`3oo`0:00003002o`h00_l=00;o
3P02o``00_lE00Oo2002o`D00_l700Oo2@02o`T01_l800Oo1`02o`8000?o0?l00P02o`800_l900;o
1`03o`/00_l800;o00H0o`00o`02oa800_l400Oo1`02oaL01ol;00;o3`02o`L00_l500;o4@02oa80
0ol800?o0P03o`D00_l<00;o3P09o`H01_l800;o0P03o`030?oo00X0000<00;o3P02o`d00_l;00Co
3@02oaD01Ol;00;o0`02o`H01ol;00;o2@06o`P01Ol900;o00@0ool00_l00`3oo`0200;o2@02o`H0
1?l;00;o2002o`030?oo00;o00<0ool04P02oa800_lG00Go3@02o`l00_l800;o0`02oa800_lA00Co
2002o`@00_l500;o3002o`h00_l500?o1@06o`P00_l200;o0P02o`X0000=00;o3@02o`d00_l;00?o
3@02oaH00_l0103oool:00;o0`02o`D00ol@00;o2@02o`800_l800;o00@0oooo2002o`030?oo0080
00Co0?oo0P02o`T00_l500Ko2P02o`P00_l00`3oo`02o`030?oo01800_l=00;o0`02o`<00_lB00;o
00@0oooo3002o`l00_l800;o0`02oa800_l@00Ko1`02o`@00_l500;o3002o`h00_l600;o1@02o`80
0_l800;o00<0ool00`02o`X0000=00;o3@02o`d00_l=00;o3002oaH00_l200?o2P02o`040?ooo`D0
0_l70003o`0000L00_l900;o0P02o`800_l400;o0P03o`L00_l00`3o00020004o`3oo`800ol800;o
1@02o`800_l:00;o1`02o`<00_l300;o4@02o`P00_l300;o0`02o`<00_lB00;o0P03o`/00_l?00;o
2@02o`040?oooa800ol700;o1P02o`800_l600;o1P02o`@00ol700;o0P03o`L00_l400;o1P02o`D0
0_l200;o0P02o`@01Ol300;o2P0000d00ol<00;o3@02o`h00_l;00;o5P02o`<00ol900;o00<0ool0
1P02o`H00_l900;o2@02o`H00_l400;o0`03o`H01?l300Co0`02o`L00_l500?o0`02o`T00_l700;o
0`02o`<00_lB00;o1P03o`<00_l300;o0`02oa800_l300?o2P02o`l00_l900;o00<0ool05002o`L0
0_l500?o0`02o`D00_l600;o1@02o`L00_l300;o1`02o`@00_l600;o1@02o`H00_l400Co1002o`X0
000>00;o3002o`d00_l>00;o2P02oaL00_l400?o2005o`H00ol400?o2@02o`T00_l600;o1002o`@0
0ol500Co1003o`@00_l500;o1P02o`@00_l900;o1`02o`P00_lB00?o1004o`<00_l300;o0`02oa80
0_l400?o2@02o`l00_l900Go5003o`D00ol500;o1002o`@00ol600?o1003o`D00ol300?o1@03o`@0
0_l500?o1@02o`H00_l400Co1002o`X0000?00;o1`03o`030?oo00T00ol00`3oo`0800;o0`03o`T0
0_lF00Go0`05o`<01ol800Wo1@0:o`<03?l200Go0`05o`801?l500Co0`09o`@01Ol200Go0`0:o`80
1_l200Ko4P0:o`<03?l@00Go0`05o`<02_l600[o0`07oaH02_l300Go0P05o`030?oo00Co0P06o`@0
2_l400[o0P0;o`@03?l300Co0P06o`T0000@0003o`0000D01_l900Ko2007o`X000?o00005@05o`<0
1Ol300Oo2P05o`030?l000@02_l300co0P05o`<01Ol200Co1@04o`D01Ol600Go0P05o`<02_l200Ko
0P06oa@01Ol00`3oo`0300co4005o`<01Ol300[o1P0:o`<01olH00Go00<0ool00`05o`801Ol00`3o
o`04o`801_l600Go00<0ool01P05o`030?oo00802Ol600co0`03o`<01_l900006`03o``00ol:00Co
o`2o0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(114\\) HASIFKMQYIW GS KIMC EY CBUGN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?oo`0[00003P02ocL00_mm00[o
o`0Z00003@02ocT00_mm00Go0P02ool0:P0000d00_li00;oO@000ol0003o0300000=00;o2@09o`H0
2Ol800Ko2P02oaD01?l300Co0P06o`<01_l0103oo`05o`L02_l300Oo1`05o`H00_l200Go0`05o`D0
1Ol800So1@0:o`D00_l400;o5`06o`H00_l00`3oo`03oa<01Ol600;o0`0:o`<01Ol300Go1P05oa<0
3?l500So5`05o`D02_l900Co2P06o`D01_l300;o2P0000`00_l:00Wo1P09o`P01_l;00;o5004o`<0
1?l200Ko0`06o`030?oo00So1@0:o`<01ol700Go1@03o`801Ol300Go0`09o`H02?l500[o1@02o`@0
0_lE00[o100:oa401Ol500?o0`0:o`<01Ol300Go1009oa403?l500So5@09o`<02ol600So1P0:o`<0
1_l200?o2P0000`00_l>00;o3@02o`d00_l=00;o5@02o`D00_l500;o1`02o`<00ol500?o2002o`T0
0_l<00;o1@03o`@00_l700;o0`03o`D00ol800;o3002o`P00ol400?o4`04o`D00_l400?o1@03oa80
0_l500?o2002o`P00_l700;o1003o`D00olB00;o1P02o`P00_lG00?o1@03o`@00_l500?o1@02o`@0
0_l500Co1@02o`@00_l400Co2P0000`00_l>00;o3@02o`d00_l=00;o5@02o`D00_l500;o1`02o`<0
0_l700;o2002o`T00_l<00;o1@02o`D00_l700;o0`02o`L00_l800;o3002o`P01?l300?o4`02o`L0
0_l400;o1`02oa800_l500;o2@02o`P00_l700;o1002o`L00_lB00;o1P02o`P00_lG00;o1`02o`@0
0_l600;o1002o`H00_l400;o1`02o`@00_l400Co2P0000`00_l>00;o3@02o`L02_l;00;o5@02o`D0
0_l500_o0`02o`L00_l800;o2@02o`800_l800;o1002o`H00_l300;o0P02o`800_l900;o1`02o``0
0_l800Co0P04oa800ol700;o1002o`L00_lB00;o1002o`X00_l800;o0`02o`800_l300?o6`02o`80
0_l200;o2002oaH00ol=00;o1P02o`@00_l600;o0`03o`L00_l400;o0`05o`X0000<00;o3P02o`d0
0_l700[o2`02oaD00_l500;o1P09o``00ol800;o2@02o`800_l800?o0P03o`H00_l200?o0P02o`80
0_l900;o1`02o``00_l800;o00@0o`001?lB00;o1007o`/00olB00?o0P03o`X00_l800;o0P03o`80
0_l300;o7002o`800_l<00;o5P02o`h00_l600;o1002o`H00_l300;o1007o`<00_l300;o00<0ool0
2P0000`00_l>00;o3@02o`L00_l400;o3@02oaD00_l500;o1P02o`D00_l700Oo2@02o`T01_l800Oo
1`02o`8000?o0?l00P02o`800_l900;o1`03o`/00_l800;o00H0o`00o`02oa800_l400Oo1P07oa<0
1ol;00;o2002o`8000?o0?l00P02o`<00_lL00Ko3003oaD00_l>00;o1@03o`@00_l600;o0`02o`@0
1ol300;o0P03o`030?oo00X0000<00;o3P02o`d00_l800;o0`02o`d00_lE00Wo1`02o`<00_l600Oo
2`02o`T01_l800Go2@02o`040?oo00;o00<0ool00P02o`T00_l600Co2`02o`P00_l00`3oo`02o`03
0?oo01800_l?00Oo5@05o`d00_l800;o00@0ool00_l00`3oo`0300;o7006o`/01?lE00;o3P09o`D0
0_l600;o0`02o`h00_l200;o0P02o`X0000=00;o3@02o`d00_l90004o`0000;o3002oaH02Ol700;o
0`02o`D00ol@00;o2@02o`800_l800;o00@0oooo2002o`030?oo008000Co0?oo0P02o`T00_l500Ko
2P02o`P00_l00`3oo`02o`030?oo01800_l>00?o6P02o`040?ooo``00_l800;o00<0ool00P001?l0
ool300;o7002o`800_l:00Ko5002o`h02?l600;o1P02o`<00_l>00;o00<0ool00`02o`X0000=00;o
3@02o`d00_l900;o0P02o``00_lF00;o1@02o`P00_l0103oool500;o1`000ol0000700;o2@02o`80
0_l200;o1002o`800ol700;o00<0o`000P001?l0ool200?o2002o`D00_l200;o2P02o`L00_l300;o
0`02oa400_l800;o1002o`L000?o00004@02o`800ol;00;o2002o`030?l0008000Co0?oo0`03o`L0
0_lB00;o0P02o`800_l600;o0P02oa@00ol700;o1002o`@00ol500;o1P02o`<00_l800;o1005o`<0
0_l:00003@03o``00_l=00;o2P000ol00002o``00_lF00;o1@02o`P00_l00`3oo`0600;o1P02o`T0
0_l900;o1P02o`@00_l300?o1P04o`<01?l300;o1`02o`D00ol300;o2@02o`L00_l300;o0`02oa80
0_l600?o1002o`H00_lC00;o0`03o`X00_l800Co0`04o`@00_l700;o4P02o`H00_l500?o0`02oa@0
0_l700;o1002o`D00_l500;o1P02o`@00_l600?o1004o`@00_l:00003P02o``00_l=00;o2`001?l0
ool;00;o5`02o`D00_l800Go1P03o`@00ol900;o2@02o`H00_l400;o1003o`D01?l400?o1002o`D0
0_l600;o1002o`T00_l700;o2002oa800ol400Co1003o`@00olC00;o1003o`T00_l800Co1003o`@0
0ol500?o4P02o`H00_l500;o1002oa@00ol500?o1002o`@00ol500;o1P02o`@00ol400Co1004o`@0
0_l:00003`02o`L00ol00`3oo`0900?o00<0ool02`04o`X00_lG00Co0`04o`@01ol800Wo1@0:o`<0
3?l200Go0`05o`801?l500Co0`09o`@01Ol200Go0`0:o`801_l200Ko4P0:o`D02OlA00Go0`05o`<0
2_l300Co1@04o`@02_l@00co0`05o`801OlC00[o0P0:o`D01?l400Co100:o`<01?l200Ko2@000100
00?o00001@06o`T01_l<00?o2P000ol0000F00Co0`04o`@01ol:00Go00<0o`00100:o`<03?l200Go
0`05o`801?l500Co1@05o`H01Ol200Go0`0:o`801_l200Ko5005o`030?oo00L01Ol00`3o000@00Go
0`05o`<02_l300Co1@04o`H01Ol00`3oo`0@00co0`05o`801OlE00Go00<0ool00P09o`H01?l400Co
1P05o`030?oo00<00ol300Ko2@0001/00ol<00?o3003ool0_P000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(115\\) LAUIGLMQ IU GS KIMC EY CBQIN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ogh00_l400?onP02o`@00olW00003P02ocL0
0_mm00[on@0:obH0000=00;o>@02ogd01Ol200;onP05o`800_lV00003@02ocT00_mm0003o`000?l0
0@000ol0000/00003@02o`T02Ol600Wo1P05o`d00_lD00go00<0ool01?l300Ko1@04o`L02_l700Ko
100=o`801Ol300Go1@05oaD02_l800Co6006o`H00_l00`3oo`03oa<01Ol600;o0`0:o`<01Ol300Go
1P05oa<03?l500So5`05o`D02_l800Go1`0:o`@01_l300;o2P0000`00_l:00Wo1P09o`@02Ol<00;o
4`0=o`030?oo00Co0`06o`<02?l500[o1@0:o`803Ol200Go0`05o`<02OlC00[o1P08oa@02_l400[o
4@05o`D00ol300[o0`05o`<01Ol400Wo4@0<o`D02?lE00Wo0`0;o`D02Ol500[o1006o`800ol:0000
3002o`h00_l=00;o1`02o`D00_l<00;o5P02o`H00_l300;o1`02o`D00_l400;o2@02o`P01?l500;o
1@02o`H00_l300;o1`02o`<00ol500?o5P02o`X00_l400;o4`04o`D00_l400?o1@03oa800_l500?o
2002o`P00_l700;o1003o`D00olB00;o1P02o`P00_lG00?o1@03o`@00_l500?o0`03o`D00ol800;o
2@02o`@01?l:00003002o`h00_l=00;o3`02o`/00_lF00;o1P02o`<00_l700;o1002o`H00_l800;o
2002o`L00_l500;o1P02o`<00_l700;o0`02o`L00_lF00;o2@02o`H00_lB00;o1`02o`@00_l700;o
4P02o`D00_l900;o2002o`L00_l400;o1`02oa800_l600;o2002oaL00_l700;o1002o`H00_l300;o
1`02o`P00_l900;o1004o`X0000<00;o3P02o`d00_l?00;o2`02oaH00_l600;o0`0;o`@00_l600;o
2002o`L00ol700;o1@02o`H00_l300;o0`02o`800_l200;o2@02oaD00_l900;o1P02oa400ol700;o
1002o`L00_lB00;o1002o`X00_l800;o0`02o`800_l300?o6`02o`800_l200;o2002oaH00ol=00;o
1P02o`800_l900;o1`02o`T00_l300Go2P0000`00_l>00;o3@02o`l00_l;00;o5P02o`H00_l400Wo
1@02o`H00_l800;o1`02o`@01ol400;o1P02o`<00_l200?o0P02o`800_l900;o5@02o`T00_l600;o
4@02o`@01ol;00?o4P03o`800ol:00;o2002o`800ol200;o0`02oa`00_l200;o3002oaH00_l>00;o
1P02o`800_l900;o1`02o`T00_l300;o00<0ool02P0000`00_l>00;o3@02o`l00_l;00;o5P02o``0
0_l500;o1@02o`H00_l800;o1`02o`@01ol400;o2`02o`8000?o0?l00P02o`800_l900;o5@02o`T0
0_l600;o4@02o`@01ol600Oo4`07o`/00_l800;o0P000ol0o`0200;o0`02oa`01_l<00?o5@02o`h0
0_l500?o0P02o`T00_l700;o2@02o`800ol00`3oo`0:00003002o`h00_l=00;o2002o`@00_l<00;o
5P02o`d00_l300;o1P02o`H00_l800;o1`02o`l00_l;00;o00@0ool00_l00`3oo`0200;o2@02oaD0
0_l900;o1P02oa400_l?00Oo5@05o`d00_l800;o00@0ool00_l00`3oo`0300;o7006o`/01?lE00;o
3P09o`<00_l900;o1`02o`T00_l200;o0P02o`X0000=00;o3@02o`d00_l800So2`02oaL00_l=00;o
0`02o`H00_l600;o2002o`L00_l?00;o2`02o`030?oo008000Co0?oo0P02o`T00_lE00;o2@02o`H0
0_lA00;o3P03oaX00_l0103oool<00;o2002o`030?oo008000Co0?oo0`02oa`00_l200;o2P06oa@0
0_l>00So1002o`T00_l700;o2@02o`030?oo00<00_l:00003@02o`d00_l=00;o2007o``00_lG00;o
3P02o`040?ooo`H00_l600;o2002o`L00_l800;o1@02o`/00_l00`3o00020004o`3oo`800ol800;o
5@02o`T00_l600;o4@02o`P00_l400;o1`000ol0000A00;o0P03o`/00_l800;o00<0o`000P001?l0
ool300?o1`02oa800_l200;o0P02o`H00_l200;o5003o`L00_l400;o1003o`<00ol800;o1`02o`T0
1Ol300;o2P0000d00ol<00;o3@02o`P00_lA00;o5`02o`h00_l00`3oo`0700;o1P02o`P00_l800;o
1P03o`D00_l;00Co0`04o`<00_l700;o5P02o`T00_l600;o4P02o`H00ol400;o1P02oa<00_l300?o
2P02o`P01?l300Co1002o`L00_lB00;o1P02o`D00ol300;o5002o`L00_l400;o1@02o`@00_l700;o
2002o`T01?l400;o2P0000h00_l<00;o3@02o`P00_l@00;o6002o`h01Ol700;o1P02o`P00_l800?o
1004o`D00_l;00Co1003o`@00_l500;o5`02o`T00_l600;o4P03o`@01?l400?o1003oa<00_l400?o
2@02o`P01?l400?o1003o`D00olB00;o1P02o`D00_l400;o5003o`D00ol400;o1003o`D00_l500;o
2@02o`T01?l400;o2P0000l00_l700?o00<0ool02@03o`030?oo00P00_l?00;o5P08o`P01ol700Co
1004o`<02_l500[o0P08o`L01?l500Co0`09oa<02_l400Co1004oa802_l500Wo4@05o`<01Ol300[o
0`04o`D01?l400[o400<o`<01Ol200Go4`0:o`802_l600Wo1@0:o`@01?l200Ko2@00010000?o0000
1@06o`T01_l800So2@000ol0000E00So2007o`L01?l400Co0`0:o`L01Ol00`3oo`0200So1`04o`D0
1?l500Go5@0:o`@01?l400Co5005o`030?oo00L01Ol00`3o000@00Go0`05o`<02_l300Co1@04o`H0
1Ol00`3oo`0@00co0`05o`801OlE00Go00<0ool00P09o`T01Ol700[o1003o`<01_l900006`03o``0
0ol800Soo`2m0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(116\\) LDUIKLMV IU GS KIOC CY CFQIN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`H0
2Ol700Co3@02oa@03Ol300So2P04o`L02_l300Go1P02o`030?oo00_o0P05o`<01Ol600;o5`0:o`P0
1?lH00Ko1P02o`030?oo00?o4`05o`H00_l300[o1`05o`X01OlG00Go2008oaL01Ol500Oo2`05o`L0
2_l400Ko0`02o`X0000<00;o2P09o`H02Ol600Oo3002oa<03Ol300[o1P08o`D02_l300Go1@03o`03
0?oo00_o0P05o`<01Ol500Co5P0:o`H02?lD00[o100:oa401Ol500?o0`0:o`D02Ol600Wo4`09o`H0
2?lE00Wo0`07o`T02Ol500[o1006o`800ol:00003002o`h00_l=00;o2002o`@00_l<00;o5P02o`H0
0_l400;o1004o`D00_l400;o2@02o`T00_l500?o1@02o`H00_l300;o1`02o`H01?lJ00;o2P02o`@0
0_lC00Co1@02o`@00ol500?o4P02o`D00ol800;o2003o`D00ol400?o1@03oa400ol500?o2002oaL0
0ol500?o1002o`/00ol500?o2002o`T00_l400Co2P0000`00_l>00;o3@02o`L00_l600;o2`02oaH0
0_l600;o1002o`H00_l400;o1P02o`P00_l900;o1@02o`H00_l600;o0`02o`L00_l600Co6P02o`T0
0_l600;o4P02o`L00_l400;o1`02oa800_l500;o2@02o`P00_l700;o1002o`L00_lA00;o1`02o`P0
0_lG00;o1`02o`@00_l;00;o1`02o`P00_l900;o1004o`X0000<00;o3P02o`d00_l700;o1P02o`/0
0_lF00;o1P02o`@00_l700;o0`02o`H00_l800;o2@02o`@00_l700;o1P02o`<00_l300;o0P02o`D0
0_l200;o6@02o`T00_l600;o4@03o`L00_l400;o1`02oa800_l400;o2P02o`L00_l900;o0P03oaT0
0olA00;o5P03o`d00_l200;o1P02o`T00_l700;o2@02o`<01Ol:00003002o`h00_l=00;o1`02o`H0
0_l;00;o5P02o`H00_l400;o1`02o`<00_l600;o2002o`T00ol200?o1`02o`H00_l300;o0P03o`80
0_l500;o0P02oaT00_l900;o1P02oa400_l400Oo2`03oa800ol200?o2P02o`L00_l900;o0P02oaX0
0_lB00;o5P02o`h00_l200;o1P02o`T00_l700;o2@02o`<00_l00`3oo`0:00003002o`h00_l=00;o
1`02o`H00_l;00;o5P02o``00_l700;o0`02o`H00_l800;o2@07o`P00_l;00;o0P000ol0o`0200;o
1003o`800olH00;o2@02o`H00_lA00;o1007o`H01olC00Oo2`02o`L00_l900;o0P02oaX00_lB00?o
5@02o`h01_l600;o2@02o`L00_l900;o0P03o`030?oo00X0000<00;o3P02o`d00_l700?o1002o``0
0_lF00;o3002o`L00_l300;o1P02o`P00_l900Go2P02o`/00_l0103oo`02o`030?oo00@00_l400;o
6002o`T00_l600;o4@02o`l01olE00Go3@02o`L00_l900;o0P02oaX00_lA00Co5@02o`h01_l600;o
2@02o`L00_l900;o0P02o`800_l:00003@02o`d00_l=00;o1`09o`/00_lG00;o3002o`L00_l300;o
1P02o`P00_l900;o00@0oooo2@02o`/00_l00`3oo`020004o`3oo`@00_l400;o6002o`T00_l600;o
4@02o`h00olJ00;o00@0oooo3002o`L00_l900;o0P02oaX00_l@00Ko5002o`h00_l200;o1P02o`T0
0_l700;o2@02o`030?oo00<00_l:00003@02o`d00_l=00;o1`02o`030?oo00;o3@02oaL00_l<00;o
1`02o`<00_l600;o2002o`T00_l200?o2002o`/00_l00`3o00020004o`3oo`<00_l600;o5`02o`T0
0_l600;o4@02o`P00_l400;o1`000ol0000A00;o0P03o`/00_l700;o2@02o`800ol700;o4003o`L0
0_l600;o0P02oa@00ol700;o1002o`800_l200;o0P03o`P00_l700;o2@05o`<00_l:00003@03o``0
0_l=00;o2002oa400_lG00;o3002o`H00_l400;o1P02o`P00_l900;o0`03o`L00_l;00Co0`04o`<0
0_l600;o5`02o`T00_l600;o4P02o`H00ol400;o1P02oa<00_l300?o2P02o`P00_l700;o1002o`L0
0_lA00;o1`02o`D00ol300;o5002o`L00_l400;o1P02o`<00_l700;o2002o`T01?l400;o2P0000h0
0_l<00;o3@02o`P00ol?00;o6002o``00_l400Co1002o`H00_l800;o2@02o`@00ol600;o2`04o`@0
0ol200?o1P03oaH00_l900;o1P02oa800ol400Co1003o`@00olC00;o1003o`T00_l800?o1@03o`@0
0ol500?o4@03o`D00ol500;o1002oa@00ol500?o1002o`H00_l400;o1@02o`T00_l900Co1002o`X0
000?00;o1`03o`030?oo00T00ol00`3oo`0900?o3@02oaH02?l800[o1004o`@01?l300[o0`05o`<0
1Ol00`3oo`06o`L01?l500[o0P06oa402_l400Co1004oa802_l500Wo4@05o`<01Ol300[o1@09o`H0
2_lB00[o0`05o`801OlC00[o0P0<o`@02Ol500[o1004o`801_l9000040000ol0000500Ko2@06o`X0
1ol80003o`0001D02?l800So1P04o`@01?l300[o0`05o`<01Ol00`3oo`06o`L01?l500[o0P06oa40
2_l400Co1004oa@01Ol00`3oo`0700Go00<0o`004005o`<01Ol300[o1`05o`X01Ol00`3oo`0D00Go
00<0ool00`05o`801OlE00Go00<0ool00P0<o`H01Ol700[o1003o`<01_l900006`03o``00ol<00Go
o`2l0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000
o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000o`3j0000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(117\\) LDUIKLMS HU FR KHOC AX CAQIN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`H0
2Ol700;o3`02oa@03Ol300So2P04o`L02_l300Go1P02o`030?oo00_o0P05o`<01Ol200;o00<0ool0
0olE00Co0`04o`L01?lD00Oo2005o`H00ol>00Go1P02o`<01?l300Co1P05o`X01OlB00Ko0`06o`03
0?oo00?o0P05oaD01Ol400Ko0`06o`@01Ol700[o1006o`<00_l:00003002o`X02Ol600Wo1`02oa00
0_lC00go0`0:o`H02?l500[o0`05o`D00ol00`3oo`0;o`801Ol300Go0P0:oa<01?l300Co1@08oa80
1ol800Go1@04o`h01Ol500?o0`04o`<01?l400Wo1P09oa001_l300Ko00<0ool00ol200Go4`09o`80
1_l300Ko0P09o`D02_l400Ko0P03o`X0000<00;o3P02o`d00_l;00;o3`02oaH00_l600;o1002o`@0
1?l500;o1002o`T00_l900;o1@03o`D00_l600;o0`02o`L00_l300?o1@03oa<00_l500;o1P02o`@0
0_lD00;o3@02o`D00olB00;o1@03o`D00_l500;o1003o`D00ol400?o1@03oa400_l700;o1003o`@0
0olC00?o1@03o`<00_l700;o0`03o`D00ol800;o2@02o`@01?l:00003002o`h00_l=00;o2`02o`l0
0_lF00;o1P02o`@00_l600;o1002o`H00_l800;o2@02o`D00_l600;o1P02o`<00_l700;o0`02o`L0
0_lC00;o1@02o`D00_l600;o4`02o`d00_l500;o4`02o`D00_l600;o1@02o`@00_l700;o1002o`L0
0_lA00;o1`02o`D00ol200?o5002o`L00_l300;o1`02o`<00_l700;o2002o`T00_l400Co2P0000`0
0_l>00;o3@02o`/00_l?00;o5P02o`H00_l400;o1`02o`<00_l600;o2002o`T00_l400;o1`02o`H0
0_l300;o0`02o`800_l300;o1`02oa<00_l500;o1@02o`H00_lC00;o0P02o`T00_l400;o5002o`@0
0_l700;o1@02o`<00_l900;o0P03oaX02ol600;o0P02oa@00ol<00_o0P02o`T00_l700;o2@02o`<0
1Ol:00003002o`h00_l=00;o30000ol0000=00;o5P02o`H00_l400;o1`02o`<00_l600;o2002o`T0
0ol200?o1`02o`H00_l300;o0P03o`800_l;00?o4`02o`D00_l500;o1P02oa<00_l200;o2@02o`<0
0olD00?o0P03o`L00_l500;o0`02o`T00_l200;o7009o`P01?lE00;o3P09o`<00_l900;o1`02o`T0
0_l300;o00<0ool02P0000`00_l>00;o3@02o``00_l>00;o5P02o``00_l700;o0`02o`H00_l800;o
2@07o`P00_l;00;o0P000ol0o`0200;o1P07oa@00_l500;o1@02o`H00_lC00Ko2@07oaD01ol800;o
1@02o`<00_l900;o0P02oa`00_l500;o2004oaD00_l>00;o1@02o`<00_l900;o1`02o`T00_l200?o
00<0ool02P0000`00_l>00;o3@02o``00_l>00;o5P02o``00_l700;o0`02o`H00_l800;o2@05o`X0
0_l;00;o00@0ool00_l00`3oo`0400Oo5P09o`D00_l600;o4`06o`T02OlC00Go2P09o`<00_l900;o
0P02oad00_l300;o2@03oaH00_l?00;o0`02o`@00_l900;o1`02o`T00_l200;o0P02o`X0000=00;o
3@02o`d00_l=0003o`0000/00_lG00;o3002o`L00_l300;o1P02o`P00_l900;o00@0oooo2@02o`/0
0_l00`3oo`020004o`3oo`<00olK00Wo1@02o`H00_lC00;o0P02o`T00_l500?o4P02o`040?ooo`T0
2Ol300;o2@02o`800_lM00;o0`02o`T01?lE00;o3`02o`<00_l400;o2@02o`L00_l900;o00<0ool0
0`02o`X0000=00;o3@02o`d00_l=00;o3002oaL00_l<00;o1`02o`<00_l600;o2002o`T00_l200?o
2002o`/00_l00`3o00020004o`3oo`<00_l70003o`0001800_l500;o1@02o`H00_lC00;o0P02o`80
0_l500;o1P02oa800_l200?o2002o`D00_l300;o2@02o`800ol700;o5002o`040?ooo`P01_lD00?o
1`02o`H00_l0103oool400?o2002o`L00_l900Go0`02o`X0000=00?o3002o`d00_l=00;o3002oaL0
0_l<00;o1P02o`@00_l600;o2002o`T00_l300?o1`02o`/01?l300Co0`02o`H00_lD00;o1@02o`D0
0_l600;o4`02o`H00_l500;o1P02oa800_l300?o1`02o`D00_l400;o1`02o`@00_l700;o5002o`03
0?oo00P00ol200?o5002o`L00_l600;o00<0ool01P02o`L00_l800;o2@04o`@00_l:00003P02o``0
0_l=00;o3P000ol0000900;o6002o``00_l400Co1002o`H00_l800;o2@02o`@00ol600;o2`04o`@0
0ol300?o1003oa@00_l500;o1@02o`H00_lC00;o1P02o`D00_l500?o4P02o`@00ol600;o1@02o`@0
0ol500?o1003o`D00olD00Go2002o`@00_lD00?o1@03o`H01Ol700;o1@02o`T00_l900Co1002o`X0
000?00;o1`03o`030?oo00T00ol00`3oo`0700;o1@02o`T00_lF00So200:o`@01?l400Co0`0:o`<0
1Ol300Go00<0ool01_l700Co1@04o`<02OlC00Co0`04o`<01?l400Co400<o`<02olA00Go0`05o`<0
1?l300Co1009o`H02_lA00Oo1`05o`801OlC00[o0`07o`P02Ol500[o1004o`801_l9000040000ol0
000500Ko2@06o`L02Ol90003o`0001D02?l800So1P04o`@01?l300[o0`05o`<01Ol00`3oo`06o`L0
1?l500Co1@05o`030?l001801?l300Co0`04o`@01?l@00co0`09oa<01Ol300Go0`04o`<01?l600Go
2P05o`030?oo01401ol700Go0P05oaD01Ol00`3oo`0300Oo2P05o`L02_l400?o0`06o`T0000K00?o
3003o`L02Ooo0;d0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(118\\) LDUILLMSXHU FR GHOC AXZCAQEN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.183333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0PP02o`@00olW00003P02ocL00_oo0840
2_lV00003@02ocT00_oo08401Ol200;o9P0000d00_li00;oo`210003o`0002`0000=00;o2@09o`H0
2Ol700Co3@02oa@03Ol300So2P04o`L02_l300go00<0ool02ol200Go0`05o`800_l00`3oo`03o`H0
1Ol200Go0`04o`<01?l700Co5007o`P01Ol600?o4P06o`H01?l300Co1P05o`X01OlB00Ko0`06o`03
0?oo00?o0P05o`<02_l800Go1006o`<01_l400Go1P0<o`<01_l300;o2P0000`00_l:00Wo1P09o`D0
2?l<00;o4`0=o`<02_l600So1@0:o`<03Ol00`3oo`0;o`801Ol300Go0P0:o`@01Ol200Go0`04o`<0
1?l500So4P07o`P01Ol500Co400:o`@01?l300Co1009o`H02Ol@00Ko0`06o`030?oo00?o0P05o`<0
2_l600Wo0P06o`<01_l200Wo100<o`<01_l200?o2P0000`00_l>00;o3@02o`L00ol400?o2`02oaH0
0_l600;o1002o`@01?l500;o1002o`T00_l:00;o1P02o`@00_l600;o0`02o`L00_l300?o1@03o`@0
0ol400?o1@02o`D00_l600;o1002oa@00_l=00;o1@03oa401?l500;o1@02o`D00_l400?o1@03o`@0
0ol500?o4@02o`L00_l400?o1003o`D00_l500;o1@03o`D00ol300;o1`02o`<00ol500?o1@02o`H0
0_l400;o1004o`X0000<00;o3P02o`d00_l700;o1P02o`/00_lF00;o1P02o`@00_l600;o1002o`H0
0_l800;o2P02o`H00_l400;o1P02o`<00_l700;o0`02o`L00_l500?o0P03o`H00_l500;o1@02o`H0
0_lC00;o3@02o`D00_lB00;o1`02o`D00_l500;o1002o`L00_l400;o1`02oa400_l700;o1@03o`80
0ol600?o1002o`D00_l700;o0`02o`L00_l300;o1`02o`D00_l600;o1002o`@01?l:00003002o`h0
0_l=00;o1`02o`H00_l;00;o5P02o`H00_l400;o1`02o`<00_l600;o2002o`X00_l600;o1002o`H0
0_l300;o0`02o`800_l300;o1`02o`H00_l200;o1`02o`D00_l500;o1P02oa<00_l200;o2@02o`@0
0_lB00?o1`02o`D00_l500;o0`02o`T00_l200?o6P0;o`H00_l200;o2003o`<00_l400?o300;o`80
0_l900;o1002o`800_l200;o1002o`<01Ol:00003002o`h00_l=00;o1`02o`H00_l;00;o5P02o`H0
0_l400;o1`02o`<00_l600;o2002o`X00_l600;o1002o`H00_l300;o0P03o`800_l;00?o1`04o`P0
0_l500;o1@02o`H00_lC00;o0P02o`T00_l300?o4P02o`@01ol400;o1@02o`<00_l900;o0P02oa`0
2Ol800Co2P02o`<00_l400;o3P09o`<00_l900;o1002o`800_l800;o0`02o`030?oo00X0000<00;o
3P02o`d00_l800;o1002o``00_lF00;o3002o`L00_l300;o1P02o`P00_l:00;o3002o`/00_l20003
o`3o00800_l600Oo2004o`P00_l500;o1@02o`H00_lC00Ko2@07oa<00_l400Oo1002o`D00_l300;o
2@02o`800_lL00;o1@02o`P01?l:00?o2002o`h00_l500;o0`02o`T00_l400Ko2002o`800ol00`3o
o`0:00003002o`h00_l=00;o2@07o``00_lF00;o3002o`L00_l300;o1P02o`P00_l:00;o3002o`/0
0_l0103oo`02o`030?oo00@01ol:00?o2@09o`D00_l600;o4`06o`T02OlA00;o3`09o`<00_l900;o
0P02oad00_l300;o2@03o``00ol700;o3`02o`<00_l400;o2@02o`@01_l800;o0P02o`800_l:0000
3@02o`d00_l=00;o2@06o``00_lG00;o3002o`L00_l300;o1P02o`P00_l:00;o3002o`/00_l00`3o
o`020004o`3oo`<00ol?00Co2009o`D00_l600;o4`02o`800_l900;o1@03oa000_l?00Wo0`02o`T0
0_l200;o7@02o`<00_l900Co1`02o`<00_l700;o3`02o`<00_l400;o2@02o`@00_l200;o2002o`03
0?oo00<00_l:00003@02o`d00_l=00;o2002o`@00_l;00;o5`02o``00_l700;o0`02o`H00_l800;o
2P02o``00_l;00;o00<0o`000P001?l0ool300;o1`000ol0000500Ko1`02o`D00_l500;o1P02oa<0
0_l200;o0P02o`D00_l600;o4002o`P00_l500;o1@02o`<00_l900;o0P03o`L00_lD00;o00@0oooo
2006o`H00_l300?o1P03o`L00_l600;o00@0oooo1003o`P00_l400;o0P02o`800_l400Go0`02o`X0
000=00?o3002o`d00_l700;o1P02o`X00_lG00;o3002o`H00_l400;o1P02o`P00_l:00;o3002o`/0
1?l300Co0`02o`H00_l600?o0P03o`H00_l500;o1@02o`H00_lC00;o1P02o`D00_l600;o4@02o`H0
0ol500;o1@02o`@00_l700;o1002o`L00_lD00;o00<0ool02003o`800ol500;o1003o`H00_l700;o
1P02o`030?oo00H00_l700;o1@02o`H00_l400Co1002o`X0000>00;o3002o`d00_l700;o1P02o`T0
0_lH00;o3002o`@01?l400;o1P02o`P00_l:00;o3002o`/01?l400?o0`03o`@00ol600;o1002o`H0
0_l500;o1@02o`H00_lC00;o1P02o`D00_l500?o4@03o`@01?l500;o1@02o`@00ol500?o1003o`D0
0olD00Go2002o`@00_l500;o1@02o`H00ol500?o1P05o`L00_l500;o1P02o`H00_l400Co1002o`X0
000?00;o1`03o`030?oo00T00ol00`3oo`0700?o1003o`P00_lF00So200:o`@01?l400Co0`0:o`<0
2?l600So1`04o`D01?l300Wo1005o`801Ol300Co0`04o`<01?l400Co400<o`<02olC00[o1004o`<0
1?l400Wo1P0:oa401ol700Go0P05o`<02_l600[o0`07o`P02Ol400co0`04o`801_l9000040000ol0
000500Ko2@06o`P02?l90003o`0001D02?l800So1P04o`@01?l300[o0`08o`H02?l700Co1@04o`D0
1Ol00`3o000300Go0P05o`<01?l300Co0`04o`@01?l@00co0`09oaL01Ol00`3oo`0400Co0`04o`H0
1Ol:00Go00<0ool04@07o`L01Ol200Go0`0:o`P01Ol00`3oo`0300Oo2P05o`H03?l300?o0`06o`T0
000K00?o3003o`T01_oo0;h0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0
003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X0003o0?X00000\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
%% Graphics
/Courier findfont 24  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.05 0.0952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
[(\\(119\\) LEUJKLMSXHU GT LMOA AX GAPEN)] .5 .05 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{505, 50},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->4.98333,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007i0000<PP10`4000010?ooooooc?ooVOooI_oo
<ooo0?o<ooo<c?o<VOo<I_o<<oo<0?nIoonIc?nIVOnII_nI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oolcc?lcVOlcI_lc<olc0?l0ool0c?l0VOl0I_l0<ol00<coolcoc<coVLcoI/co<lco0<c<olc<c<c<
VLc<I/c<<lc<0<bIolbIc<bIVLbII/bI<lbI0<aVolaVc<aVVLaVI/aV<laV0<`col`cc<`cVL`cI/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`009WooiWoc9WoVIWoIYWo<iWo09W<oiW<c9W<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIYVI<iVI09UVoiUVc9UVVIUVIYUV<iUV09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c9T0
VIT0IYT0<iT006KoofKoc6KoVFKoIVKo<fKo06K<ofK<c6K<VFK<IVK<<fK<06JIofJIc6JIVFJIIVJI
<fJI06IVofIVc6IVVFIVIVIV<fIV06HcofHcc6HcVFHcIVHc<fHc06H0ofH0c6H0VFH0IVH0<fH003?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c3?<VC?<IS?<<c?<03>Ioc>Ic3>IVC>IIS>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V03<coc<cc3<cVC<cIS<c<c<c03<0oc<0c3<0VC<0IS<0<c<0003oo`3oc03oV@3oIP3o
<`3o003<o`3<c03<V@3<IP3<<`3<002Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc01VV@1VIP1V<`1V000c
o`0cc00cV@0cIP0c<`0c0000o`00c000V@00IP00<nh00=d00;/00:X008P007L005D004@002800140
003^003M002k002Z0028001g001E0014000R000A0000kP00g@00^`00ZP00R000M`00E@00A0008P00
4Nk^k]gMgK^k^jZZZXR8R7MgMeEEEDA4A28R8Q4A4@000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP00010000?o0000<`000ol0003o0;40000?00;o=@02ool0/P0000h00_lg00;oo`2a00003@02ocT0
0_oo0;00000=00;o>@02ool0/00000d00_l900Wo1P09o`@01Ol?00;o500=o`803?l700Co2006o`H0
1Ol600;o00<0ool02ol200Go0`05o`800_l00`3oo`03o`H01Ol200Go0`04o`<01?l700Co6006o`L0
2?lB00go0P05o`<01Ol500Go1@06o`<01_l=00Ko0`06o`030?oo00?o0P05oaD01_l300Ko0`0>o`L0
3?l300Ko0`02o`X0000<00;o2P09o`H02Ol400Oo3P02oa<03Ol200co1@08o`@02Ol500Go1@03o`03
0?oo00_o0P05o`<01Ol200[o1005o`801Ol300Co0`04o`D02?lD00[o1@08oa803Ol200Go0`05o`<0
2Ol300Ko0`06o`d01_l300Ko00<0ool00ol200Go4`0:o`030?oo00Co0`0>o`L03?l300Ko0P03o`X0
000<00;o3P02o`d00_l<00?o3@02oaH00_l600;o1002o`H00_l500;o1002o`@00ol400?o1P02o`D0
0ol500;o1P02o`<00_l700;o0`03o`D00ol400?o1003o`D00_l500;o1P02o`@00_lC00Co1@02o`P0
0_lH00;o1P02o`<00_l700;o0`03o`D00ol400;o1`02oa400_l700;o1003o`@00olC00Co1@02o`<0
0_l700;o1002o`d00_l600;o1002o`@01?l:00003002o`h00_l=00;o3@03o``00_lF00;o1P02o`@0
0_l600;o1002o`H00_l300;o1P02o`H00_l500;o1P02o`H00_l300;o1`02o`<00_l700;o1@03o`80
0ol600;o1@02o`D00_l600;o4P02o`L00_l800;o6002o`H00_l300;o1`02o`<00_l700;o1002o`L0
0_lA00;o1`02o`D00ol200?o5002o`L00_l300;o1`02o`@00_l=00;o1P02o`@00_l400Co2P0000`0
0_l>00;o3@02o`h00_l<00;o5P02o`H00_l400;o0P02o`800_l400;o1P02o`<00_l600;o1P02o`@0
0_l700;o1P02o`<00_l300;o0P02o`<00_l700;o1P02o`800_l700;o1@02o`D00_l600;o4@03o`L0
0_l800;o6002o`H00_l300;o0`02o`800_l200;o2@02o`<02olA00_o1P02o`800_lD00?o1`02o`<0
2ol400;o3@02o`800_l200;o1002o`<01Ol:00003002o`h00_l=00;o2P04o`030?oo00/00_lF00;o
1P02o`@00_l200;o2002o`H00_l300;o1P02o`H00ol200?o1`02o`H00_l300;o0P03o`800_l;00?o
1`04o`P00_l500;o1@02o`H00_lA00;o1007o`L00_lH00;o1P02o`<00_l200?o0P02o`800_l900;o
1009oa<02Ol800Co5@02o`@01ol300Wo1@07o`P00_l200;o2002o`<00_l00`3oo`0:00003002o`h0
0_l=00;o2009o`/00_lF00;o3006o`P00_l600;o2`02o`H01ol800;o2`02o`8000?o0?l00P02o`H0
1ol800Co2002o`D00_l500;o1P02oa400_l400Oo1`02oaP00_l;00;o0P000ol0o`0200;o0P02o`T0
0_l400;o1@02oa<00_l500;o2004oaD00_l400Oo0`02o`D00_l500Wo1P06o`P00_l200?o00<0ool0
2P0000`00_l>00;o3@02o`P00_l400?o2`02oaH00_l<00Ko2002o`H00_l;00;o1P05o`X00_l;00;o
00@0ool00_l00`3oo`0400Oo2P03o`T02Ol500;o1P02oa400_lB00;o6002o`/00_l0103oo`02o`03
0?oo00800_l900;o1@02o`<00_lE00;o0`02o`T00olF00;o3`02o`<00_l600;o1@03o`D01_l800;o
0P02o`800_l:00003@02o`d00_l=00;o1`02o`H00_l:00;o5`02o``00_l200;o2002o`H00_l;00;o
1P02o`040?ooo`T00_l;00;o00<0ool00P001?l0ool300?o3`04o`P02Ol500;o1P02oa400_l=00;o
0`02o`<00_lC00;o2`02o`030?oo008000Co0?oo0P02o`T00_l500;o0`02oaD00_l300;o2@04oaD0
0_l?00;o0`02o`H00_l600;o1@02o`800_l800;o00<0ool00`02o`X0000=00;o3@02o`d00_l700;o
1P02o`X00_lG00;o3002o`800_l200;o1002o`H00_l;00;o1P02o`800ol800;o2`02o`030?l00080
00Co0?oo0`02o`L000?o00001@06o`L00_l500;o1@02o`H00_lA00;o2002o`<00_l300;o0`02oa<0
0_l;00;o00<0o`000P001?l0ool200;o2@02o`H00_l0103ooolF00;o00@0oooo2006oa@00_l800;o
1P02o`040?ooo`H00_l600;o1@02o`800_l200;o1005o`<00_l:00003@03o``00_l=00;o1`02o`H0
0_l:00;o5`02o``00_l600;o1002o`H00_l;00;o1P02o`<00ol700;o2`04o`<01?l300;o1P02o`H0
0ol200?o1P02o`D00_l500;o1P02oa800_l600?o0`02o`<00_l300;o4`02o`/01?l300Co0`02o`L0
0_l700;o00<0ool05`02o`030?oo00P00ol200?o5002o`H00ol600;o00<0ool01`02o`H00_l500;o
1P02o`@01?l400;o2P0000h00_l<00;o3@02o`L00_l60003o`0000P00_lH00;o3002o`H00_l400;o
1P02o`/00_l600;o1003o`H00_l;00Co1003o`<00ol400?o1P02o`@00_l600;o1@02o`D00_l600;o
4P03o`@01?l300;o0`02o`<00_lC00;o2`04o`@00ol300?o1@03o`L01OlG00Go2002o`@00_lD00?o
1004o`H01Ol700;o1@03o`D00_l600;o1004o`@00_l:00003`02o`L00ol00`3oo`0900?o00<0ool0
2002o`@00_l900;o5P08o`L03?l300Co1004o`D02_l00`3oo`03o`<01Ol00`3oo`06o`L01?l500Co
0`09o`@01Ol200Go0`04o`<01?l300Co1004oa802_l300co4008o`L01?l500Co0`09o`D01olE00Oo
1`05o`801OlC00[o0`07o`H02ol400co0`04o`801_l9000040000ol0000500Ko2@06o`P01ol:0003
o`0001D02?l700co0`04o`@01?l500[o00<0ool00ol300Go00<0ool01_l700Co1@04o`D01Ol00`3o
000300Go0P05o`<01?l300Co0`04o`@01?lD00Go00<0ool00`0<oa002?l700Co1@04o`D01Ol700Oo
5@07o`L01Ol200Go5@05o`030?oo00<01ol600Wo1P0<o`<00ol300Ko2@0001/00ol<00?o2P04ool0
_`000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0
nP000?l0nP000?l0nP000?l0nP000?l0nP000?l0nP000001\
\>"],
  ImageRangeCache->{{{0, 504}, {49, 0}} -> {-0.540005, -0.525005, 0.00214288, 
  0.0214288}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "See also the QuickTime movie ",
  StyleBox["Weasel-50-5-0.5.movie",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  " in the directory \[RightGuillemet]Movies\[LeftGuillemet]. The first \
parameter indicates the population size (50), the second and third parameters \
denote mutation radius (1) and mutation rate (0.1), respectively."
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation \[Ellipsis]",
  FontColor->RGBColor[1, 0, 0]]], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Packages", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Statistics`DescriptiveStatistics`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Random generation of character sequences", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(createSentence[l_:  28] := Table[Random[Integer, {65, 93}], {l}]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["From strings to numbers", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(encodeSentence[sent_String] := 
      ToCharacterCode[sent] /. {32 \[Rule] 91, 44 \[Rule] 92, 46 \[Rule] 93}
          \)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToCharacterCode["\< ,.\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({32, 44, 46}\)], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["From numbers to strings", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(interpretSentence[sent_List] := 
      FromCharacterCode[sent /. {91 \[Rule] 32, 92 \[Rule] 44, 93 \[Rule] 46}]
        \)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Hamming disctance", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(distanceSquared[s1_, s2_] := Plus@@\(\((#1\^2&)\)/@\((s1 - s2)\)\)\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation operator", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(mutateSentence[sent_, mutDistance_:  1, mutRate_:  0.1] := 
      sent - Table[
            If[Random[Real, {0, 1}] \[LessEqual] mutRate, 
              Random[Integer, {\(-mutDistance\), mutDistance}], 0], {
              Length[sent]}] /. {x_ /; x < 65 \[RuleDelayed] 65, 
          x_ /; x > 93 \[RuleDelayed] 93}\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial population", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initialPop[n_, l_:  28] := Table[createSentence[l], {n}]; \)\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["From generation to generation", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(nextGeneration[pop_, comparedSentence_, mutDistance_:  1, mutRate_:  .1]
         := \n\tModule[{}, \n\t\t
        fitnesses = \((distanceSquared[comparedSentence, #1]&)\)/@pop; \n\t\t
        \n\t\tminIndex = 
          First[First[Position[fitnesses, m = Min[fitnesses]]]]; \n\t\t\n\t\t
        Print[stepCounter, "\<: Min.: \>", m]; \n\t\t\(stepCounter++\); \n\t\t
        Print[interpretSentence[
            pop\[LeftDoubleBracket]minIndex\[RightDoubleBracket]]]; \n\t\t\n
        \t\tAppendTo[bestFitnesses, 
          fitnesses\[LeftDoubleBracket]minIndex\[RightDoubleBracket]]; 
        AppendTo[bestSentences, 
          pop\[LeftDoubleBracket]minIndex\[RightDoubleBracket]]; \n\t\t\n\t\t
        If[m == 0, pop, 
          Join[Table[
              mutateSentence[
                pop\[LeftDoubleBracket]minIndex\[RightDoubleBracket], 
                mutDistance, mutRate], {Length[pop] - 1}], {
              pop\[LeftDoubleBracket]minIndex\[RightDoubleBracket]}]]]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution loop", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(evolveSentences[comparedSentence_, popSize_:  50, 
        mutationDistance_:  1, mutationRate_:  .1] := \n\t
      Module[{}, \n\t\t\n\t\tstepCounter = 0; \n\t\t
        bestFitnesses = \(bestSentences = {}\); \n\t\t\n\t\t
        sentenceEvolution = 
          FixedPoint[
            nextGeneration[#1, comparedSentence, mutationDistance, 
                mutationRate]&, 
            initialPop[popSize, Length[comparedSentence]]]; \n\t]\)], "Input",\

  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["References \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Download the ",
  ButtonBox["latest version",
    ButtonData:>{
      URL[ 
      "http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html#\
CumulativeSelection"], None},
    ButtonStyle->"Hyperlink"],
  " of this notebook from"
}], "Text"],

Cell["\<\
http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html\
\
\>", "Text",
  TextAlignment->Center,
  FontSize->13]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"RulerBar",
CellGrouping->Automatic,
WindowSize->{664, 678},
WindowMargins->{{238, Automatic}, {81, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Cumulative Selection"}]]}, {Cell[ 
        TextData[ {"Cumulative Selection"}]], Inherited, Inherited}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> "../../StyleSheets/CourseStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "single step selection"->{
    Cell[6905, 206, 214, 5, 50, "Text",
      CellTags->"single step selection"]},
  "cumulative selection: introducation"->{
    Cell[9018, 284, 467, 8, 110, "Text",
      CellTags->"cumulative selection: introducation"]},
  "mutation"->{
    Cell[11764, 384, 509, 8, 110, "Text",
      CellTags->"mutation"]},
  "cumulative selection: experiments"->{
    Cell[25467, 772, 231, 5, 50, "Text",
      CellTags->"cumulative selection: experiments"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"single step selection", 2787440, 54754},
  {"cumulative selection: introducation", 2787566, 54757},
  {"mutation", 2787680, 54760},
  {"cumulative selection: experiments", 2787793, 54763}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 2, 113, "Title"],
Cell[1819, 55, 108, 2, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1952, 61, 173, 5, 66, "Subtitle"],

Cell[CellGroupData[{
Cell[2150, 70, 31, 0, 61, "Section"],
Cell[2184, 72, 219, 4, 50, "Text"],
Cell[2406, 78, 277, 4, 50, "Text"],
Cell[2686, 84, 119, 3, 31, "Text"],
Cell[2808, 89, 240, 5, 50, "Text"],
Cell[3051, 96, 119, 3, 31, "Text"],
Cell[3173, 101, 68, 0, 32, "Text"],
Cell[3244, 103, 741, 16, 86, "Text"],
Cell[3988, 121, 198, 6, 32, "Text"],
Cell[4189, 129, 173, 3, 32, "Text"],
Cell[4365, 134, 213, 7, 32, "Text"],
Cell[4581, 143, 154, 3, 32, "Text"],
Cell[4738, 148, 144, 3, 32, "Text"],
Cell[4885, 153, 145, 3, 32, "Text"],
Cell[5033, 158, 576, 11, 86, "Text"],
Cell[5612, 171, 286, 5, 68, "Text"],
Cell[5901, 178, 876, 19, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6814, 202, 88, 2, 45, "Section"],
Cell[6905, 206, 214, 5, 50, "Text",
  CellTags->"single step selection"],
Cell[7122, 213, 634, 14, 212, "Text"],

Cell[CellGroupData[{
Cell[7781, 231, 43, 1, 29, "Input"],
Cell[7827, 234, 78, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7942, 240, 37, 1, 27, "Input"],
Cell[7982, 243, 61, 1, 29, "Output"]
}, Open  ]],
Cell[8058, 247, 406, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[8489, 262, 89, 2, 41, "Input"],
Cell[8581, 266, 61, 1, 29, "Output"]
}, Open  ]],
Cell[8657, 270, 220, 5, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8914, 280, 101, 2, 45, "Section"],
Cell[9018, 284, 467, 8, 110, "Text",
  CellTags->"cumulative selection: introducation"],

Cell[CellGroupData[{
Cell[9510, 296, 90, 2, 40, "Subsection"],
Cell[9603, 300, 191, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[9819, 307, 84, 1, 45, "Input"],
Cell[9906, 310, 157, 2, 44, "Output"]
}, Open  ]],
Cell[10078, 315, 298, 5, 76, "Text"],
Cell[10379, 322, 170, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[10574, 331, 128, 3, 60, "Input"],
Cell[10705, 336, 161, 2, 44, "Output"]
}, Open  ]],
Cell[10881, 341, 172, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[11078, 349, 78, 2, 45, "Input"],
Cell[11159, 353, 36, 1, 29, "Output"]
}, Open  ]],
Cell[11210, 357, 100, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[11335, 364, 89, 2, 45, "Input"],
Cell[11427, 368, 66, 1, 29, "Output"]
}, Open  ]],
Cell[11508, 372, 123, 3, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11668, 380, 93, 2, 26, "Subsection"],
Cell[11764, 384, 509, 8, 110, "Text",
  CellTags->"mutation"],
Cell[12276, 394, 111, 3, 42, "Text"],
Cell[12390, 399, 155, 4, 42, "Text"],
Cell[12548, 405, 556, 8, 127, "Text"],
Cell[13107, 415, 71, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[13203, 419, 128, 3, 60, "Input"],
Cell[13334, 424, 161, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13532, 431, 89, 2, 45, "Input"],
Cell[13624, 435, 66, 1, 29, "Output"]
}, Open  ]],
Cell[13705, 439, 129, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[13859, 446, 58, 0, 32, "Subsubsection"],
Cell[13920, 448, 272, 7, 59, "Text"],

Cell[CellGroupData[{
Cell[14217, 459, 195, 4, 120, "Input"],
Cell[14415, 465, 1100, 23, 171, "Output"]
}, Open  ]],
Cell[15530, 491, 93, 3, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15660, 499, 58, 0, 32, "Subsubsection"],
Cell[15721, 501, 118, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[15864, 508, 195, 4, 104, "Input"],
Cell[16062, 514, 1100, 23, 171, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17211, 543, 58, 0, 24, "Subsubsection"],
Cell[17272, 545, 168, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[17465, 553, 195, 4, 104, "Input"],
Cell[17663, 559, 1100, 23, 171, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[18812, 588, 58, 0, 24, "Subsubsection"],
Cell[18873, 590, 275, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[19173, 598, 193, 4, 104, "Input"],
Cell[19369, 604, 1100, 23, 171, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20518, 633, 58, 0, 24, "Subsubsection"],
Cell[20579, 635, 197, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[20801, 642, 195, 4, 104, "Input"],
Cell[20999, 648, 1100, 23, 171, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22148, 677, 58, 0, 24, "Subsubsection"],
Cell[22209, 679, 97, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[22331, 686, 195, 4, 104, "Input"],
Cell[22529, 692, 1100, 23, 183, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23678, 721, 59, 0, 24, "Subsubsection"],
Cell[23740, 723, 265, 6, 59, "Text"],

Cell[CellGroupData[{
Cell[24030, 733, 196, 4, 93, "Input"],
Cell[24229, 739, 1100, 23, 152, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25402, 770, 62, 0, 45, "Section"],
Cell[25467, 772, 231, 5, 50, "Text",
  CellTags->"cumulative selection: experiments"],

Cell[CellGroupData[{
Cell[25723, 781, 63, 0, 45, "Subsection"],
Cell[25789, 783, 132, 3, 46, "Text"],
Cell[25924, 788, 57, 1, 27, "Text"],
Cell[25984, 791, 712, 20, 65, "Text"],
Cell[26699, 813, 76, 2, 27, "Text",
  PageBreakAbove->True],
Cell[26778, 817, 475, 18, 46, "Text"],
Cell[27256, 837, 223, 6, 29, "Text"],
Cell[27482, 845, 292, 7, 46, "Text"],
Cell[27777, 854, 64, 1, 27, "Text"],
Cell[27844, 857, 506, 16, 65, "Text"],
Cell[28353, 875, 59, 1, 27, "Text"],
Cell[28415, 878, 260, 6, 46, "Text"],
Cell[28678, 886, 381, 8, 103, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[29096, 899, 100, 2, 29, "Subsection"],
Cell[29199, 903, 283, 5, 84, "Text"],

Cell[CellGroupData[{
Cell[29507, 912, 56, 0, 32, "Subsubsection"],
Cell[29566, 914, 48, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[29639, 918, 102, 2, 47, "Input"],
Cell[29744, 922, 62, 1, 31, "Output"]
}, Open  ]],
Cell[29821, 926, 396, 12, 84, "Text"],

Cell[CellGroupData[{
Cell[30242, 942, 121, 3, 47, "Input"],
Cell[30366, 947, 164, 3, 22, "Print"],
Cell[30533, 952, 42, 1, 22, "Print"],
Cell[30578, 955, 164, 3, 22, "Print"],
Cell[30745, 960, 42, 1, 22, "Print"],
Cell[30790, 963, 164, 3, 22, "Print"],
Cell[30957, 968, 42, 1, 22, "Print"],
Cell[31002, 971, 164, 3, 22, "Print"],
Cell[31169, 976, 42, 1, 22, "Print"],
Cell[31214, 979, 164, 3, 22, "Print"],
Cell[31381, 984, 42, 1, 22, "Print"],
Cell[31426, 987, 164, 3, 22, "Print"],
Cell[31593, 992, 42, 1, 22, "Print"],
Cell[31638, 995, 164, 3, 22, "Print"],
Cell[31805, 1000, 42, 1, 22, "Print"],
Cell[31850, 1003, 164, 3, 22, "Print"],
Cell[32017, 1008, 42, 1, 22, "Print"],
Cell[32062, 1011, 162, 3, 22, "Print"],
Cell[32227, 1016, 42, 1, 22, "Print"],
Cell[32272, 1019, 162, 3, 22, "Print"],
Cell[32437, 1024, 42, 1, 22, "Print"],
Cell[32482, 1027, 164, 3, 22, "Print"],
Cell[32649, 1032, 42, 1, 22, "Print"],
Cell[32694, 1035, 164, 3, 22, "Print"],
Cell[32861, 1040, 42, 1, 22, "Print"],
Cell[32906, 1043, 164, 3, 22, "Print"],
Cell[33073, 1048, 42, 1, 22, "Print"],
Cell[33118, 1051, 164, 3, 22, "Print"],
Cell[33285, 1056, 42, 1, 22, "Print"],
Cell[33330, 1059, 164, 3, 22, "Print"],
Cell[33497, 1064, 42, 1, 22, "Print"],
Cell[33542, 1067, 164, 3, 22, "Print"],
Cell[33709, 1072, 42, 1, 22, "Print"],
Cell[33754, 1075, 164, 3, 22, "Print"],
Cell[33921, 1080, 42, 1, 22, "Print"],
Cell[33966, 1083, 164, 3, 22, "Print"],
Cell[34133, 1088, 42, 1, 22, "Print"],
Cell[34178, 1091, 162, 3, 22, "Print"],
Cell[34343, 1096, 42, 1, 22, "Print"],
Cell[34388, 1099, 162, 3, 22, "Print"],
Cell[34553, 1104, 42, 1, 22, "Print"],
Cell[34598, 1107, 162, 3, 22, "Print"],
Cell[34763, 1112, 42, 1, 22, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34854, 1119, 85, 2, 32, "Subsubsection"],
Cell[34942, 1123, 121, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[35088, 1130, 186, 3, 44, "Input"],
Cell[35277, 1135, 12171, 414, 182, 5462, 325, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[47497, 1555, 91, 2, 24, "Subsubsection"],
Cell[47591, 1559, 100, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[47716, 1564, 102, 2, 29, "Input"],
Cell[47821, 1568, 1040, 32, 347, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[48910, 1606, 86, 2, 24, "Subsubsection"],
Cell[48999, 1610, 91, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[49115, 1617, 310, 7, 137, "Input"],

Cell[CellGroupData[{
Cell[49450, 1628, 5542, 142, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[54995, 1772, 5526, 142, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[60524, 1916, 5449, 141, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[65976, 2059, 5404, 140, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[71383, 2201, 5372, 140, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[76758, 2343, 5441, 141, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[82202, 2486, 5384, 140, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[87589, 2628, 5331, 139, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[92923, 2769, 5323, 139, 66, 2115, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[98249, 2910, 5439, 141, 66, 2117, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[103691, 3053, 5463, 141, 66, 2117, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[109157, 3196, 5471, 141, 66, 2117, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[114631, 3339, 5479, 141, 66, 2117, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[120113, 3482, 5540, 142, 66, 2117, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[125656, 3626, 5409, 140, 66, 2116, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[131068, 3768, 5430, 141, 66, 2116, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[136501, 3911, 5409, 140, 66, 2116, 92, "GraphicsData", 
"PostScript", "Graphics"],
Cell[141913, 4053, 5495, 143, 66, 2153, 94, "GraphicsData", 
"PostScript", "Graphics"],
Cell[147411, 4198, 5491, 143, 66, 2153, 94, "GraphicsData", 
"PostScript", "Graphics"],
Cell[152905, 4343, 5523, 143, 66, 2153, 94, "GraphicsData", 
"PostScript", "Graphics"],
Cell[158431, 4488, 5483, 143, 66, 2153, 94, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[163941, 4635, 192, 4, 65, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[164182, 4645, 160, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[164367, 4653, 56, 0, 32, "Subsubsection"],
Cell[164426, 4655, 48, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[164499, 4659, 130, 3, 60, "Input"],
Cell[164632, 4664, 157, 2, 44, "Output"]
}, Open  ]],
Cell[164804, 4669, 396, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[165225, 4685, 99, 2, 45, "Input"],
Cell[165327, 4689, 4038, 189, 70, "Print"]
}, Closed]],
Cell[169380, 4881, 171, 4, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[169588, 4890, 37, 0, 24, "Subsubsection"],
Cell[169628, 4892, 138, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[169791, 4899, 210, 3, 75, "Input"],
Cell[170004, 4904, 14792, 497, 186, 7189, 399, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[184845, 5407, 43, 0, 24, "Subsubsection"],
Cell[184891, 5409, 251, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[185167, 5418, 76, 1, 45, "Input"],
Cell[185246, 5421, 8158, 149, 1515, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[193453, 5576, 38, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[193516, 5580, 284, 6, 137, "Input"],

Cell[CellGroupData[{
Cell[193825, 5590, 6569, 113, 58, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[200397, 5705, 6458, 111, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[206858, 5818, 6368, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[213229, 5929, 6316, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[219548, 6040, 6377, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[225928, 6152, 6271, 108, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[232202, 6262, 6385, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[238590, 6374, 6279, 108, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[244872, 6484, 6425, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[251300, 6596, 6491, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[257794, 6709, 6475, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[264272, 6822, 6499, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[270774, 6935, 6426, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[277203, 7047, 6511, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[283717, 7160, 6535, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[290255, 7273, 6580, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[296838, 7387, 6410, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[303251, 7499, 6564, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[309818, 7613, 6394, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[316215, 7725, 6361, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[322579, 7836, 6329, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[328911, 7947, 6357, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[335271, 8058, 6305, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[341579, 8169, 6333, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[347915, 8280, 6325, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[354243, 8391, 6345, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[360591, 8502, 6260, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[366854, 8612, 6313, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[373170, 8723, 6284, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[379457, 8833, 6361, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[385821, 8944, 6402, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[392226, 9056, 6369, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[398598, 9167, 6637, 113, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[405238, 9282, 6604, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[411845, 9396, 6572, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[418420, 9510, 6495, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[424918, 9623, 6531, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[431452, 9736, 6426, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[437881, 9848, 6608, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[444492, 9962, 6580, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[451075, 10076, 6491, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[457569, 10189, 6580, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[464152, 10303, 6588, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[470743, 10417, 6633, 113, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[477379, 10532, 6515, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[483897, 10645, 6491, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[490391, 10758, 6414, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[496808, 10870, 6459, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[503270, 10983, 6434, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[509707, 11095, 6552, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[516262, 11209, 6523, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[522788, 11322, 6653, 113, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[529444, 11437, 6548, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[535995, 11551, 6475, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[542473, 11664, 6333, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[548809, 11775, 6467, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[555279, 11888, 6216, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[561498, 11998, 6183, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[567684, 12107, 6110, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[573797, 12215, 6183, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[579983, 12324, 6191, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[586177, 12433, 6280, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[592460, 12543, 6256, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[598719, 12653, 6402, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[605124, 12765, 6187, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[611314, 12874, 6167, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[617484, 12983, 6106, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[623593, 13091, 6199, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[629795, 13200, 6220, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[636018, 13310, 6054, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[642075, 13418, 5997, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[648075, 13525, 6037, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[654115, 13632, 6078, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[660196, 13740, 5985, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[666184, 13847, 5904, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[672091, 13953, 5964, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[678058, 14059, 6005, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[684066, 14166, 5754, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[689823, 14270, 5746, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[695572, 14374, 5860, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[701435, 14479, 5723, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[707161, 14583, 5694, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[712858, 14686, 5621, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[718482, 14788, 5528, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[724013, 14889, 5512, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[729528, 14990, 5609, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[735140, 15092, 5642, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[740785, 15195, 5650, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[746438, 15298, 5646, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[752087, 15401, 5674, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[757764, 15504, 5621, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[763388, 15606, 5629, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[769020, 15708, 5625, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[774648, 15810, 5796, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[780471, 15917, 379, 8, 84, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[780899, 15931, 160, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[781084, 15939, 56, 0, 32, "Subsubsection"],
Cell[781143, 15941, 48, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[781216, 15945, 130, 3, 44, "Input"],
Cell[781349, 15950, 157, 2, 44, "Output"]
}, Open  ]],
Cell[781521, 15955, 396, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[781942, 15971, 75, 1, 29, "Input"],
Cell[782020, 15974, 3490, 167, 70, "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[785559, 16147, 37, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[785621, 16151, 117, 2, 29, "Input"],
Cell[785741, 16155, 11114, 480, 70, 4218, 390, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[796892, 16640, 132, 2, 38, "Input"],
Cell[797027, 16644, 10982, 592, 70, 4140, 502, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[808058, 17242, 43, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[808126, 17246, 76, 1, 70, "Input"],
Cell[808205, 17249, 7236, 132, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[815490, 17387, 38, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[815553, 17391, 284, 6, 137, "Input"],

Cell[CellGroupData[{
Cell[815862, 17401, 6435, 111, 58, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[822300, 17514, 6393, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[828696, 17626, 6142, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[834841, 17735, 6308, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[841152, 17846, 6364, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[847519, 17957, 6368, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[853890, 18068, 6502, 111, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[860395, 18181, 6142, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[866540, 18290, 5992, 105, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[872535, 18397, 6430, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[878968, 18509, 6442, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[885413, 18621, 6584, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[892000, 18735, 6426, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[898429, 18847, 6373, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[904805, 18958, 6110, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[910918, 19066, 6232, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[917153, 19176, 6151, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[923307, 19285, 6203, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[929513, 19394, 6199, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[935715, 19503, 6187, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[941905, 19612, 6066, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[947974, 19720, 6078, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[954055, 19828, 6037, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[960095, 19935, 5960, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[966058, 20041, 6070, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[972131, 20149, 5790, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[977924, 20253, 5786, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[983713, 20357, 5811, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[989527, 20462, 5916, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[995446, 20568, 5883, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1001332, 20673, 5738, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1007073, 20777, 5730, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1012806, 20881, 5721, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1018530, 20984, 5746, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1024279, 21088, 5600, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1029882, 21190, 5632, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1035517, 21292, 5636, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1041156, 21394, 5653, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1046812, 21497, 5653, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1052468, 21600, 5608, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1058079, 21702, 5559, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1063641, 21803, 5568, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1069212, 21905, 5608, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1074823, 22007, 5653, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1080479, 22110, 5624, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1086106, 22212, 5705, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1091814, 22315, 5681, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1097498, 22418, 5709, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1103210, 22521, 5705, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1108918, 22624, 5576, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1114497, 22726, 5495, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1119995, 22827, 5563, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1125561, 22928, 5576, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1131140, 23030, 5592, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1136735, 23132, 5563, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1142301, 23233, 5563, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1147867, 23334, 5543, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1153413, 23435, 5568, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1158984, 23537, 5568, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1164555, 23639, 5612, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1170170, 23741, 5559, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1175732, 23842, 5568, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1181303, 23944, 5628, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1186934, 24046, 5701, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1192638, 24149, 5673, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1198314, 24252, 5705, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1204022, 24355, 5685, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1209710, 24458, 5713, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1215426, 24561, 5709, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1221138, 24664, 5701, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1226842, 24767, 5649, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1232494, 24870, 5657, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1238154, 24973, 5653, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1243810, 25076, 5681, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1249494, 25179, 5653, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1255150, 25282, 5685, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1260838, 25385, 5665, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1266506, 25488, 5689, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1272198, 25591, 5689, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1277890, 25694, 5730, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1283623, 25798, 5677, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1289303, 25901, 5685, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1294991, 26004, 5772, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1300790, 26111, 379, 8, 84, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1301218, 26125, 160, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[1301403, 26133, 56, 0, 32, "Subsubsection"],
Cell[1301462, 26135, 48, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[1301535, 26139, 130, 3, 44, "Input"],
Cell[1301668, 26144, 157, 2, 44, "Output"]
}, Open  ]],
Cell[1301840, 26149, 396, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[1302261, 26165, 75, 1, 29, "Input"],
Cell[1302339, 26168, 4739, 225, 70, "Print"],
Cell[1307081, 26395, 42, 1, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1307172, 26402, 37, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[1307234, 26406, 117, 2, 70, "Input"],
Cell[1307354, 26410, 12254, 563, 70, 5141, 470, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1319645, 26978, 134, 2, 70, "Input"],
Cell[1319782, 26982, 15616, 753, 70, 5176, 619, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1335447, 27741, 43, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[1335515, 27745, 76, 1, 70, "Input"],
Cell[1335594, 27748, 9685, 176, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1345328, 27930, 38, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[1345391, 27934, 284, 6, 137, "Input"],

Cell[CellGroupData[{
Cell[1345700, 27944, 6217, 107, 58, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1351920, 28053, 6221, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1358144, 28162, 6278, 108, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1364425, 28272, 6185, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1370613, 28381, 6201, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1376817, 28490, 6496, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1383316, 28602, 6569, 111, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1389888, 28715, 6509, 111, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1396400, 28828, 6500, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1402903, 28940, 6562, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1409468, 29053, 6388, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1415859, 29164, 6546, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1422408, 29277, 6651, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1429062, 29391, 6433, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1435498, 29503, 6279, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1441780, 29613, 6595, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1448378, 29727, 6558, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1454939, 29840, 6765, 114, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1461707, 29956, 6599, 112, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1468309, 30070, 6400, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1474712, 30181, 6704, 113, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1481419, 30296, 6578, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1488000, 30409, 6501, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1494504, 30521, 6109, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1500616, 30629, 6024, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1506643, 30736, 6303, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1512949, 30846, 6562, 111, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1519514, 30959, 6449, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1525966, 31071, 6344, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1532313, 31182, 6469, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1538785, 31294, 6433, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1545221, 31406, 6040, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1551264, 31513, 6060, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1557327, 31620, 6194, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1563524, 31729, 6287, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1569814, 31839, 6263, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1576080, 31949, 6068, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1582151, 32056, 6003, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1588157, 32162, 6149, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1594309, 32270, 6133, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1600445, 32378, 5943, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1606391, 32484, 5655, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1612049, 32586, 5546, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1617598, 32687, 5497, 98, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1623098, 32787, 5582, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1628683, 32888, 5582, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1634268, 32989, 5432, 97, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1639703, 33088, 5679, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1645385, 33190, 5679, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1651067, 33292, 5744, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1656814, 33395, 5687, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1662504, 33497, 5720, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1668227, 33600, 5777, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1674007, 33704, 5704, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1679714, 33807, 5509, 98, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1685226, 33907, 5744, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1690973, 34010, 5817, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1696793, 34114, 5882, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1702678, 34219, 5696, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1708377, 34322, 5772, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1714152, 34425, 5529, 98, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1719684, 34525, 5720, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1725407, 34628, 5764, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1731174, 34731, 5793, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1736970, 34835, 5696, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1742669, 34938, 5598, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1748270, 35039, 5554, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1753827, 35140, 5760, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1759590, 35243, 5635, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1765228, 35345, 5926, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1771157, 35450, 5566, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1776726, 35551, 5590, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1782319, 35652, 5716, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1788038, 35755, 5947, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1793988, 35861, 5882, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1799873, 35966, 5906, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1805782, 36071, 6036, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1811821, 36178, 6157, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1817981, 36286, 5971, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1823955, 36392, 5930, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1829888, 36497, 6092, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1835983, 36604, 6052, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1842038, 36711, 5914, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1847955, 36816, 5845, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1853803, 36920, 5764, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1859570, 37023, 5777, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1865350, 37127, 5777, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1871130, 37231, 5987, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1877120, 37337, 5866, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1882989, 37442, 5975, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1888967, 37548, 5934, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1894904, 37653, 5821, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1900728, 37757, 5505, 98, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1906236, 37857, 5736, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1911975, 37960, 5841, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1917819, 38064, 5566, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1923388, 38165, 5639, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1929030, 38267, 5720, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1934753, 38370, 5663, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1940419, 38472, 5713, 101, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1946135, 38575, 5729, 101, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1951867, 38678, 5652, 100, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1957522, 38780, 5798, 102, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1963323, 38884, 5741, 101, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1969067, 38987, 5656, 100, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1974726, 39089, 5802, 102, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1980531, 39193, 5863, 103, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1986397, 39298, 5964, 104, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1992364, 39404, 5875, 103, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1998242, 39509, 5757, 101, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2004002, 39612, 5502, 98, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2009507, 39712, 5616, 100, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[2015150, 39816, 379, 8, 84, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2015578, 39830, 160, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2015763, 39838, 56, 0, 32, "Subsubsection"],
Cell[2015822, 39840, 48, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2015895, 39844, 130, 3, 65, "Input"],
Cell[2016028, 39849, 157, 2, 67, "Output"]
}, Open  ]],
Cell[2016200, 39854, 396, 12, 84, "Text"],

Cell[CellGroupData[{
Cell[2016621, 39870, 75, 1, 47, "Input"],
Cell[2016699, 39873, 5138, 239, 70, "Print"],
Cell[2021840, 40114, 42, 1, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2021931, 40121, 37, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[2021993, 40125, 117, 2, 70, "Input"],
Cell[2022113, 40129, 15087, 719, 70, 6457, 607, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2037237, 40853, 136, 2, 70, "Input"],
Cell[2037376, 40857, 21672, 769, 70, 4883, 557, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2059097, 41632, 43, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[2059165, 41636, 76, 1, 70, "Input"],
Cell[2059244, 41639, 10278, 186, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2069571, 41831, 38, 0, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[2069634, 41835, 284, 6, 137, "Input"],

Cell[CellGroupData[{
Cell[2069943, 41845, 6508, 112, 58, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2076454, 41959, 6348, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2082805, 42070, 6194, 107, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2089002, 42179, 6389, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2095394, 42291, 6304, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2101701, 42402, 6401, 110, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2108105, 42514, 6352, 109, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2114460, 42625, 6117, 106, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2120580, 42733, 5899, 104, 70, 479, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2126482, 42839, 6074, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2132559, 42947, 6151, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2138713, 43056, 5883, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2144599, 43161, 6130, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2150732, 43269, 5665, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2156400, 43372, 5770, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2162173, 43476, 5924, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2168100, 43582, 5948, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2174051, 43688, 5693, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2179747, 43791, 6187, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2185937, 43900, 5730, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2191670, 44004, 5879, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2197552, 44109, 6033, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2203588, 44216, 5766, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2209357, 44320, 5997, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2215357, 44427, 6078, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2221438, 44535, 5904, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2227345, 44641, 6017, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2233365, 44748, 5879, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2239247, 44853, 5717, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2244967, 44956, 6102, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2251072, 45064, 6305, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2257380, 45175, 5932, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2263315, 45281, 6183, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2269501, 45390, 6139, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2275643, 45499, 5794, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2281440, 45603, 5584, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2287027, 45705, 5600, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2292630, 45807, 5543, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2298176, 45908, 5802, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2303981, 46012, 5948, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2309932, 46118, 6013, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2315948, 46225, 5778, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2321729, 46329, 6045, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2327777, 46436, 6309, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2334089, 46547, 5989, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2340081, 46654, 6369, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2346453, 46765, 6175, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2352631, 46874, 6183, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2358817, 46983, 6159, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2364979, 47092, 6288, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2371270, 47202, 6280, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2377553, 47312, 6386, 110, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2383942, 47424, 6353, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2390298, 47535, 6102, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2396403, 47643, 6151, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2402557, 47752, 5940, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2408500, 47858, 5730, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2414233, 47962, 5770, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2420006, 48066, 5782, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2425791, 48170, 5920, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2431714, 48276, 5981, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2437698, 48383, 5932, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2443633, 48489, 5900, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2449536, 48595, 5948, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2455487, 48701, 5827, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2461317, 48806, 5559, 99, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2466879, 48907, 5308, 96, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2472190, 49005, 5616, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2477809, 49107, 5636, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2483448, 49209, 5673, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2489124, 49312, 5956, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2495083, 49418, 5762, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2500848, 49522, 5823, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2506674, 49627, 5855, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2512532, 49732, 5956, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2518491, 49838, 5916, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2524410, 49944, 5782, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2530195, 50048, 5644, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2535842, 50150, 5636, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2541481, 50252, 5608, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2547092, 50354, 5693, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2552788, 50457, 6001, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2558792, 50564, 5924, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2564719, 50670, 6167, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2570889, 50779, 6167, 107, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2577059, 50888, 5908, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2582970, 50994, 6268, 108, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2589241, 51104, 6029, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2595273, 51211, 6078, 106, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2601354, 51319, 6329, 109, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2607686, 51430, 5968, 104, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2613657, 51536, 5705, 101, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2619365, 51639, 5851, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2625219, 51744, 5802, 102, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2631024, 51848, 5815, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2636842, 51953, 5616, 100, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2642461, 52055, 5815, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2648279, 52160, 6009, 105, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2654291, 52267, 5867, 103, 70, 480, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2660161, 52372, 5884, 103, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2666048, 52477, 5949, 104, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2672000, 52583, 6091, 106, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2678094, 52691, 6281, 108, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2684378, 52801, 5905, 104, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2690286, 52907, 6099, 106, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2696388, 53015, 6184, 107, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2702575, 53124, 6184, 107, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2708762, 53233, 6184, 107, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2714949, 53342, 6221, 108, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2721173, 53452, 6472, 111, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2727648, 53565, 5917, 104, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2733568, 53671, 5884, 103, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2739455, 53776, 5941, 104, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2745399, 53882, 5990, 105, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2751392, 53989, 5706, 101, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2757101, 54092, 5617, 100, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2762721, 54194, 5791, 102, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2768515, 54298, 6042, 105, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2774560, 54405, 6021, 105, 70, 481, 31, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[2780608, 54514, 379, 8, 84, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2781048, 54529, 145, 3, 45, "Section"],

Cell[CellGroupData[{
Cell[2781218, 54536, 78, 2, 40, "Subsection"],
Cell[2781299, 54540, 105, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2781441, 54547, 110, 2, 26, "Subsection"],
Cell[2781554, 54551, 154, 4, 29, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2781745, 54560, 93, 2, 26, "Subsection"],
Cell[2781841, 54564, 206, 5, 44, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2782072, 54573, 85, 2, 29, "Input"],
Cell[2782160, 54577, 94, 3, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2782303, 54586, 93, 2, 26, "Subsection"],
Cell[2782399, 54590, 207, 5, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2782643, 54600, 87, 2, 26, "Subsection"],
Cell[2782733, 54604, 156, 4, 34, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2782926, 54613, 87, 2, 26, "Subsection"],
Cell[2783016, 54617, 403, 8, 89, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2783456, 54630, 88, 2, 26, "Subsection"],
Cell[2783547, 54634, 152, 4, 29, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2783736, 54643, 99, 2, 26, "Subsection"],
Cell[2783838, 54647, 1067, 21, 330, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2784942, 54673, 84, 2, 26, "Subsection"],
Cell[2785029, 54677, 530, 12, 179, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2785608, 54695, 99, 2, 45, "Section"],
Cell[2785710, 54699, 271, 9, 27, "Text"],
Cell[2785984, 54710, 134, 5, 26, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

